import { Cascader } from 'antd'; // UI 组件库
import React, { Dispatch } from 'react'; // 公共库
// import { Action } from 'redux';
import Form, { FormComponentProps } from 'antd/lib/form';
import { connect } from 'dva';
// import moment from 'moment';
import { StateType } from '@/models/cascadeGeographic';
import { CascaderOptionType } from 'antd/lib/cascader';
import { CascaderOption } from './data.d';
// import styles from './index.less';

interface GeographicProps extends FormComponentProps {
  dispatch?: Dispatch<any>;
  /*
  dispatch: Dispatch<
    Action<'cascadeGeographic/fetch'> // 获取行政区划下的直属行政区划项
  >; */
  // loading?: boolean;
  cascadeGeographic?: StateType;
  onChange?: any;
  changeOnSelect?: boolean; // 点选时，是否直接带入数据。
  level?: string; // 定位到哪个级别返回  province,city,area 默认不传为area
  defaultValue:string[]; // 默认显示省市区, 需与level对应最多3级， 否则取level级别显示 不传为空 ["省code","市code","区code"]
  onLoadChange?:any;
}

interface GeographicState {
  options: CascaderOption[];
}
/*
interface Option {
  value: string;
  label?: React.ReactNode;
  disabled?: boolean;
  children?: Option[];
}
*/

/**
 * 将组件和models结合在一起。将models中的state绑定到组件的props中。并提供一些额外的功能，譬如dispatch
 */
@connect(
  ({
    cascadeGeographic,
    // loading,
  }: {
    cascadeGeographic: StateType;
    // loading: {
    //   models: {
    //     [key: string]: boolean;
    //   };
    // };
  }) => ({
    cascadeGeographic,
    // loading: loading.models.cascadeGeographic,
  }),
)

class LazyOptions extends React.Component<GeographicProps, GeographicState> {
  /*
  constructor(props) {
    super(props);
  }
  */

  /**
   * 定义过程化状态及操作状态（Input/Oput）
   */
  state = {
    options: [],
    preVals: [],
  };

  /**
   * 组件挂载完成函数回调方法中初始化数据
   */
  componentDidMount() {
    const { dispatch } = this.props;
    const { level } = this.props;
    if (dispatch) {
      dispatch({
        type: 'cascadeGeographic/fetch',
        payload: { area_code: '100000', level }, // 默认 id 为 100000 获取全部省级区划信息
        callback: (response: any) => {
          // console.log(response, 'response path1')
          this.setState({
            options: response,
          }, () => {
              if (this.props.defaultValue && this.props.defaultValue.length > 0) {
                  if (Number(level) > 1) {
                    this.getTwoLevelInfo()
                  }
              }
          })
        },
      })
    }
  }

  // 获取默认第二及别市信息
  getTwoLevelInfo = () => {
    const { dispatch } = this.props;
    if (dispatch) {
      dispatch({
        type: 'cascadeGeographic/fetch',
        // 默认 id 为 100000 获取全部省级区划信息
        payload: { area_code: this.props.defaultValue[0], level: this.props.level },
        callback: (response: any) => {
          // console.log(response, 'response path2')
          this.state.options.map((item, index) => {
            if (item.area_code === this.props.defaultValue[0]) {
              this.state.options[index].children = response;
            }
            return []
          })

          if (this.props.defaultValue && this.props.defaultValue.length > 1) {
            if (Number(this.props.level) > 2) {
              this.getThreeLevelInfo();
            } else {
              this.forceUpdate();
            }
          } else {
            this.forceUpdate();
          }
        },
      })
    }
  }

  // 获取默认三级 区信息
  getThreeLevelInfo = () => {
    const { dispatch } = this.props;
    if (dispatch) {
      dispatch({
        type: 'cascadeGeographic/fetch',
        // 默认 id 为 100000 获取全部省级区划信息
        payload: { area_code: this.props.defaultValue[1], level: this.props.level },
        callback: (response: any) => {
          // console.log(response, 'response path2')
          this.state.options.map(item => {
            if (item.area_code === this.props.defaultValue[0]) {
              if (item.children) {
                item.children.map((val: { area_code: string; children: any; }) => {
                    if (val.area_code === this.props.defaultValue[1]) {
                      val.children = response;
                    }
                    return [];
                })
              }
            }
            return [];
          })
          this.forceUpdate();
        },
      })
    }
  }
  /*
  onChange = (selectedOptions: any) => {
  }
*/

  /**
   * 用于动态加载选项，无法与 showSearch 一起使用
   * (selectedOptions) => void
   */
  /*
  handleChange = (value: any, selectedOptions: any) => {
    // console.log('pre::state::', this.state);
    // console.log('pre::props::', this.props);
    // console.log('pre:::::::::::', this.props.value);
    // console.log('this val->>>>>>>>>', value);

    // console.log('selectedOptions:::::::::', selectedOptions)
    // debugger
    // const { onChange } = this.props;

    // console.log(this.props,'this.props,cas')
  };
*/
  /**
   *
   *
   */
  handleOver = () => {
    // debugger
    // const { onChange } = this.props;
    // console.log('value:::');
    // console.log(value, selectedOptions);
    // onChange(value);
    // console.log(this.props,'this.props,cas')
    // alert(0);
  };

  loadData = (selectedOptions: any) => {
    // debugger
    const targetOption = selectedOptions[selectedOptions.length - 1];
    targetOption.loading = true;
    // console.log(selectedOptions)
    const { dispatch, level, onLoadChange } = this.props;
    if (dispatch) {
      dispatch({
        type: 'cascadeGeographic/fetch',
        payload: { ...targetOption, level },
        callback: (response: any) => {
          targetOption.loading = false;
          targetOption.children = response;
          this.setState({
            options: this.state.options,
          }, () => {
            //  onLoadChange(selectedOptions) 
          })
        },
      })
    }
  };

  /**
   * 选择后渲染方法
   * @param label
   * @param selectedOptions
   */
  displayRender = (label:string[]) => label.join(' / ')

  /**
   * 渲染方法
   */
  render() {
    const fieldNames = { label: 'area_name', value: 'area_code', children: 'children' }; // 定义字段
    const { changeOnSelect } = this.props;
    // console.log(this.state,'path .state.组件')
    // console.log(this.props,'path .props.组件')
    // const options = this.props.cascadeGeographic.data?this.props.cascadeGeographic.data.list:""
    // console.log(options,'path .option.组件')
    return (
      <Cascader
        key="id"
        options={this.state.options}
        allowClear={false}
        loadData={this.loadData}
        onChange={this.props.onChange ? this.props.onChange : this.handleChange}
        changeOnSelect={changeOnSelect}
        fieldNames={fieldNames}
        placeholder="请选择"
        defaultValue={this.props.defaultValue ? this.props.defaultValue : []}
        displayRender={this.props.displayRender ? this.props.displayRender : this.displayRender}
      />
    );
  }
}
export default Form.create<GeographicProps>()(LazyOptions);
