import { Avatar, Icon, Menu, Spin, message, Modal } from 'antd';
import { ClickParam } from 'antd/es/menu';
import { FormattedMessage } from 'umi-plugin-react/locale';
import React from 'react';
import { connect } from 'dva';
import router from 'umi/router';
// import cookie from 'react-cookies'

import { ConnectProps, ConnectState } from '@/models/connect';
import PasswordPanel from './PasswordPanel'
import { CurrentUser } from '@/models/user';
import HeaderDropdown from '../HeaderDropdown';
import styles from './index.less';
// import { ExclamationCircleOutlined } from '@ant-design/icons';

const { confirm } = Modal;

export interface GlobalHeaderRightProps extends ConnectProps {
  currentUser?: CurrentUser;
  menu?: boolean;
  teacherInfo?: any;
  type: boolean;
}

class AvatarDropdown extends React.Component<GlobalHeaderRightProps> {
  state = {
    personName: '',
    modalVisible: false,
    type: false,
  }
  handleType = () => {
    this.setState({ type: true })
  }

  onMenuClick = (event: ClickParam) => {
    const { key } = event;

    if (key === 'logout') {
      let _this = this;
      this.showConfirm(_this);
    }

    if (key === 'password') {
      this.setState({ modalVisible: true, type: false })
    }
    if (key === 'settings') {
      router.push("/account/")
      // this.setState({ modalVisible: true, type: false })
    }

  };

  showConfirm = (_this: any) => {
    confirm({
      title: '您确定要退出登录吗?',
      // icon: <ExclamationCircleOutlined />,
      content: '',
      onOk() {
        // _this.removeCookies(1)
        let downloadUrl =  window.location.origin + "/base/loginperson/RemoveCookie";
        window.open(downloadUrl, "_self");
      },
      onCancel() {
        console.log('Cancel');
      },
    });
  }

  removeCookies = (type: any) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'user/RemoveCookie',
      payload: {},
      callback: (response: any) => {
        if (response.success) {
          if (type === 1) {
            message.success('操作成功');
            location.reload()
          } else {
            location.reload()
          }

        }
      }
    })
  }

  componentDidMount() {
    const { dispatch } = this.props;
    dispatch({
      type: 'user/GetPersonRoleInfo',
      payload: {},
      callback: (response: any) => {
        this.setState({ personName: response.person_name })
      }
    })

  }

  //关闭退出登录弹窗
  handleModalVisible = () => {
    this.setState({ modalVisible: false, type: false })
  }

  //修改密码确认回调
  handleAdd = (fieldsValue: any) => {
    if (fieldsValue.new_pass === fieldsValue.sure_pass) {
      const { dispatch } = this.props;
      dispatch({
        type: 'user/UpdateLoginPassWordInfo',
        payload: {
          oldPassWord: fieldsValue.local_pass,
          newPassWord: fieldsValue.new_pass,
        },
        callback: (response: any) => {
          if (response.success) {
            message.success('修改成功！请重新登录');
            this.setState({ modalVisible: false, type: false }, () => {
              this.removeCookies(2)
            })
          } else {
            message.error(response.message);
          }

        }
      })
    } else {
      message.error('新密码与确认密码输入不一致！');
    }
  }



  render(): React.ReactNode {
    console.log(this.props, 'propsTeacher')
    console.log(document.cookie, 'propsTeacher')
    const { currentUser = { avatar: '', name: '' }, menu, teacherInfo } = this.props;

    const menuHeaderDropdown = (
      <Menu className={styles.menu} selectedKeys={[]} onClick={this.onMenuClick}>
        {menu && (
          <Menu.Item key="center">
            <Icon type="user" />
            <FormattedMessage id="menu.account.center" defaultMessage="account center" />
          </Menu.Item>
        )}
        {menu && (
          <Menu.Item key="settings">
            <Icon type="setting" />
            <FormattedMessage id="menu.account.settings" defaultMessage="account settings" />
          </Menu.Item>
        )}
        {/* {menu && <Menu.Divider />}
        <Menu.Item key="password">
          <Icon type="edit" />
          <FormattedMessage id="menu.account.password" defaultMessage="password" />
        </Menu.Item> */}
        {menu && <Menu.Divider />}
        <Menu.Item key="settings">
          <Icon type="edit" />
          <FormattedMessage id="menu.account.personalSettings" defaultMessage="personalSettings" />
        </Menu.Item>

        <Menu.Item key="logout">
          <Icon type="logout" />
          <FormattedMessage id="menu.account.logout" defaultMessage="logout" />
        </Menu.Item>

      </Menu>
    );

    return this.state.personName !== '' ? (
      [<HeaderDropdown overlay={menuHeaderDropdown}>
        <span className={`${styles.action} ${styles.account}`} style={{ float: 'right' }}>
          <Avatar size="small" className={styles.avatar} src="head.png" alt="avatar" />
          <span className={styles.name}>{this.state.personName}</span>
        </span>
      </HeaderDropdown>,
      <PasswordPanel modalVisible={this.state.modalVisible} handleModalVisible={this.handleModalVisible} handleAdd={this.handleAdd}
        type={this.state.type}
        handleType={this.handleType}
      />]

    ) : (
        <Spin size="small" style={{ marginLeft: 8, marginRight: 8 }} />
      );
  }
}
export default connect(({ user }: ConnectState) => ({
  teacherInfo: user.teacherInfo,
  currentUser: user.currentUser,
}))(AvatarDropdown);
