/**
 * Ant Design Pro v4 use `@ant-design/pro-layout` to handle Layout.
 * You can view component api by:
 * https://github.com/ant-design/ant-design-pro-layout
 */

import ProLayout, {
  MenuDataItem,
  BasicLayoutProps as ProLayoutProps,
  Settings,
  DefaultFooter,
} from '@ant-design/pro-layout';
import React, { useState, useEffect } from 'react';
import Link from 'umi/link';
import { Dispatch } from 'redux';
import { connect } from 'dva';
import { formatMessage } from 'umi-plugin-react/locale';

import Authorized from '@/utils/Authorized';
import RightContent from '@/components/GlobalHeader/RightContent';
import { ConnectState } from '@/models/connect';
import { isAntDesignPro } from '@/utils/utils';

import logo from '../assets/logo.svg';

export interface BasicLayoutProps extends ProLayoutProps {
  breadcrumbNameMap: {
    [path: string]: MenuDataItem;
  };
  settings: Settings;
  dispatch: Dispatch;
}
export type BasicLayoutContext = { [K in 'location']: BasicLayoutProps[K] } & {
  breadcrumbNameMap: {
    [path: string]: MenuDataItem;
  };
};

/**
 * use Authorized check all menu item
 * 检测菜单项权限
 */
const menuDataRender = (menuList: MenuDataItem[]): MenuDataItem[] =>

  menuList.map(

    item => {
      console.log(item)
      //屏蔽登录权限验证

      const localItem = {
        ...item,
        children: item.children ? menuDataRender(item.children) : [],
      };
      return Authorized.check(item.authority, localItem, null) as MenuDataItem;
      // return item as MenuDataItem;
    });

const links:
  | {
    key?: string | undefined;
    title: React.ReactNode;
    href: string;
    blankTarget?: boolean | undefined;
  }[]
  | undefined = [];
const copyright = '东北师大理想软件股份有限公司';

const footerRender: BasicLayoutProps['footerRender'] = () => {
  if (!isAntDesignPro()) {
    return <DefaultFooter links={links} copyright={copyright} />;
  }
  return (
    <>
      <DefaultFooter links={links} copyright={copyright} />
      <div
        style={{
          padding: '0px 24px 24px',
          textAlign: 'center',
        }}
      >
        <a href="https://www.edusoa.com" target="_blank" rel="noopener noreferrer">
          <img
            src="http://www.edusoa.com/dsideal_yy/images/portals_index/logo.png"
            width="82px"
            alt="理想智慧云"
          />
        </a>
      </div>
    </>
  );
};

const BasicLayout: React.FC<BasicLayoutProps> = props => {
  const [menuData, setMenuData] = useState([]);
  const { dispatch, children, settings } = props;
  /**
   * constructor
   */
  console.log(props, 'user props')
  useEffect(() => {
    if (dispatch) {

      dispatch({
        type: 'user/GetPersonRoleInfo',
        callback: (response: any) => {
          const role_id: string = response.role_id

          console.log(role_id, 'user props callback')

          let menu = [];

          switch (role_id) {
            case "A66C757C-F797-454D-99DE-2A3F5415BC22":
              // 超级管理员
              menu = [
                // demo------------------------------------------------------------------------------
                // {
                //   name: 'ceshi',
                //   path: '/ceshi',
                //   // icon: 'profile',
                //   routes: [
                //     {
                //       name: 'demo',
                //       path: '/ceshi/demo',
                //       // component: './infoManagement', 
                //     },
                //   ]
                // },
                // 系统信息管理
                {
                  name: 'infoManagement',
                  path: '/infoManagement',
                  icon: 'profile',
                  routes: [
                    {
                      name: 'userPasswordSettings',
                      path: '/infoManagement/userPasswordSettings',
                      // component: './infoManagement', 
                    },
                    {
                      name: 'globalInfoManagement',
                      path: '/infoManagement/globalInfoManagement',
                      // component: './infoManagement', 
                    },
                    {
                      name: 'position',
                      path: '/infoManagement/position',
                      component: './infoManagement/position',
                    },
                  ]
                },
                // 机构信息管理
                {
                  name: 'organization',
                  path: '/organization',
                  icon: 'code-sandbox',
                  routes: [
                    {
                      // 教育局信息管理
                      name: 'bureau',
                      path: '/organization/bureau',
                      routes: [
                        {
                          // 部门信息管理
                          name: 'branch',
                          path: '/organization/bureau/department/:id',
                          hideInMenu: true,
                        },
                        {
                          // 教职工信息管理
                          name: 'teacher',
                          path: '/organization/bureau/teacher/:id',
                          hideInMenu: true,
                        },
                        {
                          // 教育局管理（未启用教育局）
                          name: 'disableEdu',
                          path: '/organization/bureau/disableEdu/:id',
                          hideInMenu: true,
                        },
                      ]
                    },
                    {
                      // 教辅单位信息管理
                      name: 'effect',
                      path: '/organization/effect',
                      routes: [
                        {
                          // 部门信息管理
                          name: 'branch',
                          path: '/organization/effect/branch/:id',
                          hideInMenu: true,
                        },
                        {
                          // 教职工信息管理
                          name: 'teacher',
                          path: '/organization/effect/teacher/:id',
                          hideInMenu: true,
                        },
                      ]
                    },
                    {
                      // 学校信息管理
                      name: 'school',
                      path: '/organization/school',
                      routes: [
                        {
                          // 部门信息管理
                          name: 'branch',
                          path: '/organization/school/branch/:id',
                          hideInMenu: true,
                        },
                        {
                          // 班级管理
                          name: 'class',
                          path: '/organization/school/class/:id',
                          hideInMenu: true,
                        },
                        {
                          name: 'student',
                          path: '/organization/school/student/:id',
                          hideInMenu: true,
                        },
                        {
                          name: 'teacher',
                          path: '/organization/school/teacher/:id',
                          hideInMenu: true,
                        },
                      ]
                    },
                  ],
                },
                // 管理员账号管理
                {
                  name: 'admin',
                  path: '/admin',
                  icon: 'user',
                  routes: [
                    {
                      name: 'districtAdmin',
                      path: '/admin/districtAdmin',
                    },
                    {
                      name: 'cityUnitAdmin',
                      path: '/admin/cityUnitAdmin',
                    },
                    {
                      name: 'districtUnitAdmin',
                      path: '/admin/districtUnitAdmin',
                    },
                  ]
                },
                // 基础数据录入情况
                {
                  name: 'basicdata',
                  path: '/dashboard',
                  icon: 'dashboard',
                  routes: [
                    {
                      name: 'workplace',
                      path: '/dashboard/workplace',
                    },
                    {
                      name: 'analysiss',
                      path: '/dashboard/workplace/analysis/:code',
                      hideInMenu: true,
                    },
                    // {
                    //   name: 'analysiss',
                    //   path: '/dashboard/workplace/analysis/:code/:num',
                    //   hideInMenu: true,
                    // },
                    {
                      name: 'monitors',
                      path: '/dashboard/workplace/analysis/monitor/:id',
                      hideInMenu: true,
                    },
                  ]
                },
                // 数据统计分析
                {
                  name: 'sjtjfx',
                  path: '/sjtjfx',
                  icon: 'pie-chart',
                  routes: [
                    {
                      name: '数据分析',
                      path: 'http://d1.edusoa.com:7777/baseService/html/pages/dataSystem/dataSystem.html',
                      target: '_blank'
                    },
                    {
                      name: '数据中心',
                      path: 'http://d1.edusoa.com:7777/baseService/html/pages/statistical/index.html',
                      target: '_blank'
                    },
                    {
                      name: '教与学状态监控',
                      path: 'http://www.edusoa.com/dsideal_yy/index.html',
                      target: '_blank'
                    },
                  ]
                },
                // 数据采集
                {
                  name: 'acquisition',
                  path: '/dataAcquisition',
                  icon: 'profile',
                  routes: [
                    {
                      name: 'acquisitionMsg',
                      path: '/dataAcquisition/acquisition',
                      // target: '_blank'
                    },
                  ]
                },
                {
                  name: '数据交换',
                  path: 'http://116.141.0.168:35080/dsSupport',
                  icon: 'swap',
                  target: "_blank"

                }
              ];
              setMenuData(menu)
              break;
            case "5CC3293C-3AA5-45B7-B54B-CA8CC549FB81":
              // 市管理员
              menu = [
                {
                  // 机构信息管理
                  name: 'organization',
                  path: '/organization',
                  icon: 'code-sandbox',
                  routes: [
                    {
                      // 教辅单位信息管理
                      name: 'effect',
                      path: '/organization/effect',
                      routes: [
                        {
                          // 部门信息管理
                          name: 'branch',
                          path: '/organization/effect/branch/:id',
                          hideInMenu: true,
                        },
                        {
                          // 教职工信息管理
                          name: 'teacher',
                          path: '/organization/effect/teacher/:id',
                          hideInMenu: true,
                        },
                      ]
                    },
                    {
                      // 学校信息管理
                      name: 'school',
                      path: '/organization/school',
                      routes: [
                        {
                          // 部门信息管理
                          name: 'branch',
                          path: '/organization/school/branch/:id',
                          hideInMenu: true,
                        },
                        {
                          // 班级管理
                          name: 'class',
                          path: '/organization/school/class/:id',
                          hideInMenu: true,
                        },
                        {
                          // 学生管理
                          name: 'student',
                          path: '/organization/school/student/:id',
                          hideInMenu: true,
                        },
                        {
                          // 教职工信息管理
                          name: 'teacher',
                          path: '/organization/school/teacher/:id',
                          hideInMenu: true,
                        },
                      ]
                    },
                  ],
                },
                {
                  // 管理员账号管理
                  name: 'admin',
                  path: '/admin',
                  icon: 'user',
                  routes: [
                    {
                      // 地区管理员
                      name: 'districtAdmin',
                      path: '/admin/districtAdmin',
                    },
                    {
                      // 市级单位管理员
                      name: 'cityUnitAdmin',
                      path: '/admin/cityUnitAdmin',
                    },
                  ]
                },
                {
                  // 基础数据录入情况
                  name: 'basicdata',
                  path: '/dashboard',
                  icon: 'dashboard',
                  routes: [
                    {
                      // 市基础数据录入统计
                      name: 'workplace',
                      path: '/dashboard/workplace',
                    },
                    {
                      name: 'analysiss',
                      path: '/dashboard/workplace/analysis/:code',
                      hideInMenu: true,
                    },
                    {
                      name: 'monitors',
                      path: '/dashboard/workplace/analysis/monitor/:id',
                      hideInMenu: true,
                    },
                  ]
                }
              ];
              setMenuData(menu)
              break;
            case "BF61C95F-3ADD-4F37-9FCD-97E69E1BF6E3":
              //	区(县)管理员
              menu = [
                {
                  // 机构信息管理
                  name: 'organization',
                  path: '/organization',
                  icon: 'code-sandbox',
                  routes: [
                    {
                      // 教辅单位信息管理
                      name: 'effect',
                      path: '/organization/effect',
                      routes: [
                        {
                          // 部门信息管理
                          name: 'branch',
                          path: '/organization/effect/branch/:id',
                          hideInMenu: true,
                        },
                        {
                          // 教职工信息管理
                          name: 'teacher',
                          path: '/organization/effect/teacher/:id',
                          hideInMenu: true,
                        },
                      ]
                    },
                    {
                      // 学校信息管理
                      name: 'school',
                      path: '/organization/school',
                      routes: [
                        {
                          // 部门信息管理
                          name: 'branch',
                          path: '/organization/school/branch/:id',
                          hideInMenu: true,
                        },
                        {
                          // 班级管理
                          name: 'class',
                          path: '/organization/school/class/:id',
                          hideInMenu: true,
                        },
                        {
                          // 学生管理
                          name: 'student',
                          path: '/organization/school/student/:id',
                          hideInMenu: true,
                        },
                        {
                          // 教职工信息管理
                          name: 'teacher',
                          path: '/organization/school/teacher/:id',
                          hideInMenu: true,
                        },
                      ]
                    },
                  ],
                },
                {
                  // 管理员账号管理
                  name: 'admin',
                  path: '/admin',
                  icon: 'user',
                  routes: [
                    {
                      // 区级单位管理员
                      name: 'districtUnitAdmin',
                      path: '/admin/districtUnitAdmin',
                    },
                  ]
                },
                {
                  // 基础数据录入情况
                  name: 'basicdata',
                  path: '/dashboard',
                  icon: 'dashboard',
                  routes: [
                    {
                      // 区(县)基础数据录入统计
                      name: 'analysis',
                      path: '/dashboard/analysis',
                    },
                    {
                      name: 'monitors',
                      path: '/dashboard/workplace/analysis/monitor/:id',
                      hideInMenu: true,
                    },
                  ]
                }
              ];
              setMenuData(menu)
              break;
            case "9CD6B804-0F89-4626-A812-29465CFC7410":
              //	教育机构管理员
              menu = [
                {
                  path: '/',
                  redirect: '/organization/effect/branch',
                },
                {
                  // 机构信息管理
                  name: 'organization',
                  path: '/organization',
                  icon: 'code-sandbox',
                  routes: [
                    {
                      // 部门信息管理
                      name: 'branch',
                      path: '/organization/branch',
                    },
                    {
                      // 教职工信息管理
                      name: 'teacher',
                      path: '/organization/teacher',
                    },
                  ],
                },
              ];
              setMenuData(menu)
              break;
            case "73E897FC-C9D1-4E48-AE22-AC7586425C1D":
              //	学校管理员
              menu = [
                {
                  // 机构信息管理
                  name: 'organization',
                  path: '/organization',
                  icon: 'code-sandbox',
                  routes: [
                    {
                      // 部门信息管理
                      name: 'branch',
                      path: '/organization/branch',
                    },
                    {
                      // 教职工信息管理
                      name: 'teacher',
                      path: '/organization/teacher',
                    },
                    {
                      // 班级管理
                      name: 'class',
                      path: '/organization/class',
                    },
                    {
                      // 学生信息管理
                      name: 'student',
                      path: '/organization/student',
                    },
                  ],
                },
                {
                  // 基础数据录入情况
                  name: 'basicdata',
                  path: '/dashboard',
                  icon: 'dashboard',
                  routes: [
                    {
                      // 校基础数据录入统计
                      name: 'monitor',
                      path: '/dashboard/monitor',
                    },
                  ]
                }
              ];

              setMenuData(menu)
              break;
            default:
            // 与 case 1 和 case 2 不同时执行的代码
          }


        }
      });

      dispatch({
        type: 'settings/getSetting',

      });
    }
  }, []);

  /**
   * init variables
   */
  const handleMenuCollapse = (payload: boolean): void => {
    if (dispatch) {
      dispatch({
        type: 'global/changeLayoutCollapsed',
        payload,
      });
    }
  };

  // const menudata = () =>{

  //   return  menudata
  // } 

  return (
    <ProLayout
      logo={logo}
      onCollapse={handleMenuCollapse}
      menuHeaderRender={(logoDom, titleDom) => (
        <Link to="/">
          {logoDom}
          {titleDom}
        </Link>
      )}
      menuItemRender={(menuItemProps, defaultDom) => {
        if (menuItemProps.isUrl) {
          return defaultDom;
        }
        return <Link to={menuItemProps.path}>{defaultDom}</Link>;
      }}
      breadcrumbRender={(routers = []) => [
        {
          path: '/',
          breadcrumbName: formatMessage({
            id: 'menu.home',
            defaultMessage: 'Home',
          }),
        },
        ...routers,
      ]}
      itemRender={(route, params, routes, paths) => {
        const first = routes.indexOf(route) === 0;
        return first ? (
          <Link to={paths.join('/')}>{route.breadcrumbName}</Link>
        ) : (
            <span>{route.breadcrumbName}</span>
          );
      }}
      footerRender={footerRender}

      // menuDataRender={menuDataRender}
      menuDataRender={() => menuDataRender(menuData)}
      formatMessage={formatMessage}
      rightContentRender={rightProps => <RightContent {...rightProps} />}
      {...props}
      {...settings}
    >
      {children}
    </ProLayout>
  );
};

export default connect(({ global, settings }: ConnectState) => ({
  collapsed: global.collapsed,
  settings,
}))(BasicLayout);
