import { AnyAction, Reducer } from 'redux';
import { EffectsCommandMap } from 'dva';
import { queryGeographic } from '@/services/cascadeGeographic'; // 查询区划信息接口
import { TableListData, TableListItem } from './data.d';
/**
 * 级联选择下拉项类型定义
 */

 
export interface StateType {
  data: TableListData;
}

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: StateType) => T) => T },
) => void;

/**
 * 级联选择下拉项类型定义
 */
export interface ModelType {
  namespace: string;
  state: StateType;
  effects: {
    fetch: Effect;
    // add: Effect;
    // remove: Effect;
    // update: Effect;
  };
  reducers: {
    save: Reducer<StateType>;
  };
}

const Model: ModelType = {
  namespace: 'cascadeGeographic',

  state: {
    data: {
      list: [],
    },
  },

  effects: {
    *fetch({ payload,callback }, { call, put }) {
      const response = yield call(queryGeographic, payload);
      const items: TableListItem[] = [];
      response.list.forEach((item: TableListItem) => {
        // console.log('is children path', payload);
        const level = payload.level

        // 控制层级
        if(level==item.area_level_id){
          items.push({ ...item });
        }else{
          items.push({ ...item, isLeaf: false });
        }
        
      });
      yield put({
        type: 'save',
        payload: { id: payload.id, list: items },
      });
      callback(items);
// return items
    },
  },

  reducers: {
    /**
     * 存储状态,把原数据与新数据合并
     * @param state
     * @param action
     */
    save(state: any, action) {
      return {
        ...state,// id: "", list: Array(), pagination: {}
      };
    },
  },
};

export default Model;
