import { AnyAction, Reducer } from 'redux';
import { EffectsCommandMap } from 'dva';
import { fetchDict, GetStageInfo, GetSubjectInfo, GetMultipleDictInfo} from '@/services/dict'; // 查询区划信息接口
import { TableListData } from './data.d';
/**
 * 级联选择下拉项类型定义
 */

 
export interface StateType {
  data: TableListData;
}

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: StateType) => T) => T },
) => void;

/**
 * 级联选择下拉项类型定义
 */
export interface ModelType {
  namespace: string;
  state: StateType;
  effects: {
    fetch: Effect;
    GetStageInfo: Effect;
    GetSubjectInfo: Effect;
    GetMultipleDictInfo:Effect;
    // add: Effect;
    // remove: Effect;
    // update: Effect;
  };
  reducers: {
    save: Reducer<StateType>;
  };
}

const Model: ModelType = {
  namespace: 'dict',

  state: {
    data: {
      list: [],
    },
  },

  effects: {
    *fetch({ payload,callback }, { call, put }) {
      const response = yield call(fetchDict, payload);
      callback(response);
    },

    //获取学段
    *GetStageInfo({ payload,callback }, { call, put }) {
      const response = yield call(GetStageInfo, payload);
      callback(response);
    },

    //获取学科
    *GetSubjectInfo({ payload,callback }, { call, put }) {
      const response = yield call(GetSubjectInfo, payload);
      callback(response);
    },

    //获取字典（多个）
    *GetMultipleDictInfo({ payload,callback }, { call, put }) {
      const response = yield call(GetMultipleDictInfo, payload);
      callback(response);
    },
  },

  reducers: {
    /**
     * 存储状态,把原数据与新数据合并
     * @param state
     * @param action
     */
    save(state: any, action) {
      return {
        dictAllInfo:action,
        ...state,// id: "", list: Array(), pagination: {}
      };
    },
  },
};

export default Model;
