import { Effect } from 'dva';
import { Reducer } from 'redux';

import { fetchProvince, fetchCity, fetchArea, fetchGeographic } from '@/services/geographic';

export interface CurrentGeographic {
  avatar?: string;
  name?: string;
  title?: string;
  group?: string;
  signature?: string;
  tags?: {
    key: string;
    label: string;
  }[];
  Geographicid?: string;
  unreadCount?: number;
}

export interface GeographicModelState {
  currentGeographic?: CurrentGeographic;
}

export interface GeographicModelType {
  namespace: 'geographic';
  state: GeographicModelState;
  effects: {
    fetchProvince: Effect;
    fetchCity: Effect;
    fetchArea: Effect;
    fetchGeographic: Effect;
  };
  reducers: {
    changeLoading: Reducer<GeographicModelState>;
    setCity: Reducer<GeographicModelState>;
    setProvince: Reducer<GeographicModelState>;
    setGeographic: Reducer<GeographicModelState>;
  };
}

const GeographicModel: GeographicModelType = {
  namespace: 'geographic',

  state: {
    currentGeographic: {},
  },

  effects: {
    *fetchProvince(_, { call, put }) {
      let response = yield call(fetchProvince);
      yield put({
        type: 'setProvince',
        payload: response,
      });
      response = JSON.parse(JSON.stringify(response).replace(/name/g, 'label'));
      response = JSON.parse(JSON.stringify(response).replace(/id/g, 'value'));
      response.forEach((item: any) => {
        item.isLeaf = false;
      });
      response.forEach((item: any) => {
        item.level = 1;
      });

      return response;
    },
    *fetchCity({ payload, callback }, { call, put }) {
      let response: any = yield call(fetchCity, payload);

      response = JSON.parse(JSON.stringify(response).replace(/name/g, 'label'));
      response = JSON.parse(JSON.stringify(response).replace(/id/g, 'value'));
      response.forEach((item: any) => {
        item.level = 2;
      });
      // response.forEach((item:any)=>{item.isLeaf=false})
      // console.log(response,'response')
      yield put({
        type: 'setCity',
        payload: response,
      });
      callback(response);
      return response;
    },
    *fetchArea(_, { call, put }) {
      const response = yield call(fetchArea);
      yield put({
        type: 'save',
        payload: response,
      });
    },
    *fetchGeographic({ payload, callback }, { call, put }) {
      // 一个接口拿数据
      const response = yield call(fetchGeographic, payload);
      // response = JSON.parse(JSON.stringify(response).replace(/name/g,"label"))
      // response = JSON.parse(JSON.stringify(response).replace(/id/g,"value"))
      //为顶层所有加isLeaf
      if(!payload){
        response.list.forEach((item:any)=>{item.isLeaf=false})
      }

      yield put({
        type: 'setGeographic',
        payload: response,
      });
      callback(response);
    },
  },

  reducers: {
    setProvince(state, action) {
      return {
        ...state,
        Province: action.payload || {},
      };
    },
    changeLoading(state, action) {
      return {
        ...state,
        currentGeographic: action.payload || {},
      };
    },
    setCity(state, action) {
      return {
        ...state,
        city: action.payload || {},
      };
    },
    setGeographic(state, action) {
      return {
        ...state,
        geographic: action.payload || {},
      };
    },
  },
};

export default GeographicModel;
