import { Effect } from 'dva';
import { Reducer } from 'redux';

import { queryCurrent, query as queryUsers,GetPersonRoleInfo,GetTeacherInfo,RemoveCookie,UpdateLoginPassWordInfo,
  GetBindAuthorizationInfo,UnbindAuthorizationInfo } from '@/services/user';

import cookie from 'react-cookies';

export interface CurrentUser {
  avatar?: string;
  name?: string;
  title?: string;
  group?: string;
  signature?: string;
  tags?: {
    key: string;
    label: string;
  }[];
  userid?: string;
  unreadCount?: number;
}

export interface UserModelState {
  currentUser?: CurrentUser;
  teacherInfo?:any;
}

export interface UserModelType {
  namespace: 'user';
  state: UserModelState;
  effects: {
    fetch: Effect;
    fetchCurrent: Effect;
    GetPersonRoleInfo: Effect;
    GetTeacherInfo: Effect;
    RemoveCookie: Effect;
    UpdateLoginPassWordInfo: Effect;
    GetBindAuthorizationInfo: Effect;
    UnbindAuthorizationInfo: Effect;
  };
  reducers: {
    saveCurrentUser: Reducer<UserModelState>;
    changeNotifyCount: Reducer<UserModelState>;
    saveTeacherName:Reducer<UserModelState>;
  };
}

const UserModel: UserModelType = {
  namespace: 'user',

  state: {
    currentUser: {},
    teacherInfo:{},
  },

  effects: {
    *fetch(_, { call, put }) {
      const response = yield call(queryUsers);
      yield put({
        type: 'save',
        payload: response,
      });
    },
    *fetchCurrent(_, { call, put }) {
      const response = yield call(queryCurrent);

      yield put({
        type: 'saveCurrentUser',
        payload: response,
      });
    },
    // 获取人员角色信息
    *GetPersonRoleInfo({_,callback}, { call, put }) {
      const response = yield call(GetPersonRoleInfo);
      if (callback) callback(response.list[0]);
    },

      //获取教职工信息
      *GetTeacherInfo({ payload, callback }, { call, put }) {
        const response = yield call(GetTeacherInfo, payload);
        yield put({
          type: 'saveTeacherName',
          payload: response,
        });
      },

      //清除COOKIE
      *RemoveCookie({ payload, callback }, { call, put }) {
        const response = yield call(RemoveCookie, payload);
        if (callback) callback(response);
      },
      //修改登录密码
      *UpdateLoginPassWordInfo({ payload, callback }, { call, put }) {
         const response = yield call(UpdateLoginPassWordInfo, payload);
         if (callback) callback(response);
      },
      
      *GetBindAuthorizationInfo({ payload, callback }, { call, put }) {
         const response = yield call(GetBindAuthorizationInfo, payload);
         if (callback) callback(response);
      },
      *UnbindAuthorizationInfo({ payload, callback }, { call, put }) {
         const response = yield call(UnbindAuthorizationInfo, payload);
         if (callback) callback(response);
      },
      
  },

  reducers: {
    saveTeacherName(state, action){
      return {
        ...state,
        teacherInfo:action.payload
      }
    },
    saveCurrentUser(state, action) {
      return {
        ...state,
        currentUser: action.payload || {},
      };
    },
    changeNotifyCount(
      state = {
        currentUser: {},
      },
      action,
    ) {
      return {
        ...state,
        currentUser: {
          ...state.currentUser,
          notifyCount: action.payload.totalCount,
          unreadCount: action.payload.unreadCount,
        },
      };
    },
  },
};

export default UserModel;
