import { Card, Form, List, message, Modal } from 'antd';
const { confirm } = Modal;
import React, { Component } from 'react';

import { Dispatch, Action } from 'redux';
import { FormComponentProps } from 'antd/es/form';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { connect } from 'dva';
import { StateType } from './model';
import PasswordPanel from './components/PasswordPanel'

interface TableListProps extends FormComponentProps {
  dispatch: Dispatch<
    Action<
      | 'config/EnableEduInfo'
      | 'user/GetBindAuthorizationInfo'
      | 'user/UnbindAuthorizationInfo'
    >
  >;
  loading: boolean;
  config: StateType;
}

interface TableListState {
  modalVisible: boolean,
  type: boolean,
  bindAuthorizationInfo: Array<string>,
  data: any
}

/* eslint react/no-multi-comp:0 */
@connect(
  ({
    user,
    loading,
  }: {
    user: StateType;
    loading: {
      models: {
        [key: string]: boolean;
      };
    };
  }) => ({
    user,
    loading: loading.models.config,
  }),
)
class TableList extends Component<TableListProps, TableListState> {
  state: TableListState = {
    modalVisible: false,
    type: false,
    bindAuthorizationInfo: ['wx', 'qq'],
    data: []
  };
  componentDidMount() {
    // const areaCode = this.state.areaCode;
    // this.getEduList(areaCode);
    // 默认列表内容
    this.getList()
  }


getList = () =>{
  const data = [{
    title: '修改密码',
    description: "修改当前账号密码",
    avatar: <img src="./icons/modifyPassword.svg" width="50" />,
    action: [<a key="list-loadmore-edit" onClick={() => { this.setState({ modalVisible: true, type: false }) }}>修改</a>]
  }]

  const { dispatch } = this.props
  dispatch({
    type: 'user/GetBindAuthorizationInfo',
    payload: {},
    callback: (response: any) => {
      if (response.success === true) {
        const list = response.list
        if (list.indexOf("wx") >= 0) {
          data.push(
            {
              title: '微信',
              description: "当前已绑定微信账号",
              avatar: <img src="./icons/wechat.svg" width="50" />,
              action: [<a onClick={()=>{this.UnbindAuthorizationInfo("wx",'微信')}}>解除绑定</a>]
            })
        }
        if (list.indexOf("qq") >= 0) {
          data.push(
            {
              title: '腾讯QQ',
              description: "当前已绑定腾讯QQ号",
              avatar: <img src="./icons/qq.svg" width="50" />,
              action: [<a onClick={()=>{this.UnbindAuthorizationInfo("qq",'腾讯QQ')}}>解除绑定</a>]
            })
        }
        if (list.indexOf("weibo") >= 0) {
          data.push(
            {
              title: '微博',
              description: "当前已绑定微博账号",
              avatar: <img src="./icons/weibo.svg" width="50" />,
              action: [<a onClick={()=>{this.UnbindAuthorizationInfo("weibo",'新浪微博')}}>解除绑定</a>]
            })
        }
        this.setState({
          bindAuthorizationInfo: response.list,
          data: data
        })
      }
    }
  })



}
  UnbindAuthorizationInfo = (e:string,text:string)=>{

    const { dispatch } = this.props
    const _ = this
    confirm({
      title: '解除绑定?',
      content: '确认是否取消绑定'+text+'',
      okText: '是',
      okType: 'danger',
      cancelText: '否',
      onOk() {

      
        dispatch({
          type: 'user/UnbindAuthorizationInfo',
          payload: {
            typeName:e
          },
          callback: (response: any) => {
            if (response.success === true) {
              _.getList()
            }
          }
        })
    
      },
      onCancel() {
        console.log('Cancel');
      },
    });





  }

  //关闭退出登录弹窗
  handleModalVisible = () => {
    this.setState({ modalVisible: false, type: false })
  }

  handleType = () => {
    this.setState({ type: true })
  }

  //修改密码确认回调
  handleAdd = (fieldsValue: any) => {
    console.log(fieldsValue, 'fieldsValue')
    if (fieldsValue.new_pass === fieldsValue.sure_pass) {
      const { dispatch } = this.props;
      dispatch({
        type: 'user/UpdateLoginPassWordInfo',
        payload: {
          oldPassWord: fieldsValue.local_pass,
          newPassWord: fieldsValue.new_pass,
        },
        callback: (response: any) => {
          console.log()
          if (response.success) {
            message.success('修改成功！请重新登录');
            this.setState({ modalVisible: false, type: false }, () => {
              this.removeCookies(2)
            })
          } else {
            message.error(response.message);
          }

        }
      })
    } else {
      message.error('新密码与确认密码输入不一致！');
    }
  }

  render() {





    return (
      <PageHeaderWrapper>
        <Card bordered={false}>
          <List
            itemLayout="horizontal"
            dataSource={this.state.data}
            renderItem={item => (
              <List.Item
                actions={item.action}
              >
                <List.Item.Meta
                  avatar={item.avatar}
                  title={item.title}
                  description={item.description}

                />
              </List.Item>
            )}
          />
        </Card>
        <PasswordPanel
          modalVisible={this.state.modalVisible}
          handleModalVisible={this.handleModalVisible}
          handleAdd={this.handleAdd}
          type={this.state.type}
          handleType={this.handleType}
        />
      </PageHeaderWrapper>
    );
  }
}

export default Form.create<TableListProps>()(TableList);
