import { AnyAction, Reducer } from 'redux';
import { EffectsCommandMap } from 'dva';
import {
  EnableEduInfo,
} from './service';

// eslint-disable-next-line import/no-unresolved
import { TableListData, EduInfoData } from './data.d';

export interface StateType {
  data?: TableListData;
  eduInfo?: EduInfoData;
}

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: StateType) => T) => T },
) => void;

export interface ModelType {
  namespace: string;
  state: StateType;
  effects: {
    EnableEduInfo: Effect;
  };
  reducers: {
    save: Reducer<StateType>;
  };
}

const Model: ModelType = {
  namespace: 'config',

  state: {
    data: {
      list: [],
      pagination: {},
    },
  },

  effects: {
    // 获取已启用教育局列表
    *EnableEduInfo({ payload }, { call, put }) {
      const response = yield call(EnableEduInfo, payload);
      yield put({
        type: 'save',
        payload: response,
      });
    },
  },

  reducers: {
    save(state, action) {
      return {
        ...state,
        data: action.payload,
      };
    }
  },
};

export default Model;
