import { Button, Card, Col, Form, Row, Select, message, Popconfirm, } from 'antd';
import React, { Component, Fragment } from 'react';
import { Dispatch, Action } from 'redux';
import { FormComponentProps } from 'antd/es/form';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { connect } from 'dva';
import { StateType } from './model';
import StandardTable, { StandardTableColumnProps } from './components/StandardTable';
import { TableListItem, TableListPagination, getListInfo } from './data';

import styles from './style.less';


const { Option } = Select;
const FormItem = Form.Item;
interface TableListProps extends FormComponentProps {
  dispatch: Dispatch<
    Action<
      | 'admin/districtAdminList'
      | 'admin/ExportRegion'
      | 'admin/ResetPassword'
      | 'admin/getMeeageInfo'
    >
  >;
  loading: boolean;
  admin: StateType;
}

interface TableListState {
  selectedRows: TableListItem[];
  formValues: { [key: string]: string };
  stepFormValues: Partial<TableListItem>;
  areaCode: string;
  page: number;
  pageSize: number;
  regionalInformation: [];// 地区信息
  selectDefault: string;
}

/* eslint react/no-multi-comp:0 */
@connect(
  ({
    admin,
    geographic,
    loading,
  }: {
    admin: StateType;
    geographic: StateType;
    loading: {
      models: {
        [key: string]: boolean;
      };
    };
  }) => ({
    admin,
    geographic,
    loading: loading.models.admin,
  }),
)
class TableList extends Component<TableListProps, TableListState> {

  state: TableListState = {
    selectedRows: [],
    formValues: {},
    stepFormValues: {},
    areaCode: '',
    page: 1,
    pageSize: 10,
    regionalInformation: [],
    selectDefault: ""
  };

  columns: StandardTableColumnProps[] = [
    {
      title: '序号',
      dataIndex: 'area_code',
      render: (text, record, index) =>
        `${(this.state.page - 1) * (this.state.pageSize) + (index + 1)}`,
    },
    {
      title: '管理员名称',
      dataIndex: 'person_name',
      key: 'person_name',
    },
    {
      title: '登录名',
      dataIndex: 'login_name',
      key: 'login_name',
    },
    {
      title: '初始密码',
      dataIndex: 'original_pwd',
      key: 'original_pwd',
    },
    {
      title: '操作',
      width: 200,
      render: (text, record) => (
        <Popconfirm
          title={'是否确认重置密码？'}
          okText="确认"
          cancelText="取消"
          onConfirm={() => this.resetPassword(text, record)}
        >
          <a>
            重置密码
          </a>
        </Popconfirm>
      ),
    },
  ];

  componentDidMount() {
    const { dispatch } = this.props;
    dispatch({
      type: 'admin/getMeeageInfo',
      payload: {
        areaType: 1
      },
      callback: (response: any) => {
        if (response.success === true) {
          this.setState({
            regionalInformation: response.list,
            areaCode: response.list[0].area_code,
          })
          this.getList();
        }
      }
    })
  }


  renderForm() {
    return this.renderSimpleForm();
  }

  renderSimpleForm() {
    const { form } = this.props;
    const { getFieldDecorator } = form;
    return (
      <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
        <Col md={22} sm={12}>
          {/* 所在行政区划： */}
          {/* <Select defaultValue={this.state.areaCode} style={{ width: 120 }} onChange={this.handleChange}>
            {this.state.regionalInformation.map((item: any, index) => {
              return <Option value={item.area_code}>{item.area_name}</Option>
            })}
          </Select> */}
          <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 6 }} label="所在行政区划：">
            {getFieldDecorator('所在行政区划：', {
              initialValue: this.state.areaCode
            })(
              <Select defaultValue={this.state.areaCode} style={{ width: 120 }} onChange={this.handleChange}>
                {this.state.regionalInformation.map((item: any, index) => {
                  return <Option value={item.area_code}>{item.area_name}</Option>
                })}
              </Select>
            )}
          </FormItem>
        </Col>
        <Col md={2} sm={12}>
          <Button type="primary" htmlType="submit" onClick={() => this.handleExport()}>
            导出
          </Button>
        </Col>
      </Row>
    );
  }

  // 筛选
  handleChange = (value: any) => {
    this.state.areaCode = value;
    this.state.page = 1;
    this.getList()
  }

  // 获取列表
  getList = () => {
    const { dispatch } = this.props;
    dispatch({
      type: 'admin/districtAdminList',
      payload: {
        page: this.state.page,
        limit: this.state.pageSize,
        areaCode: this.state.areaCode,
      }
    });
  }
  // 重置密码
  resetPassword = (text: any, record: any) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'admin/ResetPassword',
      payload: {
        ids: text.id,
      },
      callback: (response: any) => {
        if (response.success) {
          message.success("操作成功");
          this.getList();
        } else {
          message.error("操作失败" + response.messge)
        }
      }
    })
  }

  // 导出
  handleExport = () => {
    // const { dispatch } = this.props;
    // dispatch({
    //   type: 'admin/ExportRegion',
    //   payload: {
    //     areaCode: this.state.areaCode,
    //   }
    // })
    // console.log(window.location.origin)
    let downloadUrl = window.location.origin + "/base/loginperson/ExportAreaManagerInfoExcel?areaCode=" + this.state.areaCode;
    window.open(downloadUrl, "_self");
  }

  // 分页
  handleStandardTableChange = (
    pagination: Partial<TableListPagination>,
    // filtersArg: Record<keyof TableListItem, string[]>,
    // sorter: SorterResult<TableListItem>,
  ) => {
    this.state.page = pagination.current;
    this.state.pageSize = pagination.pageSize;
    this.getList()
  };

  render() {
    const {
      admin: { data },
      loading,
    } = this.props;
    const { selectedRows } = this.state;
    data.pagination = {
      current: this.state.page,
      total: data.count,
      pageSize: this.state.pageSize,
      showTotal: ((total:any) => {
        return `共 ${total} 条`;
      }),
    }
    return (
      <PageHeaderWrapper>
        <Card bordered={false}>
          <div className={styles.tableList}>
            <div className={styles.tableListForm}>{this.renderForm()}</div>
            <StandardTable
              rowSelection={false}
              rowKey={record => record.org_id}
              selectedRows={selectedRows}
              loading={loading}
              data={data}
              columns={this.columns}
              onChange={this.handleStandardTableChange}
            />
          </div>
        </Card>
      </PageHeaderWrapper>
    );
  }
}

export default Form.create<TableListProps>()(TableList);
