import { Button, Card, Col, Divider, Form, Input, Popconfirm, Row, message, Select } from 'antd';
import React, { Component, Fragment } from 'react';

import { Dispatch, Action } from 'redux';
import { FormComponentProps } from 'antd/es/form';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { connect } from 'dva';
import { StateType } from './model';
import StandardTable, { StandardTableColumnProps } from './components/StandardTable';
// import { AddClassForm } from './components/AddClassForm';
import AddClassForm from "./components/AddClassForm"
import SetClassTeacher from "./components/SetClassTeacher"
import { FormValueType } from './components/UpdateForm';
import { TableListItem,ClassInfo,getClassInfo } from './data';

import styles from './style.less';
import UpdataClassInfo from './components/UpdataClassInfo';
const FormItem = Form.Item;

interface TableListProps extends FormComponentProps {
  dispatch: Dispatch<
    Action<
      | 'classInfo/PageClassInfo'
      | 'classInfo/GetClassInfo'
      | 'classInfo/AddClassInfo'
      | 'classInfo/DeleteClassInfo'
      | 'classInfo/SetClassTeacher'
      | 'classInfo/UpdateClassInfo'
      | 'classInfo/GetStageInfo'
      | 'classInfo/GetRxnfInfo'
      | 'classInfo/GetOrgTreeInfo'
    >
  >;
  loading: boolean;
  classInfo: StateType;
}

interface TableListState {
  addVisible: boolean;
  modalVisible: boolean;
  updateModalVisible: boolean;
  expandForm: boolean;
  selectedRows: TableListItem[];
  formValues: { [key: string]: string };
  stepFormValues: Partial<TableListItem>;
  areaCode: string;
  rxnf: string;
  StageInfo: Array<string>;
  RxnfInfo: Array<string>;
  page:number;
  pageSize:number;
  orgId:string;
  stageId:string;
  classInfo:{[key:string]:string};
  setTeacherVisible:boolean;
  setTeacherClassId:string;
  setTeacherId:string;
  
}

/* eslint react/no-multi-comp:0 */
@connect(
  ({
    classInfo,
    geographic,
    loading,
  }: {
    classInfo: StateType;
    geographic: StateType;
    loading: {
      models: {
        [key: string]: boolean;
      };
    };
  }) => ({
    classInfo,
    geographic,
    loading: loading.models.classInfo,
  }),
)
class TableList extends Component<TableListProps, TableListState> {

  state: TableListState = {
    addVisible: false,
    modalVisible: false,
    updateModalVisible: false,
    expandForm: false,
    selectedRows: [],
    formValues: {},
    stepFormValues: {},
    areaCode: '220100',
    rxnf: "",
    StageInfo:[],
    RxnfInfo:[],
    page:1,
    pageSize:10,
    orgId:"",
    stageId:"",
    classInfo:{},
    setTeacherVisible:false,
    setTeacherClassId:"",
    setTeacherId:"",
  };

  columns: StandardTableColumnProps[] = [
    {
      title: '序号',
      dataIndex: 'area_code',
      render: (text, record, index) =>
      `${(this.state.page - 1) * (this.state.pageSize) + (index + 1)}`,
      
    },
    {
      title: '班级名称',
      dataIndex: 'class_name',
      key: 'class_name',
    },
    {
      title: '班级别名',
      dataIndex: 'class_alias',
      key: 'class_alias',
    },
    {
      title: '学生人数',
      dataIndex: 'student_count',
      key: 'student_count',
    },
    {
      title: '班主任',
      dataIndex: 'teacher_name',
      key: 'teacher_name',
    },
    {
      title: '操作',
      width: 200,
      render: (text, record) => (
        <Fragment>
          <Popconfirm
            title={'是否确认删除『' + record.class_name + '』？'}
            okText="确认"
            cancelText="取消"
            onConfirm={() => this.deleteClass(record.class_id)}
          >
            <a>删除</a>
          </Popconfirm>
          <Divider type="vertical" />
          <a onClick={() => this.handleModalVisible( record.class_id,true)}>
            修改
          </a>
          <Divider type="vertical" />
          <a onClick={() => this.handleSetTeacherVisible(record.class_id,record.teacher_id,true)}>
            设置班主任
          </a>
        </Fragment>
      ),
    },
  ];

  componentDidMount() {
    const { dispatch } = this.props;
    const orgId = this.props.match.params.id
    this.setState({
      orgId:orgId
    })
    // 获取学制
    dispatch({
      type: 'classInfo/GetStageInfo',
      payload: {
        orgId: orgId,
      },
      callback: (response: any) => {
        this.setState({
          StageInfo:response,
          stageId:response[0].stage_id
        })
        // 获取入学年份
        dispatch({
          type: 'classInfo/GetRxnfInfo',
          payload: {
            orgId: orgId,
            stageId:response[0].stage_id
          },
          callback: (response: any) => {
            console.log(response,'fields,1')

            const fields = {
              orgId: orgId,
              stageId:this.state.stageId,
              rxnf:response[0]
            }

            this.setState({
              RxnfInfo:response,
              rxnf:response[0]
            })
            this.getClassList(fields)

          },
        });


      },
    });
  }

// 新增弹窗
  handleAddVisible = (flag?: boolean) => {
    this.setState({
      addVisible: !!flag,
    });
  };

  // 新增提交处理   BUG : 新增后没有刷新入学年份下拉列表筛选。
  handleAdd = (fields: ClassInfo) => {
    const { dispatch } = this.props;
    fields.orgId = this.props.match.params.id;
    console.log(fields,'school fileds')
    dispatch({
      type: 'classInfo/AddClassInfo',
      payload: {
        ...fields,
      },
      callback: (response: any) => {
        console.log(response,"school.callback")
        if(response.success){
          message.success('添加成功。');
          // const areaCode = this.state.areaCode;
          const fields = {
            orgId: this.state.orgId,
            stageId:this.state.stageId,
            rxnf:this.state.rxnf
          }
          this.getClassList(fields);

          this.handleAddVisible();
        }else{
          // const areaCode = this.state.areaCode;
          // this.getEffectList(areaCode);
          message.error('添加失败。'+response.message);
        }
      },
    });
    
  };

  // 获取列表
  getClassList(fields?: getClassInfo, pagination?: any) {

    console.log(fields,'fields')
    const { dispatch } = this.props;
    // const schoolId = this.props.match.params.id
    if(!pagination){
      pagination = {
        page: this.state.page,
        limit: this.state.pageSize,
      }
    }
    if(!fields){
      fields = {
        orgId:this.state.orgId,
        stageId:this.state.stageId,
        rxnf:this.state.rxnf
      }
    }

    dispatch({
      type: 'classInfo/PageClassInfo',
      payload: {
        ...fields,
        ...pagination
      },
    });
  }

// 获取入学年份
  getRxnf = (stageId:string) =>{
    const { dispatch } = this.props;
    const orgId =  this.state.orgId
    const { form } = this.props;
    form.setFieldsValue({rxnf:""});
    dispatch({
      type: 'classInfo/GetRxnfInfo',
      payload: {
        orgId: orgId,
        stageId:stageId
      },
      callback: (response: any) => {


        const fields = {
          orgId: orgId,
          stageId:stageId,
          rxnf:response[0]
        }

        // console.log(response,'rxnf')
        this.setState({
          RxnfInfo:response,
          stageId:stageId,
          rxnf:response[0]
        })
        // console.log(fields)
        this.getClassList(fields)
        form.setFieldsValue({rxnf:response[0]});
      },
    });

}

  toggleForm = () => {
    const { expandForm } = this.state;
    this.setState({
      expandForm: !expandForm,
    });
  };

  handleRxnf = (e) => {
      const values = {
        orgId:this.state.orgId,
        stageId:this.state.stageId,
        rxnf:e
      };
      this.setState({
        rxnf:e
      });
      this.getClassList(values);
  };

  // 修改班级弹窗传参
  handleModalVisible = (classId:string,flag?: boolean) => {
    if (flag) {
      const { dispatch } = this.props;
      dispatch({
        type: 'classInfo/GetClassInfo',
        payload: {
          classId: classId,
        },
        callback: (response: any) => {
          this.setState({
            classInfo:response,
            modalVisible: !!flag,
          });
        },
      });

      
    } else {
      this.setState({
        modalVisible: !!flag,
      });
    }
  };

  handleUpdateModalVisible = (flag?: boolean, record?: FormValueType) => {
    this.setState({
      updateModalVisible: !!flag,
      stepFormValues: record || {},
    });
  };

  // 修改教育局信息
  handleModify = (fields: { desc: any }) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'classInfo/UpdateClassInfo',
      payload: {
        ...fields,
      },
      callback: (response: any) => {
        if (response) {
          
          this.getClassList();
          message.success('修改成功');
        } else {
          message.error('修改失败');
        }
      },
    });
    this.handleModalVisible('');
  };

  onChange = (value: number, selectedOptions: any) => {
    console.log(value, selectedOptions);
  };

  // 删除班级
  deleteClass = (classIds: string) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'classInfo/DeleteClassInfo',
      payload: {
        classIds: classIds,
      },
      callback: response => {
        if (response) {
          
          this.getClassList();
          message.success('班级成功');
        } else {
          message.error('禁用失败');
        }
      },
    });

    // message.success('禁用成功');
  };

  // 设置班主任弹窗
  handleSetTeacherVisible = (classId:string,teacherId:string,flag?: boolean,isAddSuccess?:boolean) => {

    // 如果增加教师成功刷新列表
if(isAddSuccess){
  this.getClassList();
}

console.log(classId,teacherId,flag,'flag')
    this.setState({
      setTeacherId:teacherId,
      setTeacherClassId:classId,
      setTeacherVisible: !!flag,
    });
  };








  renderSimpleForm() {
    const { form } = this.props;
    const { getFieldDecorator } = form;
    const { StageInfo, RxnfInfo} = this.state

    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={8} sm={24}>
          <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 6 }} label="学部">
        {getFieldDecorator('stageId',{
          initialValue:this.state.stageId,
        })(
          // <Input />
        <Select
          style={{ width: '100%' }}
          showSearch={true}
          onChange={(e)=>this.getRxnf(e)}
          >
             {StageInfo?.map(item => (
                  <Select.Option value={item.stage_id} key={item.stage_id} >{item.stage_name}</Select.Option>
                ))}
            </Select>
            )}
      </FormItem>
          </Col>
          <Col md={8} sm={24}>
          <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 6 }} label="入学年份">
        {form.getFieldDecorator('rxnf',{
          initialValue:this.state.rxnf,
        }  )(
        <Select
          style={{ width: '100%' }}
          showSearch={true}
          onChange = {(e)=>this.handleRxnf(e)}
          >

             {RxnfInfo?RxnfInfo.map(item => (
                  <Select.Option value={item} key={item} >{item}</Select.Option>
                )):<Select.Option value="" key="" ></Select.Option>}
            </Select>
            )}
      </FormItem>
          </Col>
          <Col md={4} sm={12}>
            <span className={styles.submitButtons}>
              {/* <Button type="primary" htmlType="submit">
                查询
              </Button> */}
     
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  renderForm() {
    return this.renderSimpleForm();
  }

  render() {
    const {
      classInfo: { data },
      loading,
    } = this.props;
    
    const { selectedRows,addVisible, modalVisible,setTeacherVisible } = this.state;

    const addClassMethods = {
      handleAddVisible: this.handleAddVisible,
      addVisible: this.state.addVisible,
      handleAdd:this.handleAdd,
      StageList:this.props.classInfo.StageInfo
    };
    const parentMethods = {
      handleModify: this.handleModify,
      handleModalVisible: this.handleModalVisible,
      classInfo:this.state.classInfo
    };
    const setTeacherMethods={
      setTeacherVisible:this.state.setTeacherVisible,
      handleSetTeacherVisible:this.handleSetTeacherVisible,
      orgId:this.state.orgId,
      setTeacherClassId:this.state.setTeacherClassId,
      setTeacherId:this.state.setTeacherId,
      ...this.props,
    }
    data.pagination = {
      current:this.state.page,
      total:data.count,
      pageSize:this.state.pageSize,
    
    }
    return (
      <PageHeaderWrapper>
        <Card bordered={false}>
          <div className={styles.tableList}>
            <div className={styles.tableListForm}>{this.renderForm()}</div>
            <div className={styles.tableListOperator}>
              <Button
                icon="plus"
                type="primary"
                onClick={()=>this.handleAddVisible(true)}
              >
                增加班级
              </Button>
            </div>
            <StandardTable
              // rowSelection={false}
              rowKey={record => record.org_id}
              selectedRows={selectedRows}
              loading={loading}
              data={data}
              columns={this.columns}
            />
          </div>
        </Card>

        <AddClassForm {...addClassMethods} modalVisible={addVisible} />
        <UpdataClassInfo {...parentMethods} modalVisible={modalVisible} />
        <SetClassTeacher {...setTeacherMethods} modalVisible={setTeacherVisible} />
      </PageHeaderWrapper>
    );
  }
}

export default Form.create<TableListProps>()(TableList);
