import { AnyAction, Reducer } from 'redux';
import { EffectsCommandMap } from 'dva';
import { GetDistrictAdministrator, GetUnitAdministrator, ExportRegionAdministrator, ExportUnitAdministrator, GetMessage, ResetPassword } from './service';

// eslint-disable-next-line import/no-unresolved
import { TableListData } from './data';

export interface StateType {
  data?: TableListData;
}

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: StateType) => T) => T },
) => void;

export interface ModelType {
  namespace: string;
  state: StateType;
  effects: {
    districtAdminList: Effect;
    UnitAdministrator: Effect;
    ExportRegion: Effect;
    ExportUnits: Effect;
    getMeeageInfo: Effect;
    ResetPassword: Effect;
  };
  reducers: {
    save: Reducer<StateType>;
    saveUnit: Reducer<StateType>;
  };
}

const Model: ModelType = {
  namespace: 'admin',

  state: {
    data: {
      list: [],
      pagination: {},
    },
  },

  effects: {
    // 获取地区管理员列表(虚拟)
    *districtAdminList({ payload }, { call, put }) {
      const response = yield call(GetDistrictAdministrator, payload);
      yield put({
        type: 'save',
        payload: response,
      });
    },
    // 获取单位管理员列表
    *UnitAdministrator({ payload }, { call, put }) {
      const response = yield call(GetUnitAdministrator, payload);
      yield put({
        type: 'saveUnit',
        payload: response,
      });
    },
    // 导出地区管理员
    *ExportRegion({ payload, callback }, { call, put }) {
      const response = yield call(ExportRegionAdministrator, payload);
      if (callback) callback(response);
    },
    // 导出单位管理员
    *ExportUnits({ payload, callback }, { call, put }) {
      const response = yield call(ExportUnitAdministrator, payload);
      if (callback) callback(response);
    },
    // 根据人员ID获取所管辖的地区信息
    *getMeeageInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetMessage, payload);
      if (callback) callback(response);
    },
    //重置密码
    *ResetPassword({ payload, callback }, { call, put }) {
      const response = yield call(ResetPassword, payload);
      if (callback) callback(response);
    },
  },

  reducers: {
    save(state, action) {
      return {
        ...state,
        data: action.payload,
      };
    },
    saveUnit(state, action) {
      return {
        ...state,
        data: action.payload,
      };
    },
  },
};

export default Model;
