import { Form, Input, Modal, Select } from 'antd';
import { FormComponentProps } from 'antd/es/form';
import React, { useState } from 'react';
// import { number } from 'prop-types';
import CascadeGeographic from '@/components/CascadeGeographic';

const { Option } = Select;

const FormItem = Form.Item;

interface EditFormProps extends FormComponentProps {
  updateModalVisible: boolean;
  handleUpdate: (fieldsValue: { desc: string }) => void;
  handleUpdateModalVisible: () => void;
  // cityCode: string;
  changeCityCode: (e: string) => void;
  values: any;
}

const EditForm: React.FC<EditFormProps> = props => {
  const [Code, setCode] = useState('');

  const { updateModalVisible, form, handleUpdate, handleUpdateModalVisible, values } = props;
  const { getFieldDecorator } = form;
  const okHandle = () => {
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      // form.resetFields();
      handleUpdate(fieldsValue);
    });
  };
  /*
  let value = 'test'
  const codeOnChange = (e: string[]) => {
    value = e[0]
    console.log(value, 'this.props,cas')
  }
  */

  /**
   * 修改区域代码事件
   * @param e
   */
  const handleAreaChange = (e: any) => {
    const { value } = e.target;
    e.target.value = value.replace(/[^0-9]/gi, '');
    // console.log('v:', value.charCodeAt());
    // console.log('onChange:', e);
    // changeCityCode();
  };

  /**
   * 修改省市事件
   * @param e
   */
  const handleCityChange = (value: any) => {
    // 修改所在城市获取城市code前4位
    const cityCodeHandle = value[value.length - 1];

    if (cityCodeHandle) {
      setCode(cityCodeHandle.substring(0, 4));
    } else {
      setCode('');
    }
  };

  // const cityCode:string = props.cityCode
  console.log([values.master_code.slice(0, 3) + "000", values.master_code])
  // console.log(props.cityCode,'this.propsssss')
  return (
    <Modal
      destroyOnClose
      title="编辑行政区"
      visible={updateModalVisible}
      width={750}
      onOk={okHandle}
      onCancel={() => handleUpdateModalVisible()}
    >
      {/* 所在行政区划 */}
      <FormItem labelCol={{ span: 7 }} wrapperCol={{ span: 10 }} label="所在城市">
        {getFieldDecorator('area', {
          initialValue: [values.master_code.slice(0, 3) + "000", values.master_code],
          rules: [{ required: true, message: '请选择所在行政区' }],
        })(<CascadeGeographic changeOnSelect={false} level="2" defaultValue={[values.master_code.slice(0, 3) + "000", values.master_code]} onChange={handleCityChange} />)}
      </FormItem>
      {/* 行政区代码 */}
      <FormItem labelCol={{ span: 7 }} wrapperCol={{ span: 6 }} label="行政区代码">
        {form.getFieldDecorator('code', {
          initialValue: values.area_code,
          rules: [
            {
              required: true,
              message: '请输入2位数字',
            },
            {
              message: '只能输入2位数字',
              pattern: /^([1-9]\d|\d){2}$/,
            },
          ],
        })(<Input addonBefore={Code} maxLength={2} onChange={handleAreaChange} />)}
      </FormItem>
      {/* 行政区名称 */}
      <FormItem labelCol={{ span: 7 }} wrapperCol={{ span: 10 }} label="行政区名称">
        {form.getFieldDecorator('name', {
          initialValue: values.area_name,
          rules: [
            {
              required: true,
              message: '请输入行政区名称。',
            },
            {
              min: 3,
              max: 50,
              message: '请输入3-50个汉字、字母或数字',
            },
          ],
        })(<Input placeholder="请输入" maxLength={50} />)}
      </FormItem>
      {/* 行政区类型 */}
      <FormItem labelCol={{ span: 7 }} wrapperCol={{ span: 6 }} label="行政区类型">
        {form.getFieldDecorator('type', {
          initialValue: values.area_level_id,
          rules: [{ required: true, message: '请选择行政区类型' }],
        })(
          <Select placeholder="请选择" style={{ width: '100%' }}>
            <Option value={1}>县市区</Option>
            <Option value={2}>开发区</Option>
          </Select>,
        )}
      </FormItem>
    </Modal>
  );
};

export default Form.create<EditFormProps>()(EditForm);
