import { AnyAction, Reducer } from 'redux';
import { EffectsCommandMap } from 'dva';
import { addGeographic, queryGeographic, removeGeographic, updateGeographic } from './service';

import { TableListData, TableListItem } from './data.d';

export interface StateType {
  data: TableListData;
}

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: StateType) => T) => T },
) => void;

/**
 * 级联选择下拉项类型定义
 */
export interface ModelType {
  namespace: string;
  state: StateType;
  effects: {
    fetch: Effect;
    add: Effect;
    remove: Effect;
    update: Effect;
  };
  reducers: {
    save: Reducer<StateType>;
  };
}

const Model: ModelType = {
  namespace: 'area',

  state: {
    data: {
      list: [],
      pagination: {},
    },
  },

  effects: {
    *fetch({ payload }, { call, put }) {
      const response = yield call(queryGeographic, payload);
      // console.log(response, 'effects queryGeographic 1');
      const items: TableListItem[] = [];
      response.list.forEach((item: TableListItem) => {
        console.log('is children', payload.id);
        if (payload.id === '' || (payload.id.charAt(2) === '0' && payload.id.charAt(3) === '0')) {
          items.push({ ...item, children: [] });
        } else {
          items.push({ ...item });
        }
      });
      yield put({
        type: 'save',
        payload: { id: payload.id, list: items, pagination: {} },
      });
    },

    *add({ payload, callback }, { call, put }) {
      const response = yield call(addGeographic, payload);
      // yield put({
      //   type: 'save',
      //   payload: response,
      // });
      if (callback) callback(response);
    },

    *remove({ payload, callback }, { call, put }) {
      const response = yield call(removeGeographic, payload);
      // yield put({
      //   type: 'save',
      //   payload: response,
      // });
      if (callback) callback(response);
    },

    *update({ payload, callback }, { call, put }) {
      const response = yield call(updateGeographic, payload);
      // yield put({
      //   type: 'save',
      //   payload: response,
      // });
      if (callback) callback(response);
    },
  },

  reducers: {
    /**
     * 存储状态,把原数据与新数据合并
     * @param state
     * @param action
     */
    save(state: any, action) {
      // console.log('state::1:', state);
      const { id } = action.payload || '100000'; // 提取传递的id
      // console.log('state::id:', action.payload.id);
      // console.log('action.payload:', action.payload);
      let data = {}; // 存储叠加后数据
      const {
        data: { list },
      } = state || { data: { list: [] } };
      // console.log('list:', list)

      /**
       * 定义当前路径解析变量
       */
      const path: string[] = [];
      // 判断是否为全国
      if (id !== '' && (id.length === 6 || id !== '100000')) {
        // 获取市级
        if (id.charAt(1) !== '0') {
          path[0] = `${id.charAt(0) + id.charAt(1)}0000`;
        }
        // 获取区级
        if (id.charAt(3) !== '0') {
          path[1] = `${id.charAt(0) + id.charAt(1) + id.charAt(2) + id.charAt(3)}00`;
        }
      }
      console.log('path:', path);
      console.log('path.length:', path.length);

      let idx = 0;
      /**
       * 获取省级
       */
      if (path.length === 0) {
        /**
         * action.payload
         * id: "220000", list: Array(9), pagination: {}
         */
        data = action.payload; // 需要判断处理
      }

      /**
       * 获取市级
       */
      if (path.length === 1) {
        console.log('=====id=====', id);
        console.log('=====path[0]=====', path[0]);
        console.log('=====list=====', list);

        // 在省级区划中检索对应id的索引值
        idx = list.findIndex((v: { area_code: string }) => v.area_code === path[0]);
        list[idx].children.push(...action.payload.list);
        data = { ...state.data, list };
      }

      /**
       * 获取区级
       */
      if (path.length === 2) {
        // 在省级区划中检索对应id的索引值
        const idxProvince = list.findIndex((v: { area_code: string }) => v.area_code === path[0]);
        console.log('list: ', list);
        console.log('idxProvince: ', idxProvince);

        const idxCity = list[idxProvince].children.findIndex(
          (v: { area_code: string }) => v.area_code === path[1],
        );
        console.log('idxCity: ', idxCity);
        list[idxProvince].children[idxCity].children.push(...action.payload.list);
        data = { ...state.data, list };
      }

      return {
        ...state,
        data: { ...data }, // id: "", list: Array(), pagination: {}
      };
    },
  },
};

export default Model;
