import {
  Button,
  Card,
  Col,
  Divider,
  Popconfirm,
  Form,
  Row,
  message,
} from 'antd';
import React, { Component, Fragment } from 'react';

import { Dispatch, Action } from 'redux';
import { FormComponentProps } from 'antd/es/form';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { SorterResult } from 'antd/es/table';
import { connect } from 'dva';
import { StateType } from './model';
import CreateForm from './components/addOrEditModal';
import StandardTable, { StandardTableColumnProps } from './components/StandardTable';

import { TableListItem, TableListPagination, TableListParams, GetOrglistItem } from './data.d';

import styles from './style.less';

const getValue = (obj: { [x: string]: string[] }) =>
  Object.keys(obj)
    .map(key => obj[key])
    .join(',');

interface TableListProps extends FormComponentProps {
  dispatch: Dispatch<
    Action<
      | 'branch/getList'
      | 'branch/getInfo'
      | 'branch/addInfo'
      | 'branch/editInfo'
      | 'branch/deleteInfo'
      | 'branch/getPersonMsg'
    >
  >;
  loading: boolean;
  branch: StateType;
}

interface TableListState {
  addInfoModal: boolean;
  editInfoModal: boolean;
  expandForm: boolean;
  selectedRows: TableListItem[];
  formValues: { [key: string]: string };
  stepFormValues: Partial<TableListItem>;

  orgInfo: {};
  org_id: string;
  depId: string;
  identityId: string;
}

/* eslint react/no-multi-comp:0 */
@connect(
  ({
    branch,
    loading,
  }: {
    branch: StateType;
    loading: {
      models: {
        [key: string]: boolean;
      };
    };
  }) => ({
    branch,
    loading: loading.models.branch,
  }),
)
class TableList extends Component<TableListProps, TableListState> {
  state: TableListState = {
    addInfoModal: false,
    editInfoModal: false,
    expandForm: false,
    selectedRows: [],
    formValues: {},
    stepFormValues: {},

    orgInfo: {},// 部门信息（某一条）
    org_id: "",
    depId: "",// 學校管理員（學校/部門Id）
    identityId: "",// 登录人身份id
  };

  columns: StandardTableColumnProps[] = [
    // {
    //   title: '序号',
    //   dataIndex: 'org_id',
    //   render: (text, record, index) =>
    //     `${(index + 1)}`,

    // },
    {
      title: '部门',
      dataIndex: 'org_name',
    },
    {
      title: '部门代码',
      dataIndex: 'org_code',
    },
    {
      title: '部门领导',
      dataIndex: 'manager_name',
    },
    {
      title: '排序号',
      dataIndex: 'sort_id',
    },
    {
      title: '操作',
      width: 450,
      render: (text, record) => (
        text.parent_id === "00000000-0000-0000-0000-000000000000" ? < Fragment >
          <a onClick={() => { this.handleModalVisible(text.org_id, true) }}>增加</a>
        </Fragment>
          : < Fragment >
            <a onClick={() => { this.handleModalVisible(text.org_id, true) }}>增加</a>
            <Divider type="vertical" />
            <a onClick={() => { this.handleUpdateModalVisible(text.org_id, true) }}>编辑</a>
            <Divider type="vertical" />
            <Popconfirm
              title={'是否确认删除『' + text.org_name + '』？'}
              okText="确认"
              cancelText="取消"
              onConfirm={() => this.handleDelete(text.org_id)}
            >
              <a style={{ color: "red" }}>删除</a>
            </Popconfirm>
          </Fragment>

      ),
    },
  ];

  componentDidMount() {
    // alert(this.props.match.params.id)
    this.props.branch.data.list = [];
    this.getOrgList()
  }

  //获取列表
  getOrgList = () => {
    const { dispatch } = this.props;
    const bureauId = this.props.match.params.id;
    if (bureauId == undefined) {
      dispatch({
        type: 'branch/getPersonMsg',
        payload: {},
        callback: (response: any) => {
          this.setState({ depId: response.list[0].rule_id, identityId: response.list[0].role_id })
          this.getList()
        },
      });
    } else {
      this.getList()
    }
  }
  getList = () => {
    const { dispatch } = this.props;
    dispatch({
      type: 'branch/getList',
      payload: {
        orgId: this.props.match.params.id ? this.props.match.params.id : this.state.depId
      },
      // callback: () => {
      //   this.setState({ openList: true })
      //   this.forceUpdate()
      // }
    });
  }
  //获取信息
  getOrgInfo = (orgId: string) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'branch/getInfo',
      payload: {
        orgId: orgId
      },
      callback: (response: any) => {
        this.setState({ orgInfo: response.list })
      },
    });
  }

  //删除部门
  handleDelete = (orgId: string) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'branch/deleteInfo',
      payload: {
        orgId: orgId
      },
      callback: (response: any) => {
        if (response.success) {
          message.success('删除成功');
          this.getList();
        } else {
          this.getList();
          message.error('删除失败,' + response.message);
        }
      },
    });
  }

  handleStandardTableChange = (
    pagination: Partial<TableListPagination>,
    filtersArg: Record<keyof TableListItem, string[]>,
    sorter: SorterResult<TableListItem>,
  ) => {
    const { dispatch } = this.props;
    const { formValues } = this.state;

    const filters = Object.keys(filtersArg).reduce((obj, key) => {
      const newObj = { ...obj };
      newObj[key] = getValue(filtersArg[key]);
      return newObj;
    }, {});

    const params: Partial<TableListParams> = {
      currentPage: pagination.current,
      pageSize: pagination.pageSize,
      ...formValues,
      ...filters,
    };
    if (sorter.field) {
      params.sorter = `${sorter.field}_${sorter.order}`;
    }

    dispatch({
      type: 'branch/getList',
      payload: params,
    });
  };

  handleSelectRows = (rows: TableListItem[]) => {
    this.setState({
      selectedRows: rows,
    });
  };

  // 新增部门
  handleModalVisible = (orgId: string, flag?: boolean) => {
    this.setState({ addInfoModal: !!flag, org_id: orgId })
    if (this.state.editInfoModal === false) {
      this.getOrgInfo(orgId)
    }
  };

  // 编辑部门
  handleUpdateModalVisible = (record: string, flag?: boolean) => {
    this.setState({
      editInfoModal: !!flag,
    });
    if (this.state.editInfoModal === false) {
      this.getOrgInfo(record)
    }
  };

  // 新增、编辑调接口
  handleAdd = (fields: { desc: any }) => {
    if (this.state.addInfoModal === true) {
      const { dispatch } = this.props;
      const orgId = this.props.match.params.id;
      dispatch({
        type: 'branch/addInfo',
        payload: {
          orgId: orgId ? orgId : this.state.depId,
          orgCode: fields.desc.org_code,
          orgName: fields.desc.org_name,
          parentId: this.state.org_id,
          sortId: fields.desc.number,
          orgManagerIds: fields.desc.org_id,
        },
        callback: (response: any) => {
          if (response.success) {
            message.success('添加成功');
            this.getList();
            this.handleModalVisible("", false);
          } else {
            message.error('添加失败,' + response.message);
          }
        },
      });
    } else if (this.state.editInfoModal === true) {
      const { dispatch } = this.props;
      dispatch({
        type: 'branch/editInfo',
        payload: {
          orgId: this.state.orgInfo[0].org_id,
          orgCode: fields.desc.org_code,
          orgName: fields.desc.org_name,
          sortId: fields.desc.number,
          orgManagerIds: fields.desc.org_id,
        },
        callback: (response: any) => {
          if (response.success) {
            message.success('编辑成功');
            this.getList();
            this.handleUpdateModalVisible('', false);
          } else {
            message.error('编辑失败,' + response.message);
          }
        },
      });
    }
  };

  //返回按钮
  renderSimpleForm() {
    if (this.state.identityId === "9CD6B804-0F89-4626-A812-29465CFC7410" || this.state.identityId === "73E897FC-C9D1-4E48-AE22-AC7586425C1D") {
      return ""
    } else {
      return (
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={22}></Col>
          <Col md={2} style={{ marginBottom: "12px" }}>
            <Button type="primary" onClick={() => { window.history.back() }}>
              返回
          </Button>
          </Col>
        </Row>
      );
    }
  }

  render() {
    const {
      branch: { data },
      loading,
    } = this.props;

    const { selectedRows, addInfoModal, editInfoModal } = this.state;
    const parentMethods = {
      handleAdd: this.handleAdd,
      handleModalVisible: this.handleModalVisible,
      handleUpdateModalVisible: this.handleUpdateModalVisible,
    };
    return (
      <PageHeaderWrapper>
        <Card bordered={false}>
          <div className={styles.tableList}>
            <div className={styles.tableListForm}>{this.renderSimpleForm()}</div>
            {data.list && data.list.length ? <StandardTable
              rowKey={record => record.org_id}
              selectedRows={selectedRows}
              loading={loading}
              data={data}
              rowSelection={false}
              defaultExpandAllRows={data.list[0].children ? true : false}
              columns={this.columns}
              onSelectRow={this.handleSelectRows}
              onChange={this.handleStandardTableChange}
            /> : ""}

          </div>
        </Card>
        <CreateForm
          {...parentMethods}
          dispatchProps={this.props}
          orgId={this.props.match.params.id}
          orgInfo={this.state.orgInfo}
          type={this.state.addInfoModal === true ? "add" : "edit"}
          modalVisible={this.state.addInfoModal === true ? addInfoModal : editInfoModal}
        />
      </PageHeaderWrapper>
    );
  }
}

export default Form.create<TableListProps>()(TableList);
