import { Col, Icon, Row, Tooltip } from 'antd';

import { FormattedMessage } from 'umi-plugin-react/locale';
import React from 'react';
import numeral from 'numeral';
import { ChartCard, MiniArea, MiniBar, MiniProgress, Field } from './Charts';
import { VisitDataType } from '../data.d';

const topColResponsiveProps = {
  xs: 24,
  sm: 12,
  md: 12,
  lg: 12,
  xl: 6,
  style: { marginBottom: 24 },
};

const IntroduceRow = ({ loading, visitData }: { loading: boolean; visitData: VisitDataType[] }) => (
  <Row gutter={24} type="flex">
    {visitData.map((item: any,index) => {
      return <Col {...topColResponsiveProps}>
        <ChartCard
          bordered={false}
          title={item.title
            // <FormattedMessage id="dashboard-analysis.analysis.total-sales" defaultMessage="Total Sales" />
          }
          action={
            <Tooltip
              title={
                <FormattedMessage id="dashboard-analysis.analysis.introduce" defaultMessage="Introduce" />
              }
            >
              {/* <Icon type="info-circle-o" /> */}
              {index === 0 ? <span style={{ background: "#ffa300", color: "#fff", padding: "3px 6px" }}>所</span> : ""}
              {index === 1 ? <span style={{ background: "#31a8fa", color: "#fff", padding: "3px 6px" }}>所</span> : ""}
              {index === 2 ? <span style={{ background: "#009993", color: "#fff", padding: "3px 6px" }}>人</span> : ""}
              {index === 3 ? <span style={{ background: "#ff6393", color: "#fff", padding: "3px 6px" }}>人</span> : ""}
            </Tooltip>
          }
          loading={loading}
          total={numeral(item.total_count).format('0,0')}
          footer={
            <Field
              label={
                "本学期新增"
                // <FormattedMessage id="dashboard-analysis.analysis.day-sales" defaultMessage="Daily Sales" />
              }
              value={index === 0 || index === 1 ? numeral(item.current_term_add_count).format('0,0') + "所" : numeral(item.current_term_add_count).format('0,0') + "人"}
            />
          }
          contentHeight={46}
        >
          {/* <Trend flag="up" style={{ marginRight: 16 }}>
        <FormattedMessage id="dashboard-analysis.analysis.week" defaultMessage="Weekly Changes" />
        <span className={styles.trendText}>12%</span>
      </Trend>
      <Trend flag="down">
        <FormattedMessage id="dashboard-analysis.analysis.day" defaultMessage="Daily Changes" />
        <span className={styles.trendText}>11%</span>
      </Trend> */}
        </ChartCard>
      </Col>
    })}
  </Row>
);

export default IntroduceRow;
