import { Card, Col, DatePicker, Row, Tabs } from 'antd';
import { FormattedMessage, formatMessage } from 'umi-plugin-react/locale';

import { RangePickerValue } from 'antd/es/date-picker/interface';
import React from 'react';
import numeral from 'numeral';
import { VisitDataType } from '../data.d';
import { Bar } from './Charts';
import styles from '../style.less';

const { RangePicker } = DatePicker;
const { TabPane } = Tabs;

const SalesCard = ({
  rangePickerValue,
  schoolStudentList,
  schoolTeacherList,
  unitTeacherList,
  baseRanking,
  code,
  isActive,
  handleRangePickerChange,
  loading,
  props,
}: {
  rangePickerValue: RangePickerValue;
  isActive: (key: 'today' | 'week' | 'month' | 'year') => string;
  schoolStudentList: VisitDataType[];
  schoolTeacherList: VisitDataType[];
  unitTeacherList: VisitDataType[];
  baseRanking: VisitDataType[];
  code: string;
  loading: boolean;
  props: {}
  handleRangePickerChange: (dates: RangePickerValue, dateStrings: [string, string]) => void;
}) => (
    <Card loading={loading} bordered={false} bodyStyle={{ padding: 0 }}>
      <div className={styles.salesCard}>
        <Row type="flex">
          <Col xl={16} lg={12} md={12} sm={24} xs={24}>
            <Tabs
              tabBarExtraContent={null}
              size="large"
              tabBarStyle={{ marginBottom: 24 }}
              defaultActiveKey={props.location.query.thisKey && props.location.query.thisKey === "unitNum" || props.location.query.thisKey === "unitNumber" ? "teacherDep" : "student"}
            >
              <TabPane
                tab={"各学校学生数量"}
                key="student"
              >
                <Row type="flex">
                  <Col xl={24} lg={24} md={24} sm={24} xs={24}>
                    <div className={styles.salesBar}>
                      <Bar
                        code={code}
                        keyType="student"
                        height={350}
                        title={null}
                        props={props}
                        data={schoolStudentList}
                      />
                    </div>
                  </Col>
                </Row>
              </TabPane>
              <TabPane
                tab={"各学校教职工数量"}
                key="teacher"
              >
                <Row>
                  <Col xl={24} lg={24} md={24} sm={24} xs={24}>
                    <div className={styles.salesBar}>
                      <Bar
                        code={code}
                        keyType="teacher"
                        height={350}
                        title={null}
                        props={props}
                        data={schoolTeacherList}
                      />
                    </div>
                  </Col>
                </Row>
              </TabPane>
              <TabPane
                tab={"各教辅单位教职工数量"}
                key="teacherDep"
              >
                <Row>
                  <Col xl={24} lg={24} md={24} sm={24} xs={24}>
                    <div className={styles.salesBar}>
                      <Bar
                        keyType="teacherDep"
                        height={350}
                        title={null}
                        props={props}
                        data={unitTeacherList}
                      />
                    </div>
                  </Col>
                </Row>
              </TabPane>
            </Tabs>
          </Col>
          <Col xl={8} lg={12} md={12} sm={24} xs={24}>
            <div className={styles.salesRank} style={{ padding: "36px 24px" }}>
              <h4 className={styles.rankingTitle}>
                基础数据访问排名
                    {/* <FormattedMessage
                      id="dashboard-analysis.analysis.sales-ranking"
                      defaultMessage="Sales Ranking"
                    /> */}
              </h4>
              <ul className={styles.rankingList}>
                {baseRanking.length > 0 ? baseRanking.map((item, i) => (
                  <li key={item.org_id}>
                    <span className={`${styles.rankingItemNumber} ${i < 3 ? styles.active : ''}`}>
                      {i + 1}
                    </span>
                    <span className={styles.rankingItemTitle} title={item.org_name}>
                      {item.org_name}
                    </span>
                    <span className={styles.rankingItemValue}>
                      {numeral(item.count).format('0,0')}
                    </span>
                  </li>
                )) : <div style={{ width: "100%", textAlign: "center", fontSize: "18px", marginTop: "20px" }}>暂无数据</div>}
              </ul>
            </div>
          </Col>
        </Row>
      </div>
    </Card>
  );

export default SalesCard;
