/*
  区县基础数据录入统计
*/

import { Col, Dropdown, Icon, Menu, Row, Button } from 'antd';
import React, { Component, Suspense } from 'react';

import { Dispatch } from 'redux';
import { GridContent } from '@ant-design/pro-layout';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { RadioChangeEvent } from 'antd/es/radio';
import { RangePickerValue } from 'antd/es/date-picker/interface';
import { connect } from 'dva';
import PageLoading from './components/PageLoading';
import { getTimeDistance } from './utils/utils';
import { AnalysisData } from './data.d';
import styles from './style.less';

const IntroduceRow = React.lazy(() => import('./components/IntroduceRow'));
const SalesCard = React.lazy(() => import('./components/SalesCard'));
// const TopSearch = React.lazy(() => import('./components/TopSearch'));
const ProportionSalesStudent = React.lazy(() => import('./components/ProportionSalesStudent'));
const ProportionSalesTeacher = React.lazy(() => import('./components/ProportionSalesTeacher'));
// const OfflineData = React.lazy(() => import('./components/OfflineData'));

interface AnalysisProps {
  dashboardAnalysis: AnalysisData;
  dispatch: Dispatch<any>;
  loading: boolean;
}

interface AnalysisState {
  salesType: 'all' | 'online' | 'stores';
  currentTabKey: string;
  rangePickerValue: RangePickerValue;
  codeNum: string;
  companyName: string;
}

@connect(
  ({
    dashboardAnalysis,
    loading,
  }: {
    dashboardAnalysis: any;
    loading: {
      effects: { [key: string]: boolean };
    };
  }) => ({
    dashboardAnalysis,
    loading: loading.effects.dashboardAnalysis,
  }),
)
class Analysis extends Component<
AnalysisProps,
AnalysisState
> {
  state: AnalysisState = {
    salesType: 'all',
    currentTabKey: '',
    rangePickerValue: getTimeDistance('year'),
    codeNum: "",
    companyName: "",
  };

  reqRef: number = 0;

  timeoutId: number = 0;

  componentDidMount() {
    const { dispatch } = this.props;
    this.reqRef = requestAnimationFrame(() => {
      if (this.props.match.params.code) {
        this.state.codeNum = this.props.match.params.code;
        this.getAllMsg()
      } else {
        dispatch({
          type: 'dashboardAnalysis/getPersonMsg',
          callback: (data: any) => {
            console.log(data, "999999999999999")
            this.state.codeNum = data.list[0].rule_id;
            this.state.companyName = data.list[0].rule_name;
            this.getAllMsg()
          }
        });
      }
    });
  }

  componentWillUnmount() {
    const { dispatch } = this.props;
    dispatch({
      type: 'dashboardAnalysis/clear',
    });
    cancelAnimationFrame(this.reqRef);
    clearTimeout(this.timeoutId);
  }
  getAllMsg = () => {
    const { dispatch } = this.props;
    dispatch({
      type: 'dashboardAnalysis/schoolStudentNum',
      payload: {
        districtCode: this.state.codeNum,
        xxbxlx: "-1"
      }
    });
    dispatch({
      type: 'dashboardAnalysis/schoolTeacherNum',
      payload: {
        districtCode: this.state.codeNum,
        xxbxlx: "-1"
      }
    });

    if (this.props.match.params.num) {
      dispatch({
        type: 'dashboardAnalysis/unitTeacherNum',
        payload: {
          districtCode: this.state.codeNum,
          directly: 1,
        }
      });
      dispatch({
        type: 'dashboardAnalysis/baseInfo',
        payload: {
          districtCode: this.state.codeNum,
          directly: 1,
        }
      });
      dispatch({
        type: 'dashboardAnalysis/baseRanking',
        payload: {
          areaCode: this.state.codeNum,
          topNum: "10",
          directly: 1,
        }
      });
      dispatch({
        type: 'dashboardAnalysis/getStudentNum',
        payload: {
          areaCode: this.state.codeNum,
          directly: 1,
        }
      });
      dispatch({
        type: 'dashboardAnalysis/getTeacherNum',
        payload: {
          areaCode: this.state.codeNum,
          directly: 1,
        }
      });
    } else {
      dispatch({
        type: 'dashboardAnalysis/unitTeacherNum',
        payload: {
          districtCode: this.state.codeNum,
        }
      });
      dispatch({
        type: 'dashboardAnalysis/baseInfo',
        payload: {
          districtCode: this.state.codeNum
        }
      });
      dispatch({
        type: 'dashboardAnalysis/baseRanking',
        payload: {
          areaCode: this.state.codeNum,
          topNum: "10"
        }
      });
      dispatch({
        type: 'dashboardAnalysis/getStudentNum',
        payload: {
          areaCode: this.state.codeNum,
        }
      });
      dispatch({
        type: 'dashboardAnalysis/getTeacherNum',
        payload: {
          areaCode: this.state.codeNum,
        }
      });
    }
  }

  handleChangeSalesType = (e: RadioChangeEvent) => {
    this.setState({
      salesType: e.target.value,
    });
  };

  handleTabChange = (key: string) => {
    this.setState({
      currentTabKey: key,
    });
  };

  handleRangePickerChange = (rangePickerValue: RangePickerValue) => {
    const { dispatch } = this.props;
    this.setState({
      rangePickerValue,
    });

    dispatch({
      type: 'dashboardAnalysis/fetchSalesData',
    });
  };

  selectDate = (type: 'today' | 'week' | 'month' | 'year') => {
    const { dispatch } = this.props;
    this.setState({
      rangePickerValue: getTimeDistance(type),
    });

    dispatch({
      type: 'dashboardAnalysis/fetchSalesData',
    });
  };

  isActive = (type: 'today' | 'week' | 'month' | 'year') => {
    const { rangePickerValue } = this.state;
    const value = getTimeDistance(type);
    if (!rangePickerValue[0] || !rangePickerValue[1]) {
      return '';
    }
    if (
      rangePickerValue[0].isSame(value[0], 'day') &&
      rangePickerValue[1].isSame(value[1], 'day')
    ) {
      return styles.currentDate;
    }
    return '';
  };

  render() {
    const { rangePickerValue, salesType, currentTabKey } = this.state;
    const { dashboardAnalysis, loading } = this.props;
    const {
      schoolStudentList,
      schoolTeacherList,
      unitTeacherList,
      studentList,
      teacherList,
      baseInfo,
      baseRanking,
    } = dashboardAnalysis;
    // console.log(this.props, "1111111111111")
    return (
      <PageHeaderWrapper
      >
        < Row >
          <Col sm={24} style={{ fontSize: "16px", marginBottom: "20px" }}>
            <Icon type="environment" style={{ color: "#1890ff", marginRight: "20px" }} />
            {this.props.location.query.area_name ? this.props.location.query.area_name : this.state.companyName}
          </Col>
        </Row >
        <GridContent>
          <React.Fragment>
            {this.props.match.params.code ? <Button type="primary" onClick={() => { window.history.back() }} style={{ position: "absolute", top: "40px", right: "0px" }}>返回</Button> : ""}
            <Suspense fallback={<PageLoading />}>
              <IntroduceRow loading={loading} visitData={baseInfo} />
            </Suspense>
            <Suspense fallback={null}>
              {/* 柱状图 */}
              <SalesCard
                code={this.state.codeNum}
                rangePickerValue={rangePickerValue}
                schoolStudentList={schoolStudentList}
                schoolTeacherList={schoolTeacherList}
                unitTeacherList={unitTeacherList}
                baseRanking={baseRanking}
                props={this.props}
                isActive={this.isActive}
                handleRangePickerChange={this.handleRangePickerChange}
                loading={loading}
              />
            </Suspense>
            <Row
              gutter={24}
              type="flex"
              style={{
                marginTop: 24,
              }}
            >
              {/* 饼状图 */}
              <Col xl={12} lg={24} md={24} sm={24} xs={24}>
                <Suspense fallback={null}>
                  <ProportionSalesStudent
                    dropdownGroup={null}
                    salesType={salesType}
                    loading={loading}
                    studentList={studentList}
                    handleChangeSalesType={this.handleChangeSalesType}
                  />
                </Suspense>
              </Col>
              {/* 饼状图 */}
              <Col xl={12} lg={24} md={24} sm={24} xs={24}>
                <Suspense fallback={null}>
                  <ProportionSalesTeacher
                    dropdownGroup={null}
                    salesType={salesType}
                    loading={loading}
                    salesPieData={teacherList}
                    handleChangeSalesType={this.handleChangeSalesType}
                  />
                </Suspense>
              </Col>
            </Row>
            {/* <Suspense fallback={null}>
            <OfflineData
              activeKey={activeKey}
              loading={loading}
              offlineData={offlineData}
              offlineChartData={offlineChartData}
              handleTabChange={this.handleTabChange}
            />
          </Suspense> */}
          </React.Fragment>
        </GridContent>
      </PageHeaderWrapper>
    );
  }
}

export default Analysis;
