import { AnyAction, Reducer } from 'redux';

import { EffectsCommandMap } from 'dva';
import { AnalysisData } from './data.d';
import { GetSchoolStudentNum, GetSchoolTeacherNum, GetUnitTeacherNum, GetStudentNum, GetTeacherNum, GetBaseInfo, GetBaseRanking, GetStageInfo, GetPersonMsg } from './service';
import { useCallback } from 'react';

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: AnalysisData) => T) => T },
) => void;

export interface ModelType {
  namespace: string;
  state: AnalysisData;
  effects: {
    schoolStudentNum: Effect;
    schoolTeacherNum: Effect;
    unitTeacherNum: Effect;
    getStudentNum: Effect;
    getTeacherNum: Effect;
    baseInfo: Effect;
    baseRanking: Effect;
    stageInfo: Effect;
    getPersonMsg: Effect;
  };
  reducers: {
    save: Reducer<AnalysisData>;
    clear: Reducer<AnalysisData>;
  };
}

const initState = {
  schoolStudentList: [],
  schoolTeacherList: [],
  unitTeacherList: [],
  studentList: [],
  teacherList: [],
  baseInfo: [],
  baseRanking: [],
};

const Model: ModelType = {
  namespace: 'dashboardAnalysis',

  state: initState,

  effects: {
    *schoolStudentNum({ payload }, { call, put }) {
      const response = yield call(GetSchoolStudentNum, payload);
      yield put({
        type: 'save',
        payload: {
          schoolStudentList: response.list,
        },
      });
    },
    *schoolTeacherNum({ payload }, { call, put }) {
      const response = yield call(GetSchoolTeacherNum, payload);
      yield put({
        type: 'save',
        payload: {
          schoolTeacherList: response.list,
        },
      });
    },
    *unitTeacherNum({ payload }, { call, put }) {
      const response = yield call(GetUnitTeacherNum, payload);
      yield put({
        type: 'save',
        payload: {
          unitTeacherList: response.list,
        },
      });
    },
    *getTeacherNum({ payload }, { call, put }) {
      const response = yield call(GetTeacherNum, payload);
      yield put({
        type: 'save',
        payload: {
          teacherList: response.list,
        },
      });
    },
    *getStudentNum({ payload }, { call, put }) {
      const response = yield call(GetStudentNum, payload);
      yield put({
        type: 'save',
        payload: {
          studentList: response.list,
        },
      });
    },
    *baseInfo({ payload }, { call, put }) {
      const response = yield call(GetBaseInfo, payload);
      yield put({
        type: 'save',
        payload: {
          baseInfo: response.list,
        },
      });
    },
    *baseRanking({ payload }, { call, put }) {
      const response = yield call(GetBaseRanking, payload);
      yield put({
        type: 'save',
        payload: {
          baseRanking: response.list,
        },
      });
    },
    *stageInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetStageInfo, payload);
      if (callback) callback(response)
    },
    // 获取人员角色信息
    *getPersonMsg({ payload, callback }, { call, put }) {
      const response = yield call(GetPersonMsg, payload);
      if (callback) callback(response);
    },
  },

  reducers: {
    save(state, { payload }) {
      return {
        ...state,
        ...payload,
      };
    },
    clear() {
      return initState;
    },
  },
};

export default Model;
