import { Card, Col, DatePicker, Row, Tabs } from 'antd';
import { FormattedMessage, formatMessage } from 'umi-plugin-react/locale';

import { RangePickerValue } from 'antd/es/date-picker/interface';
import React from 'react';
import numeral from 'numeral';
import { VisitDataType } from '../data';
import { BarTeacher, Pie } from './Charts';
import styles from '../style.less';

const { RangePicker } = DatePicker;
const { TabPane } = Tabs;

const rankingListData: { title: string; total: number }[] = [];
for (let i = 0; i < 10; i += 1) {
  rankingListData.push({
    title: formatMessage({ id: 'dashboard-analysis.analysis.test' }, { no: i }),
    total: 323234,
  });
}

const SalesCard = ({
  rangePickerValue,
  teacherList,
  teacherSexNum,
  isActive,
  handleRangePickerChange,
  loading,
  selectDate,
}: {
  rangePickerValue: RangePickerValue;
  isActive: (key: 'today' | 'week' | 'month' | 'year') => string;
  teacherList: VisitDataType[];
  teacherSexNum: VisitDataType[];
  loading: boolean;
  handleRangePickerChange: (dates: RangePickerValue, dateStrings: [string, string]) => void;
  selectDate: (key: 'today' | 'week' | 'month' | 'year') => void;
}) => (
    <Card loading={loading} bordered={false} bodyStyle={{ padding: 0 }}>
      <div className={styles.salesCard}>
        <Tabs
          tabBarExtraContent={null}
          size="large"
          tabBarStyle={{ marginBottom: 24 }}
        >
          <TabPane
            tab={"教师数量"}
            key="student"
          >
            <Row type="flex">
              <Col xl={14} lg={12} md={12} sm={24} xs={24}>
                <div className={styles.salesBar}>
                  <BarTeacher
                    height={350}
                    title={null}
                    data={teacherList}
                  />
                </div>
              </Col>
              <Col xl={10} lg={12} md={12} sm={24} xs={24}>
                <div className={styles.salesRank}>
                  <h4 className={styles.rankingTitle}>
                    教师男女比例
                    {/* <FormattedMessage
                      id="dashboard-analysis.analysis.sales-ranking"
                      defaultMessage="Sales Ranking"
                    /> */}
                  </h4>
                  <div>
                    <Pie
                      hasLegend
                      // subTitle={<FormattedMessage id="dashboard-analysis.analysis.sales" defaultMessage="Sales" />}
                      // total={() => <Yuan>{salesPieData.reduce((pre, now) => now.y + pre, 0)}</Yuan>}
                      data={teacherSexNum}
                      valueFormat={value => <span>{value}</span>}
                      height={300}
                      lineWidth={4}
                    />
                  </div>

                </div>
              </Col>
            </Row>
          </TabPane>
        </Tabs>
      </div>
    </Card>
  );

export default SalesCard;
