
import React, { Component, Suspense } from 'react';
import { Button, Row, Col, Icon } from 'antd';

import { Dispatch } from 'redux';
import { GridContent } from '@ant-design/pro-layout';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { RadioChangeEvent } from 'antd/es/radio';
import { RangePickerValue } from 'antd/es/date-picker/interface';
import { connect } from 'dva';
import PageLoading from './components/PageLoading';
import { getTimeDistance } from './utils/utils';
import { AnalysisData } from './data.d';
import styles from './style.less';

const IntroduceRow = React.lazy(() => import('./components/IntroduceRow'));
const SalesCard = React.lazy(() => import('./components/SalesCard'));
const SalesCardTeacher = React.lazy(() => import('./components/SalesCardTeacher'));
// const TopSearch = React.lazy(() => import('./components/TopSearch'));
// const OfflineData = React.lazy(() => import('./components/OfflineData'));

interface AnalysisProps {
  dashboardMonitor: AnalysisData;
  dispatch: Dispatch<any>;
  loading: boolean;
  schoolPeriod: [];
}

interface AnalysisState {
  salesType: 'all' | 'online' | 'stores';
  currentTabKey: string;
  rangePickerValue: RangePickerValue;
  schoolPeriod: [];
  idNum: string;
  companyName: string;
}

@connect(
  ({
    dashboardMonitor,
    loading,
  }: {
    dashboardMonitor: any;
    loading: {
      effects: { [key: string]: boolean };
    };
  }) => ({
    dashboardMonitor,
    loading: loading.effects.dashboardMonitor,
  }),
)
class Analysis extends Component<
AnalysisProps,
AnalysisState
> {
  state: AnalysisState = {
    salesType: 'all',
    currentTabKey: '',
    rangePickerValue: getTimeDistance('year'),
    schoolPeriod: [],
    idNum: "",
    companyName: "",
  };

  reqRef: number = 0;

  timeoutId: number = 0;

  componentDidMount() {
    const { dispatch } = this.props;
    this.state.idNum = this.props.match.params.id ? this.props.match.params.id : "";
    this.reqRef = requestAnimationFrame(() => {
      if (this.props.match.params.id) {
        this.state.idNum = this.props.match.params.id;
        this.getAllMsg()
      } else {
        dispatch({
          type: 'dashboardWorkplace/getPersonRoleInfo',
          callback: (response: any) => {
            this.state.idNum = response.list[0].rule_id;
            this.state.companyName = response.list[0].rule_name;
            this.getAllMsg()
          }
        })
      }
    });
  }

  componentWillUnmount() {
    const { dispatch } = this.props;
    dispatch({
      type: 'dashboardMonitor/clear',
    });
    cancelAnimationFrame(this.reqRef);
    clearTimeout(this.timeoutId);
  }
  getAllMsg = () => {
    const { dispatch } = this.props;
    dispatch({
      type: 'dashboardMonitor/getBaseInfo',
      payload: {
        schoolId: this.state.idNum,
      }
    });
    dispatch({
      type: 'dashboardMonitor/getSchoolPeriod',
      payload: {
        schoolId: this.state.idNum,
      },
      callback: (response: any) => {
        this.setState({ schoolPeriod: response })
        response.map((item: any) => {
          dispatch({
            type: 'dashboardMonitor/getStudentNum',
            payload: {
              schoolId: this.state.idNum,
              stageId: item.stage_id
            }
          });
        })
      }
    });

    dispatch({
      type: 'dashboardMonitor/getTeacherNum',
      payload: {
        schoolId: this.state.idNum,
      }
    });
    dispatch({
      type: 'dashboardMonitor/getStudentSexNum',
      payload: {
        schoolId: this.state.idNum,
      }
    });
    dispatch({
      type: 'dashboardMonitor/getTeacherSexNum',
      payload: {
        schoolId: this.state.idNum,
      }
    });
  }
  handleChangeSalesType = (e: RadioChangeEvent) => {
    this.setState({
      salesType: e.target.value,
    });
  };

  handleTabChange = (key: string) => {
    this.setState({
      currentTabKey: key,
    });
  };

  handleRangePickerChange = (rangePickerValue: RangePickerValue) => {
    const { dispatch } = this.props;
    this.setState({
      rangePickerValue,
    });

    dispatch({
      type: 'dashboardMonitor/fetchSalesData',
    });
  };

  selectDate = (type: 'today' | 'week' | 'month' | 'year') => {
    const { dispatch } = this.props;
    this.setState({
      rangePickerValue: getTimeDistance(type),
    });

    dispatch({
      type: 'dashboardMonitor/fetchSalesData',
    });
  };

  isActive = (type: 'today' | 'week' | 'month' | 'year') => {
    const { rangePickerValue } = this.state;
    const value = getTimeDistance(type);
    if (!rangePickerValue[0] || !rangePickerValue[1]) {
      return '';
    }
    if (
      rangePickerValue[0].isSame(value[0], 'day') &&
      rangePickerValue[1].isSame(value[1], 'day')
    ) {
      return styles.currentDate;
    }
    return '';
  };

  render() {
    const { rangePickerValue, salesType, currentTabKey } = this.state;
    const { dashboardMonitor, loading } = this.props;
    const {
      studentListSmall,
      studentListMiddle,
      studentListHigh,
      teacherList,
      baseInfo,
      teacherSexNum,
      studentSexNum,
    } = dashboardMonitor;
    // const activeKey = currentTabKey || (offlineData[0] && offlineData[0].name);
    return (
      <PageHeaderWrapper
      >
        < Row >
          <Col sm={24} style={{ fontSize: "16px", marginBottom: "20px" }}>
            <Icon type="environment" style={{ color: "#1890ff", marginRight: "20px" }} />
            {this.props.location.query.org_name ? this.props.location.query.org_name : this.state.companyName}
          </Col>
        </Row >
        <GridContent>
          <React.Fragment>
            {this.props.match.params.id ? <Button type="primary" onClick={() => { window.history.back() }} style={{ position: "absolute", top: "40px", right: "0px" }}>返回</Button> : ""}
            <Suspense fallback={<PageLoading />}>
              <IntroduceRow loading={loading} visitData={baseInfo} />
            </Suspense>
            <Suspense fallback={null}>
              {/* 柱状图 */}
              <SalesCard
                rangePickerValue={rangePickerValue}
                schoolPeriod={this.state.schoolPeriod}
                studentListSmall={studentListSmall}
                studentListMiddle={studentListMiddle}
                studentListHigh={studentListHigh}
                studentSexNum={studentSexNum}
                isActive={this.isActive}
                handleRangePickerChange={this.handleRangePickerChange}
                loading={loading}
                selectDate={this.selectDate}
              />
            </Suspense>
            <Suspense fallback={null}>
              {/* 柱状图 */}
              <SalesCardTeacher
                rangePickerValue={rangePickerValue}
                teacherList={teacherList}
                teacherSexNum={teacherSexNum}
                isActive={this.isActive}
                handleRangePickerChange={this.handleRangePickerChange}
                loading={loading}
                selectDate={this.selectDate}
              />
            </Suspense>
          </React.Fragment>
        </GridContent>
      </PageHeaderWrapper>
    );
  }
}

export default Analysis;
