import { AnyAction, Reducer } from 'redux';

import { EffectsCommandMap } from 'dva';
import { AnalysisData } from './data.d';
import { GetBaseInfo, GetSchoolPeriod, GetStudentNum, GetTeacherNum, GetTeacherSexNum, GetStudentSexNum, GetPersonRoleInfo } from './service';

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: AnalysisData) => T) => T },
) => void;


export interface ModelType {
  namespace: string;
  state: AnalysisData;
  effects: {
    getSchoolPeriod: Effect;
    getStudentNum: Effect;
    getTeacherNum: Effect;
    getBaseInfo: Effect;
    getStudentSexNum: Effect;
    getTeacherSexNum: Effect;
    getPersonRoleInfo: Effect;
  };
  reducers: {
    save: Reducer<AnalysisData>;
    clear: Reducer<AnalysisData>;
  };
}

const initState = {
  schoolPeriod: [],
  studentListSmall: [],
  studentListMiddle: [],
  studentListHigh: [],
  teacherList: [],
  baseInfo: [],
  teacherSexNum: [],
  studentSexNum: [],
};

const Model: ModelType = {
  namespace: 'dashboardMonitor',

  state: initState,

  effects: {
    *getSchoolPeriod({ payload, callback }, { call, put }) {
      const response = yield call(GetSchoolPeriod, payload);
      yield put({
        type: 'save',
        payload: {
          getSchoolPeriod: response.list,
        },
      });
      if (callback) callback(response.list);
    },
    *getStudentNum({ payload }, { call, put }) {
      const response = yield call(GetStudentNum, payload);
      if (payload.stageId === "2") {
        yield put({
          type: 'save',
          payload: {
            studentListSmall: response.list,
          },
        });
      } else if (payload.stageId === "3") {
        yield put({
          type: 'save',
          payload: {
            studentListMiddle: response.list,
          },
        });
      } else {
        yield put({
          type: 'save',
          payload: {
            studentListHigh: response.list,
          },
        });
      }

    },
    *getTeacherNum({ payload }, { call, put }) {
      const response = yield call(GetTeacherNum, payload);
      yield put({
        type: 'save',
        payload: {
          teacherList: response.list,
        },
      });
    },
    *getBaseInfo({ payload }, { call, put }) {
      const response = yield call(GetBaseInfo, payload);
      yield put({
        type: 'save',
        payload: {
          baseInfo: response.list,
        },
      });
    },
    *getTeacherSexNum({ payload }, { call, put }) {
      const response = yield call(GetTeacherSexNum, payload);
      yield put({
        type: 'save',
        payload: {
          teacherSexNum: response.list,
        },
      });
    },
    *getStudentSexNum({ payload }, { call, put }) {
      const response = yield call(GetStudentSexNum, payload);
      yield put({
        type: 'save',
        payload: {
          studentSexNum: response.list,
        },
      });
    },
    *getPersonRoleInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetPersonRoleInfo, payload);
      if (callback) callback(response);
    },
  },

  reducers: {
    save(state, { payload }) {
      return {
        ...state,
        ...payload,
      };
    },
    clear() {
      return initState;
    },
  },
};

export default Model;
