import { Axis, Chart, Geom, Tooltip } from 'bizcharts';
import React, { Component } from 'react';

import Debounce from 'lodash.debounce';
import autoHeight from '../autoHeight';
import styles from '../index.less';
// import Link from 'umi/link';

export interface BarProps {
  title: React.ReactNode;
  color?: string;
  padding?: [number, number, number, number];
  height?: number;
  data: {
    x: string;
    y: number;
  }[];
  forceFit?: boolean;
  autoLabel?: boolean;
  style?: React.CSSProperties;
  props: {};
  thisKey: string;
}

class Bar extends Component<
  BarProps,
  {
    autoHideXLabels: boolean;
    directly: number;
  }
  > {
  state = {
    autoHideXLabels: false,
    directly: 1,
  };

  root: HTMLDivElement | undefined = undefined;

  node: HTMLDivElement | undefined = undefined;

  resize = Debounce(() => {
    if (!this.node || !this.node.parentNode) {
      return;
    }
    const canvasWidth = (this.node.parentNode as HTMLDivElement).clientWidth;
    const { data = [], autoLabel = true } = this.props;
    if (!autoLabel) {
      return;
    }
    const minWidth = data.length * 30;
    const { autoHideXLabels } = this.state;

    if (canvasWidth <= minWidth) {
      if (!autoHideXLabels) {
        this.setState({
          autoHideXLabels: true,
        });
      }
    } else if (autoHideXLabels) {
      this.setState({
        autoHideXLabels: false,
      });
    }
  }, 500);

  componentDidMount() {
    window.addEventListener('resize', this.resize, { passive: true });
  }

  componentWillUnmount() {
    window.removeEventListener('resize', this.resize);
  }

  handleRoot = (n: HTMLDivElement) => {
    this.root = n;
  };

  handleRef = (n: HTMLDivElement) => {
    this.node = n;
  };

  render() {
    const {
      height = 1,
      title,
      forceFit = true,
      data,
      color = 'rgba(24, 144, 255, 0.85)',
      padding,
      thisKey,
    } = this.props;
    // console.log(thisKey, "111111111111111")
    const { autoHideXLabels } = this.state;
    var scale = {};
    if (data.length > 0) {
      var a = Math.max.apply(Math, data.map((item) => { return item.count }))
      if (a <= 2) {
        scale = {
          count: {
            min: 0,
            range: [
              0,
              1
            ],
            ticks: [
              0,
              1,
              2,
            ]
          }
        };
      } else {
        scale = {
          count: {
            min: 0,
            // tickCount: 5,
          }
        };
      }
    }

    const tooltip: [string, (...args: any[]) => { name?: string; value: string }] = [
      'area_name*count',
      (x: string, y: string) => ({
        name: x,
        value: y,
      }),
    ];

    return (
      <div className={styles.chart} style={{ height }} ref={this.handleRoot}>
        <div ref={this.handleRef}>
          {title && <h4 style={{ marginBottom: 20 }}>{title}</h4>}
          <Chart
            scale={scale}
            height={title ? height - 41 : height}
            forceFit={forceFit}
            data={data}
            padding={padding || 'auto'}
            onClick={(views: any) => {
              if (views) {
                const { _origin } = views.data;
                // console.log(_origin, "5555555555")
                if (_origin.area_code.substring(_origin.area_code.length - 2) === "00") {
                  window.location.href = `#/dashboard/workplace/analysis/${_origin.area_code}/${this.state.directly}?thisKey=` + thisKey + `&area_name=` + _origin.area_name;
                } else {
                  window.location.href = `#/dashboard/workplace/analysis/${_origin.area_code}?thisKey=` + thisKey + `&area_name=` + _origin.area_name;
                }
              }
            }}
          >
            <Axis
              name="area_name"
              title={false}
              label={autoHideXLabels ? undefined : {}}
              tickLine={autoHideXLabels ? undefined : {}}
            />
            <Axis name="count" min={1} />
            <Tooltip showTitle={false} crosshairs={false} />
            <Geom type="interval" position="area_name*count" color={color} tooltip={tooltip} style={{ cursor: "pointer" }} />
          </Chart>
        </div>
      </div >
    );
  }
}

export default autoHeight()(Bar);
