import { Card, Col, DatePicker, Row, Tabs } from 'antd';
import { FormattedMessage, formatMessage } from 'umi-plugin-react/locale';

import { RangePickerValue } from 'antd/es/date-picker/interface';
import React from 'react';
import numeral from 'numeral';
import { schoolList } from '../data.d';
import { Bar } from './Charts';
import styles from '../style.less';

const { RangePicker } = DatePicker;
const { TabPane } = Tabs;

const SalesCard = ({
  rangePickerValue,
  schoolList,
  newSchoolList,
  educationalList,
  newEducationalList,
  baseRanking,
  handleRangePickerChange,
  loading,
  props,
  selectDate,
}: {
  rangePickerValue: RangePickerValue;
  schoolList: schoolList[];
  newSchoolList: schoolList[];
  educationalList: schoolList[];
  newEducationalList: schoolList[];
  baseRanking: schoolList[];
  loading: boolean;
  props: {};
  handleRangePickerChange: (dates: RangePickerValue, dateStrings: [string, string]) => void;
  selectDate: (key: 'today' | 'week' | 'month' | 'year') => void;
}) => (
    <Card loading={loading} bordered={false} bodyStyle={{ padding: 0 }}>
      <div className={styles.salesCard}>
        <Row type="flex">
          <Col xl={16} lg={12} md={12} sm={24} xs={24}>
            <Tabs
              tabBarExtraContent={null}
              size="large"
              tabBarStyle={{ marginBottom: 24 }}

            >
              <TabPane
                tab={"县市区学校数量"}
                key="schoolNum"
              >
                <Row type="flex">
                  <Col xl={24} lg={24} md={24} sm={24} xs={24}>
                    <div className={styles.salesBar}>
                      <Bar
                        thisKey="schoolNum"
                        props={props}
                        height={400}
                        title={null}
                        data={schoolList}
                      />
                    </div>
                  </Col>
                </Row>
              </TabPane>
              <TabPane
                tab={"开发区学校数量"}
                key="schoolNumber"
              >
                <Row>
                  <Col xl={24} lg={24} md={24} sm={24} xs={24}>
                    <div className={styles.salesBar}>
                      <Bar
                        thisKey="schoolNumber"
                        props={props}
                        height={400}
                        title={null}
                        data={newSchoolList}
                      />
                    </div>
                  </Col>
                </Row>
              </TabPane>
              <TabPane
                tab={"县市区教辅单位数量"}
                key="unitNum"
              >
                <Row>
                  <Col xl={24} lg={24} md={24} sm={24} xs={24}>
                    <div className={styles.salesBar}>
                      <Bar
                        props={props}
                        thisKey="unitNum"
                        height={400}
                        title={null}
                        data={educationalList}
                      />
                    </div>
                  </Col>
                </Row>
              </TabPane>
              <TabPane
                tab={"开发区教辅单位数量"}
                key="unitNumber"
              >
                <Row>
                  <Col xl={24} lg={24} md={24} sm={24} xs={24}>
                    <div className={styles.salesBar}>
                      <Bar
                        thisKey="unitNumber"
                        props={props}
                        height={400}
                        title={null}
                        data={newEducationalList}
                      />
                    </div>
                  </Col>
                </Row>
              </TabPane>
            </Tabs>
          </Col>
          <Col xl={8} lg={12} md={12} sm={24} xs={24}>
            <div className={styles.salesRank} style={{ padding: "36px 24px" }}>
              <h4 className={styles.rankingTitle}>
                基础数据访问排名
                  </h4>
              <ul className={styles.rankingList}>
                {baseRanking.length > 0 ? baseRanking.map((item, i) => (
                  <li key={item.org_name}>
                    <span className={`${styles.rankingItemNumber} ${i < 3 ? styles.active : ''}`}>
                      {i + 1}
                    </span>
                    <span className={styles.rankingItemTitle} title={item.org_name}>
                      {item.org_name}
                    </span>
                    <span className={styles.rankingItemValue}>
                      {numeral(item.count).format('0,0')}
                    </span>
                  </li>
                )) : <div style={{ width: "100%", textAlign: "center", fontSize: "18px", marginTop: "20px" }}>暂无数据</div>}
              </ul>
            </div>
          </Col>
        </Row>
      </div>
    </Card>
  );

export default SalesCard;
