import { Col, Dropdown, Icon, Menu, Row } from 'antd';
import React, { Component, Suspense } from 'react';

import { Dispatch } from 'redux';
import { GridContent } from '@ant-design/pro-layout';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { RadioChangeEvent } from 'antd/es/radio';
import { RangePickerValue } from 'antd/es/date-picker/interface';
import { connect } from 'dva';
import PageLoading from './components/PageLoading';
import { getTimeDistance } from './utils/utils';
import { Workplaces } from './data.d';
import styles from './style.less';

const IntroduceRow = React.lazy(() => import('./components/IntroduceRow'));
const SalesCard = React.lazy(() => import('./components/SalesCard'));
// const TopSearch = React.lazy(() => import('./components/TopSearch'));
const ProportionSalesStudent = React.lazy(() => import('./components/ProportionSalesStudent'));
const ProportionSalesTeacher = React.lazy(() => import('./components/ProportionSalesTeacher'));
// const OfflineData = React.lazy(() => import('./components/OfflineData'));

interface WorkplaceProps {
  dashboardWorkplace: Workplaces;
  dispatch: Dispatch<any>;
  loading: boolean;
}

interface WorkplaceState {
  salesTeacherType: 'all' | 'online' | 'stores';
  salesStudentType: 'all' | 'online' | 'stores';
  currentTabKey: string;
  rangePickerValue: RangePickerValue;
  codeNum: string;
  companyName: "";
}

@connect(
  ({
    dashboardWorkplace,
    loading,
  }: {
    dashboardWorkplace: any;
    loading: {
      effects: { [key: string]: boolean };
    };
  }) => ({
    dashboardWorkplace,
    loading: loading.effects.dashboardWorkplace,
  }),
)
class Workplace extends Component<
WorkplaceProps,
WorkplaceState
> {
  state: WorkplaceState = {
    salesTeacherType: 'all',
    salesStudentType: 'all',
    currentTabKey: '',
    rangePickerValue: getTimeDistance('year'),
    codeNum: "",
    companyName: "",
  };

  reqRef: number = 0;

  timeoutId: number = 0;

  componentDidMount() {
    const { dispatch } = this.props;
    this.reqRef = requestAnimationFrame(() => {
      dispatch({
        type: 'dashboardWorkplace/getPersonRoleInfo',
        callback: (response: any) => {
          // this.setState({ codeNum: response.list[0].rule_id });

          if (response.list[0].role_id === "A66C757C-F797-454D-99DE-2A3F5415BC22") {
            this.state.codeNum = "220100";
            this.getAllMsg()
          } else {
            this.state.codeNum = response.list[0].rule_id;
            this.state.companyName = response.list[0].rule_name;
            this.getAllMsg()
          }
        },
      });
    });
  }

  componentWillUnmount() {
    const { dispatch } = this.props;
    dispatch({
      type: 'dashboardWorkplace/clear',
    });
    cancelAnimationFrame(this.reqRef);
    clearTimeout(this.timeoutId);
  }
  getAllMsg = () => {
    const { dispatch } = this.props;
    // 县区市学校数量
    dispatch({
      type: 'dashboardWorkplace/getSchoolNum',
      payload: {
        areaType: "1",
        cityCode: this.state.codeNum,
        xxbxlx: '0'
      },
    });
    // 开发区学校数量
    dispatch({
      type: 'dashboardWorkplace/getSchoolNum',
      payload: {
        areaType: "2",
        cityCode: this.state.codeNum,
        xxbxlx: '0'
      },
    });
    // 县区市教辅单位数量
    dispatch({
      type: 'dashboardWorkplace/getEducationalNum',
      payload: {
        areaType: "1",
        cityCode: this.state.codeNum,
      },
    });
    // 开发区教辅单位数量
    dispatch({
      type: 'dashboardWorkplace/getEducationalNum',
      payload: {
        areaType: "2",
        cityCode: this.state.codeNum,
      },
    });

    dispatch({
      type: 'dashboardWorkplace/getStudentNum',
      payload: {
        areaCode: this.state.codeNum,
      },
    });
    dispatch({
      type: 'dashboardWorkplace/getTeacherNum',
      payload: {
        areaCode: this.state.codeNum,
      },
    });
    dispatch({
      type: 'dashboardWorkplace/getBaseInfo',
      payload: {
        cityCode: this.state.codeNum,
      },
    });
    dispatch({
      type: 'dashboardWorkplace/getBaseRanking',
      payload: {
        areaCode: this.state.codeNum,
        topNum: "10"
      },
    });
  }

  handleChangeSalesType = (e: RadioChangeEvent) => {
    this.setState({
      salesTeacherType: e.target.value,
    });
  };

  handleTabChange = (key: string) => {
    this.setState({
      currentTabKey: key,
    });
  };

  handleRangePickerChange = (rangePickerValue: RangePickerValue) => {
    const { dispatch } = this.props;
    this.setState({
      rangePickerValue,
    });

    dispatch({
      type: 'dashboardWorkplace/fetchSalesData',
    });
  };

  selectDate = (type: 'today' | 'week' | 'month' | 'year') => {
    const { dispatch } = this.props;
    this.setState({
      rangePickerValue: getTimeDistance(type),
    });

    dispatch({
      type: 'dashboardWorkplace/fetchSalesData',
    });
  };

  render() {
    const { rangePickerValue, salesStudentType, salesTeacherType, currentTabKey } = this.state;
    const { dashboardWorkplace, loading } = this.props;
    const {
      schoolList,
      newSchoolList,
      educationalList,
      newEducationalList,
      studentList,
      teacherList,
      baseInfo,
      baseRanking
    } = dashboardWorkplace;
    // console.log(this.props)

    return (
      <PageHeaderWrapper
      >
        < Row >
          <Col sm={24} style={{ fontSize: "16px", marginBottom: "20px" }}>
            <Icon type="environment" style={{ color: "#1890ff", marginRight: "20px" }} />
            {this.state.codeNum === "220100" ? "长春市" : this.state.companyName}
          </Col>
        </Row >
        <GridContent>
          <React.Fragment>
            <Suspense fallback={<PageLoading />}>
              <IntroduceRow loading={loading} visitData={baseInfo} />
            </Suspense>
            <Suspense fallback={null}>
              {/* 柱状图 */}
              <SalesCard
                props={this.props}
                rangePickerValue={rangePickerValue}
                schoolList={schoolList}
                newSchoolList={newSchoolList}
                educationalList={educationalList}
                newEducationalList={newEducationalList}
                baseRanking={baseRanking}
                handleRangePickerChange={this.handleRangePickerChange}
                loading={loading}
                selectDate={this.selectDate}
              />
            </Suspense>
            <Row
              gutter={24}
              type="flex"
              style={{
                marginTop: 24,
              }}
            >
              {/* 饼状图 */}
              <Col xl={12} lg={24} md={24} sm={24} xs={24}>
                <Suspense fallback={null}>
                  <ProportionSalesStudent
                    dropdownGroup={null}
                    salesType={salesStudentType}
                    loading={loading}
                    salesPieData={studentList}
                    handleChangeSalesType={this.handleChangeSalesType}
                  />
                </Suspense>
              </Col>
              {/* 饼状图 */}
              <Col xl={12} lg={24} md={24} sm={24} xs={24}>
                <Suspense fallback={null}>
                  <ProportionSalesTeacher
                    dropdownGroup={null}
                    salesType={salesTeacherType}
                    loading={loading}
                    salesPieData={teacherList}
                    handleChangeSalesType={this.handleChangeSalesType}
                  />
                </Suspense>
              </Col>
            </Row>
            {/* <Suspense fallback={null}>
            <OfflineData
              activeKey={activeKey}
              loading={loading}
              offlineData={offlineData}
              offlineChartData={offlineChartData}
              handleTabChange={this.handleTabChange}
            />
          </Suspense> */}
          </React.Fragment>
        </GridContent>
      </PageHeaderWrapper>
    );
  }
}

export default Workplace;
