import { AnyAction, Reducer } from 'redux';

import { EffectsCommandMap } from 'dva';
import { Workplaces } from './data.d';
import { GetSchoolNum, GetEducationalNum, GetStudentNum, GetTeacherNum, GetBaseInfo, GetBaseRanking, GetPersonRoleInfo } from './service';

export interface StateType {
  data: Workplaces;
}

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: Workplaces) => T) => T },
) => void;

export interface ModelType {
  namespace: string;
  state: Workplaces;
  effects: {
    getSchoolNum: Effect;
    getEducationalNum: Effect;
    getStudentNum: Effect;
    getTeacherNum: Effect;
    getBaseInfo: Effect;
    getBaseRanking: Effect;
    getPersonRoleInfo: Effect;
  };
  reducers: {
    save: Reducer<Workplaces>;
    // saveSchoolone: Reducer<Workplaces>;
    // saveSchooltwo: Reducer<Workplaces>;
    // saveEduOne: Reducer<Workplaces>;
    // saveEdutwo: Reducer<Workplaces>;
    clear: Reducer<Workplaces>;
  };
}

const initState = {
  schoolList: [],
  newSchoolList: [],
  educationalList: [],
  newEducationalList: [],
  studentList: [],
  teacherList: [],
  baseInfo: [],
  baseRanking: [],
};

const Model: ModelType = {
  namespace: 'dashboardWorkplace',

  state: initState,

  effects: {
    *getSchoolNum({ payload }, { call, put }) {
      const response = yield call(GetSchoolNum, payload);
      if (payload.areaType === "1") {
        yield put({
          type: 'save',
          payload: {
            schoolList: response.list,
          },
        });
      } else {
        yield put({
          type: 'save',
          payload: {
            newSchoolList: response.list,
          },
        });
      }
    },
    *getEducationalNum({ payload }, { call, put }) {
      const response = yield call(GetEducationalNum, payload);
      if (payload.areaType === "1") {
        yield put({
          type: 'save',
          payload: {
            educationalList: response.list,
          },
        });
      } else {
        yield put({
          type: 'save',
          payload: {
            newEducationalList: response.list,
          },
        });
      }
    },
    *getStudentNum({ payload }, { call, put }) {
      const response = yield call(GetStudentNum, payload);
      yield put({
        type: 'save',
        payload: {
          studentList: response.list,
        },
      });
    },
    *getTeacherNum({ payload }, { call, put }) {
      const response = yield call(GetTeacherNum, payload);
      yield put({
        type: 'save',
        payload: {
          teacherList: response.list,
        },
      });
    },
    *getBaseInfo({ payload }, { call, put }) {
      const response = yield call(GetBaseInfo, payload);
      yield put({
        type: 'save',
        payload: {
          baseInfo: response.list,
        },
      });
    },
    *getBaseRanking({ payload }, { call, put }) {
      const response = yield call(GetBaseRanking, payload);
      yield put({
        type: 'save',
        payload: {
          baseRanking: response.list,
        },
      });
    },
    *getPersonRoleInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetPersonRoleInfo, payload);
      if (callback) callback(response);
    },
  },

  reducers: {
    save(state, { payload }) {
      return {
        ...state,
        ...payload,
      };
    },
    // saveSchoolone(state, { payload }) {
    //   return {
    //     ...state,
    //     ...payload,
    //   };
    // },
    // saveSchooltwo(state, { payload }) {
    //   return {
    //     ...state,
    //     ...payload,
    //   };
    // },
    // saveEduOne(state, { payload }) {
    //   return {
    //     ...state,
    //     ...payload,
    //   };
    // },
    // saveEdutwo(state, { payload }) {
    //   return {
    //     ...state,
    //     ...payload,
    //   };
    // },
    clear() {
      return initState;
    },
  },
};

export default Model;
