import { Button, Card, Col, Divider, Form, Input, Popconfirm, Row, message, Table, Select } from 'antd';
import React, { Component, Fragment } from 'react';

import { Dispatch, Action } from 'redux';
import router from 'umi/router';
import { FormComponentProps } from 'antd/es/form';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { connect } from 'dva';
import { StateType } from './model';
import StandardTable, { StandardTableColumnProps } from './components/StandardTable';
import { FormValueType } from './components/UpdateForm';
import { TableListItem } from './data.d';


import styles from './style.less';
import UpdataEduInfo from './components/UpdataEduInfo';
const FormItem = Form.Item;
const { Option } = Select;
interface TableListProps extends FormComponentProps {
  dispatch: Dispatch<
    Action<
      | 'acquisitionMsg/EnableEduInfo'
    >
  >;
  loading: boolean;
  acquisitionMsg: StateType;
}

interface TableListState {
  modalVisible: boolean;
  updateModalVisible: boolean;
  expandForm: boolean;
  selectedRows: TableListItem[];
  formValues: { [key: string]: string };
  stepFormValues: Partial<TableListItem>;
  areaCode: string;
  codeArr: any;
  eduInfo: { [key: string]: string };
}

/* eslint react/no-multi-comp:0 */
@connect(
  ({
    acquisitionMsg,
    geographic,
    loading,
  }: {
    acquisitionMsg: StateType;
    geographic: StateType;
    loading: {
      models: {
        [key: string]: boolean;
      };
    };
  }) => ({
    acquisitionMsg,
    geographic,
    loading: loading.models.acquisitionMsg,
  }),
)
class TableList extends Component<TableListProps, TableListState> {
  state: TableListState = {
    modalVisible: false,
    updateModalVisible: false,
    expandForm: false,
    selectedRows: [],
    formValues: {},
    stepFormValues: {},
    areaCode: this.props.location.query.code1 ? this.props.location.query.code1 : '220100',
    codeArr: this.props.location.query.code ? [this.props.location.query.code, this.props.location.query.code1] : ["220000", "220100"],
    eduInfo: {},
  };
  columns: StandardTableColumnProps[] = [
    {
      title: '序号',
      dataIndex: 'index',
      // render(text, record, index) {
      //   return <span>{index + 1}</span>;
      // },
    },
    {
      title: '系统名称',
      dataIndex: 'system_name',
      key: 'system_name',
    },
    {
      title: '学期',
      dataIndex: 'school',
      key: 'school',
    },
    {
      title: '班级',
      dataIndex: 'class',
      key: 'class',
    },
    {
      title: '姓名',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: '数据1',
      dataIndex: 'msg1',
      key: 'msg1',
    },
    {
      title: '数据2',
      dataIndex: 'msg2',
      key: 'msg2',
    },
    // {
    //   title: '操作',
    //   width: 400,
    //   render: (text, record) => (
    //     <Fragment>
    //       <Popconfirm
    //         title={'是否确认禁用『' + record.org_name + '』？'}
    //         okText="确认"
    //         cancelText="取消"
    //         onConfirm={() => this.disableEdu(record.org_id)}
    //       >
    //         <a>禁用</a>
    //       </Popconfirm>
    //       <Divider type="vertical" />
    //       <a onClick={() => this.handleModalVisible(record.org_id, true)}>
    //         编辑
    //       </a>
    //     </Fragment>
    //   ),
    // },
  ];
  data = [
    {
      index: 1,
      system_name: "综合素质评价系统",
      school: "2019上学期",
      class: "2016级3班",
      name: "黎明",
      msg1: "数据A",
      msg2: "数据B"
    },
    {
      index: 2,
      system_name: "综合素质评价系统",
      school: "2019上学期",
      class: "2016级3班",
      name: "黎明",
      msg1: "数据A",
      msg2: "数据B"
    },
    {
      index: 3,
      system_name: "综合素质评价系统",
      school: "2019上学期",
      class: "2016级3班",
      name: "黎明",
      msg1: "数据A",
      msg2: "数据B"
    },
    {
      index: 4,
      system_name: "综合素质评价系统",
      school: "2019上学期",
      class: "2016级3班",
      name: "黎明",
      msg1: "数据A",
      msg2: "数据B"
    },
    {
      index: 5,
      system_name: "综合素质评价系统",
      school: "2019上学期",
      class: "2016级3班",
      name: "黎明",
      msg1: "数据A",
      msg2: "数据B"
    },
  ]
  componentDidMount() {
    // const areaCode = this.state.areaCode;
    // this.getEduList(areaCode);
  }

  // 获取列表
  getEduList(areaCode: string, orgName?: string) {
    const { dispatch } = this.props;
    dispatch({
      type: 'acquisitionMsg/EnableEduInfo',
      payload: {
        page: 1,
        limit: 99,
        areaCode: areaCode,
        orgName: orgName,
      },
    });
  }

  handleSearch = (e: React.FormEvent) => {
    e.preventDefault();
    const { form } = this.props;
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      const values = {
        ...fieldsValue,
      };
      this.setState({
        formValues: values,
      }, () => {
        this.getEduList(this.state.areaCode, values.org);
      });
    });
  };

  //下拉筛选
  handleSelect = (value: any) => {
    let code = value[value.length - 1]
    const { form } = this.props;
    form.resetFields();
    this.setState({ areaCode: code, formValues: {}, codeArr: value })
    this.getEduList(code);
  }


  renderSimpleForm() {
    const { form } = this.props;
    const { getFieldDecorator } = form;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={8} sm={24}>
            <FormItem label="学期">
              {getFieldDecorator('school')(<Select
                showSearch
                placeholder="请选择"
                optionFilterProp="children"
              // onChange={onChange}
              // onFocus={onFocus}
              // onBlur={onBlur}
              // onSearch={onSearch}
              // filterOption={(input, option) =>
              //   option.props.children.toLowerCase().indexOf(input.toLowerCase()) >= 0
              // }
              >
                <Option value="2019上学期">2019上学期</Option>
              </Select>)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="班级">
              {getFieldDecorator('class')(<Select
                showSearch
                placeholder="请选择"
                optionFilterProp="children"
              // onChange={onChange}
              // onFocus={onFocus}
              // onBlur={onBlur}
              // onSearch={onSearch}
              // filterOption={(input, option) =>
              //   option.props.children.toLowerCase().indexOf(input.toLowerCase()) >= 0
              // }
              >
                <Option value="2016级3班">2016级3班</Option>
              </Select>)}
            </FormItem>
          </Col>
          <Col md={4} sm={12}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              {/* <Button style={{ marginLeft: 8 }} onClick={this.handleFormReset}>
                重置
              </Button> */}
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  renderForm() {
    return this.renderSimpleForm();
  }

  render() {
    const {
      acquisitionMsg: { data },
      loading,
    } = this.props;

    const { selectedRows, modalVisible } = this.state;

    return (
      <PageHeaderWrapper>
        <Card bordered={false}>
          <div className={styles.tableList}>
            <div className={styles.tableListForm}>{this.renderForm()}</div>
            {/* <StandardTable
              rowSelection={false}
              rowKey={record => record.org_id}
              selectedRows={selectedRows}
              loading={loading}
              data={this.data}
              columns={this.columns}
            /> */}
            <Table columns={this.columns} dataSource={this.data} />
          </div>
        </Card>
      </PageHeaderWrapper>
    );
  }
}

export default Form.create<TableListProps>()(TableList);
