import { Form, Input, Modal, Cascader, Select, Radio, Icon, Switch } from 'antd';
import React, { useState } from 'react';
import { FormComponentProps } from 'antd/es/form';
import CascadeGeographic from '@/components/CascadeGeographic';

const { Option } = Select;
const FormItem = Form.Item;
interface CreateFormProps extends FormComponentProps {
  modalVisible: boolean;
  handleAdd: (fieldsValue: { desc: string }) => void;
  handleEdit: (fieldsValue: { desc: string }) => void;
  handleModalVisible: () => void;
  globalInfo: any;
  checkType: string;
}
const { TextArea } = Input;
const CreateForm: React.FC<CreateFormProps> = props => {
  const [isBatch, setisBatch] = useState("0")
  const { modalVisible, form, handleAdd, handleModalVisible, handleEdit, checkType, globalInfo } = props;
  const okHandle = () => {
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      // form.resetFields();
      if (checkType === "add") {
        handleAdd(fieldsValue);
      } else {
        handleEdit(fieldsValue);
      }

    });
  };
  return (
    <Modal
      destroyOnClose
      title="新增教育局"
      visible={modalVisible}
      onOk={okHandle}
      maskClosable={false}
      onCancel={() => handleModalVisible()}
      width="700px"
    >
      {/* 全局变量代码 */}
      <FormItem labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="全局变量代码">
        {form.getFieldDecorator('number', {
          initialValue: checkType === "add" ? "" : globalInfo.global_code,
          rules: [
            {
              pattern: new RegExp('^\\w+$', 'g'),
              message: '全局变量代码必须为字母或者数字',
            },
            {
              min: 2,
              max: 50,
              message: '长度不在范围内',
            },
            {
              required: true,
              message: '请输入2~50位字母和数字',
            },
          ]
        })(
          <Input maxLength={50} />
        )}
      </FormItem>
      {/* 全局变量值类型 */}
      <Form.Item labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="全局变量值类型">
        {form.getFieldDecorator('type', {
          initialValue: isBatch,
        })(
          <Radio.Group buttonStyle="solid" onChange={(e) => { setisBatch(e.target.value) }}>
            <Radio value="0">文本</Radio>
            <Radio value="1">文件</Radio>
          </Radio.Group>
        )}
      </Form.Item>
      {/* 全局变量值 */}
      {
        isBatch === "0" ? <FormItem labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="全局变量值">
          {form.getFieldDecorator('value', {
            initialValue: checkType === "add" ? "" : globalInfo.global_value,
            rules: [
              {
                min: 1,
                max: 225,
                message: '长度不在范围内',
              },
              {
                required: true,
                message: '请输入1~255位字母、汉字、数字、字符',
              },
            ]
          })(
            <Input maxLength={255} />
          )}
        </FormItem> : <FormItem labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="全局变量值">
            {form.getFieldDecorator('value', {
              initialValue: checkType === "add" ? "" : globalInfo.global_value,
              rules: [
                {
                  min: 1,
                  max: 225,
                  message: '长度不在范围内',
                },
                {
                  required: true,
                  message: '请输入1~255位字母、汉字、数字、字符',
                },
              ]
            })(
              <Input maxLength={255} />
            )}
          </FormItem>
      }


      {/* 全局变量备注 */}
      <Form.Item
        labelCol={{ span: 7 }}
        wrapperCol={{ span: 15 }}
        label="全局变量备注"
      >
        {form.getFieldDecorator('remarks', {
          initialValue: checkType === "add" ? "" : globalInfo.global_remarks,
          rules: [
            {
              min: 1,
              max: 500,
              message: '长度不在范围内',
            },
            {
              required: false,
              message: '请输入1~500位字母、汉字、数字、字符',
            },
          ]
        })(<TextArea allowClear maxLength={500} />)}
      </Form.Item>
    </Modal>
  );
};

export default Form.create<CreateFormProps>()(CreateForm);
