import { Button, Card, Col, Divider, Form, Input, Popconfirm, Row, message, Table, Select } from 'antd';
import React, { Component, Fragment } from 'react';

import { Dispatch, Action } from 'redux';
import { FormComponentProps } from 'antd/es/form';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { connect } from 'dva';
import { StateType } from './model';
import StandardTable, { StandardTableColumnProps } from './components/StandardTable';
import { TableListItem } from './data.d';


import styles from './style.less';
import CreateForm from './components/CreateForm';

interface TableListProps extends FormComponentProps {
  dispatch: Dispatch<
    Action<
      | 'globalInfoManagement/getGlobalList'
      | 'globalInfoManagement/getGlobalInfo'
      | 'globalInfoManagement/addGlobalInfo'
      | 'globalInfoManagement/editGlobalInfo'
      | 'globalInfoManagement/deleteGlobalInfo'
    >
  >;
  loading: boolean;
  globalInfoManagement: StateType;
}

interface TableListState {
  modalVisible: boolean;
  selectedRows: TableListItem[];
  formValues: { [key: string]: string };
  stepFormValues: Partial<TableListItem>;
  checkType: string;
  checkList: [];
  globalInfo: {};
}

/* eslint react/no-multi-comp:0 */
@connect(
  ({
    globalInfoManagement,
    geographic,
    loading,
  }: {
    globalInfoManagement: StateType;
    geographic: StateType;
    loading: {
      models: {
        [key: string]: boolean;
      };
    };
  }) => ({
    globalInfoManagement,
    geographic,
    loading: loading.models.globalInfoManagement,
  }),
)
class TableList extends Component<TableListProps, TableListState> {
  state: TableListState = {
    modalVisible: false,
    selectedRows: [],
    formValues: {},
    stepFormValues: {},
    checkType: "add",
    checkList: [],
    globalInfo: {},
  };
  columns: StandardTableColumnProps[] = [
    {
      title: '序号',
      dataIndex: 'index',
      render(text, record, index) {
        return <span>{index + 1}</span>;
      },
    },
    {
      title: '全局变量代码',
      dataIndex: 'global_code',
      key: 'global_code',
    },
    {
      title: '全局变量值',
      dataIndex: 'global_value',
      key: 'global_value',
    },
    {
      title: '全局变量备注',
      dataIndex: 'global_remarks',
      key: 'global_remarks',
    },
    {
      title: '操作',
      width: 400,
      render: (text, record) => (
        <Fragment>
          <a onClick={() => { this.setState({ modalVisible: true, checkType: "edit", globalInfo: record }) }}>
            编辑
          </a>
          <Divider type="vertical" />

          <Popconfirm
            title={'是否确认删除当前数据？'}
            okText="确认"
            cancelText="取消"
            onConfirm={() => this.handleDelete(text.global_id)}
          >
            <a style={{ color: "red" }}>删除</a>
          </Popconfirm>
        </Fragment>
      ),
    },
  ];
  // 新增
  handleAdd = (fieldsValue: any) => {
    // console.log(fieldsValue)
    const { dispatch } = this.props;
    dispatch({
      type: 'globalInfoManagement/addGlobalInfo',
      payload: {
        globalTypeId: 1,
        globalCode: fieldsValue.number,
        globalValue: fieldsValue.value,
        globalRemarks: fieldsValue.remarks,
        sortId: 1,
      },
      callback: (data: any) => {
        if (data.success) {
          message.success("保存成功");
          this.getEduList();
          this.handleModalVisible();
        } else {
          message.error("保存失败," + data.message)
        }
      }
    });
  }

  // 编辑
  handleEdit = (fieldsValue) => {
    // console.log(fieldsValue)
    const { dispatch } = this.props;
    dispatch({
      type: 'globalInfoManagement/editGlobalInfo',
      payload: {
        globalId: this.state.globalInfo.global_id,
        globalTypeId: 1,
        globalCode: fieldsValue.number,
        globalValue: fieldsValue.value,
        globalRemarks: fieldsValue.remarks,
        sortId: 1,
      },
      callback: (data: any) => {
        if (data.success) {
          message.success("保存成功");
          this.getEduList();
          this.handleModalVisible();
        } else {
          message.error("保存失败," + data.message)
        }
      }
    });
  }
  // 删除（单个）
  handleDelete = (ids: any) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'globalInfoManagement/deleteGlobalInfo',
      payload: {
        globalIds: ids,
      },
      callback: (data: any) => {
        if (data.success) {
          message.success("删除成功");
          this.getEduList();
        } else {
          message.error("删除失败," + data.message)
        }
      }
    });
  }
  // 批量
  handleMoreDelete = () => {
    let Ids = [];
    let global_ids = "";
    const { dispatch } = this.props;
    if (this.state.selectedRows.length > 0) {
      this.state.selectedRows.map((item: any) => {
        Ids.push(item.global_id);
      })
      global_ids = Ids.join(",")
      dispatch({
        type: 'globalInfoManagement/deleteGlobalInfo',
        payload: {
          globalIds: global_ids,
        },
        callback: (data: any) => {
          if (data.success) {
            message.success("删除成功");
            this.setState({ selectedRows: [], })
            this.getEduList();
          } else {
            message.error("删除失败," + data.message)
          }
        }
      });
    } else {
      message.error("请先选择你要删除的数据!")
    }
  }
  // 关闭modal
  handleModalVisible = () => {
    this.setState({ modalVisible: false })
  }
  componentDidMount() {
    this.getEduList();
  }

  // 获取列表
  getEduList() {
    const { dispatch } = this.props;
    dispatch({
      type: 'globalInfoManagement/getGlobalList',
      payload: {
        page: 1,
        limit: 10,
        globalTypeId: -1,
      },
    });
  }

  // // 复选框（勾选数据）
  // onSelectChange = (selectedRowKeys, selectedRows) => {
  //   this.setState({ checkList: selectedRows });
  // };
  handleSelectRows = (rows: TableListItem[]) => {
    this.setState({
      selectedRows: rows,
    });
  };
  renderSimpleForm() {
    const { form } = this.props;
    const { getFieldDecorator } = form;
    return (
      <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
        <Col md={24} sm={24}>
          <span className={styles.submitButtons}>
            <Button type="primary" htmlType="submit" onClick={() => { this.setState({ modalVisible: true }) }}>
              新增
              </Button>
            <Button type="danger" style={{ marginLeft: 16 }} onClick={() => this.handleMoreDelete()}>
              批量删除
              </Button>
          </span>
        </Col>
      </Row>
    );
  }

  renderForm() {
    return this.renderSimpleForm();
  }

  render() {
    const {
      globalInfoManagement: { data },
      loading,
    } = this.props;
    // console.log(this.state,"444444444")
    const { selectedRows, modalVisible } = this.state;
    const parentMethods = {
      handleAdd: this.handleAdd,
      handleEdit: this.handleEdit,
      handleModalVisible: this.handleModalVisible,
      checkType: this.state.checkType,
      globalInfo: this.state.globalInfo,
    }
    // const rowSelection = {
    //   onChange: this.onSelectChange,
    // };
    return (
      <PageHeaderWrapper>
        <Card bordered={false}>
          <div className={styles.tableList}>
            <div className={styles.tableListForm}>{this.renderForm()}</div>
            <StandardTable
              // rowSelection={rowSelection}
              rowKey={record => record.global_id}
              selectedRows={selectedRows}
              loading={loading}
              data={data}
              onSelectRow={this.handleSelectRows}
              columns={this.columns}
            />
          </div>
        </Card>
        <CreateForm {...parentMethods} modalVisible={modalVisible} dispatchProps={this.props} />
      </PageHeaderWrapper>
    );
  }
}

export default Form.create<TableListProps>()(TableList);
