import { AnyAction, Reducer } from 'redux';
import { EffectsCommandMap } from 'dva';
import {
  GetGlobalList,
  GetGlobalInfo,
  AddGlobalInfo,
  EditGlobalInfo,
  DeleteGlobalInfo
} from './service';

// eslint-disable-next-line import/no-unresolved
import { TableListData, EduInfoData } from './data.d';

export interface StateType {
  data?: TableListData;
  eduInfo?: EduInfoData;
}

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: StateType) => T) => T },
) => void;

export interface ModelType {
  namespace: string;
  state: StateType;
  effects: {
    getGlobalList: Effect;
    getGlobalInfo: Effect;
    addGlobalInfo: Effect;
    editGlobalInfo: Effect;
    deleteGlobalInfo: Effect;
  };
  reducers: {
    save: Reducer<StateType>;
  };
}

const Model: ModelType = {
  namespace: 'globalInfoManagement',

  state: {
    data: {
      list: [],
      pagination: {},
    },
  },

  effects: {
    
    *getGlobalList({ payload, callback }, { call, put }) {
      const response = yield call(GetGlobalList, payload);
      yield put({
        type: 'save',
        payload: response,
      });
      // if (callback) callback(response);
    },
    
    *getGlobalInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetGlobalInfo, payload);
      if (callback) callback(response);
    },
    
    *addGlobalInfo({ payload, callback }, { call, put }) {
      const response = yield call(AddGlobalInfo, payload);
      if (callback) callback(response);
    },
    
    *editGlobalInfo({ payload, callback }, { call, put }) {
      const response = yield call(EditGlobalInfo, payload);
      if (callback) callback(response);
    },
    
    *deleteGlobalInfo({ payload, callback }, { call, put }) {
      const response = yield call(DeleteGlobalInfo, payload);
      if (callback) callback(response);
    },
  },

  reducers: {
    save(state, action) {
      return {
        ...state,
        data: action.payload,
      };
    }
  },
};

export default Model;
