import { Form, Tag, Input, Icon, Modal, InputNumber } from 'antd';

import { FormComponentProps } from 'antd/es/form';
import React, { useState, useEffect } from 'react';
import { StateType } from '../model';
import { Dispatch, Action } from 'redux';
import Field from '../../../authority/permission/components/Charts/Field/index';

const FormItem = Form.Item;

interface CreateFormProps extends FormComponentProps {
  type: string;
  prePositionId: string;
  dispatchProps: any;
  modalVisible: boolean;
  handleAdd: (fieldsValue: { desc: string }) => void;
  handleModalVisible: () => void;
  dispatch: Dispatch<
    Action<
      | 'position/getInfo'
    >
  >;
  loading: boolean;
}

const CreateForm: React.FC<CreateFormProps> = props => {

  const { modalVisible, form, handleAdd, handleModalVisible, dispatchProps, prePositionId } = props;
  const [prePositionInfo, setPrePositionInfo] = useState([])




  const { dispatch } = dispatchProps

  useEffect(() => {
    if (prePositionId) {
      dispatch({
        type: 'position/getInfo',
        payload: {
          id: prePositionId,
        },
        callback: (response: any) => {

          setPrePositionInfo(response.list[0])
        },
      });
    }
  }, [prePositionId]);










  const okHandle = () => {
    // alert()
    form.validateFields((err, fieldsValue) => {
      if (err) return;

      let fields = { ...fieldsValue }
      fields.parentId = prePositionInfo.id;
      fields.areaLevel = prePositionInfo.area_level;
      fields.orgType = prePositionInfo.org_type;
      fields.xxbxlxm = prePositionInfo.xxbxlxm;
      fields.nodeName = fields.name;


      handleAdd({ ...fields });

    });
  };


  // 关闭form
  const handleClickChange = () => {

    handleModalVisible()

  }

  return (
    [<Modal
      destroyOnClose
      title="增加职务"
      visible={modalVisible}
      onOk={okHandle}
      maskClosable={false}
      onCancel={handleClickChange}
      width="700px"
    >
      {/* 部门代码*/}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 16 }} label="职务名称" >
        {form.getFieldDecorator('name', {
          initialValue: "",
          rules: [
            {
              required: true,
              message: '请输入1-30个汉字、字母或数字',
            },
            {
              min: 1,
              max: 30,
              message: '长度不在范围内',
            },
            {
              pattern: new RegExp('^[\u4E00-\u9FA5A-Za-z0-9]+$', 'g'),
              message: '职务名称必须为汉字、字母或者数字',
            },
          ],
        })(<Input placeholder="请输职务名称" maxLength={30} />)}
      </FormItem>


      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 4 }} label="排序号">
        {form.getFieldDecorator('sortId', {
          rules: [
            {
              pattern: new RegExp('^[0-9]*$', 'g'),
              message: '请输入1~4位数字。',
            },
          ],
        })(<InputNumber style={{ width: "100%" }} placeholder="请输入排序号" maxLength={4} min={1} max={9999} />)}
      </FormItem>
    </Modal>
    ]
  );
};


export default Form.create<CreateFormProps>()(CreateForm);
