import { Form, Tag, Input, Icon, Modal, InputNumber } from 'antd';

import { FormComponentProps } from 'antd/es/form';
import React, { useState, useEffect } from 'react';
import { StateType } from '../model';
import { Dispatch, Action } from 'redux';
import Field from '../../../authority/permission/components/Charts/Field/index';

const FormItem = Form.Item;

interface CreateFormProps extends FormComponentProps {
  type: string;
  positionId: string;
  dispatchProps: any;
  modalVisible: boolean;
  handleEdit: (fieldsValue: { desc: string }) => void;
  handleUpdateModalVisible: () => void;
  dispatch: Dispatch<
    Action<
      | 'position/getInfo'
    >
  >;
  loading: boolean;
}

const CreateForm: React.FC<CreateFormProps> = props => {

  const { modalVisible, form, handleEdit, handleUpdateModalVisible, dispatchProps, positionId } = props;
  const [positionInfo, setPositionInfo] = useState([])




  const { dispatch } = dispatchProps

  useEffect(() => {
    if (positionId) {
      dispatch({
        type: 'position/getInfo',
        payload: {
          id: positionId,
        },
        callback: (response: any) => {
          setPositionInfo(response.list[0])
        },
      });
    }
  }, [positionId]);










  const okHandle = () => {
    // alert()
    form.validateFields((err, fieldsValue) => {
      if (err) return;

    //   let fields = { ...fieldsValue }
    //   fields.parentId = prePositionInfo.id;
    //   fields.areaLevel = prePositionInfo.area_level;
    //   fields.orgType = prePositionInfo.org_type;
    //   fields.xxbxlxm = prePositionInfo.xxbxlxm;
    //   fields.nodeName = fields.name;
    fieldsValue.nodeName = fieldsValue.name;
    fieldsValue.id=positionInfo.id


      handleEdit({ ...fieldsValue });

    });
  };


  // 关闭form
  const handleClickChange = () => {

    handleUpdateModalVisible()

  }


  console.log(positionInfo,'positionInfo')
  return (
    [<Modal
      destroyOnClose
      title="编辑职务"
      visible={modalVisible}
      onOk={okHandle}
      maskClosable={false}
      onCancel={handleClickChange}
      width="700px"
    >
      {/* 部门代码*/}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 16 }} label="职务名称" >
        {form.getFieldDecorator('name', {
          initialValue: positionInfo.node_name,
          rules: [
            {
              required: true,
              message: '请输入1-30个汉字、字母或数字',
            },
            {
              min: 1,
              max: 30,
              message: '长度不在范围内',
            },
            {
              pattern: new RegExp('^[\u4E00-\u9FA5A-Za-z0-9]+$', 'g'),
              message: '职务名称必须为汉字、字母或者数字',
            },
          ],
        })(<Input placeholder="请输职务名称" maxLength={30} />)}
      </FormItem>


      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 4 }} label="排序号">
        {form.getFieldDecorator('sortId', {
            initialValue:positionInfo.sort_id,
          rules: [
            {
              pattern: new RegExp('^[0-9]*$', 'g'),
              message: '请输入1~4位数字。',
            },
          ],
        })(<InputNumber style={{ width: "100%" }} placeholder="请输入排序号" maxLength={4} min={1} max={9999} />)}
      </FormItem>
    </Modal>
    ]
  );
};


export default Form.create<CreateFormProps>()(CreateForm);
