import {
  Button,
  Card,
  Col,
  Divider,
  Popconfirm,
  Form,
  Row,
  message,
} from 'antd';
import React, { Component, Fragment } from 'react';

import { Dispatch, Action } from 'redux';
import { FormComponentProps } from 'antd/es/form';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { SorterResult } from 'antd/es/table';
import { connect } from 'dva';
import { StateType } from './model';
import AddPosition from './components/addPosition';
import EditPosition from './components/editPosition';
import StandardTable, { StandardTableColumnProps } from './components/StandardTable';

import { TableListItem, TableListPagination, TableListParams, GetOrglistItem } from './data.d';

import styles from './style.less';

const getValue = (obj: { [x: string]: string[] }) =>
  Object.keys(obj)
    .map(key => obj[key])
    .join(',');

interface TableListProps extends FormComponentProps {
  dispatch: Dispatch<
    Action<
      | 'position/getList'
      | 'position/getInfo'
      | 'position/addInfo'
      | 'position/editInfo'
      | 'position/deleteInfo'
      | 'position/getPersonMsg'
    >
  >;
  loading: boolean;
  position: StateType;
}

interface TableListState {
  addInfoModal: boolean;
  editInfoModal: boolean;
  // editInfoModal: boolean;
  selectedRows: TableListItem[];
  formValues: { [key: string]: string };
  stepFormValues: Partial<TableListItem>;
  prePositionId: string;
  positionId:string;
}

/* eslint react/no-multi-comp:0 */
@connect(
  ({
    position,
    loading,
  }: {
    position: StateType;
    loading: {
      models: {
        [key: string]: boolean;
      };
    };
  }) => ({
    position,
    loading: loading.models.position,
  }),
)
class TableList extends Component<TableListProps, TableListState> {
  state: TableListState = {
    addInfoModal: false,
    editInfoModal: false,
    // editInfoModal: false,
    selectedRows: [],
    formValues: {},
    stepFormValues: {},
    prePositionId: "",
    positionId:""
  };

  columns: StandardTableColumnProps[] = [
    // {
    //   title: '序号',
    //   dataIndex: 'org_id',
    //   render: (text, record, index) =>
    //     `${(index + 1)}`,

    // },
    {
      title: '名称',
      dataIndex: 'node_name',
    },

    {
      title: '排序号',
      dataIndex: 'sort_id',
    },
    {
      title: '操作',
      width: 450,
      render: (text, record) => (< Fragment >
        {text.maintain_id.toString().substr(0, 1) == 1 ? <a onClick={() => { this.handleModalVisible(text.id, true) }} style={{paddingRight:"10px"}}>增加</a> : ""}
        {text.maintain_id.toString().substr(1, 1) == 1 ? <a onClick={() => { this.handleUpdateModalVisible(text.id, true) }} style={{paddingRight:"10px"}}>编辑</a> : ""}
        {text.maintain_id.toString().substr(2, 1) == 1 ? <Popconfirm
          title={'是否确认删除『' + text.org_name + '』？'}
          okText="确认"
          cancelText="取消"
          onConfirm={() => this.handleDelete(text.id)}
        >
          <a style={{ color: "red" }}>删除</a>
        </Popconfirm> : ""}

      </Fragment>

      ),
    },
  ];

  componentDidMount() {
    // alert(this.props.match.params.id)
    this.props.position.data.list = [];
    // this.getOrgList()
    this.getList()
  }


  getList = () => {
    const { dispatch } = this.props;
    dispatch({
      type: 'position/getList',
    });
  }


  //删除部门
  handleDelete = (id: string) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'position/deleteInfo',
      payload: {
        id: id
      },
      callback: (response: any) => {
        if (response.success) {
          message.success('删除成功');
          this.getList();
        } else {
          this.getList();
          message.error('删除失败,' + response.message);
        }
      },
    });
  }

  handleStandardTableChange = (
    pagination: Partial<TableListPagination>,
    filtersArg: Record<keyof TableListItem, string[]>,
    sorter: SorterResult<TableListItem>,
  ) => {
    const { dispatch } = this.props;
    const { formValues } = this.state;

    const filters = Object.keys(filtersArg).reduce((obj, key) => {
      const newObj = { ...obj };
      newObj[key] = getValue(filtersArg[key]);
      return newObj;
    }, {});

    const params: Partial<TableListParams> = {
      currentPage: pagination.current,
      pageSize: pagination.pageSize,
      ...formValues,
      ...filters,
    };
    if (sorter.field) {
      params.sorter = `${sorter.field}_${sorter.order}`;
    }

    dispatch({
      type: 'position/getList',
      payload: params,
    });
  };


  // 新增部门
  handleModalVisible = (prePositionId: string, flag?: boolean) => {

    this.setState({ addInfoModal: !!flag, prePositionId: prePositionId })


  };

  // 编辑部门
  handleUpdateModalVisible = (positionId: string, flag?: boolean) => {
    this.setState({ editInfoModal: !!flag, positionId: positionId })

  };



  // 新增、编辑调接口
  handleAdd = (fields: { desc: any }) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'position/AddPositionInfo',
      payload: {
        ...fields
      },
      callback: (response: any) => {
        if (response.success) {
          message.success('添加成功');
          this.getList();
          this.handleModalVisible("", false);
        } else {
          message.error('添加失败,' + response.message);
        }
      },
    });

  };

  handleEdit = (fields: { desc: any }) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'position/editInfo',
      payload: {
        ...fields
      },
      callback: (response: any) => {
        if (response.success) {
          message.success('编辑成功');
          this.getList();
          this.handleUpdateModalVisible('', false);
        } else {
          message.error('编辑失败,' + response.message);
        }
      },
    });
  }

  render() {
    const {
      position: { data },
      loading,
    } = this.props;
    console.log(this.state, 'this.state')
    const { selectedRows } = this.state;
    const parentMethods = {
      handleAdd: this.handleAdd,
      handleModalVisible: this.handleModalVisible,
      prePositionId: this.state.prePositionId

    };

    const editMethods = {
      handleEdit: this.handleEdit,
      handleUpdateModalVisible: this.handleUpdateModalVisible,
      positionId: this.state.positionId

    };
    return (
      <PageHeaderWrapper>
        <Card bordered={false}>
          <div className={styles.tableList}>

            {data.list && data.list.length ? <StandardTable
              rowKey={record => record.id}
              selectedRows={selectedRows}
              loading={loading}
              data={data}
              rowSelection={false}
              defaultExpandAllRows={data.list[0].children ? true : false}
              columns={this.columns}
              onChange={this.handleStandardTableChange}
            /> : ""}

          </div>
        </Card>
        <AddPosition
          {...parentMethods}
          dispatchProps={this.props}
          // PositionId={this.props.match.params.id}
          modalVisible={this.state.addInfoModal}
        />
        <EditPosition
          {...editMethods}
          dispatchProps={this.props}
          // PositionId={this.props.match.params.id}
          modalVisible={this.state.editInfoModal}
        />
      </PageHeaderWrapper>
    );
  }
}

export default Form.create<TableListProps>()(TableList);
