import { AnyAction, Reducer } from 'redux';
import { EffectsCommandMap } from 'dva';
import { TreePositionInfo, GetPositionInfo, AddPositionInfo, UpdatePositionInfo, DeletePositionInfo } from './service';

// eslint-disable-next-line import/no-unresolved
import { TableListData } from './data';

export interface StateType {
  data: TableListData;
}

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: StateType) => T) => T },
) => void;

export interface ModelType {
  namespace: string;
  state: StateType;
  effects: {
    getList: Effect;
    getInfo: Effect;
    AddPositionInfo: Effect;
    editInfo: Effect;
    deleteInfo: Effect;
    getTeacherList: Effect;
    getPersonMsg: Effect;
  };
  reducers: {
    save: Reducer<StateType>;
  };
}

const Model: ModelType = {
  namespace: 'position',

  state: {
    data: {
      list: [],
      pagination: {},
    },
  },

  effects: {
    *getList({ payload }, { call, put }) {
      const response = yield call(TreePositionInfo, payload);
      yield put({
        type: 'save',
        payload: response,
      });
    },
    *getInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetPositionInfo, payload);
      if (callback) callback(response);
    },
    *AddPositionInfo({ payload, callback }, { call, put }) {
      console.log(payload,'1111')
      const response = yield call(AddPositionInfo, payload);
      if (callback) callback(response);
    },
    *editInfo({ payload, callback }, { call, put }) {
      const response = yield call(UpdatePositionInfo, payload);
      if (callback) callback(response);
    },
    *deleteInfo({ payload, callback }, { call, put }) {
      const response = yield call(DeletePositionInfo, payload);
      yield put({
        type: 'save',
        payload: response,
      });
      if (callback) callback(response);
    },
  
  },

  reducers: {
    save(state, action) {
      return {
        ...state,
        data: action.payload,
      };
    },
  },
};

export default Model;
