import { Button, Card, Col, Form, Row, message, Table, Radio } from 'antd';
import React, { Component, Fragment } from 'react';

import { Dispatch, Action } from 'redux';
import { FormComponentProps } from 'antd/es/form';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { connect } from 'dva';
import { StateType } from './model';
import { StandardTableColumnProps } from '../components/StandardTable';

import { TableListItem } from './data.d';


import styles from './style.less';

interface TableListProps extends FormComponentProps {
  dispatch: Dispatch<
    Action<
      | 'infoMangement/getInfoMangement'
      | 'infoMangement/updateGlobalInfo'
    >
  >;
  loading: boolean;
  infoMangement: StateType;
}

interface TableListState {
  selectedRows: TableListItem[];
  formValues: { [key: string]: string };
  selectvalue: number;
}

/* eslint react/no-multi-comp:0 */
@connect(
  ({
    infoMangement,
    geographic,
    loading,
  }: {
    infoMangement: StateType;
    geographic: StateType;
    loading: {
      models: {
        [key: string]: boolean;
      };
    };
  }) => ({
    infoMangement,
    geographic,
    loading: loading.models.infoMangement,
  }),
)
class TableList extends Component<TableListProps, TableListState> {
  state: TableListState = {
    selectedRows: [],
    formValues: {},
    selectvalue: 1,
  };

  componentDidMount() {
    this.getMessage();
  }

  // componentWillMount() {
  //   this.getMessage();
  // }

  // 获取列表
  getMessage() {
    const { dispatch } = this.props;
    dispatch({
      type: 'infoMangement/getInfoMangement',
      payload: {
        codes: "passwordType"
      },
      callback: (response: any) => {
        // console.log(response, "88888888888")
        this.setState({ selectvalue: parseInt(response.list[0].global_value) })
      }
    });
  }

  updateUserSave = () => {
    const { dispatch } = this.props;
    dispatch({
      type: 'infoMangement/updateGlobalInfo',
      payload: {
        globalId: "954839E9-D743-4FC2-A8EA-EE32327A2895",
        globalTypeId: "1",
        globalCode: "passwordType",
        sortId: "1",
        globalValue: this.state.selectvalue
      },
      callback: (response: any) => {
        if (response.success) {
          message.success("保存成功");
        } else {
          message.error("保存失败" + response.message)
        }
      }
    });
  }
  onChange = (e: any) => {
    this.setState({ selectvalue: e.target.value, })
  }
  render() {
    // this.state.selectvalue = this.props.infoMangement.data.length > 0 ? parseInt(this.props.infoMangement.data[0].global_value) : 1;
    return (
      <PageHeaderWrapper>
        <Card bordered={false}>
          <div className={styles.tableList}>
            {/* <Table columns={this.columns} dataSource={this.data} /> */}
            <Radio.Group onChange={this.onChange} value={this.state.selectvalue}>
              <Radio style={{ width: "100%", lineHeight: "30px", marginBottom: "30px" }} value={1}>
                等保要求的密码强度 &nbsp;&nbsp;
                <span style={{ color: "#f00" }}>(8位长度以上大小写字母数字特殊字符组合)</span>
              </Radio>
              <Radio style={{ width: "100%", lineHeight: "30px", marginBottom: "30px" }} value={2}>
                非等保要求的密码强度 &nbsp;&nbsp;
                <span style={{ color: "#f00" }}>(6位长度以上密码)</span>
              </Radio>
            </Radio.Group>
          </div>
          <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
            <Col md={24} sm={12}>
              <Button type="primary" htmlType="submit" onClick={this.updateUserSave}>
                保存
              </Button>
            </Col>
          </Row>
        </Card>
      </PageHeaderWrapper >
    );
  }
}

export default Form.create<TableListProps>()(TableList);
