import { AnyAction, Reducer } from 'redux';
import { EffectsCommandMap } from 'dva';
import {
  GetInfoMangement,
  UpdateGlobalInfo
} from './service';

// eslint-disable-next-line import/no-unresolved
import { TableListData, EduInfoData } from './data.d';

export interface StateType {
  data?: TableListData;
  eduInfo?: EduInfoData;
}

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: StateType) => T) => T },
) => void;

export interface ModelType {
  namespace: string;
  state: StateType;
  effects: {
    getInfoMangement: Effect;
    updateGlobalInfo: Effect;
  };
  reducers: {
    save: Reducer<StateType>;
  };
}

const Model: ModelType = {
  namespace: 'infoMangement',

  state: {
    data: {
      list: [],
      pagination: {},
    },
  },

  effects: {
    // 获取已启用教育局列表
    *getInfoMangement({ payload, callback }, { call, put }) {
      const response = yield call(GetInfoMangement, payload);
      // yield put({
      //   type: 'save',
      //   payload: response.list,
      // });
      if (callback) callback(response);
    },
    // 获取已启用教育局列表
    *updateGlobalInfo({ payload, callback }, { call, put }) {
      const response = yield call(UpdateGlobalInfo, payload);
      if (callback) callback(response);
    },
  },

  reducers: {
    save(state, action) {
      return {
        ...state,
        data: action.payload,
      };
    }
  },
};

export default Model;
