import { Card, Form, message, Button } from 'antd';
import React, { Component, Fragment } from 'react';

import { Dispatch, Action } from 'redux';
import { FormComponentProps } from 'antd/es/form';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { connect } from 'dva';
import { StateType } from './model';
import StandardTable, { StandardTableColumnProps } from './components/StandardTable';
import UpdateForm from './components/UpdateForm';

import styles from './style.less';

import AddEduInfo from './components/AddEduInfo';

interface TableListProps extends FormComponentProps {
  dispatch: Dispatch<Action<'organizationBureau/fetchDisableEdu'>>;
  loading: boolean;
  organizationBureau: StateType;
}

interface TableListState {
  modalVisible: boolean;
  updateModalVisible: boolean;

  // formValues: { [key: string]: string };
  // options: Iteam[];
  modifyId: string;
}

/* eslint react/no-multi-comp:0 */
@connect(
  ({
    organizationBureau,
    loading,
  }: {
    organizationBureau: StateType;
    loading: {
      models: {
        [key: string]: boolean;
      };
    };
  }) => ({
    organizationBureau,
    loading: loading.models.organizationBureau,
  }),
)
class TableList extends Component<TableListProps, TableListState> {
  state: TableListState = {
    modalVisible: false,
    updateModalVisible: false,

    // formValues: {},
    // options: [],
    modifyId: '',
  };

  columns: StandardTableColumnProps[] = [
    {
      title: '序号',
      dataIndex: 'area_code',
      render(text, record, index) {
        return <span>{index + 1}</span>;
      },
    },
    {
      title: '机构名称',
      dataIndex: 'org_name',
      key: 'org_name',
    },
    {
      title: '操作',
      render: (text, record) => (
        <Fragment>
          <a onClick={() => this.handleModalVisible(record.org_id, true)}>启用</a>
        </Fragment>
      ),
    },
  ];

  componentDidMount() {
    const { dispatch } = this.props;

    const areaCode = this.props.match.params.id;

    dispatch({
      type: 'organizationBureau/fetchDisableEduList',
      payload: {
        page: 1,
        limit: 1000,
        areaCode: areaCode,
      },
    });
  }

  handleModalVisible = (id: string, flag?: boolean) => {
    this.setState({
      modalVisible: !!flag,
      modifyId: id,
    });
  };

  handleAdd = (fields: { desc: any }) => {
    const { dispatch } = this.props;
    const areaCode = this.props.match.params.id;
    dispatch({
      type: 'organizationBureau/EnableEdu',
      payload: {
        ...fields,
      },
      callback: response => {
        if (response) {
          message.success('启用成功');
          dispatch({
            type: 'organizationBureau/fetchDisableEduList',
            payload: {
              page: 1,
              limit: 1000,
              areaCode: areaCode,
            },
          });
        } else {
          message.error('启用失败');
        }
      },
    });
    this.handleModalVisible('', false);
  };

  onChange = (value: number, selectedOptions: any) => {
    console.log(value, selectedOptions);
  };

  render() {
    // const data  =this.props.organizationBureau
    const {
      organizationBureau: { data },
      loading,
    } = this.props;

    const { selectedRows, modalVisible, updateModalVisible, stepFormValues } = this.state;

    const parentMethods = {
      handleAdd: this.handleAdd,
      handleModalVisible: this.handleModalVisible,
      dispatch: this.props.dispatch,
      modifyId: this.state.modifyId,
      eduInfo: this.props.organizationBureau.eduInfo,
    };
    const updateMethods = {
      handleUpdateModalVisible: this.handleUpdateModalVisible,
      handleUpdate: this.handleUpdate,
    };

    // console.log(this.state, 'this.state');
    return (
      <PageHeaderWrapper>
        <Card bordered={false}>
          <div className={styles.tableList}>
            <div style={{ overflow: "hidden" }}>
              {/* <Button style={{ float: "right", marginBottom: "20px" }} onClick={()=>{window.history.back()}} type="primary"> */}
              <Button style={{ float: "right", marginBottom: "20px" }} onClick={()=>{window.history.back()}} type="primary">
                返回
              </Button>
            </div>
            <StandardTable
              rowKey={record => record.area_code}
              selectedRows={selectedRows}
              loading={loading}
              data={data}
              columns={this.columns}
              rowSelection={false}
              onSelectRow={this.handleSelectRows}
              onChange={this.handleStandardTableChange}
            />
          </div>
        </Card>
        <AddEduInfo {...parentMethods} modalVisible={modalVisible} />

      </PageHeaderWrapper>
    );
  }
}

export default Form.create<TableListProps>()(TableList);
