import { Button, Card, Col, Divider, Form, Input, Popconfirm, Row, message } from 'antd';
import React, { Component, Fragment } from 'react';

import { Dispatch, Action } from 'redux';
import router from 'umi/router';
import { FormComponentProps } from 'antd/es/form';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { connect } from 'dva';
import { StateType } from './model';
import StandardTable, { StandardTableColumnProps } from './components/StandardTable';
import { FormValueType } from './components/UpdateForm';
import { TableListItem } from './data.d';
import CascadeGeographic from '../../../components/CascadeGeographic'

import styles from './style.less';
import UpdataEduInfo from './components/UpdataEduInfo';
const FormItem = Form.Item;

interface TableListProps extends FormComponentProps {
  dispatch: Dispatch<
    Action<
      | 'organizationBureau/add'
      | 'organizationBureau/EnableEduInfo'
      | 'organizationBureau/remove'
      | 'organizationBureau/UpdateEduInfo'
      | 'geographic/fetchProvince'
      | 'geographic/GetEduInfoById'
    >
  >;
  loading: boolean;
  organizationBureau: StateType;
}

interface TableListState {
  modalVisible: boolean;
  updateModalVisible: boolean;
  expandForm: boolean;
  selectedRows: TableListItem[];
  formValues: { [key: string]: string };
  stepFormValues: Partial<TableListItem>;
  areaCode: string;
  codeArr: any;
  eduInfo: { [key: string]: string };
}

/* eslint react/no-multi-comp:0 */
@connect(
  ({
    organizationBureau,
    geographic,
    loading,
  }: {
    organizationBureau: StateType;
    geographic: StateType;
    loading: {
      models: {
        [key: string]: boolean;
      };
    };
  }) => ({
    organizationBureau,
    geographic,
    loading: loading.models.organizationBureau,
  }),
)
class TableList extends Component<TableListProps, TableListState> {
  state: TableListState = {
    modalVisible: false,
    updateModalVisible: false,
    expandForm: false,
    selectedRows: [],
    formValues: {},
    stepFormValues: {},
    areaCode: this.props.location.query.code1 ? this.props.location.query.code1 : '220100',
    codeArr: this.props.location.query.code ? [this.props.location.query.code, this.props.location.query.code1] : ["220000", "220100"],
    eduInfo: {},
  };
  columns: StandardTableColumnProps[] = [
    {
      title: '序号',
      dataIndex: 'area_code',
      render(text, record, index) {
        return <span>{index + 1}</span>;
      },
    },
    {
      title: '教育局名称',
      dataIndex: 'org_name',
      key: 'org_name',
    },
    {
      title: '教育局代码',
      dataIndex: 'org_code',
      key: 'org_code',
    },
    {
      title: '操作',
      width: 400,
      render: (text, record) => (
        <Fragment>
          <Popconfirm
            title={'是否确认禁用『' + record.org_name + '』？'}
            okText="确认"
            cancelText="取消"
            onConfirm={() => this.disableEdu(record.org_id)}
          >
            <a>禁用</a>
          </Popconfirm>
          <Divider type="vertical" />
          <a onClick={() => this.handleModalVisible(record.org_id, true)}>
            编辑
          </a>
          <Divider type="vertical" />
          <a href={'#/organization/bureau/department/' + record.org_id} onClick={() => {
            // router.push({
            //   pathname: '/organization/bureau/' + record.area_code,
            // });
            router.push({
              pathname: '/organization/bureau/',
              query: {
                code: this.state.codeArr[0],
                code1: this.state.codeArr[1],
              },
            })
          }}>
            部门管理
          </a>
          <Divider type="vertical" />
          <a href={'#/organization/bureau/teacher/' + record.org_id} onClick={() => {
            // router.push({
            //   pathname: '/organization/bureau/' + record.area_code,
            // });
            router.push({
              pathname: '/organization/bureau/',
              query: {
                code: this.state.codeArr[0],
                code1: this.state.codeArr[1],
              },
            })
          }}>
            教职工管理
          </a>
        </Fragment>
      ),
    },
  ];

  componentDidMount() {
    // console.log(this.props, "2222222222")
    const areaCode = this.state.areaCode;
    this.getEduList(areaCode);
  }

  // 获取列表
  getEduList(areaCode: string, orgName?: string) {
    const { dispatch } = this.props;
    dispatch({
      type: 'organizationBureau/EnableEduInfo',
      payload: {
        page: 1,
        limit: 99,
        areaCode: areaCode,
        orgName: orgName,
      },
    });
  }

  // handleFormReset = () => {
  //   const { form } = this.props;
  //   form.resetFields();
  //   this.setState({
  //     formValues: {},
  //   });

  //   const areaCode = this.state.areaCode;
  //   this.getEduList(areaCode);
  // };

  toggleForm = () => {
    const { expandForm } = this.state;
    this.setState({
      expandForm: !expandForm,
    });
  };

  handleSearch = (e: React.FormEvent) => {
    e.preventDefault();
    const { form } = this.props;
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      const values = {
        ...fieldsValue,
      };
      this.setState({
        formValues: values,
      }, () => {
        this.getEduList(this.state.areaCode, values.org);
      });
    });
  };

  //下拉筛选
  handleSelect = (value: any) => {
    let code = value[value.length - 1]
    const { form } = this.props;
    form.resetFields();
    this.setState({ areaCode: code, formValues: {}, codeArr: value })
    this.getEduList(code);
  }

  // 修改教育局弹窗传参
  handleModalVisible = (orgID: string, flag?: boolean) => {
    if (flag) {
      const { dispatch } = this.props;
      dispatch({
        type: 'organizationBureau/GetEduInfoById',
        payload: {
          orgId: orgID,
        },
        callback: (response: any) => {
          this.setState({
            eduInfo: response,
            modalVisible: !!flag,
          });
        },
      });
    } else {
      this.setState({
        modalVisible: !!flag,
      });
    }
  };

  handleUpdateModalVisible = (flag?: boolean, record?: FormValueType) => {
    this.setState({
      updateModalVisible: !!flag,
      stepFormValues: record || {},
    });
  };

  // 修改教育局信息
  handleModify = (fields: { desc: any }) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'organizationBureau/UpdateEduInfo',
      payload: {
        ...fields,
      },
      callback: (response: any) => {
        if (response.success) {
          const areaCode = this.state.areaCode;
          this.getEduList(areaCode);
          message.success('编辑成功');
          this.handleModalVisible('');
        } else {
          message.error('编辑失败,' + response.message);
        }
      },
    });
  };

  onChange = (value: number, selectedOptions: any) => {
  };

  // 禁用教育局
  disableEdu = (orgId: string) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'organizationBureau/DisableEdu',
      payload: {
        orgId: orgId,
      },
      callback: response => {
        if (response) {
          const areaCode = this.state.areaCode;
          this.getEduList(areaCode);
          message.success('禁用成功');
        } else {
          message.error('禁用失败');
        }
      },
    });

    // message.success('禁用成功');
  };

  // onLoadChange = (selectedOptions: any) => {

  // }

  renderSimpleForm() {
    const { form } = this.props;
    const { getFieldDecorator } = form;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={8} sm={24}>
            <FormItem label="所在行政区划">
              {getFieldDecorator('areaCode', {
                initialValue: this.state.codeArr,
              })(<CascadeGeographic changeOnSelect={false} level="2" defaultValue={this.state.codeArr} onChange={this.handleSelect} />)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="教育局名称">
              {getFieldDecorator('org')(<Input placeholder="请输入" allowClear={true} maxLength={30} />)}
            </FormItem>
          </Col>
          <Col md={4} sm={12}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              {/* <Button style={{ marginLeft: 8 }} onClick={this.handleFormReset}>
                重置
              </Button> */}
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  renderForm() {
    return this.renderSimpleForm();
  }

  render() {
    // const data  =this.props.organizationBureau
    const {
      organizationBureau: { data },
      loading,
    } = this.props;

    const { selectedRows, modalVisible } = this.state;

    const parentMethods = {
      handleModify: this.handleModify,
      handleModalVisible: this.handleModalVisible,
      eduInfo: this.state.eduInfo,
    };

    return (
      <PageHeaderWrapper>
        <Card bordered={false}>
          <div className={styles.tableList}>
            <div className={styles.tableListForm}>{this.renderForm()}</div>
            <div className={styles.tableListOperator}>
              <Button
                icon="plus"
                type="primary"
                href={'#/organization/bureau/disableEdu/' + this.state.areaCode}
                onClick={() => {
                  // router.push({
                  //   pathname: '/organization/bureau/' + this.state.areaCode
                  // });
                  // console.log(this.state.codeArr,"22222255555555555")
                  router.push({
                    pathname: '/organization/bureau/',
                    query: {
                      code: this.state.codeArr[0],
                      code1: this.state.codeArr[1],
                    },
                  })
                }}
              >
                启用教育局
              </Button>
            </div>
            <StandardTable
              rowSelection={false}
              rowKey={record => record.org_id}
              selectedRows={selectedRows}
              loading={loading}
              data={data}
              columns={this.columns}
            />
          </div>
        </Card>
        <UpdataEduInfo {...parentMethods} modalVisible={modalVisible} />
      </PageHeaderWrapper>
    );
  }
}

export default Form.create<TableListProps>()(TableList);
