import { AnyAction, Reducer } from 'redux';
import { EffectsCommandMap } from 'dva';
import {
  EnableEdu,
  EnableEduInfo,
  fetchDisableEduList,
  UpdateEduInfo,
  GetEduInfoById,
  DisableEdu,
} from './service';

// eslint-disable-next-line import/no-unresolved
import { TableListData, EduInfoData } from './data.d';

export interface StateType {
  data?: TableListData;
  eduInfo?: EduInfoData;
}

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: StateType) => T) => T },
) => void;

export interface ModelType {
  namespace: string;
  state: StateType;
  effects: {
    EnableEduInfo: Effect;
    fetchDisableEduList: Effect;
    GetEduInfoById: Effect;
    EnableEdu: Effect;
    DisableEdu: Effect;
    UpdateEduInfo: Effect;
  };
  reducers: {
    save: Reducer<StateType>;
    eduInfo: Reducer<StateType>;
  };
}

const Model: ModelType = {
  namespace: 'organizationBureau',

  state: {
    data: {
      list: [],
      pagination: {},
    },
    eduInfo: {
      count: '',
      list: [],
      message: '',
      success: '',
    },
  },

  effects: {
    // 获取已启用教育局列表
    *EnableEduInfo({ payload }, { call, put }) {
      const response = yield call(EnableEduInfo, payload);
      yield put({
        type: 'save',
        payload: response,
      });
    },
    // 获取未启用的教育局列表
    *fetchDisableEduList({ payload }, { call, put }) {
      const response = yield call(fetchDisableEduList, payload);
      yield put({
        type: 'save',
        payload: response,
      });
    },
    // 根据教育局ID获取教育局信息
    *GetEduInfoById({ payload, callback }, { call, put }) {
      const response = yield call(GetEduInfoById, payload);
      yield put({
        type: 'eduInfo',
        payload: response,
      });
      if (callback) callback(response.list[0]);
    },
    // 启用教育局
    *EnableEdu({ payload, callback }, { call }) {
      const response = yield call(EnableEdu, payload);
      if (callback) callback(response);
    },
    // 禁用用教育局
    *DisableEdu({ payload, callback }, { call }) {
      const response = yield call(DisableEdu, payload);

      if (callback) callback(response);
    },
    // 修改教育局信息
    *UpdateEduInfo({ payload, callback }, { call }) {
      const response = yield call(UpdateEduInfo, payload);
      if (callback) callback(response);
    },
  },

  reducers: {
    save(state, action) {
      return {
        ...state,
        data: action.payload,
      };
    },
    eduInfo(state, action) {
      const EduInfo = action.payload.list[0];
      return {
        ...state,
        eduInfo: EduInfo,
      };
    },
  },
};

export default Model;
