import { Form, Input, Modal,Select,Cascader,Tooltip,Row,Col } from 'antd';

import { FormComponentProps } from 'antd/es/form';
import React from 'react';

const FormItem = Form.Item;

interface CreateFormProps extends FormComponentProps {
  modalVisible: boolean;
  handleAdd: (fieldsValue: { desc: string }) => void;
  handleModalVisible: () => void;
}
const CreateForm: React.FC<CreateFormProps> = props => {
  const { modalVisible, form, handleAdd, handleModalVisible } = props;
  const okHandle = () => {
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      form.resetFields();
      handleAdd(fieldsValue);
    });
  };
  return (
    <Modal
      destroyOnClose
      title="新建规则"
      visible={modalVisible}
      onOk={okHandle}
      onCancel={() => handleModalVisible()}
      width="700px"
    >
      {/* 所属机构 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="所属机构">
        {form.getFieldDecorator('parent_id', {
          rules: [{ required: true, message: '请选择所属机构！'}],
        })(
          <Select
          style={{ width: '100%' }}
          showSearch={true}
          >
        <Option value="WiFi">WiFi</Option>
        <Option value="Cellular">蜂窝 (2G / 2G / 4G / 5G)</Option>
        <Option value="Ethernet">以太网</Option>
        <Option value="LoRaWAN">LoRaWAN</Option>
        <Option value="Other">其他</Option>
      </Select>)}
      </FormItem>

      {/* 部门代码 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="部门代码">
        {form.getFieldDecorator('org_code', {
          rules: [{ required: true, message: '请输部门代码！', min: 5 }],
        })(<Input placeholder="请输入" />)}
      </FormItem>
      {/* 部门名称 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 10 }} label="部门名称">
        {form.getFieldDecorator('org_name', {
          rules: [{ required: true, message: '请输入部门名称！', min: 5 }],
        })(<Input placeholder="请输入" />)}
      </FormItem>
      {/* 部门类型 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 10 }} label="部门类型">
        {form.getFieldDecorator('org_ename',{
          rules: [{ required: true, message: '请选择所属机构！'}],
        })(
          <Select
          style={{ width: '100%' }}
          showSearch={true}
          >
        <Option value="WiFi">WiFi</Option>
        <Option value="Cellular">蜂窝 (2G / 2G / 4G / 5G)</Option>
        <Option value="Ethernet">以太网</Option>
        <Option value="LoRaWAN">LoRaWAN</Option>
        <Option value="Other">其他</Option>
      </Select>)}
      </FormItem>
      {/* 序号 */}
            <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 10 }} label="排序号">
        {form.getFieldDecorator('org_name')(<Input placeholder="排序号" />)}
      </FormItem>
      {/* 部门负责人 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="部门负责人">
        {form.getFieldDecorator('xxbxlxm')(<Select
          style={{ width: '100%' }}
          showSearch={true}
          >
        <Option value="WiFi">WiFi</Option>
        <Option value="Cellular">蜂窝 (2G / 2G / 4G / 5G)</Option>
        <Option value="Ethernet">以太网</Option>
        <Option value="LoRaWAN">LoRaWAN</Option>
        <Option value="Other">其他</Option>
      </Select>)}
      </FormItem>
      {/* 部门分管领导 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="部门分管领导">
        {form.getFieldDecorator('xxjbzm')(<Input placeholder="请输入" />)}
      </FormItem>
    </Modal>
  );
};

export default Form.create<CreateFormProps>()(CreateForm);
