import {
  Badge,
  Button,
  Card,
  Statistic,
  Descriptions,
  Divider,
  Dropdown,
  Icon,
  Menu,
  Popover,
  Steps,
  Table,
  Tooltip,
  Empty,
  Switch,
} from 'antd';
import { GridContent, PageHeaderWrapper, RouteContext } from '@ant-design/pro-layout';
import React, { Component, Fragment } from 'react';

import { Dispatch } from 'redux';
import classNames from 'classnames';
import { connect } from 'dva';
import { AdvancedProfileData } from './data.d';
import styles from './style.less';
import { any } from 'prop-types';

const action = (
  <RouteContext.Consumer>
    {({ isMobile }) => {
      return (
        <Fragment>
          <Button type="primary">发布</Button>
        </Fragment>
      );
    }}
  </RouteContext.Consumer>
);

const description = (
  <RouteContext.Consumer>
    {({ isMobile }) => (
      <Descriptions className={styles.headerList} size="small" column={isMobile ? 1 : 3}>
        <Descriptions.Item label="ProductKey">
          bh98d29drasc <a href="">复制</a>
        </Descriptions.Item>
        <Descriptions.Item label="ProductSecret">
          XX 服务 <a href="">重置</a> <a href="">复制</a>
        </Descriptions.Item>
        <Descriptions.Item label="设备数">
          2017-07-07 <a href="">前往管理</a>
        </Descriptions.Item>
      </Descriptions>
    )}
  </RouteContext.Consumer>
);

interface ProductDetailState {
  operationKey: string;
  tabActiveKey: string;
}

@connect(
  ({
    equipmentAndproductDetail,
    loading,
  }: {
    equipmentAndproductDetail: AdvancedProfileData;
    loading: {
      effects: { [key: string]: boolean };
    };
  }) => ({
    equipmentAndproductDetail,
    loading: loading.effects['equipmentAndproductDetail/fetchAdvanced'],
  }),
)
class ProductDetail extends Component<
  { loading: boolean; equipmentAndproductDetail: AdvancedProfileData; dispatch: Dispatch<any> },
  ProductDetailState
> {
  public state: ProductDetailState = {
    operationKey: 'infomation',
    tabActiveKey: 'infomation',
  };

  componentDidMount() {
    const { dispatch } = this.props;
    dispatch({
      type: 'equipmentAndproductDetail/fetchAdvanced',
    });
  }

  onOperationTabChange = (key: string) => {
    this.setState({ operationKey: key });
  };

  onTabChange = (tabActiveKey: string) => {
    this.setState({ tabActiveKey });
  };

  render() {
    const { operationKey, tabActiveKey } = this.state;
    //const { equipmentAndproductDetail, loading } = this.props;

    return (
      <PageHeaderWrapper
        title="智能家居网关"
        extra={action}
        className={styles.pageHeader}
        content={description}
        //extraContent={extra}
        tabActiveKey={tabActiveKey}
        onTabChange={this.onTabChange}
        tabList={[
          {
            key: 'infomation',
            tab: '产品信息',
          },
          {
            key: 'topic',
            tab: 'Topic类列表',
          },
          {
            key: 'define',
            tab: '功能定义',
          },
          {
            key: 'subscribe',
            tab: '服务端订阅',
          },
          /*{
            key: 'log',
            tab: '日志服务',
          },
          {
            key: 'debug',
            tab: '在线调试',
          },*/
        ]}
      >
        <div className={styles.main}>
          {tabActiveKey === 'infomation' && (
            <GridContent>
              <Card title="产品信息" style={{ marginBottom: 24 }}>
                <Descriptions bordered column={{ xxl: 3, xl: 3, lg: 3 }}>
                  <Descriptions.Item label="产品名称">智能家居网关</Descriptions.Item>
                  <Descriptions.Item label="节点类型">网关</Descriptions.Item>
                  <Descriptions.Item label="创建时间">2019/10/11 15:34:29</Descriptions.Item>

                  <Descriptions.Item label="所属分类">网关</Descriptions.Item>
                  <Descriptions.Item label="数据格式">
                    ICA 标准数据格式 (Alink JSON)
                  </Descriptions.Item>
                  <Descriptions.Item label="认证方式">设备密钥</Descriptions.Item>

                  <Descriptions.Item label="动态注册">
                    <Switch defaultChecked size="small" />
                  </Descriptions.Item>
                  <Descriptions.Item label="是否接入网关">否</Descriptions.Item>
                  <Descriptions.Item label="状态">
                    <Badge color="orange" text="开发中" />
                  </Descriptions.Item>

                  <Descriptions.Item label="连网协议">WiFi</Descriptions.Item>
                  <Descriptions.Item label="产品描述">WL-ZGWMDPB-G100-01</Descriptions.Item>
                </Descriptions>
              </Card>
              <Card title="标签信息" bordered={false}>
                产品标签：无标签信息，<a href="">立即添加</a>
              </Card>
            </GridContent>
          )}
          {tabActiveKey === 'topic' && (
            <Card title="Topic类列表">
              <Table
                columns={[
                  { title: 'Topic类', dataIndex: 'topic', key: 'topic' },
                  { title: '操作权限', dataIndex: 'auth', key: 'auth' },
                  { title: '描述', dataIndex: 'description', key: 'description' },
                  { title: '操作', dataIndex: 'action', key: 'action' },
                ]}
                dataSource={[
                  {
                    topic: '/sys/a1imrB1BXVG/${deviceName}/thing/event/property/post',
                    auth: '发布',
                    description: '设备属性上报',
                  },
                  {
                    topic: '/sys/a1imrB1BXVG/${deviceName}/thing/service/property/set',
                    auth: '订阅',
                    description: '设备属性上报',
                  },
                  {
                    topic: '/sys/a1imrB1BXVG/${deviceName}/thing/event/${tsl.event.identifer}/post',
                    auth: '发布',
                    description: '设备属性上报',
                  },
                  {
                    topic: '/sys/a1imrB1BXVG/${deviceName}/thing/service/${tsl.event.identifer}',
                    auth: '订阅',
                    description: '设备属性上报',
                  },
                ]}
              />
            </Card>
          )}
          {tabActiveKey === 'define' && (
            <GridContent>
              <Card title="标准功能" style={{ marginBottom: 24 }}>
                <Table
                  columns={[
                    { title: '功能类型', dataIndex: 'type', key: 'type' },
                    { title: '功能名称', dataIndex: 'name', key: 'name' },
                    { title: '标识符', dataIndex: 'tag', key: 'tag' },
                    { title: '数据类型', dataIndex: 'dataType', key: 'dataType' },
                    { title: '数据定义', dataIndex: 'dataDefine', key: 'dataDefine' },
                    { title: '操作', dataIndex: 'action', key: 'action' },
                  ]}
                  dataSource={[]}
                />
              </Card>
              <Card title="自定义功能">
                <Table
                  columns={[
                    { title: '功能类型', dataIndex: 'type', key: 'type' },
                    { title: '功能名称', dataIndex: 'name', key: 'name' },
                    { title: '标识符', dataIndex: 'tag', key: 'tag' },
                    { title: '数据类型', dataIndex: 'dataType', key: 'dataType' },
                    { title: '数据定义', dataIndex: 'dataDefine', key: 'dataDefine' },
                    { title: '操作', dataIndex: 'action', key: 'action' },
                  ]}
                  dataSource={[]}
                />
              </Card>
            </GridContent>
          )}
          {tabActiveKey === 'subscribe' && (
            <GridContent>
              <Card title="服务端订阅" style={{ marginBottom: 24 }}>
                <Table columns={[]} dataSource={[]} />
              </Card>
              <Card title="服务端订阅 (推送MNS)">
                <Table columns={[]} dataSource={[]} />
              </Card>
            </GridContent>
          )}
        </div>
      </PageHeaderWrapper>
    );
  }
}

export default ProductDetail;
