import { Form, Input, Modal, InputNumber } from 'antd';
import React from 'react';
import { FormComponentProps } from 'antd/es/form';

const FormItem = Form.Item;
interface AddEduInfo extends FormComponentProps {
  modalVisible: boolean;
  handleAdd: (fieldsValue: { desc: string }) => void;
  handleModalVisible: () => void;
  dispatch: (payload: {}) => void;
}

const AddEduInfo: React.FC<AddEduInfo> = props => {
  const { modalVisible, form, handleAdd, handleModalVisible, areaCode } = props;

  const okHandle = () => {
    form.validateFields((err, fieldsValue) => {
      const data = fieldsValue;
      if (err) return;
      // form.resetFields();
      data.areaCode = areaCode;
      handleAdd(data);
    });
  };

  return (
    <Modal
      destroyOnClose
      title="新建教辅单位"
      visible={modalVisible}
      onOk={okHandle}
      maskClosable={false}
      onCancel={() => handleModalVisible()}
      width="700px"
    >
      {/* 所在行政区划 */}
      <FormItem labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="教辅单位代码">
        {form.getFieldDecorator('orgCode', {
          rules: [
            {
              required: true,
              message: '请输入2-20个字母或数字',
            },
            {
              min: 2,
              max: 20,
              message: '长度不在范围内',
            },
            {
              pattern: new RegExp('^\\w+$', 'g'),
              message: '教辅单位代码必须为字母或者数字',
            },
          ],
        })(<Input maxLength={20} />)}
      </FormItem>

      <FormItem labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="教辅单位名称">
        {form.getFieldDecorator('orgName', {
          rules: [
            {
              required: true,
              message: '请输入1-30个汉字、字母或者数字',
            },
            {
              pattern: new RegExp('^[\u4E00-\u9FA5A-Za-z0-9]+$', 'g'),
              message: '教辅单位名称必须为汉字、字母或者数字',
            },
            {
              max: 30,
              message: '长度不在范围内',
            },
          ],
        })(<Input maxLength={30} />)}
      </FormItem>
      <Form.Item labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="教辅单位法定代表人">
        {form.getFieldDecorator('fddbr', {
          rules: [
            {
              pattern: new RegExp('^[\u4E00-\u9FA5A-Za-z0-9]+$', 'g'),
              message: '请输入汉字、字母或者数字',
            },
            {
              min: 2,
              max: 30,
              message: '长度范围在2-30个字符之间。',
            },
          ],
        })(<Input maxLength={30} />)}
      </Form.Item>
      <Form.Item labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="教辅单位法定代表人电话">
        {form.getFieldDecorator('fddbrdh', {
          rules: [
            {
              min: 2,
              max: 30,
              message: '长度范围在2-30个字符之间。',
            },
            {
              pattern: new RegExp('^[ 0-9+-]*$', 'g'),
              message: '请输入电话可用字符。',
            },
          ],
        })(<Input maxLength={30} />)}
      </Form.Item>
      <Form.Item labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="教辅单位地址">
        {form.getFieldDecorator('address', {
          rules: [
            {
              pattern: new RegExp('^[\u4E00-\u9FA5A-Za-z0-9-]+$', 'g'),
              message: '请输入汉字、字母或者数字',
            },
            {
              min: 2,
              max: 100,
              message: '长度范围在2-100个字符之间。',
            },
          ],
        })(<Input maxLength={100} />)}
      </Form.Item>

      <Form.Item labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="联系电话">
        {form.getFieldDecorator('lxdh', {
          rules: [
            {
              min: 2,
              max: 30,
              message: '长度范围在2-30个字符之间。',
            },
            {
              pattern: new RegExp('^[ 0-9+-]*$', 'g'),
              message: '请输入电话可用字符。',
            },
          ],
        })(<Input maxLength={30} />)}
      </Form.Item>

      <Form.Item labelCol={{ span: 7 }} wrapperCol={{ span: 8 }} label="排序号">
        {form.getFieldDecorator('sortId', {
          rules: [
            {
              pattern: new RegExp('^[0-9]*$', 'g'),
              message: '请输入1~4位数字',
            },
          ]
        })(<InputNumber style={{ width: "100%" }} placeholder="请输入排序号" maxLength={4} min={1} max={9999} />)}
      </Form.Item>
    </Modal>
  );
};

export default Form.create<AddEduInfo>()(AddEduInfo);
