import { Form, Input, Modal, Collapse, Cascader, Radio, Select, Popover, Icon } from 'antd';

import { FormComponentProps } from 'antd/es/form';
import React from 'react';
import { } from 'antd';
const { TextArea } = Input;
const { Option } = Select;
const { Panel } = Collapse;
const FormItem = Form.Item;
interface CreateFormProps extends FormComponentProps {
  modalVisible: boolean;
  handleAdd: (fieldsValue: { desc: string }) => void;
  handleModalVisible: () => void;
}

const CreateForm: React.FC<CreateFormProps> = props => {
  const { modalVisible, form, handleAdd, handleModalVisible } = props;
  const okHandle = () => {
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      form.resetFields();
      handleAdd(fieldsValue);
    });
  };
  const residences = [
    {
      value: 'zhihuixiaoyuan',
      label: '智慧校园',
      children: [
        {
          value: 'zhihuijiaoshi',
          label: '智慧教室',
          children: [
            {
              value: 'jiaoxue',
              label: '教学',
            },
            {
              value: 'guanli',
              label: '管理',
            },
          ],
        },
      ],
    },
    {
      value: 'litishucheng',
      label: '智慧实习',
      children: [
        {
          value: 'nanjing',
          label: 'Nanjing',
          children: [
            {
              value: 'zhonghuamen',
              label: 'Zhong Hua Men',
            },
          ],
        },
      ],
    },
  ];
  const customPanelStyle = {
    background: '#f7f7f7',
    borderRadius: 4,
    marginBottom: 24,
    border: 0,
    overflow: 'hidden',
  };
  return (
    <Modal
      destroyOnClose
      title="新建产品"
      visible={modalVisible}
      onOk={okHandle}
      onCancel={() => handleModalVisible()}
    >

      <Collapse bordered={false} defaultActiveKey={['1', '2', '3']} expandIconPosition='right'>
        <Panel showArrow={false} header="产品信息" key="1" style={customPanelStyle}>
          <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 16 }} label="产品名称">
            {form.getFieldDecorator('desc', {
              rules: [{ required: true, message: '请输入至少五个字符的规则描述！', min: 5 }],
            })(<Input placeholder="请输入您的产品名称" />)}
          </FormItem>
          <Form.Item labelCol={{ span: 6 }} wrapperCol={{ span: 16 }} label={<span>所属分类 <Popover overlayStyle={{width:'300px'}} content="选择的品类定义了该类设备的物模型，您可以直接选择并快速完成产品的功能定义，您也可以根据实际需要进行扩展和自定义完成产品的功能定义。品类的物模型标准来源于ICA联盟。" title="帮助"><Icon type="question-circle" theme="filled" style={{opacity:0.3}} /></Popover></span>}>
            {form.getFieldDecorator('residence', {
              //initialValue: ['zhejiang', 'hangzhou', 'xihu'],
              rules: [
                { type: 'array', required: true, message: 'Please select your habitual residence!' },
              ],
            })(<Cascader options={residences} style={{ width: '100%' }} placeholder="请选择所属分类" />)}
          </Form.Item>
        </Panel>
        <Panel showArrow={false} header={<span>节点类型</span>} key="2" style={customPanelStyle}>
          <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 16 }} label="节点类型">
            {form.getFieldDecorator('desc', {
              initialValue: 1,
              rules: [{ required: true, message: '请输入至少五个字符的规则描述！', min: 5 }],
            })(
              <Radio.Group >
                <Radio value={1}>设备</Radio>
                <Radio value={2}>网关</Radio>
              </Radio.Group>
            )}
          </FormItem>
        </Panel>
        <Panel showArrow={false} header="连网与数据" key="3" style={customPanelStyle}>
          <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 16 }} label="连网方式">

            {form.getFieldDecorator('desc', {
              initialValue: 'WiFi',
              rules: [{ required: true, message: '请输入至少五个字符的规则描述！', min: 5 }],
            })(
              <Select style={{ width: '100%' }}>
                <Option value="WiFi">WiFi</Option>
                <Option value="Cellular">蜂窝 (2G / 2G / 4G / 5G)</Option>
                <Option value="Ethernet">以太网</Option>
                <Option value="LoRaWAN">LoRaWAN</Option>
                <Option value="Other">其他</Option>
              </Select>
            )}
          </FormItem>
          <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 16 }} label="数据格式">
            {form.getFieldDecorator('format', {
              initialValue: 'ICA',
              rules: [{ required: true, message: '请选择数据格式！', min: 5 }],
            })(
            <Select style={{ width: '100%' }}>
              <Option value="ICA">ICA 标准数据格式 (Alink JSON)</Option>
              <Option value="Custom">透传/自定义</Option>
            </Select>
            )}
          </FormItem>
        </Panel>
        <Panel header="更多信息" key="4" style={customPanelStyle}>
          <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 16 }} label="产品描述">
            {form.getFieldDecorator('desc', {
              rules: [{ required: true, message: '请输入至少五个字符的规则描述！', min: 5 }],
            })(<TextArea rows={4} placeholder="产品描述" />)}
          </FormItem>
        </Panel>
      </Collapse>

    </Modal>
  );
};

export default Form.create<CreateFormProps>()(CreateForm);