import { Form, Input, Modal, InputNumber } from 'antd';
import React, { useEffect } from 'react';
import { FormComponentProps } from 'antd/es/form';

const FormItem = Form.Item;
interface UpdataEduInfo extends FormComponentProps {
  modalVisible: boolean;
  handleUpdate: (fieldsValue: { desc: string }) => void;
  handleEditModalVisible: () => void;

  dispatch: (payload: {}) => void;
  modifyId: string;
  eduInfo: { [key: string]: string };
}

const UpdataEduInfo: React.FC<UpdataEduInfo> = props => {
  const {
    modalVisible,
    form,
    handleUpdate,
    handleEditModalVisible,
    dispatch,
    modifyId,
    eduInfo,
  } = props;

  const okHandle = () => {
    form.validateFields((err, fieldsValue) => {
      const data = fieldsValue;
      if (err) return;
      form.resetFields();

      data.orgId = eduInfo.org_id;

      handleUpdate(data);
    });
  };

  useEffect(() => {
    if (modifyId) {
      dispatch({
        type: 'organizationBureau/GetEduInfoById',
        payload: {
          orgId: modifyId,
        },
      });
    }
  }, [modifyId]);

  return (
    <Modal
      destroyOnClose
      title="编辑教辅单位信息"
      visible={modalVisible}
      onOk={okHandle}
      maskClosable={false}
      onCancel={() => handleEditModalVisible()}
      width="700px"
    >
      {/* 所在行政区划 */}
      <FormItem labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="教辅单位代码">
        {form.getFieldDecorator('orgCode', {
          initialValue: eduInfo.org_code,
          rules: [
            {
              required: true,
              message: '请输入2-20个字母或数字',
            },
            {
              min: 2,
              max: 20,
              message: '长度不在范围内',
            },
            {
              pattern: new RegExp('^\\w+$', 'g'),
              message: '教辅单位代码必须为字母或者数字',
            },
          ],
        })(<Input maxLength={20} />)}
      </FormItem>


      <FormItem labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="教辅单位名称">
        {form.getFieldDecorator('orgName', {
          initialValue: eduInfo.org_name,
          rules: [
            {
              required: true,
              message: '请输入1-30个汉字、字母或者数字',
            },
            {
              pattern: new RegExp('^[\u4E00-\u9FA5A-Za-z0-9]+$', 'g'),
              message: '教辅单位名称必须为汉字、字母或者数字',
            },
            {
              max: 30,
              message: '长度不在范围内',
            },
          ],
        })(<Input maxLength={30} />)}
      </FormItem>
      <Form.Item labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="教辅单位法定代表人">
        {form.getFieldDecorator('fddbr', {
          initialValue: eduInfo.fddbr,
          rules: [
            {
              pattern: new RegExp('^[\u4E00-\u9FA5A-Za-z0-9]+$', 'g'),
              message: '请输入汉字、字母或者数字',
            },
            {
              min: 2,
              max: 30,
              message: '长度范围在2-30个字符之间。',
            },
          ],
        })(<Input maxLength={30} />)}
      </Form.Item>
      <Form.Item labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="教辅单位法定代表人电话">
        {form.getFieldDecorator('fddbrdh', {
          initialValue: eduInfo.fddbrdh,
          rules: [
            {
              min: 2,
              max: 30,
              message: '长度范围在2-30个字符之间。',
            },
            {
              pattern: new RegExp('^[ 0-9+-]*$', 'g'),
              message: '请输入电话可用字符。',
            },
          ],
        })(<Input maxLength={30} />)}
      </Form.Item>
      <Form.Item labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="教辅单位地址">
        {form.getFieldDecorator('address', {
          initialValue: eduInfo.address,
          rules: [
            {
              pattern: new RegExp('^[\u4E00-\u9FA5A-Za-z0-9-]+$', 'g'),
              message: '请输入汉字、字母或者数字',
            },
            {
              min: 2,
              max: 100,
              message: '长度范围在2-100个字符之间。',
            },
          ],
        })(<Input maxLength={100} />)}
      </Form.Item>

      <Form.Item labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="联系电话">
        {form.getFieldDecorator('lxdh', {
          initialValue: eduInfo.lxdh,
          rules: [
            {
              min: 2,
              max: 30,
              message: '长度范围在2-30个字符之间。',
            },
            {
              pattern: new RegExp('^[ 0-9+-]*$', 'g'),
              message: '请输入电话可用字符。',
            },
          ],
        })(<Input maxLength={30} />)}
      </Form.Item>

      <Form.Item labelCol={{ span: 7 }} wrapperCol={{ span: 8 }} label={'排序号'}>
        {form.getFieldDecorator('sortId', {
          initialValue: eduInfo.sort_id + '',
          rules: [
            {
              pattern: new RegExp('^[0-9]*$', 'g'),
              message: '请输入1~4位数字',
            },
          ]
        })(<InputNumber style={{ width: "100%" }} placeholder="请输入排序号" maxLength={4} min={1} max={9999} />)}
      </Form.Item>
    </Modal>
  );
};

export default Form.create<UpdataEduInfo>()(UpdataEduInfo);
