import {
  Button,
  Card,
  Col,
  Divider,
  Popconfirm,
  Form,
  Input,
  Row,
  message,
  Select,
} from 'antd';


import React, { Component, Fragment } from 'react';

import { Dispatch, Action } from 'redux';
import { FormComponentProps } from 'antd/es/form';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { SorterResult } from 'antd/es/table';
import { connect } from 'dva';
import router from 'umi/router';
import Link from 'umi/link';
import { control } from 'keymaster';
import { CascaderOptionType } from 'antd/lib/cascader';
import { StateType } from './model';
import AddEffectForm from './components/AddEffectForm';
import UpdataEffectForm from './components/UpdataEffectForm'

import StandardTable, { StandardTableColumnProps } from './components/StandardTable';
import { FormValueType } from './components/UpdateForm';

import { TableListItem } from './data.d';

import styles from './style.less';
import CascadeGeographic from '../../../components/CascadeGeographic'

const FormItem = Form.Item;
const { Option } = Select;

interface TableListProps extends FormComponentProps {
  dispatch: Dispatch<
    Action<
      | 'organizationEffect/PageEduAssistInfo'
      | 'organizationEffect/GetEduAssistInfoById'
      | 'organizationEffect/AddEduAssistInfo'
      | 'organizationEffect/UpdateEduAssistInfo'
      | 'organizationEffect/DeleteEduAssistInfo'
      | 'organizationEffect/getPersonMsg'
      | 'organizationEffect/getRegionMsg'
    >
  >;
  loading: boolean;
  organizationEffect: StateType;
}

interface TableListState {
  eduInfo: { [key: string]: string };
  modalVisible: boolean;
  updateModalVisible: boolean;
  expandForm: boolean;
  selectedRows: TableListItem[];
  formValues: { [key: string]: string };
  stepFormValues: Partial<TableListItem>;
  areaCode: string;
  codeArr: any;
  areaParentCode: string;
  page: number,
  pageSize: number,
  orgName: string,
  orgtype: number,
  regionalInformation: [];
  showAddBtn: boolean;
}

/* eslint react/no-multi-comp:0 */
@connect(
  ({
    organizationEffect,
    loading,
  }: {
    organizationEffect: StateType;
    loading: {
      models: {
        [key: string]: boolean;
      };
    };
  }) => ({
    organizationEffect,
    loading: loading.models.organizationEffect,
  }),
)
class TableList extends Component<TableListProps, TableListState> {
  state: TableListState = {
    modalVisible: false,
    updateModalVisible: false,
    expandForm: false,
    selectedRows: [],
    formValues: {},
    stepFormValues: {},
    areaCode: this.props.location.query.code && this.props.location.query.code2 !== "" ? this.props.location.query.code2 : this.props.location.query.code && this.props.location.query.code1 !== "" ? this.props.location.query.code1 : '220100',
    codeArr: this.props.location.query.code ? [this.props.location.query.code, this.props.location.query.code1, this.props.location.query.code2] : ["220000", "220100",""],
    areaParentCode: '',
    eduInfo: {},
    page: 1,
    pageSize: 10,
    orgName: '',
    orgtype: 1,
    regionalInformation: [],
    showAddBtn: true,
  };

  columns: StandardTableColumnProps[] = [
    {
      title: '序号',
      dataIndex: 'org_id',
      // render(text, record, index) {
      //   return <span>{index + 1}</span>;
      // },
      // render: (text, record, index) =>
      //   `${((this.props.organizationEffect.data.pagination.current || 1) - 1) *
      //     (this.props.organizationEffect.data.pagination.pageSize || 10) +
      //     (index + 1)}`,

      render: (text, record, index) =>
        `${(this.state.page - 1) * (this.state.pageSize) + (index + 1)}`,

    },
    {
      title: '教辅单位名称',
      dataIndex: 'org_name',
    },
    {
      title: '教辅单位代码',
      dataIndex: 'org_code',
    },
    {
      title: '操作',
      render: (text, record) => (
        <Fragment>
          <a onClick={() => { this.handleEditModalVisible(record.org_id, true) }}>编辑</a>
          <Divider type="vertical" />

          <Popconfirm
            title={`是否确认删除『${record.org_name}』？`}
            okText="确认"
            cancelText="取消"
            onConfirm={() => this.handleDelete(record.org_id)}
          >
            <a style={{ color: 'red' }}>删除</a>
          </Popconfirm>
          <Divider type="vertical" />
          <Link to={`/organization/effect/branch/${record.org_id}`} onClick={() => {
            // router.push({
            //   pathname: '/organization/effect/' + record.area_code,
            // });
            router.push({
              pathname: '/organization/effect/',
              query: {
                code: this.state.codeArr[0],
                code1: this.state.codeArr[1] ? this.state.codeArr[1] : "",
                code2: this.state.codeArr[2] ? this.state.codeArr[2] : "",
              },
            })
          }}>部门管理</Link>
          <Divider type="vertical" />
          <Link to={'/organization/effect/teacher/' + record.org_id} onClick={() => {
            // router.push({
            //   pathname: '/organization/effect/' + record.area_code,
            // });
            router.push({
              pathname: '/organization/effect/',
              query: {
                code: this.state.codeArr[0],
                code1: this.state.codeArr[1] ? this.state.codeArr[1] : "",
                code2: this.state.codeArr[2] ? this.state.codeArr[2] : "",
              },
            })
          }}>教职工管理</Link>

        </Fragment>
      ),
    },
  ];

  renderAdvancedForm: any;

  componentDidMount() {
    const { areaCode } = this.state;
    const { dispatch } = this.props;
    console.log('this:', this)
    dispatch({
      type: 'organizationEffect/getPersonMsg',
      callback: (data: any) => {
        if (data.list[0].role_id === 'A66C757C-F797-454D-99DE-2A3F5415BC22') {
          this.setState({ orgtype: 1 })
          this.getEffectList(areaCode);
        } else if (data.list[0].role_id === '5CC3293C-3AA5-45B7-B54B-CA8CC549FB81') {
          this.setState({ orgtype: 2 })
          dispatch({
            type: 'organizationEffect/getRegionMsg',
            payload: {
              areaType: '1',
            },
            callback: (response: any) => {
              if (response.success === true) {
                this.getEffectList(response.list[0].area_code);
                this.setState({
                  regionalInformation: response.list,
                  areaCode: response.list[0].area_code,
                  areaParentCode: response.list[0].parent_code,
                })
              }
            },
          })
        } else if (data.list[0].role_id === 'BF61C95F-3ADD-4F37-9FCD-97E69E1BF6E3') {
          this.setState({ orgtype: 3 })
          dispatch({
            type: 'organizationEffect/getRegionMsg',
            payload: {
              areaType: '2',
            },
            callback: (response: any) => {
              if (response.success === true) {
                this.getEffectList(response.list[0].area_code);
                this.setState({
                  regionalInformation: response.list,
                  areaCode: response.list[0].area_code,
                  areaParentCode: response.list[0].parent_code,
                })
              }
            },
          })
        }
      },
    });
  }

  // 获取列表
  getEffectList(areaCode: string, pagination?: { [key: string]: string }) {
    const { dispatch } = this.props;
    if (!pagination) {
      pagination = {
        page: this.state.page,
        limit: this.state.pageSize,
      }
    }
    // debugger
    dispatch({
      type: 'organizationEffect/PageEduAssistInfo',
      payload: {
        areaCode,
        ...pagination,
        orgName: this.state.orgName,
      },
    });
  }


  // 分页
  handleStandardTableChange = (

    pagination: { [key: string]: string },
    // filtersArg: Record<keyof TableListItem, string[]>,
    sorter: SorterResult<TableListItem>,
  ) => {
    const { formValues, areaCode } = this.state;

    const page = pagination.current;
    const { pageSize } = pagination;

    pagination = {
      page,
      limit: pageSize,
    }

    this.getEffectList(areaCode, pagination)
    this.setState({
      page,
      pageSize,
    })
  };


  // // 表单重置
  // handleFormReset = () => {
  //   const { form } = this.props;
  //   form.resetFields();
  //   this.setState({
  //     formValues: {},
  //   });
  //   const areaCode = this.state.areaCode;
  //   this.state.orgName = "";
  //   this.getEffectList(areaCode);
  // };

  toggleForm = () => {
    const { expandForm } = this.state;
    this.setState({
      expandForm: !expandForm,
    });
  };


  handleSelectRows = (rows: TableListItem[]) => {
    this.setState({
      selectedRows: rows,
    });
  };

  handleSearch = (e: React.FormEvent) => {
    e.preventDefault();
    const { dispatch, form } = this.props;
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      const values = {
        ...fieldsValue,
      };
      this.setState({
        orgName: values.orgName,
        // areaCode: values.areaCode[values.areaCode.length - 1],
      }, () => {
        this.getEffectList(this.state.areaCode)
      });
    });
  };

  // 下拉筛选
  handleSelect = (value: any) => {
    if (this.state.orgtype === 1) {
      // this.state.codeArr = value;
      this.setState({ codeArr: value })
      if (value.length > 1) {
        let code = value[value.length - 1]
        const { form } = this.props;
        form.resetFields();
        this.setState({ areaCode: code, formValues: {}, orgName: '', showAddBtn: true })
        this.state.orgName = '';
        this.getEffectList(code);
      } else {
        // debugger
        // this.setState({ showAddBtn: false })
      }
    }
  }

  // 新增弹窗
  handleModalVisible = (flag?: boolean) => {
    this.setState({
      modalVisible: !!flag,
    });
  };

  // 修改弹窗
  handleEditModalVisible = (orgId?: string, flag?: boolean) => {
    if (flag) {
      const { dispatch } = this.props;
      dispatch({
        type: 'organizationEffect/GetEduAssistInfoById',
        payload: {
          orgId,
        },
        callback: (response: any) => {
          this.setState({
            eduInfo: response,
            updateModalVisible: !!flag,
          });
        },
      });
    } else {
      this.setState({
        updateModalVisible: !!flag,
      });
    }
  };

  // 新增提交处理
  handleAdd = (fields: { desc: any }) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'organizationEffect/AddEduAssistInfo',
      payload: {
        ...fields,
      },
      callback: (response: any) => {
        if (response.success) {
          message.success('添加成功');
          const { areaCode } = this.state;
          this.getEffectList(areaCode);
          this.handleModalVisible(false);
        } else {
          message.error(`添加失败,${response.message}`);
        }
      },
    });
  };


  // 修改调
  handleUpdate = (fields: FormValueType) => {
    const { dispatch } = this.props;
    const { areaCode } = this.state;

    dispatch({
      type: 'organizationEffect/UpdateEduAssistInfo',
      payload: {
        ...fields,
      },
      callback: (response: any) => {
        if (response.success) {
          this.getEffectList(areaCode);
          message.success('编辑成功');
          this.handleEditModalVisible('')
        } else {
          message.error(`编辑失败,${response.message}`);
        }
      },
    });
  };

  // 删除
  handleDelete = (orgIds: string) => {
    const { dispatch } = this.props;

    const { areaCode } = this.state;

    dispatch({
      type: 'organizationEffect/DeleteEduAssistInfo',
      payload: {
        orgIds,
      },
      callback: (response: any) => {
        if (response.success) {
          message.success('删除成功');
          this.getEffectList(areaCode);
        } else {
          this.getEffectList(areaCode);
          message.error(`删除失败,${response.message}`);
        }
      },
    });
    this.handleModalVisible();
  };

  onLoadChange = (selectedOptions:any) => {
  //   debugger
  //   if(selectedOptions.length === 1){
  //     this.setState({csSelect:true})
  //   }else {
  //     this.setState({csSelect:false})
  //   }
  }

  /**
   * 选择后渲染方法
   * @param label
   * @param selectedOptions
   */
  displayRender = (label:string[], selectedOptions: CascaderOptionType[]) => {
    // alert('displayRender');
    console.log('selectedOptions', selectedOptions)
    console.log('label>>>>>>####>>>>>>', label)
    console.log('label>>length>>', selectedOptions.length)
    console.log('this.state###>>>', this.state)

    //
    let path;
    if (selectedOptions.length === 1) {
      // path = ''
      path = sessionStorage.getItem('prevSelectedOptions')
    } else {
      sessionStorage.setItem('prevSelectedOptions', label.join(' / '))
      path = label.join(' / ')
    }
    return path
  }

  renderSimpleForm() {
    const { form } = this.props;
    const { getFieldDecorator } = form;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={8} sm={24}>
            <FormItem label="所在行政区划">
              {this.state.orgtype === 1 ? getFieldDecorator('areaCode', {
                initialValue: this.state.codeArr,
              })(<CascadeGeographic changeOnSelect={true} level="3" defaultValue={this.state.codeArr} onChange={this.handleSelect}
              // onLoadChange={this.onLoadChange}
              />)
                : this.state.orgtype === 2 ? getFieldDecorator('areaCode', {
                  initialValue: this.state.areaCode,
                })(<Select defaultValue={this.state.areaCode} onChange={this.handleSelect}>
                  {this.state.regionalInformation.map(item => <Option value={item.area_code}>{`${item.parent_name}/${item.area_name}`}</Option>)}
                </Select>)
                  : getFieldDecorator('areaCode', {
                    initialValue: this.state.areaCode,
                  })(<Select defaultValue={this.state.areaCode} onChange={this.handleSelect}>
                    {this.state.regionalInformation.map(item => <Option value={item.area_code}>{`${item.parent_name}/${item.area_name}`}</Option>)}
                  </Select>)}
            </FormItem>
          </Col>
          <Col md={8} sm={24}>
            <FormItem label="教辅单位名称">
              {getFieldDecorator('orgName')(<Input placeholder="请输入" allowClear maxLength={30} />)}
            </FormItem>
          </Col>

          <Col md={4} sm={12}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              {/* <Button style={{ marginLeft: 8 }} onClick={this.handleFormReset}>
                重置
              </Button> */}
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  renderForm() {
    const { expandForm } = this.state;
    return expandForm ? this.renderAdvancedForm() : this.renderSimpleForm();
  }

  render() {
    const {
      organizationEffect: { data },
      loading,
    } = this.props;

    const { selectedRows, modalVisible, updateModalVisible, stepFormValues } = this.state;


    // 新建参数
    const parentMethods = {
      handleAdd: this.handleAdd,
      handleModalVisible: this.handleModalVisible,
      areaCode: this.state.areaCode,
    };
    const updateMethods = {
      handleEditModalVisible: this.handleEditModalVisible,
      handleUpdate: this.handleUpdate,
      eduInfo: this.state.eduInfo,
    };


    data.pagination = {
      current: this.state.page,
      total: data.count,
      pageSize: this.state.pageSize,
      showTotal: ((total:any) => {
        return `共 ${total} 条`;
      }),
    }
    return (
      <PageHeaderWrapper>
        <Card bordered={false}>
          <div className={styles.tableList}>
            <div className={styles.tableListForm}>{this.renderForm()}</div>
            <div className={styles.tableListOperator}>
              {this.state.showAddBtn === true ? <Button icon="plus" type="primary" onClick={() => this.handleModalVisible(true)}>
                新建教辅单位
              </Button> : ''}

            </div>
            <StandardTable
              rowKey="org_id"
              selectedRows={selectedRows}
              loading={loading}
              data={data}
              rowSelection={false}
              columns={this.columns}
              onSelectRow={this.handleSelectRows}
              onChange={this.handleStandardTableChange}

            />
          </div>
        </Card>
        <AddEffectForm {...parentMethods} modalVisible={modalVisible} />
        <UpdataEffectForm {...updateMethods} modalVisible={updateModalVisible} />

      </PageHeaderWrapper>
    );
  }
}

export default Form.create<TableListProps>()(TableList);
