import { AnyAction, Reducer } from 'redux';
import { EffectsCommandMap } from 'dva';
import { PageEduAssistInfo, GetEduAssistInfoById, AddEduAssistInfo, UpdateEduAssistInfo, DeleteEduAssistInfo, GetPersonMsg, GetRegionMsg } from './service';

import { TableListData } from './data.d';

export interface StateType {
  data: TableListData;
}

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: StateType) => T) => T },
) => void;

export interface ModelType {
  namespace: string;
  state: StateType;
  effects: {
    PageEduAssistInfo: Effect;
    GetEduAssistInfoById: Effect;
    AddEduAssistInfo: Effect;
    UpdateEduAssistInfo: Effect;
    DeleteEduAssistInfo: Effect;
    getPersonMsg: Effect;
    getRegionMsg: Effect;
  };
  reducers: {
    save: Reducer<StateType>;
  };
}

const Model: ModelType = {
  namespace: 'organizationEffect',

  state: {
    data: {
      list: [],
      pagination: {},
    },
  },

  effects: {
    // 获取教辅单位列表
    *PageEduAssistInfo({ payload }, { call, put }) {

      let response = yield call(PageEduAssistInfo, payload);

      // 处理最后一页删除数据后当前页面没有数据从新计算页数从新拿数据。
      let listLength = response.list.length
      while (listLength < 1) {
        payload.page = payload.page == 1 ? 1 : payload.page - 1;
        response = yield call(PageEduAssistInfo, payload);
        listLength = response.list.length
        if (response.count == 0) break;
      }
      yield put({
        type: 'save',
        payload: response,
      });
    },
    // 根据教辅单位ID获取教辅单位信息
    *GetEduAssistInfoById({ payload, callback }, { call, put }) {

      const response = yield call(GetEduAssistInfoById, payload);

      if (callback) callback(response.list[0]);
    },
    // 增加教辅单位信息
    *AddEduAssistInfo({ payload, callback }, { call, put }) {
      const response = yield call(AddEduAssistInfo, payload);
      if (callback) callback(response);
    },
    // 修改教辅单位信息
    *UpdateEduAssistInfo({ payload, callback }, { call, put }) {
      const response = yield call(UpdateEduAssistInfo, payload);
      if (callback) callback(response);
    },
    // 删除教辅单位信息
    *DeleteEduAssistInfo({ payload, callback }, { call, put }) {
      const response = yield call(DeleteEduAssistInfo, payload);
      if (callback) callback(response);
    },
    // 获取人员角色信息
    *getPersonMsg({ payload, callback }, { call, put }) {
      const response = yield call(GetPersonMsg, payload);
      if (callback) callback(response);
    },
    // 根据人员ID获取所管辖的地区信息
    *getRegionMsg({ payload, callback }, { call, put }) {
      const response = yield call(GetRegionMsg, payload);
      if (callback) callback(response);
    },
  },

  reducers: {
    save(state, action) {
      return {
        ...state,
        data: action.payload,
      };
    },
  },
};

export default Model;
