import { Form, Tag, Input, Icon, Modal, InputNumber } from 'antd';

import { FormComponentProps } from 'antd/es/form';
import SelectLeader from "./selectLeader";
import React, { useState, useEffect } from 'react';
import { StateType } from '../model';
import { Dispatch, Action } from 'redux';

const FormItem = Form.Item;

interface CreateFormProps extends FormComponentProps {
  type: string;
  orgId: string;
  orgInfo: any;
  dispatchProps: any;
  modalVisible: boolean;
  handleAdd: (fieldsValue: { desc: string }) => void;
  handleModalVisible: () => void;
  handleUpdateModalVisible: () => void;
  getLeader: () => void;
  rand: number;

  dispatch: Dispatch<
    Action<
      | 'branch/getTeacherList'
    >
  >;
  loading: boolean;
  branch: StateType;
}

const CreateForm: React.FC<CreateFormProps> = props => {

  const { modalVisible, form, handleAdd, handleModalVisible, handleUpdateModalVisible, orgId, type, dispatchProps, rand } = props;
  var { orgInfo } = props;
  const [showModals, setshowModals] = useState(false); // modal显示
  const [leaderName, setleaderName] = useState(""); // 领导姓名
  const [leaderId, setleaderId] = useState(""); // 领导id

  useEffect(() => {
    if (type == 'add') {
      setleaderId("")
      form.setFieldsValue({ org_id: "" })
    }

  }, [rand])

  const okHandle = () => {
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      // form.resetFields();
      // setleaderName("")
      // console.log(fieldsValue)
      handleAdd({ desc: fieldsValue });
      setleaderName(fieldsValue.org_person)
    });
  };
  const afterClose = () => {
    setleaderName("")
    setleaderId("")
  }
  // 选中领导回显
  const checkLeader = (fields: { desc: any }) => {
    // console.log(fields)
    if (fields.desc.length) {
      form.setFieldsValue({ org_id: fields.desc[0].person_id });
      form.setFieldsValue({ org_person: fields.desc[0].xm });
      setleaderName(fields.desc[0].xm)
      setleaderId(fields.desc[0].person_id)
      cancelModal()
    } else {
      cancelModal()
    }
  }
  // 删除已选领导人
  const handleDelete = () => {
    // orgInfo = [];
    orgInfo[0].org_manager_id = "";
    orgInfo[0].org_manager_name = "";
    form.setFieldsValue({ org_id: "" });
    form.setFieldsValue({ org_person: "" });
    setleaderName("")
    setleaderId("")
  }

  // 显示弹窗（选人）
  const showModal = () => {
    setshowModals(true);
  }

  // 关闭弹窗（选人）
  const cancelModal = () => {
    setshowModals(false)
  }

  // 关闭form
  const handleClickChange = () => {
    setleaderName("")
    setleaderId("")
    if (type === "add") {
      handleModalVisible()
    } else {
      handleUpdateModalVisible()
    }
  }
  return (
    [<Modal
      destroyOnClose
      title={type === "add" ? "增加部门" : "修改部门"}
      visible={modalVisible}
      onOk={okHandle}
      afterClose={afterClose}
      maskClosable={false}
      onCancel={handleClickChange}
      width="700px"
    >
      {/* 部门代码*/}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 16 }} label="部门代码" >
        {form.getFieldDecorator('org_code', {
          initialValue: type === "add" ? "" : orgInfo && orgInfo.length > 0 ? orgInfo[0].org_code : "",
          rules: [
            {
              required: true,
              message: '请输入2-20个字母或数字',
            },
            {
              min: 2,
              max: 20,
              message: '长度不在范围内',
            },
            {
              pattern: new RegExp('^\\w+$', 'g'),
              message: '部门代码必须为字母或者数字',
            },
          ],
        })(<Input placeholder="请输入部门代码" maxLength={20} />)}
      </FormItem>
      {/* 部门名称 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 16 }} label="部门名称">
        {form.getFieldDecorator('org_name', {
          initialValue: type === "add" ? "" : orgInfo && orgInfo.length > 0 ? orgInfo[0].org_name : "",
          rules: [
            {
              required: true,
              message: '请输入1-30个汉字或字母或数字',
            },
            {
              min: 1,
              max: 50,
              message: '长度不在范围内',
            },
            {
              pattern: new RegExp('^[\u4E00-\u9FA5A-Za-z0-9]+$', 'g'),
              message: '部门名称必须为汉字或字母或者数字',
            },
          ],
        })(<Input placeholder="请输入部门名称" maxLength={30} />)}
      </FormItem>
      {/* 排序号 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 16 }} label="排序号">
        {form.getFieldDecorator('number', {
          initialValue: type === "add" ? "" : orgInfo && orgInfo.length > 0 ? orgInfo[0].sort_id : "",
          rules: [
            {
              pattern: new RegExp('^[0-9]*$', 'g'),
              message: '请输入1~4位数字',
            },
          ]
        })(<InputNumber style={{ width: "100%" }} placeholder="请输入排序号" maxLength={4} min={1} max={9999} />)}
      </FormItem>
      {/* 部门领导 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 16 }} label="部门领导">
        {form.getFieldDecorator('org_id', {
          initialValue: type === "edit" && leaderName === "" && orgInfo && orgInfo.length > 0 ? orgInfo[0].org_manager_id : leaderId,
        })}
        {form.getFieldDecorator('org_person', {
          initialValue: type === "edit" && leaderName === "" && orgInfo && orgInfo.length > 0 ? orgInfo[0].org_manager_name : leaderName,
          rules: [
            {
              required: false,
            },
          ],
        })(<div>
          {console.log(type, "edit", leaderName, orgInfo,)}
          {type === "edit" && leaderName === "" && orgInfo && orgInfo.length > 0 && orgInfo[0].org_manager_name ?
            <Tag closable onClose={handleDelete} style={{ lineHeight: "28px", fontSize: "14px" }}>
              {orgInfo[0].org_manager_name}
            </Tag>
            : leaderName !== "" ?
              <Tag closable onClose={handleDelete} style={{ lineHeight: "28px", fontSize: "14px" }}>
                {leaderName}
              </Tag>
              : ""}
          <Tag onClick={showModal} style={{ background: "#1890ff", color: "#fff", lineHeight: "28px", fontSize: "14px" }} >
            <Icon type="plus" style={{ color: "#fff" }} /> 选择部门领导
          </Tag>
        </div>

          // <Input placeholder="请选择部门领导" onClick={showModal} />
        )}
      </FormItem>
    </Modal>,
    showModals ? <SelectLeader
      key={"selectLeader"}
      modalVisible={showModals}
      checkLeader={checkLeader}
      leaderId={type === "edit" && leaderName === "" && orgInfo && orgInfo.length > 0 ? orgInfo[0].org_manager_id : leaderId}
      type={type}
      orgId={orgId}
      randomNumber={Math.random()}
      dispatchProps={dispatchProps}
      cancelModal={cancelModal}
    /> : ""
    ]
  );
};


export default Form.create<CreateFormProps>()(CreateForm);
