import { Form, Input, Modal, Row, Col, Button, Table } from 'antd';
import { FormComponentProps } from 'antd/es/form';
import React, { useState, useEffect } from 'react';

const FormItem = Form.Item;

interface CreateFormProps extends FormComponentProps {
    orgId: string;
    type: string;
    randomNumber: number;
    leaderId: [];
    modalVisible: boolean; // 显示modal
    cancelModal: () => void; // 返回上一层
    dispatchProps: any;
    checkLeader: (fieldsValue: { desc: any }) => void;
}

const SelectLeader: React.FC<CreateFormProps> = props => {
    const { modalVisible, form, cancelModal, checkLeader, dispatchProps, orgId, leaderId, randomNumber } = props;
    const dataTeacher = dispatchProps.branch.dataTeacher ? dispatchProps.branch.dataTeacher.list : [] // 分页用到（获取列表）
    const listPageNum = dispatchProps.branch.dataTeacher ? dispatchProps.branch.dataTeacher.count : 0  // 分页用到（当前总条数）
    const [oneCheck, oneCheckSet] = useState({}); // 选择领导{确认}
    // const [thisLeaderList, setLeaderList] = useState([]);// 分页用到（获取列表）
    // const [listPageNum, setListPageNum] = useState(0);// 分页用到（当前总条数）
    const [oneCheckid, setoneCheckid] = useState([]);
    const [depId, setDepId] = useState("");
    const columns = [
        {
            title: '教职工姓名',
            dataIndex: 'xm',
        },
        {
            title: '性别',
            dataIndex: 'xb_name',
        },
        {
            title: '所属部门',
            dataIndex: 'org_name',
        },
        {
            title: '账号状态',
            dataIndex: 'login_status',
        },
    ];
    // console.log('leaderId111111111:', leaderId, 'oneCheckid:', oneCheckid, "oneCheck1112:", oneCheck);

    // 搜索
    const handleSearch = () => {
        form.validateFields((err, fieldsValue) => {
            if (err) return;
            if (fieldsValue.orgName || fieldsValue.orgName === "") {
                // debugger
                fieldsValue.orgName = fieldsValue.orgName;
                const { dispatch } = dispatchProps;
                dispatch({
                    type: 'branch/getTeacherList',
                    payload: {
                        page: 1,
                        limit: 5,
                        orgId: orgId ? orgId : depId,
                        xm: fieldsValue.orgName,
                    },
                });
            }
        });
    }

    // 获取教师列表
    useEffect(() => {
        const { dispatch } = dispatchProps;
        if (orgId == undefined) {
            dispatch({
                type: 'branch/getPersonMsg',
                payload: {},
                callback: (response: any) => {
                    setDepId(response.list[0].rule_id);
                    dispatch({
                        type: 'branch/getTeacherList',
                        payload: {
                            page: 1,
                            limit: 5,
                            xm: "",
                            orgId: response.list[0].rule_id
                        }
                    });
                },
            });
        } else {
            dispatch({
                type: 'branch/getTeacherList',
                payload: {
                    page: 1,
                    limit: 5,
                    orgId: orgId,
                    xm: "",
                },
            });
        }
        // 编辑时，教师回显
        setoneCheckid(leaderId);
    }, [leaderId])

    // 点击确认
    const okHandle = () => {
        const { dispatch } = dispatchProps;
        dispatch({
            type: 'branch/getTeacherList',
            payload: {
                page: 1,
                limit: 5,
                orgId: orgId ? orgId : depId,
                xm: "",
            },
        });
        form.validateFields((err, fieldsValue) => {
            if (err) return;
            form.resetFields();
            checkLeader({ desc: oneCheck });
        });
    };
    // 点击取消
    const handleCancel = () => {
        const { dispatch } = dispatchProps;
        dispatch({
            type: 'branch/getTeacherList',
            payload: {
                page: 1,
                limit: 5,
                orgId: orgId ? orgId : depId,
                xm: "",
            },
        });
        cancelModal()
    }
    useEffect(() => {
        if (leaderId) {
            setoneCheckid(leaderId)
        } else {
            setoneCheckid([])
        }
    }, [randomNumber])
    const { getFieldDecorator } = props.form;

    // 选中某一项（数据）
    const rowSelection = {
        onChange: (selectedRowKeys: any, selectedRows: any) => {
            // console.log(selectedRowKeys,selectedRows)
            setoneCheckid(selectedRowKeys)
            oneCheckSet(selectedRows)
        },
        // onSelect: (record, selected, selectedRows, nativeEvent) => {
        //     setoneCheckid(selectedRows)
        //     oneCheckSet(selectedRows.person_id)
        // },
    };

    // 分页
    const pageOnchange = (page: number) => {
        const { dispatch } = dispatchProps;
        dispatch({
            type: 'branch/getTeacherList',
            payload: {
                page: page,
                limit: 5,
                orgId: orgId ? orgId : depId,
                xm: "",
            },
        });
    }

    return (
        <Modal
            destroyOnClose
            title={"选择部门领导"}
            visible={modalVisible}
            onOk={okHandle}
            onCancel={handleCancel}
            width="700px"
        >
            <div>
                <Form layout="inline">
                    <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
                        <Col md={20} sm={12}>
                            <FormItem label="教职工名称">
                                {getFieldDecorator('orgName')(<Input placeholder="请输入" allowClear={true} />)}
                            </FormItem>
                        </Col>
                        <Col md={4} sm={12}>
                            <span>
                                <Button type="primary" htmlType="submit" onClick={handleSearch}> 查询 </Button>
                            </span>
                        </Col>
                    </Row>
                </Form>
                <Table
                    rowSelection={{
                        selectedRowKeys: oneCheckid,
                        type: "radio",
                        ...rowSelection,
                    }}
                    rowKey={(record: any) => record.person_id}
                    columns={columns}
                    // dataSource={thisLeaderList}
                    dataSource={dataTeacher}
                    pagination={{
                        defaultCurrent: 1,
                        defaultPageSize: 5,
                        pageSize: 5,
                        total: listPageNum,
                        onChange: pageOnchange
                    }}
                />
            </div>
        </Modal>
    );
};


export default Form.create<CreateFormProps>()(SelectLeader);
