import { AnyAction, Reducer } from 'redux';
import { EffectsCommandMap } from 'dva';
import { GetOrglist, GetOrgInfo, AddOrgInfo, EditOrgInfo, DeleteOrgInfo, GetTeacherlist, GetPersonMsg } from './service';

// eslint-disable-next-line import/no-unresolved
import { TableListData } from './data';

export interface StateType {
  data: TableListData;
}

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: StateType) => T) => T },
) => void;

export interface ModelType {
  namespace: string;
  state: StateType;
  effects: {
    getList: Effect;
    getInfo: Effect;
    addInfo: Effect;
    editInfo: Effect;
    deleteInfo: Effect;
    getTeacherList: Effect;
    getPersonMsg: Effect;
  };
  reducers: {
    save: Reducer<StateType>;
    saveTeacher: Reducer<StateType>;
  };
}

const Model: ModelType = {
  namespace: 'branch',

  state: {
    data: {
      list: [],
      pagination: {},
    },
  },

  effects: {
    *getList({ payload }, { call, put }) {
      const response = yield call(GetOrglist, payload);
      yield put({
        type: 'save',
        payload: response,
      });
    },
    *getInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetOrgInfo, payload);
      if (callback) callback(response);
    },
    *addInfo({ payload, callback }, { call, put }) {
      const response = yield call(AddOrgInfo, payload);
      if (callback) callback(response);
    },
    *editInfo({ payload, callback }, { call, put }) {
      const response = yield call(EditOrgInfo, payload);
      if (callback) callback(response);
    },
    *deleteInfo({ payload, callback }, { call, put }) {
      const response = yield call(DeleteOrgInfo, payload);
      yield put({
        type: 'save',
        payload: response,
      });
      if (callback) callback(response);
    },
    *getTeacherList({ payload, callback }, { call, put }) {
      const response = yield call(GetTeacherlist, payload);
      yield put({
        type: 'saveTeacher',
        payload: response,
      });
      if (callback) callback(response);
    },
    *getPersonMsg({ payload, callback }, { call, put }) {
      const response = yield call(GetPersonMsg, payload);
      if (callback) callback(response);
    }
  },

  reducers: {
    save(state, action) {
      return {
        ...state,
        data: action.payload,
      };
    },
    saveTeacher(state, action) {
      return {
        ...state,
        dataTeacher: action.payload,
      };
    },
  },
};

export default Model;
