import { Form, Input, Modal, Radio, InputNumber, Select } from 'antd';
import React, { useState, useEffect } from 'react';
import { FormComponentProps } from 'antd/es/form';

const FormItem = Form.Item;
interface AddClassForm extends FormComponentProps {
  addVisible: boolean;
  handleAdd: (fieldsValue: { desc: string }) => void;
  handleAddVisible: () => void;
  dispatch: (payload: {}) => void;
  StageList: { [key: string]: string }
  indexNum: number;
}

const AddClassForm: React.FC<AddClassForm> = props => {

  const [isBatch, setisBatch] = useState(0)
  let [stageInfo, setStageInfo] = useState([1, 2, 3, 4, 5, 6])
  let [rxnfInfo, setRxnfInfo] = useState([])

  const { addVisible, form, handleAdd, handleAddVisible, StageList, indexNum } = props;
  useEffect(() => {
    setRxnfInfo([])
    setisBatch(0)
  }, [indexNum]);



  const okHandle = () => {
    // setisBatch(0)
    form.validateFields((err, fieldsValue) => {
      console.log(fieldsValue, 'fieldsvalue')
      fieldsValue.stageId ? fieldsValue.stageId : fieldsValue.stageId = -1;
      const data = fieldsValue;
      if (!data.endBh) {
        data.endBh = data.startBh
      }
      if (err) return;
      // form.resetFields();

      // data.areaCode = areaCode;
      handleAdd(data);
    });
  };

  // 控制是否批量建立班级
  const handelBatch = (e: any) => {
    setisBatch(e.target.value)
  }

  // 选择学部
  const handelStage = (e: any) => {
    console.log(e,)
    const { form } = props;

    form.setFieldsValue({
      schoolingLength: "",
      rxnf: ""
    });

    switch (e) {
      // 1  学前教育  3
      case "1":
        setStageInfo([3]);
        break;
      // 2  小学  5,6
      case "2":
        setStageInfo([5, 6]);
        break;
      // 3  普通初中   3,4
      case "3":
        setStageInfo([3, 4]);
        break;
      // 4  普通高中  3
      case "4":
        setStageInfo([3]);
        break;
      // 5  职业初中  2,3
      case "5":
        setStageInfo([2, 3]);
        break;
      // 6  职业高中  3
      case "6":
        setStageInfo([3]);
        break;
      // A  特殊教育  3,6,9
      case "A":
        setStageInfo([3, 6, 9]);
        break;
      default:
        setStageInfo([1, 2, 3, 4, 5, 6]);
        break;

    }
  }
  // 生成入学年份。根据选择的学制和当前年份。生成入学年份。（当年份-学制 ~ 当前年份+1）
  const handelXz = (e: any) => {
    const { form } = props;
    form.setFieldsValue({
      rxnf: ""
    });

    const xz: number = e;
    const date = new Date();
    const year = date.getFullYear();
    let rxnfData: any = []
    for (let i = year - xz; i <= year + 1; i++) {
      rxnfData.push(i)
    };
    setRxnfInfo(rxnfData)
    console.log(rxnfInfo, 'rxnfData')
  }


  // 表单校验输入的范围比较
  const bhValidate = (rule, value, callback) => {
    const { form } = props;
    const b = value;
    const e = form.getFieldValue("endBh");
    // if( b==undefined || e == undefined ){
    //   callback("请输入1-99范围的数字。");
    // }

    if (b > e) {
      callback("开始值不能大于结束值，请重新输入");
    }
    callback();
  }
  const handleVisible = () => {
    // setisBatch(0)
    setStageInfo([])
    setRxnfInfo([])
    handleAddVisible()
  }

  console.log(StageList, 'StageList.length')
  return (
    <Modal
      destroyOnClose
      title="新建班级"
      visible={addVisible}
      maskClosable={false}
      onOk={okHandle}
      onCancel={() => handleVisible()}
      width="700px"
    >
      {StageList?.length != 0 ?
        <FormItem labelCol={{ span: 7 }} wrapperCol={{ span: 7 }} label="学部">
          {form.getFieldDecorator('stageId', {
            rules: [
              {
                required: true,
                message: '请选择学部',
              },
            ]
          })(

            <Select
              style={{ width: '100%' }}
              showSearch={true}
              onChange={(e) => handelStage(e)}
            >
              {StageList?.map(item => (
                <Select.Option value={item.stage_id} key={item.stage_id} >{item.stage_name}</Select.Option>
              ))}
            </Select>
          )}
        </FormItem>
        : ""}
      <FormItem labelCol={{ span: 7 }} wrapperCol={{ span: 7 }} label="学制">
        {form.getFieldDecorator('schoolingLength', {
          rules: [
            {
              required: true,
              message: '请选择学制',
            },
          ]
        })(
          <Select
            style={{ width: '100%' }}
            onChange={(e) => handelXz(e)}
          >
            {stageInfo?.map(item => (
              <Select.Option value={item} key={item} >{item}</Select.Option>
            ))}
          </Select>
        )}
      </FormItem>
      <Form.Item labelCol={{ span: 7 }} wrapperCol={{ span: 5 }} label="入学年份">
        {form.getFieldDecorator('rxnf', {
          rules: [
            {
              required: true,
              message: '请选择入学年份',
            },
          ]
        })(
          <Select
            style={{ width: '100%' }}
          // onChange={(e)=>handelStage(e)}
          >
            {rxnfInfo?.map(item => (
              <Select.Option value={item} key={item} >{item}</Select.Option>
            ))}
          </Select>
        )}
      </Form.Item>

      <Form.Item labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="建班方式">
        {form.getFieldDecorator('batch', {
          initialValue: "0",
        })(
          <Radio.Group buttonStyle="solid" onChange={(e) => handelBatch(e)}>
            <Radio.Button value="0">单个建班</Radio.Button>
            <Radio.Button value="1">批量建班</Radio.Button>
          </Radio.Group>
        )}
      </Form.Item>


      {isBatch != 0 ? <Form.Item labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="班号">
        {form.getFieldDecorator('startBh', {
          rules: [
            {
              required: true,
              message: '请输入1~3位数字',
            },
            { validator: bhValidate, }
          ]
        })(<InputNumber maxLength={3} min={1} max={999} />)}~
        {form.getFieldDecorator('endBh', {
          rules: [
            {
              required: true,
              message: '请输入1~3位数字',
            },
          ]
        })(<InputNumber maxLength={3} min={1} max={999} />)}
      </Form.Item> :
        <div><Form.Item labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="班号">
          {form.getFieldDecorator('startBh', {
            rules: [
              {
                required: true,
                message: '请输入1~3位数字',
              },
            ]
          })(<InputNumber maxLength={3} min={1} max={999} />)}
        </Form.Item><FormItem labelCol={{ span: 7 }} wrapperCol={{ span: 11 }} label="班级别名">
            {form.getFieldDecorator('classAlias', {
              rules: [
                {
                  min: 1,
                  max: 30,
                  message: '长度为1-30',
                },
                {
                  pattern: new RegExp('^[\u4E00-\u9FA5A-Za-z0-9]+$', 'g'),
                  message: '长度1~30 汉字或字母或数字',
                },
              ]
            })(<Input maxLength={30} />)}
          </FormItem></div>}




    </Modal>
  );
};

export default Form.create<AddClassForm>()(AddClassForm);
