import { Form, Input, Modal, Cascader, Select, Popover, Icon, Switch } from 'antd';
import React from 'react';
import { FormComponentProps } from 'antd/es/form';
import CascadeGeographic from '@/components/CascadeGeographic';

const { Option } = Select;
const FormItem = Form.Item;
interface CreateFormProps extends FormComponentProps {
  modalVisible: boolean;
  handleAdd: (fieldsValue: { desc: string }) => void;
  handleModalVisible: () => void;
}

const CreateForm: React.FC<CreateFormProps> = props => {
  const { modalVisible, form, handleAdd, handleModalVisible } = props;
  const okHandle = () => {
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      form.resetFields();
      handleAdd(fieldsValue);
    });
  };

  return (
    <Modal
      destroyOnClose
      title="新增教育局"
      visible={modalVisible}
      onOk={okHandle}
      onCancel={() => handleModalVisible()}
      width="700px"
    >
      {/* 所在行政区划 */}
      <FormItem labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="所在行政区划">
        {form.getFieldDecorator('ageographic_code', {
          // initialValue: ['220000', '220100', '220102'],
          rules: [{ required: true }],
        })(
          <Cascader
            fieldNames={{ label: 'name', value: 'id' }}
            // options={options}
            // loadData={this.loadData}
            // onChange={this.onChange}
            // changeOnSelect
          />,
        )}
      </FormItem>

      {/* 所属上级机构 */}
      <FormItem labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="所属上级机构">
        {form.getFieldDecorator('parent_id', {
          rules: [{ required: true }],
        })(
          <Select style={{ width: '100%' }} showSearch>
            <Option value="WiFi">WiFi</Option>
            <Option value="Cellular">蜂窝 (2G / 2G / 4G / 5G)</Option>
            <Option value="Ethernet">以太网</Option>
            <Option value="LoRaWAN">LoRaWAN</Option>
            <Option value="Other">其他</Option>
          </Select>,
        )}
      </FormItem>

      {/* 组织机构代码 */}
      <Form.Item
        labelCol={{ span: 7 }}
        wrapperCol={{ span: 15 }}
        label={
          <span>
            组织机构代码{' '}
            <Popover overlayStyle={{ width: '300px' }} content="pop" title="帮助">
              <Icon type="question-circle" theme="filled" style={{ opacity: 0.3 }} />
            </Popover>
          </span>
        }
      >
        {form.getFieldDecorator('org_code', {
          // initialValue: ['zhejiang', 'hangzhou', 'xihu'],
          rules: [{ required: true }],
        })(<Input maxLength={20} />)}
      </Form.Item>
      {/* 组织机构名称 */}
      <Form.Item
        labelCol={{ span: 7 }}
        wrapperCol={{ span: 15 }}
        label={
          <span>
            组织机构名称{' '}
            <Popover overlayStyle={{ width: '300px' }} content="pop 提示" title="帮助">
              <Icon type="question-circle" theme="filled" style={{ opacity: 0.3 }} />
            </Popover>
          </span>
        }
      >
        {form.getFieldDecorator('org_name', {
          // initialValue: ['zhejiang', 'hangzhou', 'xihu'],
          rules: [{ required: true }],
        })(<Input maxLength={20} />)}
      </Form.Item>
      {/* 组织机构英文名 */}
      <Form.Item
        labelCol={{ span: 7 }}
        wrapperCol={{ span: 15 }}
        label={
          <span>
            组织机构英文名{' '}
            <Popover overlayStyle={{ width: '300px' }} content="pop 提示" title="帮助">
              <Icon type="question-circle" theme="filled" style={{ opacity: 0.3 }} />
            </Popover>
          </span>
        }
      >
        {form.getFieldDecorator('org_ename', {
          // initialValue: ['zhejiang', 'hangzhou', 'xihu'],
          rules: [{ required: true }],
        })(<Input maxLength={20} />)}
      </Form.Item>
      {/* 组织机构负责人 */}
      <Form.Item
        labelCol={{ span: 7 }}
        wrapperCol={{ span: 15 }}
        label={
          <span>
            组织机构负责人{' '}
            <Popover overlayStyle={{ width: '300px' }} content="pop 提示" title="帮助">
              <Icon type="question-circle" theme="filled" style={{ opacity: 0.3 }} />
            </Popover>
          </span>
        }
      >
        {form.getFieldDecorator('fzr', {})(
          <Select showSearch style={{ width: '100%' }}>
            <Option value="WiFi">WiFi</Option>
            <Option value="Cellular">蜂窝 (2G / 2G / 4G / 5G)</Option>
            <Option value="Ethernet">以太网</Option>
            <Option value="LoRaWAN">LoRaWAN</Option>
            <Option value="Other">其他</Option>
          </Select>,
        )}
      </Form.Item>
      {/* 组织机构地址 */}
      <Form.Item
        labelCol={{ span: 7 }}
        wrapperCol={{ span: 15 }}
        label={
          <span>
            组织机构地址{' '}
            <Popover overlayStyle={{ width: '300px' }} content="pop 提示" title="帮助">
              <Icon type="question-circle" theme="filled" style={{ opacity: 0.3 }} />
            </Popover>
          </span>
        }
      >
        {form.getFieldDecorator('address')(<Input />)}
      </Form.Item>
      {/* 组织机构法人 */}
      <Form.Item
        labelCol={{ span: 7 }}
        wrapperCol={{ span: 15 }}
        label={
          <span>
            组织机构法人{' '}
            <Popover overlayStyle={{ width: '300px' }} content="pop 提示" title="帮助">
              <Icon type="question-circle" theme="filled" style={{ opacity: 0.3 }} />
            </Popover>
          </span>
        }
      >
        {form.getFieldDecorator('fddbr')(<Input style={{ width: '40%' }} />)}
      </Form.Item>
      {/* 组织机构电话 */}
      <Form.Item
        labelCol={{ span: 7 }}
        wrapperCol={{ span: 15 }}
        label={
          <span>
            组织机构电话{' '}
            <Popover overlayStyle={{ width: '300px' }} content="pop 提示" title="帮助">
              <Icon type="question-circle" theme="filled" style={{ opacity: 0.3 }} />
            </Popover>
          </span>
        }
      >
        {form.getFieldDecorator('lxdh')(<Input style={{ width: '50%' }} />)}
      </Form.Item>
      {/* 启用状态 */}
      <Form.Item labelCol={{ span: 7 }} wrapperCol={{ span: 15 }} label="启用状态">
        {form.getFieldDecorator('state')(
          <Switch checkedChildren="启用" unCheckedChildren="关闭" defaultChecked />,
        )}
      </Form.Item>
    </Modal>
  );
};

export default Form.create<CreateFormProps>()(CreateForm);
