import { Form, Modal, Row, Col, message, Button, Input, TreeSelect, Table } from 'antd';
import React, { useState, useEffect } from 'react';
import { FormComponentProps } from 'antd/es/form';
import StandardTable from '../components/StandardTable';
const FormItem = Form.Item;
interface AddClassForm extends FormComponentProps {
  setTeacherVisible: boolean;
  handleAdd: (fieldsValue: { desc: string }) => void;
  handleSetTeacherVisible: (classId: string, teacherId: string, flag?: boolean, isAddSuccess?: boolean) => void;
  dispatch: (payload: {}) => void;
  StageList: { [key: string]: string };
  orgId: string;
  orgIds: string;
}


const getTreeList = (list: any) => {
  let newList = list;
  const addList = (list: Array<any>) => {
    list?.map((item, index) => {
      item.value = item.org_id;
      item.title = item.org_name;
      item.key = item.org_id;
      if (item.children) {
        addList(item.children)
      }
    })
  }

  addList(newList)

  return newList
}

const SetClassTeacher: React.FC<AddClassForm> = props => {

  const [page, setPage] = useState(1)
  const [pageSize, setPageSize] = useState(6)
  const [selectedRows, setSelectedRows] = useState("")
  const orgId = props.match.params.id
  console.log(props)
  const { setTeacherVisible, form, handleAdd, handleSetTeacherVisible, dispatch, loading, setTeacherClassId, setTeacherId, orgIds } = props;
  const { getFieldDecorator } = form;
  const { OrgInfo, teacherList } = props.classInfo
  const OrgData = getTreeList(OrgInfo)
  setTeacherId ? setTeacherId : ''

  // 默认
  const value = OrgData ? OrgData[0].value : ""

  const okHandle = () => {

    if (selectedRows) {
      dispatch({
        type: 'classInfo/SetClassTeacher',
        payload: {

          classId: setTeacherClassId,
          teacherId: selectedRows
        },
        callback: (response: any) => {

          if (response.success == true) {
            message.success(response.message);
            handleSetTeacherVisible("", "", false, true)
          } else {
            message.error(response.message);
          }



        },
      });
    }

    // form.validateFields((err, fieldsValue) => {
    //   const data = fieldsValue;

    //   if (err) return;
    //   // form.resetFields();

    //   // data.areaCode = areaCode;
    //   handleAdd(data);
    // });
  };

  useEffect(() => {
    dispatch({
      type: 'classInfo/GetOrgTreeInfo',
      payload: {
        orgId: orgId || orgIds,
      },
    });

    const fields = {
      orgId: orgId || orgIds,
      page: 1,
      limit: pageSize
    }
    getClassList(fields)
    setSelectedRows(setTeacherId ? setTeacherId : "")

  }, [setTeacherClassId]);

  const getClassList = (fields: any) => {
    dispatch({
      type: 'classInfo/PageTeacherInfo',
      payload: {
        ...fields,
      },
    });
  }


  // 分页
  const handleStandardTableChange = (e) => {
    setPage(e.current)
    const fields = {
      orgId: orgId,
      page: e.current,
      limit: pageSize
    }
    getClassList(fields)
  }

  // 查询
  const handleSearch = (e) => {
    e.preventDefault();
    form.validateFields((err, fieldsValue) => {
      if (err) return;


      const fields = {
        orgId: fieldsValue.Org,
        page: 1,
        limit: pageSize,
        xm: fieldsValue.teacherName
      }
      getClassList(fields)
    });
  }

  const handleSelectRows = (rowId: any) => {
    setSelectedRows(rowId[0])
  }

  const columns = [
    // {
    //   title: '序号',
    //   dataIndex: 'person_id',
    //   key:"person_id",
    //   render: (text, record, index) =>
    //   `${(page - 1) * (pageSize) + (index + 1)}`,

    // },
    {
      title: '姓名',
      dataIndex: 'xm',
      key: 'xm',
    },
    {
      title: '任教学段',
      dataIndex: 'stage_name',
      key: 'stage_name',
    },
    {
      title: '任教学科',
      dataIndex: 'subject_name',
      key: 'subject_name',
    },
  ];

  const rowSelection = {
    type: "radio",
    selectedRowKeys: selectedRows,
    onChange: (e) => handleSelectRows(e),

  }

  const pagination = {
    page: page,
    showSizeChanger: false,
    total: teacherList?.count
  }

  return (
    <Modal
      destroyOnClose
      title="设置班主任"
      visible={setTeacherVisible}
      onOk={okHandle}
      onCancel={() => handleSetTeacherVisible()}
      width="800px"
    >
      <Form layout="inline" onSubmit={handleSearch}>
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={10} sm={24}>
            <FormItem labelCol={{ span: 10 }} wrapperCol={{ span: 14 }} label="所属部门">
              {getFieldDecorator('Org', {

                initialValue: value,
              })(
                <TreeSelect
                  style={{ width: 200 }}
                  // value={this.state.value}
                  dropdownStyle={{ maxHeight: 400, overflow: 'auto' }}
                  treeData={OrgData}
                  placeholder="请选择部门"
                  treeDefaultExpandAll
                  treeNodeFilterProp="org_name"
                />

              )}
            </FormItem>
          </Col>
          <Col md={10} sm={24}>
            <FormItem labelCol={{ span: 10 }} wrapperCol={{ span: 14 }} label="教职工姓名">
              {form.getFieldDecorator('teacherName', {
                // initialValue:this.state.rxnf,
              })(
                <Input maxLength={10} />
              )}
            </FormItem>
          </Col>
          <Col md={4} sm={12}>
            <span>
              <Button type="primary" htmlType="submit">
                查询
              </Button>

            </span>
          </Col>
        </Row>
      </Form>
      <StandardTable
        rowSelection={rowSelection}
        rowKey={record => record.person_id}
        selectedRows={selectedRows}
        loading={loading}
        data={teacherList}
        columns={columns}
        pagination={pagination}
        onChange={(e) => handleStandardTableChange(e)}
      // onSelectRow={handleSelectRows}
      />


    </Modal>
  );
};

export default Form.create<AddClassForm>()(SetClassTeacher);
