import { Button, Card, Col, Divider, Form, Icon, Popconfirm, Row, message, Select } from 'antd';
import React, { Component, Fragment } from 'react';

import { Dispatch, Action } from 'redux';
import { FormComponentProps } from 'antd/es/form';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { connect } from 'dva';
import { StateType } from './model';
import StandardTable, { StandardTableColumnProps } from './components/StandardTable';
// import { AddClassForm } from './components/AddClassForm';
import AddClassForm from "./components/AddClassForm"
import SetClassTeacher from "./components/SetClassTeacher"
import { FormValueType } from './components/UpdateForm';
import { TableListItem, ClassInfo, getClassInfo } from './data';

import styles from './style.less';
import UpdataClassInfo from './components/UpdataClassInfo';
const FormItem = Form.Item;

interface TableListProps extends FormComponentProps {
  dispatch: Dispatch<
    Action<
      | 'classInfo/PageClassInfo'
      | 'classInfo/GetClassInfo'
      | 'classInfo/AddClassInfo'
      | 'classInfo/DeleteClassInfo'
      | 'classInfo/SetClassTeacher'
      | 'classInfo/UpdateClassInfo'
      | 'classInfo/GetStageInfo'
      | 'classInfo/GetRxnfInfo'
      | 'classInfo/GetOrgTreeInfo'
    >
  >;
  loading: boolean;
  classInfo: StateType;
}

interface TableListState {
  addVisible: boolean;
  modalVisible: boolean;
  updateModalVisible: boolean;
  expandForm: boolean;
  selectedRows: TableListItem[];
  formValues: { [key: string]: string };
  stepFormValues: Partial<TableListItem>;
  areaCode: string;
  rxnf: string;
  StageInfo: Array<string>;
  RxnfInfo: Array<string>;
  page: number;
  pageSize: number;
  orgId: string;
  identityId: string;
  stageId: string;
  classInfo: { [key: string]: string };
  setTeacherVisible: boolean;
  setTeacherClassId: string;
  setTeacherId: string;
  orgList: [];
  isStage: boolean;
}

/* eslint react/no-multi-comp:0 */
@connect(
  ({
    classInfo,
    geographic,
    loading,
  }: {
    classInfo: StateType;
    geographic: StateType;
    loading: {
      models: {
        [key: string]: boolean;
      };
    };
  }) => ({
    classInfo,
    geographic,
    loading: loading.models.classInfo,
  }),
)
class TableList extends Component<TableListProps, TableListState> {

  state: TableListState = {
    addVisible: false,
    modalVisible: false,
    updateModalVisible: false,
    expandForm: false,
    selectedRows: [],
    formValues: {},
    stepFormValues: {},
    areaCode: '220100',
    rxnf: "",
    StageInfo: [],
    RxnfInfo: [],
    page: 1,
    pageSize: 10,
    orgId: this.props.match.params.id ? this.props.match.params.id : '',
    identityId: '',
    stageId: "",
    classInfo: {},
    setTeacherVisible: false,
    setTeacherClassId: "",
    setTeacherId: "",
    orgList: [],
    isStage: true
  };

  columns: StandardTableColumnProps[] = [
    {
      title: '序号',
      dataIndex: 'area_code',
      render: (text, record, index) =>
        `${(this.state.page - 1) * (this.state.pageSize) + (index + 1)}`,

    },
    {
      title: '班级名称',
      dataIndex: 'class_name',
      key: 'class_name',
    },
    {
      title: '班级别名',
      dataIndex: 'class_alias',
      key: 'class_alias',
    },
    {
      title: '学生人数',
      dataIndex: 'student_count',
      key: 'student_count',
    },
    {
      title: '班主任',
      dataIndex: 'teacher_name',
      key: 'teacher_name',
    },
    {
      title: '操作',
      width: 200,
      render: (text, record) => (
        <Fragment>
          <Popconfirm
            title={'是否确认删除『' + record.class_name + '』？'}
            okText="确认"
            cancelText="取消"
            onConfirm={() => this.deleteClass(record.class_id)}
          >
            <a>删除</a>
          </Popconfirm>
          <Divider type="vertical" />
          <a onClick={() => this.handleModalVisible(record.class_id, true)}>
            编辑
          </a>
          <Divider type="vertical" />
          <a onClick={() => this.handleSetTeacherVisible(record.class_id, record.teacher_id, true)}>
            设置班主任
          </a>
        </Fragment>
      ),
    },
  ];

  componentDidMount() {
    if (this.props.match.params.id) {
      this.getClassInfo()
    } else {
      // alert(2)
      const { dispatch } = this.props;
      dispatch({
        type: 'classInfo/GetRoleInfo',
        payload: {},
        callback: (response: any) => {

          if (response.list[0].role_id == '73E897FC-C9D1-4E48-AE22-AC7586425C1D' || response.list[0].role_id == '9CD6B804-0F89-4626-A812-29465CFC7410') {

            this.getClassInfo(response.list[0].rule_id)
            this.setState({
              orgId: response.list[0].rule_id,
              identityId: response.list[0].role_id
            })
          } else {
            message.error('当前角色权限错误，请联系管理员重新配置菜单');
          }

        },
      });


    }



  }



  getClassInfo = (classId: string) => {
    const { dispatch } = this.props;

    const orgId = classId ? classId : this.state.orgId

    //获取orgName
    dispatch({
      type: 'classInfo/GetOrgTreeInfo',
      payload: {
        orgId: orgId,
      },
      callback: (data: any) => {
        this.setState({ orgList: data })
      }
    })



    // 获取学制
    dispatch({
      type: 'classInfo/GetStageInfo',
      payload: {
        orgId: orgId,
      },
      callback: (response: any) => {
        console.log(response, 'respoinse class')

        // 判断是否有学制。
        if (response.length > 0) {
          this.setState({
            StageInfo: response,
            stageId: response[0].stage_id
          })



          this.getRxnf(orgId, response[0].stage_id)

          // 获取入学年份
          // dispatch({
          //   type: 'classInfo/GetRxnfInfo',
          //   payload: {
          //     orgId: orgId,
          //     stageId: response[0].stage_id
          //   },
          //   callback: (response: any) => {

          //     const fields = {
          //       orgId: orgId,
          //       stageId: this.state.stageId,
          //       rxnf: response[0]
          //     }

          //     this.setState({
          //       RxnfInfo: response,
          //       rxnf: response[0]
          //     })
          //     // 获取班级列表
          //     this.getClassList(fields)

          //   },
          // });
        } else {
          this.setState({ isStage: false })

          this.getRxnf(orgId, -1)
        }

      },

    });




  }

  // 新增弹窗
  handleAddVisible = (flag?: boolean) => {

    this.setState({
      addVisible: !!flag,
    });
  };

  // 新增提交处理   BUG : 新增后没有刷新入学年份下拉列表筛选。
  handleAdd = (fields: ClassInfo) => {
    const { dispatch } = this.props;
    fields.orgId = this.state.orgId;
    const { form } = this.props
    dispatch({
      type: 'classInfo/AddClassInfo',
      payload: {
        ...fields,
      },
      callback: (response: any) => {
        if (response.success) {
          message.success('添加成功');
          // 重新设置表单

          // 重新获取入学年份
          dispatch({
            type: 'classInfo/GetRxnfInfo',
            payload: {
              orgId: this.state.orgId,
              stageId: fields.stageId
            },
            callback: (response: any) => {

              const f: any = {
                orgId: this.state.orgId,
                stageId: fields.stageId,
                rxnf: fields.rxnf
              }

              this.setState({
                RxnfInfo: response,
                rxnf: fields.rxnf.toString(),

              }, () => {
                this.setState({ stageId: fields.stageId })

              })
              // 获取班级列表
              this.getClassList(f)
              form.setFieldsValue({ stageId: fields.stageId });
              form.setFieldsValue({ rxnf: fields.rxnf });
            },
          });



          // this.getClassList(fields);

          this.handleAddVisible();
        } else {
          // const areaCode = this.state.areaCode;
          // this.getEffectList(areaCode);
          message.error('添加失败,' + response.message);
        }
      },
    });

  };

  // 获取列表
  getClassList(fields?: getClassInfo, pagination?: any) {
    const { dispatch } = this.props;

    if (!pagination) {
      pagination = {
        page: this.state.page,
        limit: this.state.pageSize,
      }
    }

    if (!fields) {
      fields = {
        orgId: this.state.orgId,
        stageId: this.state.stageId,
        rxnf: this.state.rxnf
      }
    }

    dispatch({
      type: 'classInfo/PageClassInfo',
      payload: {
        ...fields,
        ...pagination
      },
    });
  }

  // 获取入学年份
  getRxnf = (orgId: string, stageId: string) => {
    //  orgId  :   机构id
    //  stageId  :  学部id 
    const { dispatch } = this.props;
    // const orgId = this.state.orgId
    const { form } = this.props;
    form.setFieldsValue({ rxnf: "" });

    dispatch({
      type: 'classInfo/GetRxnfInfo',
      payload: {
        orgId: orgId,
        stageId: stageId
      },
      callback: (response: any) => {


        const fields = {
          orgId: orgId,
          stageId: stageId,
          rxnf: response[0]
        }

        this.setState({
          RxnfInfo: response,
          stageId: stageId,
          rxnf: response[0],
          selectedRows: []
        })
        this.getClassList(fields)
        form.setFieldsValue({ rxnf: response[0] });
      },
    });

  }

  toggleForm = () => {
    const { expandForm } = this.state;
    this.setState({
      expandForm: !expandForm,
    });
  };

  handleRxnf = (e) => {
    const values = {
      orgId: this.state.orgId,
      stageId: this.state.stageId,
      rxnf: e
    };
    this.setState({
      rxnf: e,
      selectedRows: []
    });
    this.getClassList(values);
  };

  // 修改班级弹窗传参
  handleModalVisible = (classId: string, flag?: boolean) => {
    if (flag) {
      const { dispatch } = this.props;
      dispatch({
        type: 'classInfo/GetClassInfo',
        payload: {
          classId: classId,
        },
        callback: (response: any) => {
          this.setState({
            classInfo: response,
            modalVisible: !!flag,
          });
        },
      });


    } else {
      this.setState({
        modalVisible: !!flag,
      });
    }
  };

  handleUpdateModalVisible = (flag?: boolean, record?: FormValueType) => {
    this.setState({
      updateModalVisible: !!flag,
      stepFormValues: record || {},
    });
  };

  // 修改教育局信息
  handleModify = (fields: { desc: any }) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'classInfo/UpdateClassInfo',
      payload: {
        ...fields,
      },
      callback: (response: any) => {
        if (response.success) {

          this.getClassList();
          message.success('编辑成功');
        } else {
          message.error('编辑失败,' + response.message);
        }
      },
    });
    this.handleModalVisible('');
  };

  onChange = (value: number, selectedOptions: any) => {
  };

  // 删除班级
  deleteClass = (classIds: string) => {
    const { dispatch, form } = this.props;
    dispatch({
      type: 'classInfo/DeleteClassInfo',
      payload: {
        classIds: classIds,
      },
      callback: (response: any) => {
        if (response.success) {
          // 获取入学年份
          dispatch({
            type: 'classInfo/GetRxnfInfo',
            payload: {
              orgId: this.state.orgId,
              stageId: this.state.stageId
            },
            callback: (response: any) => {

              this.setState({
                RxnfInfo: response,
                rxnf: response[0],
                selectedRows: []
              })
              // 获取班级列表
              this.getClassList();
              form.setFieldsValue({ rxnf: response[0] });//存入form值（setstate不能直接给值）
              message.success('删除班级成功');
            },
          });
          // this.getClassList();
        } else {
          message.error('删除失败,' + response.message);
        }
      },
    });

    // message.success('禁用成功');
  };

  // 设置班主任弹窗
  handleSetTeacherVisible = (classId: string, teacherId: string, flag?: boolean, isAddSuccess?: boolean) => {

    // 如果增加教师成功刷新列表
    if (isAddSuccess) {
      this.getClassList();
    }

    this.setState({
      setTeacherId: teacherId,
      setTeacherClassId: classId,
      setTeacherVisible: !!flag,
    });
  };


  //批量删除班级
  batchDeleteTeacherInfo = () => {

    if (this.state.selectedRows.length > 0) {
      let classIdAry = [];
      this.state.selectedRows.map((item) => {
        classIdAry.push(item.class_id)
      })
      let classIds = classIdAry.join(",")
      this.deleteClass(classIds)
    }

  }


  // 分页
  handleStandardTableChange = (
    pagination: Partial<TableListPagination>,
    filtersArg: Record<keyof TableListItem, string[]>,
    sorter: SorterResult<TableListItem>,
  ) => {

    const { formValues, areaCode } = this.state;
    const page = pagination.current;
    const pageSize = pagination.pageSize;

    pagination = {
      page: page,
      limit: pageSize
    }


    const values = {
      orgId: this.state.orgId,
      stageId: this.state.stageId,
      rxnf: this.state.rxnf
    };



    this.getClassList(values, pagination)
    this.setState({
      page: page,
      pageSize: pageSize
    })
  };




  renderSimpleForm() {
    const { form } = this.props;
    const { getFieldDecorator } = form;
    const { StageInfo, RxnfInfo, selectedRows } = this.state
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row>
          <Col sm={24} style={{ fontSize: "16px", marginBottom: "20px" }}>
            {/* <Icon type="environment" theme="filled" style={{ color: "#1890ff", marginRight: "20px" }} /> */}
            <Icon type="environment" style={{ color: "#1890ff", marginRight: "20px" }} />
            {this.state.orgList.length > 0 ? this.state.orgList.map((item: any) => {
              return item.org_name
            }) : ""}
          </Col>
        </Row>
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          {/* 判断是否有学段，显示选择学段下拉框 */}
          {this.state.isStage ? <Col md={8} sm={24}>
            <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 6 }} label="学部">
              {getFieldDecorator('stageId', {
                initialValue: this.state.stageId,
              })(
                // <Input />
                <Select
                  style={{ width: '100%' }}
                  showSearch={true}
                  onChange={(e) => this.getRxnf(this.state.stageId, e)}
                >
                  {StageInfo?.map(item => (
                    <Select.Option value={item.stage_id} key={item.stage_id} >{item.stage_name}</Select.Option>
                  ))}
                </Select>
              )}
            </FormItem>
          </Col> : ""}
          <Col md={8} sm={24}>
            <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 6 }} label="入学年份">
              {form.getFieldDecorator('rxnf', {
                initialValue: this.state.rxnf,
              })(
                <Select
                  style={{ width: '100%' }}
                  showSearch={true}
                  onChange={(e) => this.handleRxnf(e)}
                >
                  {RxnfInfo ? RxnfInfo.map(item => (
                    <Select.Option value={item} key={item} >{item}</Select.Option>
                  ))
                    : <Select.Option value="" key="" ></Select.Option>}
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={4} sm={12}>
            <span className={styles.submitButtons}>
              {/* <Button type="primary" htmlType="submit">
                查询
              </Button> */}

            </span>
          </Col>
        </Row>
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={22} sm={24}>
            <div className={styles.tableListOperator}>
              <Button
                icon="plus"
                type="primary"
                onClick={() => this.handleAddVisible(true)}
              >
                增加班级
              </Button>
              {selectedRows.length > 0 && (
                <Popconfirm
                  title={'是否确认删除所选中所有班级？'}
                  okText="确认"
                  cancelText="取消"
                  onConfirm={() => this.batchDeleteTeacherInfo()}
                >
                  <Button type="danger">批量删除</Button>
                </Popconfirm>
              )}
            </div>
          </Col>
          {this.state.identityId === "9CD6B804-0F89-4626-A812-29465CFC7410" || this.state.identityId === "73E897FC-C9D1-4E48-AE22-AC7586425C1D" ? "" : <Col md={2} sm={24}>
            <Button type="primary" onClick={() => { window.history.back() }}>
              返回
            </Button>
          </Col>}
        </Row>
      </Form>
    );
  }

  renderForm() {
    return this.renderSimpleForm();
  }

  handleSelectRows = (selectedRows: TableListItem[]) => {
    this.setState({
      selectedRows: selectedRows,
    });
  };



  render() {
    const {
      classInfo: { data },
      loading,
    } = this.props;

    const { selectedRows, addVisible, modalVisible, setTeacherVisible } = this.state;

    const addClassMethods = {
      handleAddVisible: this.handleAddVisible,
      addVisible: this.state.addVisible,
      handleAdd: this.handleAdd,
      StageList: this.props.classInfo.StageInfo,
      indexNum: Math.floor(Math.random() * 10)
    };
    const parentMethods = {
      handleModify: this.handleModify,
      handleModalVisible: this.handleModalVisible,
      classInfo: this.state.classInfo
    };
    const setTeacherMethods = {
      setTeacherVisible: this.state.setTeacherVisible,
      handleSetTeacherVisible: this.handleSetTeacherVisible,
      orgIds: this.state.orgId,
      setTeacherClassId: this.state.setTeacherClassId,
      setTeacherId: this.state.setTeacherId,
      ...this.props,
    }
    data.pagination = {
      current: this.state.page,
      total: data.count,
      pageSize: this.state.pageSize,
      showTotal: ((total: any) => {
        return `共 ${total} 条`;
      }),
    }
    return (
      <PageHeaderWrapper>
        <Card bordered={false}>
          <div className={styles.tableList}>
            <div className={styles.tableListForm}>{this.renderForm()}</div>
            <StandardTable
              // rowSelection={false}
              rowKey={record => record.class_id}
              selectedRows={selectedRows}
              loading={loading}
              data={data}
              columns={this.columns}
              onSelectRow={this.handleSelectRows}
              onChange={this.handleStandardTableChange}
            />
          </div>
        </Card>

        <AddClassForm {...addClassMethods} modalVisible={addVisible} />
        <UpdataClassInfo {...parentMethods} modalVisible={modalVisible} />
        <SetClassTeacher {...setTeacherMethods} modalVisible={setTeacherVisible} />
      </PageHeaderWrapper>
    );
  }
}

export default Form.create<TableListProps>()(TableList);
