import { AnyAction, Reducer } from 'redux';
import { EffectsCommandMap } from 'dva';
import {
  PageClassInfo,
  GetClassInfo,
  AddClassInfo,
  DeleteClassInfo,
  UpdateClassInfo,
  SetClassTeacher,
  GetStageInfo,
  GetRxnfInfo,
  GetOrgTreeInfo,
  PageTeacherInfo,
  GetRoleInfo
} from './service';

// eslint-disable-next-line import/no-unresolved
import { TableListData } from './data';

export interface StateType {
  data?: TableListData;
}

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: StateType) => T) => T },
) => void;

export interface ModelType {
  namespace: string;
  state: StateType;
  effects: {
    PageClassInfo: Effect;
    GetClassInfo: Effect;
    AddClassInfo: Effect;
    DeleteClassInfo: Effect;
    UpdateClassInfo: Effect;
    SetClassTeacher: Effect;
    GetStageInfo: Effect;
    GetRxnfInfo: Effect;
    GetOrgTreeInfo: Effect;
    PageTeacherInfo: Effect;
    GetRoleInfo: Effect;
  };
  reducers: {
    save: Reducer<StateType>;
    saveOrgInfo: Reducer<StateType>;
    saveTeacher: Reducer<StateType>;
    saveStageInfo: Reducer<StateType>;

  };
}

const Model: ModelType = {
  namespace: 'classInfo',

  state: {
    data: {
      list: [],
      pagination: {},
    },
  },

  effects: {
    // 获取班级列表
    *PageClassInfo({ payload }, { call, put }) {
      const response = yield call(PageClassInfo, payload);
      console.log(payload, 'school.payload')
      yield put({
        type: 'save',
        payload: response,
      });
    },
    // 获取班级信息
    *GetClassInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetClassInfo, payload);
      if (callback) callback(response.list[0]);
    },
    // 增加班级信息
    *AddClassInfo({ payload, callback }, { call, put }) {
      const response = yield call(AddClassInfo, payload);
      yield put({
        type: 'eduInfo',
        payload: response,
      });
      if (callback) callback(response);
    },
    // 删除班级信息
    *DeleteClassInfo({ payload, callback }, { call }) {
      const response = yield call(DeleteClassInfo, payload);
      if (callback) callback(response);
    },
    // 修改班级信息(只允许修改班级别名)
    *UpdateClassInfo({ payload, callback }, { call }) {
      const response = yield call(UpdateClassInfo, payload);
      if (callback) callback(response);
    },
    // 设置班主任
    *SetClassTeacher({ payload, callback }, { call }) {
      const response = yield call(SetClassTeacher, payload);
      if (callback) callback(response);
    },
    // 获取学段信息
    *GetStageInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetStageInfo, payload);
      yield put({
        type: 'saveStageInfo',
        payload: response.list,
      });
      if (callback) callback(response.list);
    },
    // 根据学校ID和学部(学段)ID获取入学年份
    *GetRxnfInfo({ payload, callback }, { call, put }) {
      // const stageId = payload.stageId
      const response = yield call(GetRxnfInfo, payload);
      yield put({
        type: 'saveRxnfInfo',
        payload: response.list,
      });
      if (callback) callback(response.list);
    },
    // 获取部门列表
    *GetOrgTreeInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetOrgTreeInfo, payload);
      yield put({
        type: 'saveOrgInfo',
        payload: response,
      });
      if (callback) callback(response.list);
    },
    // 获取教职工列表
    *PageTeacherInfo({ payload }, { call, put }) {
      const response = yield call(PageTeacherInfo, payload);

      yield put({
        type: 'saveTeacher',
        payload: response,
      });
    },


    //获取角色信息
    *GetRoleInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetRoleInfo, payload);
      if (callback) callback(response);
    },

  },

  reducers: {
    save(state, action) {
      return {
        ...state,
        data: action.payload,
      };
    },
    saveOrgInfo(state, action) {
      return {
        ...state,
        OrgInfo: action.payload.list,
      };
    },
    saveTeacher(state, action) {
      return {
        ...state,
        teacherList: action.payload,
      };
    },
    saveStageInfo(state, action) {
      return {
        ...state,
        StageInfo: action.payload,
      };
    },
  },
};

export default Model;
