import { Form, Input, Modal, Select, Radio, Checkbox, InputNumber, Row, Col } from 'antd';

import { FormComponentProps } from 'antd/es/form';
import React, { useState, useEffect } from 'react';
import QueueAnim from 'rc-queue-anim';
import CascadeGeographic from '@/components/CascadeGeographic';
const FormItem = Form.Item;

interface CreateFormProps extends FormComponentProps {
  modalVisible: boolean;
  handleAdd: (fieldsValue: { desc: string }) => void;
  handleModalVisible: () => void;
  mainSchoolVisible: boolean;
  handMainSchoolVisible: () => void;
  xxbbmDict: Array<string>;
  fsxxbxlxmDict: Array<string>;
  xxbxlxmDict: Array<string>;
  szdcxlxmDict: Array<string>;
  xxjbzmDict: Array<string>;
  fsbIdsDict: Array<string>;
  mainSchoolList: Array<string>;
  dispatchProps: any;
  areaCode: string;
  codeArr: Array<string>;
  regionalInformation: [];
  orgtype: number;
}
const CreateForm: React.FC<CreateFormProps> = props => {
  const [schoolList, setSchoolList] = useState([]);
  const [eduList, setEduList] = useState([]);
  const [nowEdu, setNowEdu] = useState("");
  // const [isBranchschool, setIsBranchschool] = useState("-1");

  const {
    modalVisible,
    form,
    handleAdd,
    handleModalVisible,
    mainSchoolVisible,
    handMainSchoolVisible,
    xxbbmDict,
    xxbxlxmDict,
    szdcxlxmDict,
    xxjbzmDict,
    fsxxbxlxmDict,
    mainSchoolList,
    dispatchProps,
    areaCode,
    codeArr,
    orgtype,
    regionalInformation
  } = props;

  let regionalInfo: any = [];
  let areaC = "";
  if (regionalInformation.length > 0) {
    regionalInfo = regionalInformation.concat();
    regionalInfo.map((item: any, index: number) => {
      if (item.parent_code === "-1") {
        regionalInfo.splice(index, 1);
      }
    })
    if (areaCode.substring(areaCode.length - 2) == "00") {
      areaC = "";
      // setNowEdu(areaC)
      // form.setFieldsValue({ managerAreaCode: areaC })
    }
  }
  // console.log(regionalInfo, areaC, "5555555555")
  // 确定提交
  const okHandle = () => {
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      // form.resetFields();

      fieldsValue.fsbIds = fieldsValue.fsbIds?.toString()
      handleAdd(fieldsValue);
    });
  };

  useEffect(() => {

    // // 截取字符串去掉省市区内的空白项
    if (codeArr[2] || codeArr[1]) {
      handleCityChange(codeArr.filter((x) => x !== ''))
    }
  }, [codeArr])


  // 主校读取
  const isMainSchool = (e: any) => {
    const { dispatch } = dispatchProps;
    dispatch({
      type: 'school/PageMainSchoolInfo',
      payload: {
        page: 1,
        limit: 1000,
        areaCode: areaCode,
      },
      callback: (response: any) => {
        setSchoolList(response.list)
      },
    });
    handMainSchoolVisible(e.target.checked);
  }

  // 所在区选择
  const handleCityChange = (e: any) => {
    const { dispatch } = dispatchProps;
    dispatch({
      type: 'school/PageEnableEduInfo',
      payload: {
        page: 1,
        limit: 1000,
        areaCode: e[1],
      },
      callback: (response: any) => {
        if (response.list.length > 0) {
          const eduLists = response.list;
          setEduList(eduLists)
          let states = false;
          eduLists.map((data: any) => {
            if (e[2] === data.area_code) {
              states = true;
            }
          })
          if (states === true) {
            setNowEdu(e[2] ? e[2] : e[1])
            form.setFieldsValue({ managerAreaCode: e[e.length - 1] })
          } else {
            setNowEdu(eduLists[0].area_code);
            form.setFieldsValue({ managerAreaCode: eduLists[0].area_code })
          }
        } else {
          setEduList([])
          setNowEdu("")
          form.setFieldsValue({ managerAreaCode: "" })
        }
      },
    });
  }

  return (
    <Modal
      destroyOnClose
      title="新建学校"
      visible={modalVisible}
      maskClosable={false}
      onOk={okHandle}
      onCancel={() => handleModalVisible()}
      width="800px"
    >

      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 8 }} label="学校代码">
        {form.getFieldDecorator('orgCode', {
          rules: [
            {
              required: true,
              message: '请输入2-20个字母或数字',
            },
            {
              min: 2,
              max: 20,
              message: '长度不在范围内',
            },
            {
              pattern: new RegExp('^\\w+$', 'g'),
              message: '学校代码必须为字母或者数字',
            },
          ],
        })(<Input placeholder="请输入学校代码" maxLength={20} />)}
      </FormItem>
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="学校名称">
        {form.getFieldDecorator('orgName', {
          rules: [
            {
              required: true,
              message: '请输入1-30个汉字、字母或数字',
            },
            {
              min: 1,
              max: 30,
              message: '长度不在范围内',
            },
            {
              pattern: new RegExp('^[\u4E00-\u9FA5A-Za-z0-9]+$', 'g'),
              message: '学校名称必须为汉字、字母或者数字',
            },
          ],
        })(<Input placeholder="请输入学校名称" maxLength={30} />)}
      </FormItem>
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 16 }} label="所在区">
        {orgtype === 1 ?
          form.getFieldDecorator('areaCode', {
            initialValue: codeArr[2] ? codeArr[2] : "",
            rules: [{ required: true, message: '选择所在区！' }],
          })(
            <CascadeGeographic
              changeOnSelect={false}
              level="3"
              defaultValue={codeArr[2] ? codeArr : ""}
              onChange={(e: any) => { handleCityChange(e) }}
            />)
          : orgtype === 2 ? form.getFieldDecorator('areaCode', {
            initialValue: areaC,
            rules: [{ required: true, message: '选择所在区！' }],
          })(<Select defaultValue={areaCode} style={{ width: "100%" }} onChange={(value: any) => {
            let abc = [];

            abc.push(value.slice(0, 2) + "0000")
            abc.push(value.slice(0, 4) + "00")
            abc.push(value)
            handleCityChange(abc)
          }}>
            {regionalInfo.map((item) => {
              return <Option value={item.area_code}>{item.parent_name + "/" + item.area_name}</Option>
            })}
          </Select>)
            : form.getFieldDecorator('areaCode', {
              initialValue: areaCode,
              rules: [{ required: true, message: '选择所在区！' }],
            })(<Select defaultValue={areaCode} style={{ width: "100%" }} onChange={(value: any) => {
              let abc = [];

              abc.push(value.slice(0, 2) + "0000")
              abc.push(value.slice(0, 4) + "00")
              abc.push(value)
              handleCityChange(abc)
            }}>
              {regionalInfo.map((item) => {
                return <Option value={item.area_code}>{item.parent_name + "/" + item.area_name}</Option>
              })}
            </Select>)}
        {/* {form.getFieldDecorator('areaCode', {
          initialValue: codeArr[2]?codeArr[2]:"",
          rules: [{ required: true, message: '选择所在区！' }],
        })(
          <CascadeGeographic
            changeOnSelect={false}
            level="3"
            defaultValue={codeArr[2]?codeArr:""}
            onChange={(e: any) => { handleCityChange(e) }}
          />)} */}
      </FormItem>
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="上级管理单位">
        {form.getFieldDecorator('managerAreaCode', {
          initialValue: nowEdu,
          rules: [{ required: true, message: '请选择上级管理单位！' }],
        })(
          <Select
            style={{ width: '100%' }}
            showSearch={true}
          >

            {eduList.map((item, index) => (
              <Select.Option value={item.area_code} key={item.area_code} >{item.org_name}</Select.Option>
            ))}

          </Select>
        )}
      </FormItem>

      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 10 }} label="是否分校">
        {form.getFieldDecorator('isBranchSchool')(
          <Checkbox.Group>
            <Checkbox value="1" style={{ lineHeight: '32px' }} onChange={(e) => { isMainSchool(e) }}>
              是
              </Checkbox>
          </Checkbox.Group>
        )}
      </FormItem>
      <QueueAnim className="demo-content">{mainSchoolVisible ? [
        <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 10 }} label="主校" key="a">
          {form.getFieldDecorator('mainSchoolId', {
            rules: [{ required: true, message: '请选择主校' }],
          })(<Select
            style={{ width: '100%' }}
            showSearch={true}

          >


            {schoolList.map((item, index) => (
              <Select.Option value={item.org_id} key={index} >{item.org_name}</Select.Option>
            ))}
            {/* {mainSchoolList.map((item, index) => (
              <Select.Option value={item.org_id} key={index} >{item.org_name}</Select.Option>
            ))} */}
          </Select>)}
        </FormItem>] : null}</QueueAnim>




      {/* 
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 6 }} label="学校办别">
        {form.getFieldDecorator('xxbbm', {
          rules: [{ required: true, message: '请选择学校办别' }],
        })(<Select
          style={{ width: '100%' }}
          showSearch={true}
        >
          {xxbbmDict.map(item => (
            <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
          ))}
        </Select>
        )}
      </FormItem> */}



      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 6 }} label="学校办学类型">
        {form.getFieldDecorator('xxbxlxm', {
          rules: [{ required: true, message: '请选择学校办学类型' }],
        })(<Select
          style={{ width: '100%' }}
          showSearch={true}
        >
          {xxbxlxmDict.map(item => (
            <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
          ))}

        </Select>)}
      </FormItem>

      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 5 }} label="学校举办者">
        {form.getFieldDecorator('xxjbzm', {
          rules: [{ required: true, message: '请选择学校举办者' }],
        })(<Select
          style={{ width: '100%' }}
          showSearch={true}
        >
          {xxjbzmDict.map(item => (
            <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
          ))}
        </Select>)}
      </FormItem>

      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 4 }} label="学校城乡类型">
        {form.getFieldDecorator('szdcxlxm', {
          rules: [{ required: true, message: '请选择学校城乡类型' }],
        })(<Select
          style={{ width: '100%' }}
          showSearch={true}
        >
          {szdcxlxmDict.map(item => (
            <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
          ))}
        </Select>)}
      </FormItem>
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 16 }} label="附设班办学类型">
        {form.getFieldDecorator('fsbIds')(<Select
          mode="multiple"
          style={{ width: '100%' }}
          showSearch={true}
        >
          {fsxxbxlxmDict.map(item => (
            <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
          ))}
        </Select>)}
      </FormItem>

      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 5 }} label="学校法定代表人">
        {form.getFieldDecorator('fddbr', {
          rules: [

            {
              min: 2,
              max: 30,
              message: '长度不在范围内',
            },
            {
              pattern: new RegExp('^[\u4E00-\u9FA5A-Za-z0-9]+$', 'g'),
              message: '学校法定代表人必须为汉字、字母或者数字',
            },
          ],
        })(<Input placeholder="请输入" maxLength={30} />)}
      </FormItem>
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 10 }} label="学校法定代表人电话">
        {form.getFieldDecorator('fddbrdh', {
          rules: [
            {
              min: 2,
              max: 30,
              message: '长度范围在2-30个字符之间。',
            },
            {
              pattern: new RegExp('^[ 0-9+-]*$', 'g'),
              message: '请输入电话可用字符。',
            },
          ],
        })(<Input placeholder="请输入" maxLength={30} />)}
      </FormItem>
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="学校地址">
        {form.getFieldDecorator('address', {
          rules: [
            {
              min: 2,
              max: 100,
              message: '请输入2-100个汉字、字母或数字',
            },
            {
              pattern: new RegExp('^[\u4E00-\u9FA5A-Za-z0-9-]+$', 'g'),
              message: '学校地址必须为汉字、字母或者数字',
            },
          ],
        })(<Input placeholder="请输入" maxLength={100} />)}
      </FormItem>
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 10 }} label="联系电话">
        {form.getFieldDecorator('lxdh', {
          rules: [
            {
              min: 2,
              max: 30,
              message: '长度范围在2-30个字符之间。',
            },
            {
              pattern: new RegExp('^[ 0-9+-]*$', 'g'),
              message: '请输入电话可用字符。',
            },
          ],
        })(<Input placeholder="请输入" maxLength={30} />)}
      </FormItem>
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 4 }} label="排序号">
        {form.getFieldDecorator('sortId', {
          rules: [
            // {
            //   min: 1,
            //   max: 4,
            //   message: '长度范围在1-4个字符之间。',
            // },
            {
              pattern: new RegExp('^[0-9]*$', 'g'),
              message: '请输入1~4位数字。',
            },
          ],
        })(<InputNumber style={{ width: "100%" }} placeholder="请输入排序号" maxLength={4} min={1} max={9999} />)}
      </FormItem>
    </Modal>
  );
};

export default Form.create<CreateFormProps>()(CreateForm);
