import {
  Cascader,
  Button,
  Card,
  Col,
  Divider,
  Dropdown,
  Form,
  Icon,
  Input,
  Menu,
  Popconfirm,
  Row,
  Select,
  message,
} from 'antd';
import React, { Component, Fragment } from 'react';

import { Dispatch, Action } from 'redux';
import { FormComponentProps } from 'antd/es/form';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { SorterResult } from 'antd/es/table';
import { connect } from 'dva';
import router from 'umi/router';
import { StateType } from './model';
import CreateForm from './components/CreateForm';
import UpdataSchoolForm from './components/UpdataSchoolForm';
import StandardTable, { StandardTableColumnProps } from './components/StandardTable';
import { FormValueType } from './components/UpdateForm';
import { CascaderOptionType } from 'antd/lib/cascader';
import { TableListItem, TableListPagination, TableListParams } from './data.d';
import CascadeGeographic from '../../../components/CascadeGeographic'

import styles from './style.less';
import Link from 'umi/link';

const FormItem = Form.Item;
const { Option } = Select;

interface TableListProps extends FormComponentProps {
  dispatch: Dispatch<
    Action<
      | 'school/PageSchoolInfo'
      | 'school/GetSchoolInfoById'
      | 'school/AddSchoolInfo'
      | 'school/UpdateSchoolInfo'
      | 'school/DeleteSchoolInfo'
      | 'school/PageMainSchoolInfo'
      | 'school/getRegionMsg'
      | 'school/getPersonMsg'
      | 'dict/fetch'
    >
  >;
  loading: boolean;
  school: StateType;
}

interface TableListState {
  modalVisible: boolean;
  updateModalVisible: boolean;
  expandForm: boolean;
  selectedRows: TableListItem[];
  formValues: { [key: string]: string };
  stepFormValues: Partial<TableListItem>;
  areaCode: string;
  codeArr: any;
  page: number;
  pageSize: number;
  xxbxlxm: string;
  mainSchoolVisible: boolean;
  xxbbmDict: Array<string>
  xxbxlxmDict: Array<string>
  szdcxlxmDict: Array<string>
  xxjbzmDict: Array<string>
  fsxxbxlxmDict: Array<string>
  mainSchoolList: Array<string>
  schoolInfo: { [key: string]: string };
  orgName: string;
  orgtype: number;
  regionalInformation: [];
  areaParentCode: string;
  showAddBtn: boolean;
  csSelect: boolean;
}

/* eslint react/no-multi-comp:0 */
@connect(
  ({
    school,
    loading,
  }: {
    school: StateType;
    loading: {
      models: {
        [key: string]: boolean;
      };
    };
  }) => ({
    school,
    loading: loading.models.school,
  }),
)
class TableList extends Component<TableListProps, TableListState> {
  state: TableListState = {
    modalVisible: false,
    updateModalVisible: false,
    expandForm: false,
    selectedRows: [],
    formValues: {},
    stepFormValues: {},
    areaCode: this.props.location.query.code && this.props.location.query.code2 !== "" ? this.props.location.query.code2 : this.props.location.query.code && this.props.location.query.code1 !== "" ? this.props.location.query.code1 : '220100',
    codeArr: this.props.location.query.code ? [this.props.location.query.code, this.props.location.query.code1, this.props.location.query.code2] : ["220000", "220100", ""],
    xxbxlxm: "-1",
    page: 1,
    pageSize: 10,
    mainSchoolVisible: false,  //弹出菜单主校是否可见
    xxbbmDict: [],
    xxbxlxmDict: [],
    szdcxlxmDict: [],
    xxjbzmDict: [],
    fsxxbxlxmDict: [],
    mainSchoolList: [],  //弹出主校列表
    schoolInfo: {},         //修改学校信息
    orgName: '',
    orgtype: 1,
    regionalInformation: [],
    areaParentCode: "",
    showAddBtn: true,
    csSelect: false,
  };

  columns: StandardTableColumnProps[] = [
    {
      title: '序号',
      dataIndex: 'org_id',
      render: (text, record, index) =>
        `${(this.state.page - 1) * (this.state.pageSize) + (index + 1)}`,

    },
    {
      title: '学校名称',
      dataIndex: 'org_name',
    },
    {
      title: '学校代码',
      dataIndex: 'org_code',
    },
    {
      title: '学校办学类型',
      dataIndex: 'xxbxlxm_name',
    },
    {
      title: '操作',
      width: 480,
      render: (text, record) => (
        <Fragment>
          <a type="link" onClick={() => { this.handleEditModalVisible(record.org_id, true) }}>编辑</a>
          <Divider type="vertical" />

          <Popconfirm
            title={'是否确认删除『' + record.org_name + '』？'}
            okText="确认"
            cancelText="取消"
            onConfirm={() => this.handleDelete(record.org_id)}
          >
            <a style={{ color: "red" }}>删除</a>
          </Popconfirm>
          <Divider type="vertical" />
          <Link to={`/organization/school/branch/${record.org_id}`} onClick={() => { this.backLocation() }}>部门管理</Link>
          <Divider type="vertical" />
          <Link to={`/organization/school/teacher/${record.org_id}`} onClick={() => { this.backLocation() }}>教职工管理</Link>

          <Divider type="vertical" />
          <Link to={`/organization/school/class/${record.org_id}`} onClick={() => { this.backLocation() }}>班级管理</Link>

          <Divider type="vertical" />
          <Link to={`/organization/school/student/${record.org_id}`} onClick={() => { this.backLocation() }}>学生管理</Link>

        </Fragment>
      ),
    },
  ];
  mainSchoolVisible: any;

  backLocation = () => {
    router.push({
      pathname: '/organization/school/',
      query: {
        code: this.state.codeArr[0],
        code1: this.state.codeArr[1] ? this.state.codeArr[1] : "",
        code2: this.state.codeArr[2] ? this.state.codeArr[2] : "",
      },
    })
  }
  componentDidMount() {
    const areaCode = this.state.areaCode;
    const { dispatch } = this.props;
    dispatch({
      type: 'school/getPersonMsg',
      callback: (data: any) => {
        if (data.list[0].role_id === "A66C757C-F797-454D-99DE-2A3F5415BC22") {
          this.setState({ orgtype: 1 })
          this.getSchoolList(areaCode);
        } else if (data.list[0].role_id === "5CC3293C-3AA5-45B7-B54B-CA8CC549FB81") {
          this.setState({ orgtype: 2 })
          dispatch({
            type: 'school/getRegionMsg',
            payload: {
              areaType: "1"
            },
            callback: (response: any) => {
              if (response.success === true) {
                this.getSchoolList(response.list[0].area_code);
                this.setState({
                  regionalInformation: response.list,
                  areaCode: response.list[0].area_code,
                  areaParentCode: response.list[0].parent_code,
                  codeArr: [response.list[0].parent_code, response.list[0].area_code, ""]
                })
              }
            }
          })
        } else if (data.list[0].role_id === "BF61C95F-3ADD-4F37-9FCD-97E69E1BF6E3") {
          this.setState({ orgtype: 3 })
          dispatch({
            type: 'school/getRegionMsg',
            payload: {
              areaType: "2"
            },
            callback: (response: any) => {
              if (response.success === true) {
                this.getSchoolList(response.list[0].area_code);
                this.setState({
                  regionalInformation: response.list,
                  areaCode: response.list[0].area_code,
                  areaParentCode: response.list[0].parent_code,
                  codeArr: [response.list[0].parent_code.slice(0, 3) + "000", response.list[0].parent_code, response.list[0].area_code]
                })
              }
            }
          })
        }
      }
    });
    dispatch({
      type: 'dict/fetch',
      payload: {
        dictKind: "xxbbm"
      },
      callback: (response: any) => {
        this.setState({
          xxbbmDict: response.list
        });
      },
    });
    dispatch({
      type: 'dict/fetch',
      payload: {
        dictKind: "xxbxlxm"
      },
      callback: (response: any) => {
        this.setState({
          xxbxlxmDict: response.list
        });
      },
    });
    dispatch({
      type: 'dict/fetch',
      payload: {
        dictKind: "szdcxlxm"
      },
      callback: (response: any) => {
        this.setState({
          szdcxlxmDict: response.list
        });
      },
    });
    dispatch({
      type: 'dict/fetch',
      payload: {
        dictKind: "xxjbzm"
      },
      callback: (response: any) => {
        this.setState({
          xxjbzmDict: response.list
        });
      },
    });
    dispatch({
      type: 'dict/fetch',
      payload: {
        dictKind: "fsxxbxlxm"
      },
      callback: (response: any) => {
        this.setState({
          fsxxbxlxmDict: response.list
        });
      },
    });

    // dispatch({
    //   type: 'school/PageMainSchoolInfo',
    //   payload: {
    //     page: 1,
    //     limit: 1000,
    //     areaCode: this.state.areaCode
    //   },
    //   callback: (response: any) => {
    //     this.setState({
    //       mainSchoolList: response.list,
    //     });
    //   },
    // });
  }

  // 获取列表
  getSchoolList(areaCode: string, pagination?: any) {
    const { dispatch } = this.props;

    if (!pagination) {
      pagination = {
        page: this.state.page,
        limit: this.state.pageSize,
      }
    }

    dispatch({
      type: 'school/PageSchoolInfo',
      payload: {
        areaCode: areaCode,
        xxbxlxm: this.state.xxbxlxm,
        orgName: this.state.orgName,
        ...pagination,
      },
    });
  }

  // 查询表单
  handleSearch = (e: React.FormEvent) => {
    e.preventDefault();
    const { form } = this.props;
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      fieldsValue.xxbxlxm = fieldsValue.xxbxlxm ? fieldsValue.xxbxlxm : -1;
      this.setState({
        orgName: fieldsValue.orgName ? fieldsValue.orgName : '',
      }, () => {
        this.getSchoolList(this.state.areaCode)
      });
    });
  };
  //下拉筛选==区划分
  handleSelect = (value: any) => {
    if (this.state.orgtype === 1) {
      this.setState({ codeArr: value })
      if (value.length > 1) {
        const code = value[value.length - 1]
        const { form } = this.props;
        form.setFieldsValue({
          orgName: ""
        })
        this.setState({ areaCode: code, formValues: {}, orgName: "", showAddBtn: true, csSelect: false })
        this.state.orgName = "";

        const pagination = {
          'page': 1,
          'limit': this.state.pageSize,
        }
        this.getSchoolList(code, pagination);
      } else {
        this.setState({ showAddBtn: false, csSelect: false })
      }
    } else {
      this.getSchoolList(value);
    }
  }
  handleSelectType = (value: any) => {
    const { form } = this.props;
    form.resetFields();
    this.setState({ formValues: {}, orgName: "", xxbxlxm: value })
    this.state.orgName = "";
    this.state.xxbxlxm = value;

    this.getSchoolList(this.state.areaCode);
  }

  // // 查询表单重置
  // handleFormReset = () => {
  //   const { form } = this.props;
  //   // form.resetFields();
  //   form.setFieldsValue({
  //     orgName: ""
  //   })
  //   this.setState({
  //     formValues: {},
  //   });

  //   const areaCode = this.state.areaCode;
  //   this.getSchoolList(areaCode);

  // };

  // 新建学校弹窗
  handleModalVisible = (flag?: boolean) => {
    this.setState({
      modalVisible: !!flag,
      mainSchoolVisible: false
    });
  };

  // 新建学校提交
  handleAdd = (fields: TableListItem) => {
    fields.isBranchSchool = fields.isBranchSchool && fields.isBranchSchool.length > 0 ? 1 : -1;
    // fields.areaCode = this.state.areaCode;
    const { dispatch } = this.props;
    dispatch({
      type: 'school/AddSchoolInfo',
      payload: {
        ...fields,
      },
      callback: (response: any) => {
        if (response.success) {
          message.success('添加成功');
          const areaCode = this.state.areaCode;
          this.getSchoolList(areaCode);
          this.handleModalVisible();
        } else {
          const areaCode = this.state.areaCode;
          this.getSchoolList(areaCode);
          message.error('添加失败,' + response.message);
        }
      },
    });
  };

  // 主校是否显示  
  handMainSchoolVisible = (flag?: boolean) => {
    this.setState({
      mainSchoolVisible: !!flag,
    });
  };

  // 删除
  handleDelete = (orgIds: string) => {
    const { dispatch } = this.props;
    const { formValues } = this.state;
    const areaCode = this.state.areaCode;

    dispatch({
      type: 'school/DeleteSchoolInfo',
      payload: {
        orgIds: orgIds
      },
      callback: (response: any) => {
        if (response.success) {
          message.success('删除成功');
          this.getSchoolList(areaCode);
        } else {
          this.getSchoolList(areaCode);
          message.error('删除失败,' + response.message);
        }
      },
    });
    this.handleModalVisible();
  };

  // 修改弹窗
  handleEditModalVisible = (orgId?: string, flag?: boolean) => {

    if (flag) {
      const { dispatch } = this.props;
      dispatch({
        type: 'school/GetSchoolInfoById',
        payload: {
          orgId: orgId,
        },
        callback: (response: any) => {
          let isMainSchool = false;
          if (response.main_school_type == 1) {
            isMainSchool = true;
          }

          this.setState({
            schoolInfo: response,
            updateModalVisible: !!flag,
            mainSchoolVisible: isMainSchool
          });
        },
      });
    } else {
      this.setState({
        updateModalVisible: !!flag,
      });
    }
  };

  // 修改学校处理
  handleUpdate = (fields: FormValueType) => {
    const { dispatch } = this.props;
    const areaCode = this.state.areaCode;

    fields.isBranchSchool = fields.isBranchSchool == 1 ? fields.isBranchSchool : -1

    dispatch({
      type: 'school/UpdateSchoolInfo',
      payload: {
        ...fields,
      },
      callback: (response: any) => {
        if (response.success) {
          this.getSchoolList(areaCode);
          message.success('编辑成功');
          this.handleEditModalVisible("")
        } else {
          message.error('编辑失败,' + response.message);

        }
      },
    });
  };

  // 分页
  handleStandardTableChange = (
    pagination: Partial<TableListPagination>,
    filtersArg: Record<keyof TableListItem, string[]>,
    sorter: SorterResult<TableListItem>,
  ) => {

    const { formValues, areaCode } = this.state;
    const page = pagination.current;
    const pageSize = pagination.pageSize;

    pagination = {
      page: page,
      limit: pageSize
    }

    this.getSchoolList(areaCode, pagination)
    this.setState({
      page: page,
      pageSize: pageSize
    })
  };



  handleUpdateModalVisible = (flag?: boolean, record?: FormValueType) => {
    this.setState({
      updateModalVisible: !!flag,
      stepFormValues: record || {},
    });
  };

  /**
   * 选择后渲染方法
   * @param label
   * @param selectedOptions
   */
  displayRender = (label: string[], selectedOptions: CascaderOptionType[]) => {
    //
    let path;
    if (selectedOptions.length === 1) {
      // path = ''
      path = sessionStorage.getItem('prevSelectedOptions')
    } else {
      sessionStorage.setItem('prevSelectedOptions', label.join(' / '))
      path = label.join(' / ')
    }
    return path
  }

  // onLoadChange = (selectedOptions:any) => {
  //   if(selectedOptions.length === 1){
  //     this.setState({csSelect:true})
  //   }else {
  //     this.setState({csSelect:false})
  //   }
  // }

  renderSimpleForm() {
    const { form } = this.props;
    const { getFieldDecorator } = form;
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
          <Col md={6} sm={24}>
            <FormItem label="所在行政区划">
              {this.state.orgtype === 1 ? getFieldDecorator('areaCode', {
                initialValue: this.state.codeArr,
              })(<CascadeGeographic changeOnSelect={true} level="3" defaultValue={this.state.codeArr} onChange={this.handleSelect}
                // onLoadChange={this.onLoadChange}
                displayRender={this.displayRender}
              />)
                : this.state.orgtype === 2 ? getFieldDecorator('areaCode', {
                  initialValue: this.state.areaCode,
                })(<Select defaultValue={this.state.areaCode} onChange={this.handleSelect}>
                  {this.state.regionalInformation.map((item) => {
                    return <Option value={item.area_code}>{item.parent_name + "/" + item.area_name}</Option>
                  })}
                </Select>)
                  : getFieldDecorator('areaCode', {
                    initialValue: this.state.areaCode,
                  })(<Select defaultValue={this.state.areaCode} onChange={this.handleSelect}>
                    {this.state.regionalInformation.map((item) => {
                      return <Option value={item.area_code}>{item.parent_name + "/" + item.area_name}</Option>
                    })}
                  </Select>)}
            </FormItem>
          </Col>
          <Col md={6} sm={12}>
            <FormItem label="学校办学类型">
              {getFieldDecorator('xxbxlxm')(
                <Select placeholder="请选择" allowClear={true} style={{ width: '100%' }} onChange={this.handleSelectType} >
                  {this.state.xxbxlxmDict.map(item => (
                    <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
                  ))}
                </Select>,
              )}
            </FormItem>
          </Col>
          <Col md={6} sm={12}>
            <FormItem label="学校名称">
              {getFieldDecorator('orgName')(<Input placeholder="请输入" allowClear={true} maxLength={30} />)}
            </FormItem>
          </Col>
          <Col md={4} sm={12}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
              {/* <Button style={{ marginLeft: 8 }} onClick={this.handleFormReset}>
                重置
              </Button> */}
            </span>
          </Col>
        </Row>
      </Form>
    );
  }

  renderForm() {
    const { expandForm } = this.state;
    return expandForm ? this.renderAdvancedForm() : this.renderSimpleForm();
  }
  renderAdvancedForm() {
    throw new Error("Method not implemented.");
  }

  render() {
    const {
      school: { data },
      loading,
    } = this.props;
    const { selectedRows, modalVisible, updateModalVisible } = this.state;
    data.pagination = {
      current: this.state.page,
      total: data.count,
      pageSize: this.state.pageSize,
      showTotal: ((total: any) => {
        return `共 ${total} 条`;
      }),
    }
    const parentMethods = {
      handleAdd: this.handleAdd,
      handleModalVisible: this.handleModalVisible,
      mainSchoolVisible: this.state.mainSchoolVisible,
      handMainSchoolVisible: this.handMainSchoolVisible,
      xxbbmDict: this.state.xxbbmDict,
      xxbxlxmDict: this.state.xxbxlxmDict,
      szdcxlxmDict: this.state.szdcxlxmDict,
      xxjbzmDict: this.state.xxjbzmDict,
      fsxxbxlxmDict: this.state.fsxxbxlxmDict,
      mainSchoolList: this.state.mainSchoolList,
      codeArr: this.state.codeArr,
      orgtype: this.state.orgtype,
      regionalInformation: this.state.regionalInformation,
    };
    const updateMethods = {
      handleUpdateModalVisible: this.handleUpdateModalVisible,
      handleUpdate: this.handleUpdate,
      handleEditModalVisible: this.handleEditModalVisible,
      mainSchoolVisible: this.state.mainSchoolVisible,
      handMainSchoolVisible: this.handMainSchoolVisible,
      xxbbmDict: this.state.xxbbmDict,
      xxbxlxmDict: this.state.xxbxlxmDict,
      szdcxlxmDict: this.state.szdcxlxmDict,
      xxjbzmDict: this.state.xxjbzmDict,
      fsxxbxlxmDict: this.state.fsxxbxlxmDict,
      mainSchoolList: this.state.mainSchoolList,
      schoolInfo: this.state.schoolInfo,
      codeArr: this.state.codeArr,
      orgtype: this.state.orgtype,
      regionalInformation: this.state.regionalInformation
    };

    return (
      <PageHeaderWrapper>
        <Card bordered={false}>
          <div className={styles.tableList}>
            <div className={styles.tableListForm}>{this.renderForm()}</div>
            <div className={styles.tableListOperator}>
              {this.state.showAddBtn === true ? <Button icon="plus" type="primary" onClick={() => this.handleModalVisible(true)}>
                新建学校
              </Button> : ""}

            </div>

            <StandardTable
              rowSelection={false}
              selectedRows={selectedRows}
              loading={loading}
              data={data}
              columns={this.columns}
              onChange={this.handleStandardTableChange}
            />
          </div>
        </Card>
        <CreateForm {...parentMethods} modalVisible={modalVisible} dispatchProps={this.props} areaCode={this.state.areaCode} />
        <UpdataSchoolForm {...updateMethods} modalVisible={updateModalVisible} dispatchProps={this.props} areaCode={this.state.areaCode} />

      </PageHeaderWrapper >
    );
  }
}

export default Form.create<TableListProps>()(TableList);
