import { AnyAction, Reducer } from 'redux';
import { EffectsCommandMap } from 'dva';
import {
  PageSchoolInfo,
  GetSchoolInfoById,
  AddSchoolInfo,
  UpdateSchoolInfo,
  DeleteSchoolInfo,
  PageMainSchoolInfo,
  GetRegionMsg,
  GetPersonMsg,
  PageEnableEduInfo,
  PageClassInfo,
  StudentTransferInfo,
} from './service';

// eslint-disable-next-line import/no-unresolved
import { TableListData } from './data.d';

export interface StateType {
  data: TableListData;
}

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: StateType) => T) => T },
) => void;

export interface ModelType {
  namespace: string;
  state: StateType;
  effects: {
    PageSchoolInfo: Effect;
    GetSchoolInfoById: Effect;
    AddSchoolInfo: Effect;
    UpdateSchoolInfo: Effect;
    DeleteSchoolInfo: Effect;
    PageMainSchoolInfo: Effect;
    getPersonMsg: Effect;
    getRegionMsg: Effect;
    PageEnableEduInfo: Effect;
    StudentTransferInfo: Effect;
  };
  reducers: {
    save: Reducer<StateType>;
  };
} 

const Model: ModelType = {
  namespace: 'school',

  state: {
    data: {
      list: [],
      pagination: {},
    },
  },

  effects: {
    *PageSchoolInfo({ payload }, { call, put }) {
 
      const response = yield call(PageSchoolInfo, payload);

      yield put({
        type: 'save',
        payload: response,
      });
    },
    *GetSchoolInfoById({ payload, callback }, { call, put }) {
      const response = yield call(GetSchoolInfoById, payload);

      console.log(response.list[0].main_school_type, 'model')
      response.list[0].main_school_type = response.list[0].main_school_type == 3 ? response.list[0].main_school_type = 1 : ""

      if (callback) callback(response.list[0]);
    },
    *AddSchoolInfo({ payload, callback }, { call, put }) {
      const response = yield call(AddSchoolInfo, payload);
      if (callback) callback(response);
    },
    *UpdateSchoolInfo({ payload, callback }, { call, put }) {
      const response = yield call(UpdateSchoolInfo, payload);
      if (callback) callback(response);
    },
    *DeleteSchoolInfo({ payload, callback }, { call, put }) {
      const response = yield call(DeleteSchoolInfo, payload);
      if (callback) callback(response);
    },
    *PageMainSchoolInfo({ payload, callback }, { call, put }) {
      const response = yield call(PageMainSchoolInfo, payload);
      if (callback) callback(response);
    },
    *getRegionMsg({ payload, callback }, { call, put }) {
      const response = yield call(GetRegionMsg, payload);
      if (callback) callback(response);
    },
    *getPersonMsg({ payload, callback }, { call, put }) {
      const response = yield call(GetPersonMsg, payload);
      if (callback) callback(response);
    },
    *PageEnableEduInfo({ payload, callback }, { call, put }) {
      const response = yield call(PageEnableEduInfo, payload);
      if (callback) callback(response);
    },
    *PageClassInfo({ payload, callback }, { call, put }) {
      const response = yield call(PageClassInfo, payload);
      if (callback) callback(response);
    },
    *StudentTransferInfo({ payload, callback }, { call, put }) {
      console.log(payload,'payload,')
      const response = yield call(StudentTransferInfo, payload);
      if (callback) callback(response);
    },
  },

  reducers: {
    save(state, action) {
      return {
        ...state,
        data: action.payload,
      };
    },
  },
};

export default Model;
