import { Form, Input, Modal,Select,DatePicker,Cascader,Tooltip,Row,Col,Radio } from 'antd';
import moment from 'moment';
import { FormComponentProps } from 'antd/es/form';
import React,{useState} from 'react';
import QueueAnim from 'rc-queue-anim';

const FormItem = Form.Item;
const { Option } = Select;
const { MonthPicker } = DatePicker
import { checkIdNo } from '@/utils/utils';
interface CreateFormProps extends FormComponentProps {
  modalVisible: boolean;
  handleAdd: (fieldsValue: { desc: string }) => void;
  handleXbDateShow: (value:boolean) => void;
  handleModalVisible: () => void;
  xbm:Array<string>;
  sfzjlxm:Array<string>;
  mzm:Array<string>;
  zzmmm:Array<string>;
  isShowDateXb:boolean;
}
const CreateForm: React.FC<CreateFormProps> = props => {
  const [isIdNumber, setIsIdNumber] = useState(0)     //身份证号输入框是否显示
  const { modalVisible, form, handleAdd, handleModalVisible, xbm, sfzjlxm, mzm, zzmmm, handleXbDateShow, isShowDateXb
  } = props;

  const okHandle = () => {
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      // form.resetFields();
      handleAdd(fieldsValue);
    });
  };

  const disabledDate = (current:any) => {
    return current && current > moment().endOf('day');
  }




  const bhValidate = (rule, value, callback) => {
    const { form } = props;
    // const b = value;
    const e = form.getFieldValue("student_zjh");


    if (e) {
      if (checkIdNo(e)) {

        parseInt(e.substr(16, 1)) % 2 == 1 ? form.setFieldsValue({ student_xb: "1" }) : form.setFieldsValue({ student_xb: "2" })
        const data = e.substring(6, 10) + "/" + e.substring(10, 12) + "/" + e.substring(12, 14); 
        // console.log(data)
        form.setFieldsValue({student_date:moment(data)})
        return true
      } else {
        return false
      }
    } else {
      return true
    }


  }


  return (
    <Modal
      destroyOnClose
      title="新增学生"
      visible={modalVisible}
      maskClosable={false}
      onOk={okHandle}
      onCancel={() => handleModalVisible()}
      width="800px"
    >
      {/* 学生姓名 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="学生姓名">
        {form.getFieldDecorator('student_name', {
          rules: [
            {
              required: true,
              message: '请输入2-20个汉字或字母或数字',
            },
            {
              min: 2,
              max: 20,
              message: '长度不在范围内',
            },
            {
              pattern: new RegExp('^[\u4E00-\u9FA5A-Za-z0-9]+$', 'g'),
              message: '学生姓名必须为汉字、字母或者数字',
            },
          ],})(<Input placeholder="请输入学生姓名" maxLength={20} />)}
      </FormItem>
        {/* 身份证件类型 */}
       <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 10 }} label="身份证件类型">
        {form.getFieldDecorator('student_sfzjlx')(<Select
          style={{ width: '100%' }}
          showSearch={true}
          onChange={(value) => {
           
            setIsIdNumber(value)
            form.setFields({teacher_zjh:""})
        }}
          >
            {sfzjlxm.map(item => (
                  <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
                ))}
      </Select>)}
      </FormItem>
        {/* 证件号 */}
      {isIdNumber == 0 ? "" : isIdNumber == 1 ? <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="身份证件号">
        {form.getFieldDecorator('student_zjh', {
          rules: [
            {
              validator: bhValidate,
              message: '身份证格式错误'
            }
          ],
        })(<Input placeholder="请输入证件号" maxLength={30} />)}
      </FormItem> : <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="证件号">
          {form.getFieldDecorator('student_zjh', {
            rules: [
              {
                min: 2,
                max: 30,
                message: '长度不在范围内',
              },
              {
                pattern: new RegExp('^\\w+$', 'g'),
                message: '证件号必须为字母或者数字',
              },
            ],
          })(<Input placeholder="请输入证件号" maxLength={30} />)}
        </FormItem>
      }
        {/* 性别 */}

        <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 5 }} label="性别">
        {form.getFieldDecorator('student_xb', {
          rules: [{ required: true, message: '请选择性别' }],
        })(<Select
          style={{ width: '100%' }}
          showSearch={true}
        >
          {xbm.map(item => (
            <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
          ))}
        </Select>)}
      </FormItem>
      {/* 出生日期 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="出生日期" key="b">
        {form.getFieldDecorator('student_date', {
          rules: [{ required: true, message: '请选择出生日期' }],
        })(<DatePicker placeholder="请选择出生日期" disabledDate={disabledDate} />)}
      </FormItem>




        {/* 出生日期 */}
        {/* <QueueAnim delay={300} className="queue-simple">
        {isShowDateXb?[
          <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 5 }} label="性别" key="a">
          {form.getFieldDecorator('student_xb', {
          rules: [{ required: true, message: '请选择性别' }],
          })(<Select
          style={{ width: '100%' }}
          showSearch={true}
          >
            {xbm.map(item => (
                  <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
                ))}
        </Select>)}
        </FormItem>,
        <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="出生日期" key="b">
        {form.getFieldDecorator('student_date',{
          rules: [{ required: true, message: '请选择出生日期'}],
        })(<DatePicker placeholder="请选择出生日期" disabledDate={disabledDate}/>)}
        </FormItem>
    ] : null
   }
      
      </QueueAnim> */}
   
       
        {/* 民族 */}
        <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 8 }} label="民族">
         {form.getFieldDecorator('student_mz', {
          rules: [{ required: true, message: '请选择民族'}],
        })(<Select
          style={{ width: '100%' }}
          showSearch={true}
          >
            {mzm.map(item => (
                  <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
                ))}
      </Select>)}
      </FormItem>
      {/* 政治面貌 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 8 }} label="政治面貌">
        {form.getFieldDecorator('student_zzmm', {
          rules: [{ required: true, message: '请选择政治面貌' }],
        })(<Select
          style={{ width: '100%' }}
          showSearch={true}
          >
             {zzmmm.map(item => (
                  <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
                ))}
      </Select>)}
      </FormItem>
       {/* 是否独生子女 */}
       <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 8 }} label="是否独生子女">
        {form.getFieldDecorator('student_sfdszn', {
          rules: [{ required: true, message: '请选择'}],
          initialValue:1,
        })( <Radio.Group>
            <Radio value={1}>是</Radio>
             <Radio value={-1}>否</Radio>
        </Radio.Group>)}
      </FormItem>
      {/* 是否残疾 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 8 }} label="是否残疾">
        {form.getFieldDecorator('student_sfcj', {
          rules: [{ required: true, message: '请选择'}],
          initialValue:-1,
        })( <Radio.Group>
            <Radio value={1}>是</Radio>
             <Radio value={-1}>否</Radio>
        </Radio.Group>)}
      </FormItem>
     {/* 是否留守儿童 */}
     <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 8 }} label="是否留守儿童">
        {form.getFieldDecorator('student_sflset', {
          rules: [{ required: true, message: '请选择'}],
          initialValue:-1,
        })( <Radio.Group>
            <Radio value={1}>是</Radio>
             <Radio value={-1}>否</Radio>
        </Radio.Group>)}
      </FormItem>
       {/* 是否进城务工随迁子女 */}
       <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 8 }} label="是否进城务工人员随迁子女">
        {form.getFieldDecorator('student_sfjcwgsqzn', {
          rules: [{ required: true, message: '请选择'}],
          initialValue:-1,
        })( <Radio.Group>
            <Radio value={1}>是</Radio>
             <Radio value={-1}>否</Radio>
        </Radio.Group>)}
      </FormItem>
     {/* 是否随迁子女 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 8 }} label="是否随迁子女">
        {form.getFieldDecorator('student_sfsqzn', {
          rules: [{ required: true, message: '请选择'}],
          initialValue:-1,
        })( <Radio.Group>
            <Radio value={1}>是</Radio>
             <Radio value={-1}>否</Radio>
        </Radio.Group>)}
      </FormItem>
      {/* 是否孤儿 */}
         <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 8 }} label="是否孤儿">
        {form.getFieldDecorator('student_gebz', {
          rules: [{ required: true, message: '请选择'}],
          initialValue:-1,
        })( <Radio.Group>
            <Radio value={1}>是</Radio>
             <Radio value={-1}>否</Radio>
        </Radio.Group>)}
      </FormItem>
    </Modal>
  );

 
};

export default Form.create<CreateFormProps>()(CreateForm);
