import { Form, Input, Modal,Upload,Button,message,Icon,Spin } from 'antd';
import { FormComponentProps } from 'antd/es/form';
import React from 'react';



interface ImportInfoProps extends FormComponentProps {
  modalVisible: boolean;
  handleImportTeacherInfo:() => void;
  handleImportTipsShow:(message:string) => void;
  handleSuccessImport: (message:string) => void;
  handleTipsLoading: () => void;
  orgId:string;
  importTipsShow:boolean;
  tipsUrl:string;
  tipsLoading:boolean;

}
const ImportInfoModal: React.FC<ImportInfoProps> = props => {
  const { modalVisible,handleImportTeacherInfo,orgId,importTipsShow,handleImportTipsShow,tipsUrl,handleSuccessImport,tipsLoading,handleTipsLoading
  } = props;

  const data = {
    name: 'excelFile',
    action: window.location.origin + '/base/student/ImportStudentExcel',
    data:{
        orgId:orgId,
    },
    accept:'.xlsx',
    showUploadList:false,
    onChange(info:any) {
        handleTipsLoading()
        console.log(info,"info")
        if(info.file.status == "done"){
          if (info.file.response.success === false) {
            handleImportTipsShow(info.file.response.message)
          }else {
            handleSuccessImport(info.file.response.message)
          }
        }
    },
  };

  const tipStyle = {
    width:'100%',
    height:'10rem',
    marginTop: '0.5rem',
    border: '1px solid #ff7575',
    borderRadius: '6px',
    background: '#FFECEC',
    paddingLeft:'5%',
    position: 'relative'
  }


  return (
    <Modal
      destroyOnClose
      title="学生数据批量导入"
      visible={modalVisible}
      onCancel={() => handleImportTeacherInfo()}
      width="1000px"
      footer={null}
      maskClosable={false}
    >
    
    <Spin spinning={tipsLoading}>
    <div key="all_modal_key" style={{width:"100%"}}>
            <div key="modal_top_text_key" style={{width:"80%",marginLeft:"14%"}}>
                <p style={{marginBottom:"0.5rem"}}>步骤说明:&nbsp;&nbsp;1.&nbsp;请您先下载导入学生数据的excel文件模板, <span style={{color:"#31a8fa",textDecoration:'underline',cursor:"pointer"}} onClick={()=>{
                  let downUrl = window.location.origin + '/base/student/DownLoadStudentTemplateExcel?orgId=' + orgId;
                  debugger
                  window.open(downUrl,'_self')
                }}>下载模板</span>;</p>
                <p style={{paddingLeft:"8.8%",marginBottom:"0.5rem"}}>2.&nbsp;按照模板要求填写要导入的学生数据;</p>
                <p style={{paddingLeft:"8.8%",marginBottom:"0.5rem"}}>3.&nbsp;点击 "上传文件" 选择已经填写完成的学生数据文件完成导入操作;</p>
                <p style={{color:"#DC143C",paddingLeft:"8.8%",marginBottom:"0"}}>4.&nbsp;注：当系统提示 "数据错误, 导入失败" 时, 根据提示信息 "重新下载" 已经填写好的学生信息数据文件, 
                </p>
                <p style={{ color: "#DC143C", paddingLeft: "8.8%", marginBottom: "0" }}>5.&nbsp;注：导入中如果同样的身份证信息在其他机构已经存在那么会进行错误提示,如果是本机构下已经存在的身份证信息,会对该学生信息进行更新;
                </p>
                <p style={{color:"#DC143C",paddingLeft:"10%"}}>&nbsp;根据模板中的错误提示信息进行完善和修改, 修改好后重新上传文件。</p>

                <div key="modal_files_div_key" style={{paddingLeft:"8.8%",marginTop:'1.5rem'}}>
                    学生数据导入：
                    <Upload {...data}>
                     <Button>
                        <Icon type='upload'/>上传文件
                     </Button>
                    </Upload>
                    <div style={{fontSize:'0.8rem',color:'#999',marginLeft:'16%',marginTop:'0.2rem'}}>支持扩展名:&nbsp; .xlsx</div>
                </div>
                {importTipsShow?
                  <div key="modal_tips_div_key" style={tipStyle}>
                  <Icon type="close-circle" style={{color:'#EA0000',fontSize:'1.2rem',position:'absolute',top:'0.5rem',left:"0.5rem"}}/>
                  <p style={{marginBottom:'0.2rem',marginTop:'0.35rem',fontSize:'1rem',fontWeight:'bolder'}}>数据错误，导入失败！</p>
                  <p style={{marginBottom:'0.2rem',color:'#999'}}>您导入的数据出现错误，请点击 "重新下载" 修改后重新上传</p>
                  <p style={{marginBottom:'0.2rem',color:'#999'}}>
                    <span style={{width:'5%',display:'inline-block',height:'1rem',background:'#dc143c',position:'relative',top:'0.1rem'}}/>&nbsp;:&nbsp;填写的信息为空或不正确</p>
                  <p style={{marginBottom:'0.2rem',color:'#999'}}>
                    <span style={{width:'5%',display:'inline-block',height:'1rem',background:'#4169e1',position:'relative',top:'0.1rem'}}/>&nbsp;:&nbsp;身份证，电话或邮箱在当前EXCEL中存在重复
                   </p>
                  <p style={{marginBottom:'0.2rem',color:'#999'}}>
                  <span style={{width:'5%',display:'inline-block',height:'1rem',background:'#ffd700',position:'relative',top:'0.1rem'}}/>&nbsp;:&nbsp;身份证在其他机构中已存在或电话、邮箱系统中已存在重复导入
                  </p>
                  <p style={{color:"#31a8fa",cursor:"pointer",width:'10%'}} onClick={()=>{
                         let downUrl = 'http://' + tipsUrl;
                         debugger
                         window.open(downUrl,'_self')
                  }}>重新下载</p>
                 </div> 
                 :null}
            </div>
        </div>
      </Spin>
   
     
    </Modal>
  );

 
};

export default Form.create<ImportInfoProps>()(ImportInfoModal);
