import { Form, Input, Modal, Upload, Button, message, Icon, Spin } from 'antd';
import { FormComponentProps } from 'antd/es/form';
import React from 'react';



interface TemplateImportModal extends FormComponentProps {
  modalVisible: boolean;
  handleImportTeacherInfo: () => void;
  handleImportTipsShow: (message: string) => void;
  handleSuccessImport: (message: string) => void;
  handleTipsLoading: () => void;
  orgId: string;
  importTipsShow: boolean;
  tipsUrl: string;
  tipsLoading: boolean;

}
const TemplateImportModal: React.FC<TemplateImportModal> = props => {
  const { modalVisible, handleImportTeacherInfo, orgId, importTipsShow, handleImportTipsShow, tipsUrl, handleSuccessImport, tipsLoading, handleTipsLoading
  } = props;

  const data = {
    name: 'excelFile',
    action: window.location.origin + '/base/class/ImportXJCSV',
    accept: '.csv',
    showUploadList: false,
    onChange(info: any) {
      handleTipsLoading()
      console.log(info, "info")
      if (info.file.status == "done") {
        if (info.file.response.success === false) {
          handleImportTipsShow(info.file.response.message)
        } else {
          handleSuccessImport(info.file.response.message)
        }
      }
    },
  };

  // const tipStyle = {
  //   width: '100%',
  //   height: '10rem',
  //   marginTop: '0.5rem',
  //   border: '1px solid #ff7575',
  //   borderRadius: '6px',
  //   background: '#FFECEC',
  //   paddingLeft: '5%',
  //   position: 'relative'
  // }


  return (
    <Modal
      destroyOnClose
      title="国家学籍系统模板导入"
      visible={modalVisible}
      onCancel={() => handleImportTeacherInfo()}
      width="700px"
      footer={null}
      maskClosable={false}
    >

      <Spin spinning={tipsLoading}>
        <div key="all_modal_key" style={{ width: "100%", height: "250px", display: "table" }}>
          <div key="modal_top_text_key" style={{ width: "80%", marginLeft: "14%", display: "table-cell", verticalAlign: "middle", textAlign: "center" }}>
            <p style={{ marginBottom: "2rem" }}>步骤说明:&nbsp;&nbsp;1.&nbsp;请您先下载导入学生数据的文件模板, <span style={{ color: "#31a8fa", textDecoration: 'underline', cursor: "pointer" }} onClick={() => {
              let downUrl = window.location.origin + '/base/class/DownLoadXJCSV';
              window.open(downUrl, '_self')
            }}>下载模板</span>;</p>
            <div key="modal_files_div_key" style={{ paddingLeft: "8.8%" }}>
              国家学籍系统模板导入：
              <Upload {...data}>
                <Button>
                  <Icon type='upload' />
                  上传文件
                </Button>
              </Upload>
              <div style={{ fontSize: '0.8rem', color: '#999', marginLeft: '16%', marginTop: '0.2rem' }}>支持扩展名:&nbsp; .csv</div>
            </div>
          </div>
        </div>
      </Spin>
    </Modal>
  );


};

export default Form.create<TemplateImportModal>()(TemplateImportModal);
