import { Form, Popconfirm, Modal, Row, Col, message, Table, Select } from 'antd';
import { FormComponentProps } from 'antd/es/form';
import React, { useState, useEffect } from 'react';
import { String } from 'lodash';
import school from '..';

const FormItem = Form.Item;

interface CreateFormProps extends FormComponentProps {
    orgId: string;
    type: string;
    randomNumber: number;
    leaderId: [];
    modalVisible: boolean; // 显示modal
    cancelModal: () => void; // 返回上一层
    studentTransferInfo: (personId:string,classId:string) => void; // 返回上一层
    dispatchProps: any;
    checkLeader: (fieldsValue: { desc: any }) => void;
    transferStudentId:string;
    areaCode:string;
}

const SelectLeader: React.FC<CreateFormProps> = props => {
    const { modalVisible, form, transferSchoolVisible, checkLeader, dispatchProps, areaCode,studentTransferInfo,transferStudentId } = props;

    const [searchSchoolList, setSearchSchoolList] = useState([])
    const [searchSchoolId, setSearchSchoolId] = useState("")
    const [stageList, setStageList] = useState([])  //学制列表
    const [stageId, setStageId] = useState("")  //学制ID
    const [rxnfList, setRxnfList] = useState([])  //入学年份列表
    const [rxnfId, setRxnfId] = useState("")  //入学年份ID
    const [page, setPage] = useState(1)  //当前页数
    const [limit, setLimit] = useState(6)  //每页条数
    const [total, setTotal] = useState(0)  //每页条数

    const [classList, setClassList] = useState([])     //班级列表

    useEffect(()=>{
        resetState()
    },[transferStudentId])


    console.log(transferStudentId, 'modalVisible')
    const columns = [

        {
            title: '序号',
            dataIndex: 'id',
            render: (text, record, index) =>
                `${(page - 1) * (limit) + (index + 1)}`
        },
        {
            title: '班级名称',
            dataIndex: 'class_name',
        },
        {
            title: '班级别名',
            dataIndex: 'class_alias',
        },
        {
            title: '学生人数',
            dataIndex: 'student_count',
        },
        {
            title: '班主任',
            dataIndex: 'teacher_name',
        },
        {
            title: '操作',
            dataIndex: 'conf',
            render: (text: any, record: { class_alias: string; class_id: string; }) => (
                <Popconfirm
                    title={'是否移动到『' + record.class_alias + '』？'}
                    okText="确认"
                    cancelText="取消"
                    onConfirm={()=>handleTransferInfo(record.class_id)}
                >
            <a>设置</a>
          </Popconfirm>
              )
        },
    ];

const resetState = () =>{
    setSearchSchoolList([])
    setSearchSchoolId("")
    setStageList([])
    setStageId("")
    setRxnfId("")
    setRxnfList([])
    setLimit(6)
    setPage(1)
    setTotal(0)
    setClassList([])
}


    // 点击取消
    const handleCancel = () => {

        transferSchoolVisible(false)
    }

    // =====================================================================================
    // 获取学校列表
    const handleSearchSchool = (value: any) => {
        
        if (value.length>1) {
            value=value.replace(/ /g,"%")
            const { dispatch } = dispatchProps;
            dispatch({
                type: 'student/ListOrgByOrgKeyWord',
                payload: {
                    keyWord: value
                },
                callback: (response: any) => {
                    setSearchSchoolList(response)
                },
            });
        }
    };

    // 选择学校获取学制
    const handleSchool = (value: any) => {
        console.log(value, 'state searchSchoolId')
        setSearchSchoolId(value)

        const { dispatch } = dispatchProps;
        dispatch({
            type: 'student/GetStageInfo',
            payload: {
                orgId: value
            },
            callback: (response: any) => {
                const stage_id = response.list[0].stage_id;
                setStageList(response.list)
                setStageId(stage_id)
                //获取入学年份
                GetRxnfInfo(value, stage_id, value)
            },
        });
    }

    // 获取入选年份
    const GetRxnfInfo = (orgId: string, stageId: string, searchSchoolId: string) => {

        const { dispatch } = dispatchProps;
        dispatch({
            type: 'student/GetRxnfInfo',
            payload: {
                orgId: orgId,
                stageId: stageId
            },
            callback: (response: any) => {

                console.log(response, 'rxnf')
                if (response.list.length > 0) {
                    const rxnf_id = response.list[0];
                    setRxnfList(response.list)
                    setRxnfId(rxnf_id)
                    setPage(1)
                    const pagination = {
                        page: 1,
                        limit: limit
                    }
                    PageClassInfo(searchSchoolId, stageId, rxnf_id,pagination)
                } else {
                    setRxnfId("")
                    setRxnfList([])
                    setClassList([])
                    message.error('无入学年份数据。');

                }
                // setSearchSchoolList(response)
            },
        });
    }

    // 获取班级列表
    const PageClassInfo = (orgId: string, stageId: string, rxnf: string, setPage?: { page: number, limit: number }) => {

        const { dispatch } = dispatchProps;

        let pagination = {
            page: page,
            limit: limit
        }
        if (setPage != undefined) {

            pagination = {
                page: setPage.page,
                limit: setPage.limit
            }
        }

        console.log(pagination, 'pagination')

        dispatch({
            type: 'student/PageClassInfo',

            payload: {
                orgId: orgId,
                stageId: stageId,
                rxnf: rxnf,
                ...pagination
            },
            callback: (response: any) => {

                console.log(response, 'classList')
                if (response.list.length > 0) {
                    //     const rxnf_id = response.list[0];
                    setClassList(response.list)
                    setTotal(response.count)
                    //     setRxnfId(rxnf_id)
                } else {

                    message.error('无班级份数据。');
                }
                // // setSearchSchoolList(response)
            },
        });
    }

    // 通过学制获取入学年份
    const handleStage = (value: any) => {
        setStageId(value)
        GetRxnfInfo(searchSchoolId, value, searchSchoolId)
    }

    const handleRxnf = (value: any) => {
        setRxnfId(value)
        setPage(1)
        const pagination = {
            page: 1,
            limit: limit
        }
        PageClassInfo(searchSchoolId, stageId, value,pagination)
    }

    const pageOnChange = (e: any) => {

        const pagination = {
            page: e.current,
            limit: e.pageSize
        }
        PageClassInfo(searchSchoolId, stageId, rxnfId, pagination)
        setPage(e.current)
        setLimit(e.pageSize)
    }

    const handleTransferInfo = (class_id:string)=>{
        // alert()
        console.log(class_id)
        studentTransferInfo(transferStudentId,class_id)
    }
    console.log(stageId, 'stage id')
    const options = searchSchoolList?.map(d => <Select.Option key={d.org_id}>{d.org_name}</Select.Option>);
    const stageOptions = stageList?.map(d => <Select.Option key={d.stage_id}>{d.stage_name}</Select.Option>);
    const rxnfOptions = rxnfList?.map(d => <Select.Option key={d}>{d}</Select.Option>);
    return (
        <Modal
            destroyOnClose
            title={"选择调转学校的班级"}
            visible={modalVisible}
            // onOk={okHandle}
            onCancel={handleCancel}
            width="900px"
            footer={null}
            maskClosable={false}
        >
            <div>
                <Form layout="inline">
                    <Row gutter={[16, { md: 8, lg: 24, xl: 48 }]} >
                        <Col md={8} sm={12}>
                            <FormItem label="学校">
                                <Select
                                    style={{ width: 200 }}
                                    showSearch
                                    value={searchSchoolId}
                                    defaultActiveFirstOption={false}
                                    showArrow={false}
                                    filterOption={false}
                                    onSearch={handleSearchSchool}
                                    onChange={handleSchool}
                                    notFoundContent={null}
                                >
                                    {options}
                                </Select>
                                {/* <Input placeholder="请输入" allowClear={true} onChange={(e) => { handleSchool(e) }} /> */}
                            </FormItem>
                        </Col>
                        <Col md={6}>
                            <FormItem label="学制">
                                <Select
                                    style={{ width: 140 }}
                                    showSearch
                                    value={stageId}
                                    defaultActiveFirstOption={false}
                                    showArrow={false}
                                    filterOption={false}
                                    // onSearch={handleSearchSchool}
                                    onChange={handleStage}
                                    notFoundContent={null}
                                >
                                    {stageOptions}
                                </Select>
                                {/* <Input placeholder="请输入" allowClear={true} onChange={(e) => { handleSchool(e) }} /> */}
                            </FormItem>
                        </Col>
                        <Col md={8}>
                            <FormItem label="入学年份">
                                <Select
                                    style={{ width: 100 }}
                                    showSearch
                                    value={rxnfId}
                                    defaultActiveFirstOption={false}
                                    showArrow={false}
                                    filterOption={false}
                                    // onSearch={handleSearchSchool}
                                    onChange={handleRxnf}
                                    notFoundContent={null}
                                >
                                    {rxnfOptions}
                                </Select>
                                {/* <Input placeholder="请输入" allowClear={true} onChange={(e) => { handleSchool(e) }} /> */}
                            </FormItem>
                        </Col>
                    </Row>
                </Form>



                <Table
                    // rowSelection={{
                    //     selectedRowKeys: oneCheckid,
                    //     type: "radio",
                    //     ...rowSelection,
                    // }}
                    rowKey={(record: any) => record.class_id}
                    columns={columns}
                    // dataSource={thisLeaderList}
                    dataSource={classList}
                    onChange={pageOnChange}
                    pagination={{
                        current: page,
                        pageSize: limit,
                        total: total
                        // defaultCurrent: 1,
                        // defaultPageSize: 5,
                        // pageSize: 5,
                        // total: listPageNum,
                        // onChange: pageOnchange
                    }}
                />
            </div>
        </Modal>
    );
};


export default Form.create<CreateFormProps>()(SelectLeader);
