import {
  Cascader,
  Button,
  Card,
  Col,
  DatePicker,
  Divider,
  Dropdown,
  Form,
  Icon,
  Input,
  InputNumber,
  Menu,
  Row,
  Select,
  message,
  Popconfirm,
  Switch
} from 'antd';
import React, { Component, Fragment } from 'react';

import { Dispatch, Action } from 'redux';
import { FormComponentProps } from 'antd/es/form';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { SorterResult } from 'antd/es/table';
import { connect } from 'dva';
import moment from 'moment';
import { StateType } from './model';
import CreateForm from './components/CreateForm';
import ClassInfoPanel from './components/ClassInfoPanel';
import ImportInfoModal from './components/ImportInfoModal'
import TransferSchool from './components/TransferSchool'
import TemplateImportModal from './components/TemplateImportModal'
import StandardTable, { StandardTableColumnProps } from './components/StandardTable';
import UpdateForm, { FormValueType } from './components/UpdateForm';

import { TableListItem, TableListPagination, TableListParams } from './data.d';

import styles from './style.less';
import Link from 'umi/link';

const FormItem = Form.Item;
const { Option } = Select;
const getValue = (obj: { [x: string]: string[] }) =>
  Object.keys(obj)
    .map(key => obj[key])
    .join(',');

interface TableListProps extends FormComponentProps {
  dispatch: Dispatch<
    Action<
      | 'student/PageStudentInfo'
      | 'student/GetStudentInfo'
      | 'student/AddStudentInfo'
      | 'student/DeleteStudentInfo'
      | 'student/UpdateStudentInfo'
      | 'student/ReviseStudentClass'
      | 'student/EnableAccountInfo'
      | 'student/DisableAccountInfo'
      | 'student/ResetManagerPassWord'
      | 'student/GetStageInfo'
      | 'student/GetRxnfInfo'
      | 'student/PageClassInfo'
      | 'student/GetRoleInfo'
      | 'dict/GetMultipleDictInfo'
      | 'student/GetOrgTreeInfo'
      | 'student/DeleteAllInfo'
      | 'student/StudentTransferInfo'
    >
  >;
  loading: boolean;
  student: StateType;
}

interface TableListState {
  modalVisible: boolean;
  updateModalVisible: boolean;
  classInfoVisible: boolean; //班级面板是否显示
  importModalVisible: boolean; //导入面板是否显示
  templateImportModal: boolean; //导入面板是否显示
  importTipsShow: boolean,//导入面板错误提示是否显示
  expandForm: boolean;
  selectedRows: TableListItem[];
  formValues: { [key: string]: string };
  stepFormValues: Partial<TableListItem>;
  areaCode: string;
  page: any;
  pageSize: any;
  teacherInfo: { [key: string]: string }; //回显教师数据
  schoolId: string;
  identityId: string;
  xm: string;
  selectTreeNode: any;
  deptTreeAry: Array<any>,
  xbm: Array<string>;
  sfzjlxm: Array<string>;
  mzm: Array<string>;
  zzmmm: Array<string>;
  teacherId: string; //已选教师ID
  stageList: any; //学段数据
  rxnfList: Array<string>; //入学年份数据
  classList: Array<string>; //班级数据
  selectStageId: string;//当前已选学段
  selectRxnfId: string;//当前已选入学年份
  selectClassId: any;//当前已选班级ID
  data: { [key: string]: any }; //表格数据
  panelStageList: Array<string>; //班级面板学段数组
  panelStageId: string; //班级面板已选学段
  panelNfList: Array<string>; //班级面板年份数组
  panelNfId: string; //班级面板已选年份
  panelClassList: Array<string>;//班级面板班级数组
  panelPagination: { [key: string]: any };//班级面板分页数据
  panelSelectClassId: string;//班级面板中已选班级
  isShowDateXb: boolean; //是否显示新增修改面板性别和出生日期
  studentId: string; //当前修改的学生ID
  studentInfo: { [key: string]: any };//当前修改的学生信息
  tipsUrl: string; //导入错误修改地址
  tipsLoading: boolean; //上传文件加载样式
  orgList: [];
  role_id: "";    //权限id
  role_list: Array<string>;   //设置超级管理员id控制权限
  transferSchoolVisible: boolean;   //设置超级管理员id控制权限
  transferStudentId: string;   //设置超级管理员id控制权限
}

/* eslint react/no-multi-comp:0 */
@connect(
  ({
    student,
    loading,
  }: {
    student: StateType;
    loading: {
      models: {
        [key: string]: boolean;
      };
    };
  }) => ({
    student,
    loading: loading.models.student,
  }),
)
class TableList extends Component<TableListProps, TableListState> {
  state: TableListState = {
    modalVisible: false,
    templateImportModal: false,
    updateModalVisible: false,
    classInfoVisible: false, //班级面板是否显示
    importModalVisible: false, //导入面板是否显示
    importTipsShow: false,//导入面板错误提示是否显示
    expandForm: false,
    selectedRows: [],
    formValues: {},
    stepFormValues: {},
    areaCode: "220100",
    page: 1,
    pageSize: 10,
    teacherInfo: {},//修改教职工信息
    schoolId: this.props.match.params.id ? this.props.match.params.id : '',
    identityId: '',
    xm: "",
    selectTreeNode: "",
    deptTreeAry: [],
    xbm: [],
    sfzjlxm: [],
    mzm: [],
    zzmmm: [],
    teacherId: "",
    stageList: [], //学段数据
    rxnfList: [], //入学年份数据
    classList: [], //班级数据
    selectStageId: "",//当前已选学段
    selectRxnfId: "",//当前已选入学年份
    selectClassId: "",//当前已选班级ID
    data: {}, //表格数据
    panelStageList: [], //班级面板学段数组
    panelStageId: "", //班级面板已选学段
    panelNfList: [], //班级面板年份数组
    panelNfId: "", //班级面板已选年份
    panelClassList: [],//班级面板班级数组
    panelPagination: { //班级面板分页数据
      current: 1,
      pageSize: 10,
      total: 0
    },
    panelSelectClassId: "",//已选班级面板中班级
    isShowDateXb: false, //是否显示新增修改面板性别和出生日期
    studentId: "", //当前修改的学生ID
    studentInfo: {},//当前修改的学生信息
    tipsUrl: "", //导入错误修改地址
    tipsLoading: false, //上传文件加载样式
    orgList: [],
    role_id: "",
    role_list: ["A66C757C-F797-454D-99DE-2A3F5415BC22", "7A1A0620-0465-431B-A726-097D9C7F963B", "5CC3293C-3AA5-45B7-B54B-CA8CC549FB81", "BF61C95F-3ADD-4F37-9FCD-97E69E1BF6E3"],
    transferSchoolVisible: false,
    transferStudentId: ""
  };

  columns: StandardTableColumnProps[] = [
    {
      title: '序号',
      render: (text, record, index) =>
        `${(this.state.page - 1) * (this.state.pageSize) + (index + 1)}`,
    },
    {
      title: '学生姓名',
      dataIndex: 'xm',
    },
    {
      title: '性别',
      dataIndex: 'xb_name',
    },
    {
      title: '登录名',
      dataIndex: 'login_name',
    },
    {
      title: '初始密码',
      dataIndex: 'original_pwd',
    },
    {
      title: '账号状态',
      dataIndex: 'login_status',
      render: (text, record) => (
        <Switch checkedChildren={text} unCheckedChildren={text} checked={text == "已启用" ? true : false}
          onChange={(checked) => { this.onChangeSwitch(checked, record.person_id) }}
        />
      )
    },
    {
      title: '操作',
      width: 300,
      render: (text, record) => (
        <Fragment>
          <a type="link" onClick={() => { this.handleUpdateModalVisible(true, record.person_id) }}>编辑</a>
          <Divider type="vertical" />
          <Popconfirm
            title={'是否确认删除『' + record.xm + '』的信息？'}
            okText="确认"
            cancelText="取消"
            onConfirm={() => this.handleDelete(record.person_id)}
          >
            <a style={{ color: "red" }}>删除</a>
          </Popconfirm>
          <Divider type="vertical" />
          <Popconfirm
            title={'是否要重置『' + record.xm + '』的密码？'}
            okText="确认"
            cancelText="取消"
            onConfirm={() => this.resetStudentPassword(record.person_id)}
          >
            <a>重置密码</a>
          </Popconfirm>

          {this.role() ? <><Divider type="vertical" /><a type="link" onClick={() => { this.transferSchoolVisible(record.person_id, true) }}>调转学校</a></> : ""}
        </Fragment>
      ),
    },
  ];

  componentDidMount() {
    this.getRoleInfo();
  }

  // 权限控制当前角色是否在设置的数组(role_list)中。
  role() {
    const arr = this.state.role_list
    const role_id = this.state.role_id

    for (var i = 0; i < arr.length; i++) {
      if (arr[i].indexOf(role_id) > -1) {
        return true
      } else {
        return false
      }
    };
    return false;
  }




  //获取角色信息验证
  getRoleInfo() {
    const { dispatch } = this.props;

    dispatch({
      type: 'student/GetRoleInfo',
      payload: {},
      callback: (response: any) => {

        this.setState({ role_id: response.list[0].role_id });

        if (response.list[0].role_id == '73E897FC-C9D1-4E48-AE22-AC7586425C1D') {
          this.setState({ schoolId: response.list[0].rule_id, identityId: response.list[0].role_id }, () => {
            this.getStageList();
          })
        } else if (response.list[0].role_id) {
          this.getStageList();
        } else {
          message.error('当前角色权限错误，请联系管理员重新配置菜单');
        }

      },
    });

  }

  //获取字典信息
  getDictInfo() {
    const { dispatch } = this.props;

    //获取字典
    dispatch({
      type: 'dict/GetMultipleDictInfo',
      payload: {
        dictKinds: "xbm,sfzjlxm,mzm,zzmmm"
      },
      callback: (response: any) => {
        this.setState({
          xbm: response.list.xbm,
          sfzjlxm: response.list.sfzjlxm,
          mzm: response.list.mzm,
          zzmmm: response.list.zzmmm,
        })
      },
    });
  }

  //获取学段信息
  getStageList() {
    const { dispatch } = this.props;
    dispatch({
      type: 'student/GetOrgTreeInfo',
      payload: {
        orgId: this.state.schoolId,
      },
      callback: (data: any) => {
        this.setState({ orgList: data })
        console.log(this.state.orgList)
      }
    });
    dispatch({
      type: 'student/GetStageInfo',
      payload: {
        orgId: this.state.schoolId
      },
      callback: (response: any) => {
        console.log(response, '111111111111111')
        let stageid = -1;
        response.list.length != 0 ? stageid = response.list[0].stage_id : "";
        this.setState({ stageList: response.list, selectStageId: stageid }, () => {
          this.getDefaultRxnfList()
        })
      },
    });
  }
  //获取默认入学年份信息
  getDefaultRxnfList() {
    const { dispatch } = this.props;
    dispatch({
      type: 'student/GetRxnfInfo',
      payload: {
        orgId: this.state.schoolId,
        stageId: this.state.selectStageId
      },
      callback: (response: any) => {
        if (response.list.length > 0) {
          this.setState({ rxnfList: response.list, selectRxnfId: response.list[0] }, () => {
            this.getDefaultClassList()
          })
        } else {
          message.error('该学部下未创建班级，创建班级后可以维护学生信息');
          this.setState({ data: {} }, () => { this.getDictInfo(); })
        }
      },
    });
  }
  //获取默认班级信息
  getDefaultClassList() {
    const { dispatch } = this.props;
    dispatch({
      type: 'student/PageClassInfo',
      payload: {
        page: 1,
        limit: 999,
        orgId: this.state.schoolId,
        stageId: this.state.selectStageId,
        rxnf: this.state.selectRxnfId
      },
      callback: (response: any) => {
        if (response.list.length > 0) {
          this.setState({ classList: response.list, selectClassId: response.list[0].class_id }, () => {
            this.getStudentList(this.state.selectClassId, this.state.xm);
          })
        } else {
          this.getDictInfo()
        }

      },
    });
  }

  // 获取学生列表
  getStudentList(schoolId: string, xm?: string, pagination?: { [key: string]: string }) {
    const { dispatch } = this.props;
    if (!pagination) {
      pagination = {
        page: this.state.page,
        limit: this.state.pageSize,
      }
    }
    dispatch({
      type: 'student/PageStudentInfo',
      payload: {
        classId: schoolId,
        xm: xm,
        ...pagination,
      },
      callback: (response: any) => {
        if (response.success) {

          this.state.data.list = response.list;
          this.state.data.pagination = {
            current: this.state.page,
            pageSize: this.state.pageSize,
            total: response.count
          }
          console.log(this.state.data.pagination, "5555555");
          this.getDictInfo();
          //  this.forceUpdate();
        } else {
          message.error('获取失败' + response.message);
        }
      },
    });
  }

  //启用/禁用账号信息
  onChangeSwitch(checked: boolean, personId: string) {
    const { dispatch } = this.props;
    if (checked) {  //启用

      dispatch({
        type: 'student/EnableAccountInfo',
        payload: {
          personIds: personId
        },
        callback: (response: any) => {
          if (response.success) {
            message.success('操作成功');
            this.getStudentList(this.state.selectClassId, this.state.xm)
          } else {
            message.error('操作失败,' + response.message);
          }
        },
      });

    } else {  //禁用

      dispatch({
        type: 'student/DisableAccountInfo',
        payload: {
          personIds: personId
        },
        callback: (response: any) => {
          if (response.success) {
            message.success('操作成功');
            this.getStudentList(this.state.selectClassId, this.state.xm)
          } else {
            message.error('操作失败,' + response.message);
          }
        },
      });
    }
  }

  //批量删除学生信息
  batchDeleteStudentInfo = () => {
    if (this.state.selectedRows.length > 0) {
      let personIdAry: any = [];
      this.state.selectedRows.map((item) => {
        personIdAry.push(item.person_id)
      })
      let personIds = personIdAry.join(",")
      this.handleDelete(personIds)
    }
  }

  //删除学生信息
  handleDelete = (personId: string) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'student/DeleteStudentInfo',
      payload: {
        personIds: personId
      },
      callback: (response: any) => {
        if (response.success) {
          let pagination = {
            page: 1,
            limit: this.state.pageSize,
          }
          message.success('操作成功');
          this.setState({
            page: 1,
            pageSize: pagination.limit,
            selectedRows: []
          }, () => { this.getStudentList(this.state.selectClassId, this.state.xm, pagination) })
        } else {
          message.error('操作失败,' + response.message);
        }
      },
    });
  }

  //重置学生密码
  resetStudentPassword = (personId: string) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'student/ResetManagerPassWord',
      payload: {
        ids: personId
      },
      callback: (response: any) => {
        if (response.success) {
          message.success('操作成功');
          this.getStudentList(this.state.selectClassId, this.state.xm)
        } else {
          message.error('操作失败,' + response.message);
        }
      },
    });
  }
  //分页操作
  handleStandardTableChange = (
    pagination: Partial<TableListPagination>,
    filtersArg: Record<keyof TableListItem, string[]>,
    sorter: SorterResult<TableListItem>,
  ) => {
    const page = pagination.current;
    const pageSize = pagination.pageSize;

    pagination = {
      page: page,
      limit: pageSize
    }

    this.setState({
      page: page,
      pageSize: pageSize
    }, () => { this.getStudentList(this.state.selectClassId, this.state.xm, pagination) })
  };

  handleFormReset = () => {
    const { form, dispatch } = this.props;
    form.resetFields();
    this.setState({
      formValues: {},
    });
    dispatch({
      type: 'school/fetch',
      payload: {},
    });
  };

  toggleForm = () => {
    const { expandForm } = this.state;
    this.setState({
      expandForm: !expandForm,
    });
  };



  handleSelectRows = (rows: TableListItem[]) => {
    this.setState({
      selectedRows: rows,
    });
  };

  //查询
  handleSearch = (e: React.FormEvent) => {
    e.preventDefault();

    const { form } = this.props;

    form.validateFields((err, fieldsValue) => {
      if (err) return;

      let pagination = {
        page: 1,
        limit: this.state.pageSize,
      }
      if (this.state.selectClassId === "") {
        message.error('该学部下暂无学生信息');
      } else {
        this.getStudentList(this.state.selectClassId, fieldsValue.studentName, pagination)
      }


      this.setState({
        page: 1,
        pageSize: pagination.limit,
        selectedRows: [],
        xm: fieldsValue.studentName
      })
    });
  };

  //新增学生信息面板弹出
  handleModalVisible = (flag?: boolean) => {
    this.setState({
      modalVisible: flag ? true : false,
      isShowDateXb: false
    });
  };

  //修改学生信息面板弹出
  handleUpdateModalVisible = (flag?: boolean, personId?: string) => {
    const { dispatch } = this.props;
    if (personId) {
      dispatch({
        type: 'student/GetStudentInfo',
        payload: {
          personId: personId
        },
        callback: (response: any) => {
          if (response.success) {
            this.setState({
              updateModalVisible: flag ? true : false,
              studentId: personId ? personId : "",
              studentInfo: response.list[0],
              isShowDateXb: response.list[0].sfzjlxm == 1 ? false : true
            });
          } else {
            message.error('操作失败,' + response.message);
          }
        },
      });
    } else {
      this.setState({
        updateModalVisible: flag ? true : false,
        isShowDateXb: false
      });
    }
  };



  //班级面板关闭
  handleClassInfoVisible = () => {
    this.setState({ classInfoVisible: false })
  }
  //班级面板弹出
  showClassInfoPanel = () => {
    // this.setState({
    //   panelStageList:this.state.stageList,
    //   panelStageId:this.state.stageList[0].stage_id,
    // },()=>{this.getPanelNfInfo()})
    const { dispatch } = this.props;
    dispatch({
      type: 'student/PageClassInfo',
      payload: {
        page: 1,
        limit: 10,
        orgId: this.state.schoolId,
        stageId: this.state.selectStageId,
        rxnf: this.state.selectRxnfId,
        removeClassId: this.state.selectClassId
      },
      callback: (response: any) => {
        if (response.list.length === 0) {
          message.error('暂无其他班级信息，无法调整');
        } else {
          this.setState({
            panelClassList: response.list, panelPagination: {
              current: 1,
              pageSize: 10,
              total: response.count
            }, classInfoVisible: true, panelSelectClassId: ""
          })
        }

      },
    });
  }
  //获取班级面板年份数据和默认
  getPanelNfInfo = () => {
    const { dispatch } = this.props;
    dispatch({
      type: 'student/GetRxnfInfo',
      payload: {
        orgId: this.state.schoolId,
        stageId: this.state.panelStageId,
      },
      callback: (response: any) => {
        if (response.success) {
          if (response.list.length > 0) {
            this.setState({ panelNfList: response.list, panelNfId: response.list[0] }, () => {
              this.getPanelClassInfo()
            })
          } else {
            this.setState({
              panelNfList: [], panelNfId: "", panelClassList: [], classInfoVisible: true, panelPagination: {
                current: 1,
                pageSize: 10,
                total: 0
              }, panelSelectClassId: ""
            })
          }

        } else {
          message.error('获取失败,' + response.message);
        }
      },
    });
  }
  //获取班级面板班级数据
  getPanelClassInfo = () => {
    const { dispatch } = this.props;
    dispatch({
      type: 'student/PageClassInfo',
      payload: {
        page: 1,
        limit: 10,
        orgId: this.state.schoolId,
        stageId: this.state.panelStageId,
        rxnf: this.state.panelNfId
      },
      callback: (response: any) => {
        this.setState({
          panelClassList: response.list, panelPagination: {
            current: 1,
            pageSize: 10,
            total: response.count
          }, classInfoVisible: true, panelSelectClassId: ""
        })
      },
    });
  }

  //显示隐藏新增修改弹出面板中性别和出生日期
  handleXbDateShow = (value: boolean) => {
    this.setState({ isShowDateXb: value })
  }

  studentTransferInfo = (personId: string, classId: string) => {

    console.log(this.state.transferStudentId, classId, 'studentTransferInfo')
    const { dispatch } = this.props;
    dispatch({
      type: 'student/StudentTransferInfo',
      payload: {
        personId: this.state.transferStudentId,
        classId: classId
      },
      callback: (response: any) => {
        console.log(response, 'response transfer')
        if (response.success) {
          let pagination = {
            page: this.state.page,
            limit: this.state.pageSize,
          }
          message.success('操作成功');
          this.transferSchoolVisible("", false)
          this.getStudentList(this.state.selectClassId, this.state.xm, pagination)
        } else {
          message.error('操作失败,' + response.message);
        }
      },
    });

  }


  //增加教职工保存
  handleAdd = (fields: { [key: string]: string }) => {
    const { dispatch } = this.props;
    let params = {
      classId: this.state.selectClassId,
      xm: fields.student_name,
      xbm: fields.student_xb ? fields.student_xb : "",
      mzm: fields.student_mz,
      zzmmm: fields.student_zzmm,
      sfzjlxm: fields.student_sfzjlx,
      sfzjh: fields.student_zjh,
      dszybz: fields.student_sfdszn,
      sqznbz: fields.student_sfsqzn,
      jcwgrysqznbz: fields.student_sfjcwgsqzn,
      lsetbz: fields.student_sflset,
      cjbz: fields.student_sfcj,
      gebz: fields.student_gebz,
      csrq: fields.student_date ? fields.student_date.format('YYYY-MM-DD') : "",//出生日期
    }


    dispatch({
      type: 'student/AddStudentInfo',
      payload: params,
      callback: (response: any) => {
        if (response.success) {
          let pagination = {
            page: 1,
            limit: this.state.pageSize,
          }
          message.success('操作成功');
          this.setState({
            page: 1,
            pageSize: pagination.limit,
            selectedRows: [],
            modalVisible: false,
          }, () => { this.getStudentList(this.state.selectClassId, this.state.xm, pagination) })
        } else {
          message.error('操作失败,' + response.message);
        }
      },
    });
  }

  //修改学生确定回调
  handleUpdate = (fields: { [key: string]: string }) => {
    const { dispatch } = this.props;
    let params = {
      personId: this.state.studentId,
      xm: fields.student_name,
      xbm: fields.student_xb ? fields.student_xb : "",
      mzm: fields.student_mz,
      zzmmm: fields.student_zzmm,
      sfzjlxm: fields.student_sfzjlx,
      sfzjh: fields.student_zjh,
      dszybz: fields.student_sfdszn,
      sqznbz: fields.student_sfsqzn,
      jcwgrysqznbz: fields.student_sfjcwgsqzn,
      lsetbz: fields.student_sflset,
      cjbz: fields.student_sfcj,
      gebz: fields.student_gebz,
      csrq: fields.student_date ? fields.student_date.format('YYYY-MM-DD') : "",//出生日期
    }

    dispatch({
      type: 'student/UpdateStudentInfo',
      payload: params,
      callback: (response: any) => {
        if (response.success) {
          message.success('操作成功');
          this.setState({
            updateModalVisible: false,
          }, () => { this.getStudentList(this.state.selectClassId, this.state.xm) })
        } else {
          message.error('操作失败,' + response.message);
        }
      },
    });
  };

  //根据学段获取入学年份
  rxnfInfoHandle(stageId: any) {
    const { dispatch } = this.props;
    dispatch({
      type: 'student/GetRxnfInfo',
      payload: {
        orgId: this.state.schoolId,
        stageId: stageId
      },
      callback: (response: any) => {
        if (response.success) {
          if (response.list.length > 0) {
            const { form } = this.props;
            form.setFieldsValue({ rxnf: "" });
            this.setState({ rxnfList: response.list, selectStageId: stageId, selectRxnfId: response.list[0] }, () => {
              form.setFieldsValue({ rxnf: this.state.selectRxnfId });
              this.getClassInfoHandle(this.state.selectRxnfId)
            })
          } else {
            message.error('该学部下暂无学生信息');
            const { form } = this.props;
            form.resetFields(['class']);
            this.setState({ rxnfList: response.list, selectStageId: stageId, selectRxnfId: "", selectClassId: "", classList: [], data: {} })
          }

        } else {
          message.error('获取失败,' + response.message);
        }
      },
    });
  }

  //根据学段和入学年份获取班级信息
  getClassInfoHandle(rxnfId: any) {
    const { dispatch } = this.props;
    dispatch({
      type: 'student/PageClassInfo',
      payload: {
        page: 1,
        limit: 999,
        orgId: this.state.schoolId,
        stageId: this.state.selectStageId,
        rxnf: rxnfId
      },
      callback: (response: any) => {
        if (response.success) {
          const { form } = this.props;
          form.setFieldsValue({ class: "" });
          if (response.list.length > 0) {
            this.setState({ classList: response.list, selectRxnfId: rxnfId, selectClassId: response.list[0].class_id }, () => {
              form.setFieldsValue({ class: this.state.selectClassId });
              this.getStudentList(this.state.selectClassId, this.state.xm)
            })
          } else {
            this.setState({ classList: response.list, selectClassId: '', data: {} })
          }


        } else {
          message.error('获取失败,' + response.message);
        }
      },
    });
  }

  //调整班级确定回调
  handleClassAdd = () => {
    if (this.state.panelSelectClassId === "") {
      message.error('请选择班级');
    } else {
      const { dispatch } = this.props;
      let personIdAry: any = [];
      this.state.selectedRows.map((item) => {
        personIdAry.push(item.person_id)
      })
      let personIds = personIdAry.join(",")
      dispatch({
        type: 'student/ReviseStudentClass',
        payload: {
          classId: this.state.panelSelectClassId,
          personIds: personIds
        },
        callback: (response: any) => {
          if (response.success) {
            message.success('操作成功');
            this.setState({ classInfoVisible: false, selectedRows: [] }, () => { this.getStudentList(this.state.selectClassId, this.state.xm) })
          } else {
            message.error('操作失败,' + response.message);
          }
        },
      });
    }
  }

  //选择班级面板回调
  onChangePanelClass = (selectedRowKeys: string) => {
    this.setState({ panelSelectClassId: selectedRowKeys })
  }

  //选择班级面板学段回调
  handlePanelStageInfo = (value: string) => {
    this.setState({ panelStageId: value }, () => { this.getPanelNfInfo() })
  }

  //选择班级面板入学年份回调
  handlePanelRxnfInfo = (value: string) => {
    this.setState({ panelNfId: value }, () => { this.getPanelClassInfo() })
  }

  //班级面板分页回调
  handlePanelTableChange = (pagination: { [key: string]: any }) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'student/PageClassInfo',
      payload: {
        page: pagination.current,
        limit: pagination.pageSize,
        orgId: this.state.schoolId,
        stageId: this.state.selectStageId,
        rxnf: this.state.selectRxnfId,
        removeClassId: this.state.selectClassId
      },
      callback: (response: any) => {
        this.setState({
          panelClassList: response.list, panelPagination: {
            current: pagination.current,
            pageSize: pagination.pageSize,
            total: response.count
          }
        })
      },
    });
  }

  //导入学生信息面板显示隐藏
  importTeacherInfo = (flag?: boolean) => {
    this.setState({
      importModalVisible: flag ? true : false,
      importTipsShow: false,
      templateImportModal: false,
      tipsLoading: false,
    });
  }


  //显示导入面板错误提示
  handleImportTipsShow = (message: string) => {
    this.setState({ importTipsShow: true, tipsUrl: message, tipsLoading: false })
  }

  //导入成功回调
  handleSuccessImport = (messages: any) => {
    this.setState({
      importModalVisible: false,
      templateImportModal: false,
      importTipsShow: false,
      tipsLoading: false
    }, () => {
      message.success(`导入成功! ${messages}`, 5);
      let pagination = {
        page: 1,
        limit: this.state.pageSize,
      }
      this.state.page = 1;
      this.state.pageSize = pagination.limit;
      this.getStudentList(this.state.selectClassId, this.state.xm, pagination);
    });
  }

  //导入中显示等待样式
  handleTipsLoading = () => {
    this.setState({ tipsLoading: true, importTipsShow: false })
  }

  // //导出本校学生信息
  // exportSchoolStudentInfo = () => {
  //   let downUrl = window.location.origin + '/base/student/ExportStudentExcel?orgId=' + this.state.schoolId + '&classId=';
  //   window.open(downUrl, '_self')
  // }

  // //导出当前班级学生账号信息
  // exportClassStudentWordInfo = () => {
  //   let downUrl = window.location.origin + '/base/student/ExportStudentExcel?orgId=' + this.state.schoolId + '&classId=' + this.state.selectClassId;
  //   window.open(downUrl, '_self')
  // }

  // //导出本校学生账号信息
  // exportSchoolUserInfo = () => {
  //   let downUrl = window.location.origin + '/base/student/ExportStudentAccountExcel?orgId=' + this.state.schoolId + '&classId=';
  //   window.open(downUrl, '_self')
  // }

  // //导出当前班级学生账号信息
  // exportClassUserInfo = () => {
  //   let downUrl = window.location.origin + '/base/student/ExportStudentAccountExcel?orgId=' + this.state.schoolId + '&classId=' + this.state.selectClassId;
  //   window.open(downUrl, '_self')
  // }

  renderSimpleForm() {
    const { form } = this.props;
    const { getFieldDecorator } = form;
    console.log(this.state.stageid?.length, "stageList")
    return (
      <Form onSubmit={this.handleSearch} layout="inline">
        <Row gutter={{ md: 8, lg: 24, xl: 48 }}>


          {this.state.stageid ? <Col md={4} sm={6}>
            <FormItem label="学部">
              {getFieldDecorator('stage', { initialValue: this.state.selectStageId })(
                <Select
                  style={{ width: '100%' }}
                  onChange={(value) => { this.rxnfInfoHandle(value) }}
                >
                  {this.state.stageList.map((item: any) => (
                    <Select.Option value={item.stage_id} key={item.stage_id} >{item.stage_name}</Select.Option>
                  ))}
                </Select>
              )}
            </FormItem>
          </Col> : ""}


          <Col md={4} sm={6}>
            <FormItem label="入学年份">
              {getFieldDecorator('rxnf', { initialValue: this.state.selectRxnfId })(
                <Select
                  style={{ width: '100%' }}
                  onChange={(value: any) => { this.getClassInfoHandle(value) }}
                >
                  {this.state.rxnfList.map(item => (
                    <Select.Option value={item} key={item} >{item}</Select.Option>
                  ))}
                </Select>
              )}
            </FormItem>
          </Col>
          <Col md={4} sm={6}>
            <FormItem label="班级">
              {getFieldDecorator('class', { initialValue: this.state.selectClassId })(
                <Select
                  style={{ width: '100%' }}
                  showSearch={true}
                  onChange={(value: any) => { this.state.selectClassId = value; this.getStudentList(this.state.selectClassId, this.state.xm) }}
                >
                  {this.state.classList.map(item => (
                    <Select.Option value={item.class_id} key={item.class_id} >{item.class_name}</Select.Option>
                  ))}
                </Select>)}
            </FormItem>
          </Col>
          <Col md={6} sm={6}>
            <FormItem label="学生姓名">
              {getFieldDecorator('studentName')(
                <Input placeholder="请输入学生姓名" allowClear={true} maxLength={20}
                  onChange={(e) => { this.state.xm = e.target.value }}
                />,
              )}
            </FormItem>
          </Col>
          <Col md={4} sm={6}>
            <span className={styles.submitButtons}>
              <Button type="primary" htmlType="submit">
                查询
              </Button>
            </span>
          </Col>
        </Row>

      </Form>
    );
  }

  orgNemaBox() {
    return < Row >
      <Col sm={24} style={{ fontSize: "16px", marginBottom: "20px" }}>
        {/* <Icon type="environment" theme="filled" style={{ color: "#1890ff", marginRight: "20px" }} /> */}
        <Icon type="environment" style={{ color: "#1890ff", marginRight: "20px" }} />
        {this.state.orgList.length > 0 ? this.state.orgList.map((item: any) => {
          return item.org_name
        }) : ""}
      </Col>
    </Row >
  }
  // 所有导出
  handleMenuClick = (value: any) => {
    if (value.key === "exportSchoolStudentInfo") {
      let downUrl = window.location.origin + '/base/student/ExportStudentExcel?orgId=' + this.state.schoolId + '&classId=';
      window.open(downUrl, '_self')
    } else if (value.key === "exportClassStudentWordInfo") {
      let downUrl = window.location.origin + '/base/student/ExportStudentExcel?orgId=' + this.state.schoolId + '&classId=' + this.state.selectClassId;
      window.open(downUrl, '_self')
    } else if (value.key === "exportSchoolUserInfo") {
      let downUrl = window.location.origin + '/base/student/ExportStudentAccountExcel?orgId=' + this.state.schoolId + '&classId=';
      window.open(downUrl, '_self')
    } else if (value.key === "exportClassUserInfo") {
      let downUrl = window.location.origin + '/base/student/ExportStudentAccountExcel?orgId=' + this.state.schoolId + '&classId=' + this.state.selectClassId;
      window.open(downUrl, '_self')
    }
    console.log(value)
  }



  transferSchoolVisible = (transferStudentId: string, flag?: boolean) => {
    console.log(transferStudentId, 'flag')

    this.setState({
      transferSchoolVisible: flag ? true : false,
      transferStudentId: transferStudentId
    })

  }






  render() {
    const {
      // student: { data },
      loading,
    } = this.props;

    const { selectedRows, modalVisible, updateModalVisible, stepFormValues, data, classInfoVisible, importModalVisible, templateImportModal } = this.state;
    const menu = (
      <Menu onClick={this.handleMenuClick} selectedKeys={[]}>
        <Menu.Item key="exportSchoolStudentInfo">导出本校学生信息</Menu.Item>
        <Menu.Item key="exportClassStudentWordInfo">导出当前班级学生信息</Menu.Item>
        <Menu.Item key="exportSchoolUserInfo">导出本校学生账号信息</Menu.Item>
        <Menu.Item key="exportClassUserInfo">导出当前班级学生账号信息</Menu.Item>
      </Menu>
    );

    const parentMethods = {
      handleAdd: this.handleAdd,
      handleModalVisible: this.handleModalVisible,
      handleXbDateShow: this.handleXbDateShow,
      xbm: this.state.xbm,
      sfzjlxm: this.state.sfzjlxm,
      mzm: this.state.mzm,
      zzmmm: this.state.zzmmm,
      isShowDateXb: this.state.isShowDateXb,
    };
    const updateMethods = {
      handleUpdateModalVisible: this.handleUpdateModalVisible,
      handleUpdate: this.handleUpdate,
      handleXbDateShow: this.handleXbDateShow,
      xbm: this.state.xbm,
      sfzjlxm: this.state.sfzjlxm,
      mzm: this.state.mzm,
      zzmmm: this.state.zzmmm,
      isShowDateXb: this.state.isShowDateXb,
      studentInfo: this.state.studentInfo,
    };
    //班级面板参数
    const classInfoMethods = {
      handleClassInfoVisible: this.handleClassInfoVisible,
      handleClassAdd: this.handleClassAdd,
      handlePanelTableChange: this.handlePanelTableChange,
      onChangePanelClass: this.onChangePanelClass,
      handlePanelStageInfo: this.handlePanelStageInfo,
      handlePanelRxnfInfo: this.handlePanelRxnfInfo,
      panelStageList: this.state.panelStageList,
      panelStageId: this.state.panelStageId,
      panelNfList: this.state.panelNfList,
      panelNfId: this.state.panelNfId,
      panelClassList: this.state.panelClassList,
      panelPagination: this.state.panelPagination,
      panelSelectClassId: this.state.panelSelectClassId,
    };

    //导出面板参数
    const importInfoMethods = {
      handleImportTeacherInfo: this.importTeacherInfo,
      handleImportTipsShow: this.handleImportTipsShow,
      handleSuccessImport: this.handleSuccessImport,
      handleTipsLoading: this.handleTipsLoading,
      orgId: this.state.schoolId,
      importTipsShow: this.state.importTipsShow,
      tipsUrl: this.state.tipsUrl,
      tipsLoading: this.state.tipsLoading,
    }

    data.pagination = {
      current: this.state.page,
      total: this.state.data.pagination ? this.state.data.pagination.total : 0,
      pageSize: this.state.pageSize,
      showTotal: ((total: any) => {
        return `共 ${total} 条`;
      }),
    }

    const TransferSchoolProps = {
      areaCode: this.state.areaCode,
      transferSchoolVisible: this.transferSchoolVisible,
      studentTransferInfo: this.studentTransferInfo,
      transferStudentId: this.state.transferStudentId
    }



    // console.log(this.test11(this.state.role_id), this.state.role_id, this.state.role_list, 'role')

    console.log(this.state, 'this.state')

    return (
      <PageHeaderWrapper>
        <Card bordered={false}>
          <div className={styles.tableList}>
            <div>{this.orgNemaBox()}</div>
            <div className={styles.tableListForm}>{this.renderSimpleForm()}</div>
            <div className={styles.tableListOperator}>
              {this.state.selectClassId === "" ? null : <Button icon="plus" type="primary" onClick={() => this.handleModalVisible(true)}>
                增加学生
              </Button>}
              {selectedRows.length > 0 && (
                <span>
                  <Popconfirm
                    title={'是否确认删除所选中的学生信息？'}
                    okText="确认"
                    cancelText="取消"
                    onConfirm={() => this.batchDeleteStudentInfo()}
                  >
                    <Button type="danger">批量删除</Button>
                  </Popconfirm>

                  <Button onClick={() => { this.showClassInfoPanel() }}>调整班级</Button>
                </span>
              )}
              {data.list ?
                [
                  <Button type="primary" onClick={() => this.importTeacherInfo(true)} style={{ marginLeft: "2%" }} >
                    导入学生信息
                  </Button>,
                  this.state.selectClassId === "B1413D43-35D0-486F-81D3-6ABF6BA4FB23" ?
                    [<Button type="primary" onClick={() => { this.setState({ templateImportModal: true }) }}>
                      国家学籍系统模板导入
                  </Button>,
                    <Button type="danger" onClick={() => {
                      const { dispatch } = this.props;
                      dispatch({
                        type: 'student/DeleteAllInfo',
                        callback: (response: any) => {
                          if (response.success) {
                            message.success('操作成功');
                            this.getStudentList(this.state.selectClassId, this.state.xm)
                          } else {
                            message.error('操作失败,' + response.message);
                          }
                        },
                      })
                    }}>
                      清空当前所有数据
                  </Button>] : "",
                  <span>
                    {/* <Button>批量操作</Button> */}
                    <Dropdown overlay={menu}>
                      <Button>
                        导出信息 <Icon type="down" />
                      </Button>
                    </Dropdown>
                  </span>,
                  //   <Button type="primary" onClick={() => this.exportSchoolStudentInfo()}

                  //   >
                  //     导出本校学生信息
                  // </Button>,
                  //   <Button type="primary" onClick={() => this.exportClassStudentWordInfo()}

                  //   >
                  //     导出当前班级学生信息
                  //  </Button>,
                  //   <Button type="primary" onClick={() => this.exportSchoolUserInfo()}

                  //   >
                  //     导出本校学生账号信息
                  // </Button>,
                  //   <Button type="primary" onClick={() => this.exportClassUserInfo()}

                  //   >
                  //     导出当前班级学生账号信息
                  //   </Button>
                ]
                : null}
              {this.state.identityId === "9CD6B804-0F89-4626-A812-29465CFC7410" || this.state.identityId === "73E897FC-C9D1-4E48-AE22-AC7586425C1D" ? "" :
                <Button style={{ float: "right", bottom: this.state.selectClassId === '' ? '1.5rem' : '0' }} type="primary" onClick={() => { window.history.back() }}>
                  返回
                </Button>
              }
            </div>
            <StandardTable
              rowKey={record => record.person_id}
              selectedRows={selectedRows}
              loading={loading}
              data={data}
              columns={this.columns}
              onSelectRow={this.handleSelectRows}
              onChange={this.handleStandardTableChange}
            />
          </div>
        </Card>
        <CreateForm {...parentMethods} modalVisible={modalVisible} />
        <UpdateForm {...updateMethods} modalVisible={updateModalVisible} />
        <ClassInfoPanel {...classInfoMethods} modalVisible={classInfoVisible} />
        <ImportInfoModal {...importInfoMethods} modalVisible={importModalVisible} />
        <TemplateImportModal {...importInfoMethods} modalVisible={templateImportModal} />
        <TransferSchool {...TransferSchoolProps} modalVisible={this.state.transferSchoolVisible} dispatchProps={this.props} />
      </PageHeaderWrapper>
    );
  }
}

export default Form.create<TableListProps>()(TableList);
