import { AnyAction, Reducer } from 'redux';
import { EffectsCommandMap } from 'dva';
import {
  PageStudentInfo, GetStudentInfo, AddStudentInfo, DeleteStudentInfo, UpdateStudentInfo, ReviseStudentClass, EnableAccountInfo,
  DisableAccountInfo, ResetManagerPassWord, GetStageInfo, GetRxnfInfo, PageClassInfo, GetRoleInfo, GetOrgTreeInfo, DeleteAllInfo,ListOrgByOrgKeyWord,StudentTransferInfo
} from './service';

// eslint-disable-next-line import/no-unresolved
import { TableListData } from './data.d';

export interface StateType {
  data: TableListData;
}

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: StateType) => T) => T },
) => void;

export interface ModelType {
  namespace: string;
  state: StateType;
  effects: {
    PageStudentInfo: Effect;
    GetStudentInfo: Effect;
    AddStudentInfo: Effect;
    DeleteAllInfo: Effect;
    DeleteStudentInfo: Effect;
    UpdateStudentInfo: Effect;
    ReviseStudentClass: Effect;
    EnableAccountInfo: Effect;
    DisableAccountInfo: Effect;
    ResetManagerPassWord: Effect;
    GetStageInfo: Effect;
    GetRxnfInfo: Effect;
    PageClassInfo: Effect;
    GetRoleInfo: Effect;
    GetOrgTreeInfo: Effect;
    ListOrgByOrgKeyWord: Effect;
    StudentTransferInfo: Effect;
  };
  reducers: {
    save: Reducer<StateType>;
  };
}

const Model: ModelType = {
  namespace: 'student',

  state: {
    data: {
      list: [],
      pagination: {},
    },
  },

  effects: {
    //获取学生列表
    *PageStudentInfo({ payload, callback }, { call, put }) {
      let response = yield call(PageStudentInfo, payload);

      // 处理最后一页删除数据后当前页面没有数据从新计算页数从新拿数据。
      let listLength = response.list.length
      while (listLength < 1) {
        payload.page = payload.page == 1 ? 1 : payload.page - 1;
        response = yield call(PageStudentInfo, payload);
        listLength = response.list.length
        if (response.count == 0) break;
      }
      if (callback) callback(response);
      // yield put({
      //   type: 'save',
      //   payload: response,
      // });
    },
    //获取学生信息
    *GetStudentInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetStudentInfo, payload);
      if (callback) callback(response);
    },
    //新增学生信息
    *AddStudentInfo({ payload, callback }, { call, put }) {
      const response = yield call(AddStudentInfo, payload);
      if (callback) callback(response);
    },
    //删除学生信息
    *DeleteStudentInfo({ payload, callback }, { call, put }) {
      const response = yield call(DeleteStudentInfo, payload);
      if (callback) callback(response);
    },
    //清空所有数据
    *DeleteAllInfo({ payload, callback }, { call, put }) {
      const response = yield call(DeleteAllInfo, payload);
      if (callback) callback(response);
    },
    //修改学生信息
    *UpdateStudentInfo({ payload, callback }, { call, put }) {
      const response = yield call(UpdateStudentInfo, payload);
      if (callback) callback(response);
    },
    //学生调整班级
    *ReviseStudentClass({ payload, callback }, { call, put }) {
      const response = yield call(ReviseStudentClass, payload);
      if (callback) callback(response);
    },
    //启用账号信息
    *EnableAccountInfo({ payload, callback }, { call, put }) {
      const response = yield call(EnableAccountInfo, payload);
      if (callback) callback(response);
    },

    //禁用账号信息
    *DisableAccountInfo({ payload, callback }, { call, put }) {
      const response = yield call(DisableAccountInfo, payload);
      if (callback) callback(response);
    },

    //重置账号密码
    *ResetManagerPassWord({ payload, callback }, { call, put }) {
      const response = yield call(ResetManagerPassWord, payload);
      if (callback) callback(response);
    },
    //获取学段信息
    *GetStageInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetStageInfo, payload);
      if (callback) callback(response);
    },
    //根据学校ID和学部(学段)ID获取入学年份
    *GetRxnfInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetRxnfInfo, payload);
      if (callback) callback(response);
    },
    //获取班级信息
    *PageClassInfo({ payload, callback }, { call, put }) {
      const response = yield call(PageClassInfo, payload);
      if (callback) callback(response);
    },
    //获取角色信息
    *GetRoleInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetRoleInfo, payload);
      if (callback) callback(response);
    },
    // 获取部门列表
    *GetOrgTreeInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetOrgTreeInfo, payload);
      if (callback) callback(response.list);
    },
    // 获取部门列表
    *ListOrgByOrgKeyWord({ payload, callback }, { call, put }) {
      const response = yield call(ListOrgByOrgKeyWord, payload);
      if (callback) callback(response.list);
    },
    // 调转学校
    *StudentTransferInfo({ payload, callback }, { call, put }) {
      const response = yield call(StudentTransferInfo, payload);
      if (callback) callback(response);
    },
  },

  reducers: {
    save(state, action) {
      return {
        ...state,
        data: action.payload,
      };
    },
  },
};

export default Model;
