import { Form, Popconfirm, Modal, message, Button, Divider, Table } from 'antd';
import { FormComponentProps } from 'antd/es/form';
import React, { useState, useEffect } from 'react';
import TransferDepartment from './TransferDepartment';


const FormItem = Form.Item;

interface CreateFormProps extends FormComponentProps {
    leaderIdaa: [];
    modalVisible: boolean; // 显示modal
    cancelModal: () => void; // 返回上一层
    dispatchProps: any;
    checkLeader: (fieldsValue: { desc: any }) => void;
    teacherMBId: string
    handleTeacherMBVisible: (personId: string, flag?: boolean) => void;
}

const SelectLeader: React.FC<CreateFormProps> = props => {
    const { modalVisible, teacherMBId, dispatchProps, handleTeacherMBVisible } = props;
    const [transferDepartmentVisible, setTransferDepartmentVisible] = useState(false)   //选择单位弹窗
    const [teacherMBIdList, setTeacherMBIdList] = useState([])  //当前教师ID
    const [rand, setRand] = useState(Math.random())  //当前教师ID
    

    const columns = [
        {
            title: '序号',
            dataIndex: 'id',
            render: (text, record, index) =>
                `${(index + 1)}`
        },
        {
            title: '姓名',
            dataIndex: 'xm',
        },
        {
            title: '单位名称',
            dataIndex: 'bureau_name',
        },
        {
            title: '部门名称',
            dataIndex: 'org_name',
        },
        {
            title: '主单位',
            dataIndex: 'is_main',
            render: (text: any, record) => (
            <div>{record.is_main==1 ? "是" : "否"}</div>
            )
        },
        {
            title: '操作',
            dataIndex: 'conf',
            render: (text: any, record: { class_alias: string; class_id: string; }) => (
                <>     
                {record.is_main!=1?<Popconfirm title={'是否将『' + record.org_name + '』为主单位？'} okText="确认" cancelText="取消" onConfirm={() => settingMainOrg(record.id,teacherMBId)} >
                <a>设置为主单位</a>
                </Popconfirm>:<a style={{pointerEvents:'none',cursor:'default',color:"#d9d9d9"}}>设置为主单位</a>}
                    <Divider type="vertical" />
                    {record.is_main!=1?<Popconfirm
                        title={'是否删除『' + record.class_alias + '』单位？'}
                        okText="确认"
                        cancelText="取消"
                        onConfirm={() => deleteTeacherMultipleBureauInfo(record.id)}
                    >
                        <a>删除</a>
                    </Popconfirm>:<a style={{pointerEvents:'none',cursor:'default',color:"#d9d9d9"}}>删除</a>}

                    
                </>
            )
        },
    ];
    // console.log('leaderId111111111:', leaderId, 'oneCheckid:', oneCheckid, "oneCheck1112:", oneCheck);




    useEffect(() => {
        resetState()
        if (teacherMBId) {
            getTeachermultipleBureauList(teacherMBId)
        }

    }, [teacherMBId])

    const resetState = () =>{
        setTransferDepartmentVisible(false)
        setTeacherMBIdList([])
    }



    // 获取所在的所有单位
    const getTeachermultipleBureauList = (personId: string) => {
        const { dispatch } = dispatchProps;
        dispatch({
            type: 'teacher/PageTeacherMultipleBureauInfo',
            payload: {
                personId: personId
            },
            callback: (response: any) => {
                console.log(response, 'response teacher')
                setTeacherMBIdList(response.list)
            }
        });
    }

    // 点击取消关闭当前窗口
    const handleCancel = () => {
        handleTeacherMBVisible("", false)
    }

    //打开/关闭、选择部门窗口
    const handleTransferDepartmentVisible = (transferPersonId: string, flag: boolean) => {
        
        setTransferDepartmentVisible(flag)
        // setTransferDepartmentVisible(transferPersonId)
        setRand(Math.random())
    }

    // 设置多单位
    const transferDepartment = (orgId: string) => {

        const { dispatch } = dispatchProps;
        dispatch({
            type: 'teacher/SettingTeacherMultipleBureauInfo',
            payload: {
                orgId: orgId,
                personId: teacherMBId
            },
            callback: (response: any) => {
                console.log(response, 'response transfer')
                if (response.success) {
                    getTeachermultipleBureauList(teacherMBId)
                    setTransferDepartmentVisible(false)
                    message.success('操作成功');
                } else {
                    message.error('操作失败,' + response.message);
                }
            },
        });

    }



    // 单位选择参数 
    const TransferDepartmentProps = {
        handleTransferDepartmentVisible: handleTransferDepartmentVisible, 
        transferDepartment: transferDepartment,
        transferPersonId: teacherMBId,
        rand:rand
    }

    // 设为主校
    const settingMainOrg = (id:string,personId:string) => {
        const { dispatch } = dispatchProps;
        dispatch({
            type: 'teacher/SettingMainOrgInfo',
            payload: {
                id: id,
                personId: personId
            },
            callback: (response: any) => {
                console.log(response, 'response transfer')
                if (response.success) {
                    getTeachermultipleBureauList(teacherMBId)
                    setTransferDepartmentVisible(false)
                    message.success('操作成功');
                } else {
                    message.error('操作失败,' + response.message);
                }
            },
        });
    }

    const deleteTeacherMultipleBureauInfo = (id:string) =>{
        const { dispatch } = dispatchProps;
        dispatch({
            type: 'teacher/DeleteTeacherMultipleBureauInfo',
            payload: {
                id: id
            },
            callback: (response: any) => {
                console.log(response, 'response transfer')
                if (response.success) {
                    getTeachermultipleBureauList(teacherMBId)
                    setTransferDepartmentVisible(false)
                    message.success('删除成功');
                } else {
                    message.error('删除失败,' + response.message);
                }
            },
        });
    }


    return (
        <Modal
            destroyOnClose
            title={"所在部门"}
            visible={modalVisible}
            // onOk={okHandle}
            onCancel={handleCancel}
            width="1000px"
            maskClosable={false}
            footer={null}
        >
            <div>
                <Button type="primary" onClick={() => { handleTransferDepartmentVisible("", true) }}>增加</Button>
            </div>
            <div>

                <Table

                    rowKey={(record: any) => record.person_id}
                    columns={columns}

                    dataSource={teacherMBIdList}
                    pagination={false}
                />
            </div>
            <TransferDepartment  {...TransferDepartmentProps} modalVisible={transferDepartmentVisible} dispatchProps={dispatchProps} />
        </Modal>
    );
};


export default Form.create<CreateFormProps>()(SelectLeader);
