import { Form, Popconfirm, Modal, Row, Col, message, Table, Select, Empty } from 'antd';
import { FormComponentProps } from 'antd/es/form';
import React, { useState, useEffect } from 'react';
import { String } from 'lodash';
import school from '..';

const FormItem = Form.Item;

interface CreateFormProps extends FormComponentProps {
    orgId: string;
    type: string;
    randomNumber: number;
    leaderId: [];
    modalVisible: boolean; // 显示modal
    cancelModal: () => void; // 返回上一层
    handleTransferDepartmentVisible: (flag?: boolean) => void; // 窗口
    transferDepartment: (classId: string) => void; // 返回上一层
    dispatchProps: any;
    checkLeader: (fieldsValue: { desc: any }) => void;
    transferPersonId: string;
}

const SelectLeader: React.FC<CreateFormProps> = props => {
    const { modalVisible, handleTransferDepartmentVisible, dispatchProps, transferDepartment, transferPersonId, rand } = props;

    const [searchSchoolList, setSearchSchoolList] = useState([])
    const [searchSchoolId, setSearchSchoolId] = useState("")
    const [orgTreeList, setOrgTreeList] = useState([])
    const [teacherMultipleBureauList, setTeacherMultipleBureauList] = useState([])
    const columns = [


        {
            title: '部门',
            dataIndex: 'org_name',
            ellipsis: true,
            width: "300px"
        },
        {
            title: '部门代码',
            dataIndex: 'org_code',
        },
        {
            title: '部门领导',
            dataIndex: 'manager_name',
        },
        {
            title: '序号',
            dataIndex: 'sort_id',
        },
        {
            title: '操作',
            dataIndex: 'conf',
            render: (text: any, record: { class_alias: string; class_id: string; },index) => (
                <Popconfirm
                    title={'是否设置到『' + record.org_name + '』？'}
                    okText="确认"
                    cancelText="取消"
                    onConfirm={() => handleTransferInfo(record.org_id)}
                >
                    {record.isIn?<a style={{pointerEvents:'none',cursor:'default',color:"#d9d9d9"}} key={index}>设置</a>:<a key={index}>设置</a>}
                </Popconfirm>
            )
        },
    ];




    useEffect(() => {
        //获取教师所在的所有单位
        PageTeacherMultipleBureauInfo()
        // 重置表单
        resetState()



    }, [rand])

 





    // 重置表单
    const resetState = () => {
        setSearchSchoolList([])
        setSearchSchoolId("")
        setOrgTreeList([])
    }


// 获取教师所在的所有部门
    const PageTeacherMultipleBureauInfo = () => {
        const { dispatch } = dispatchProps;
        dispatch({
            type: 'teacher/PageTeacherMultipleBureauInfo',
            payload: {
                personId: transferPersonId
            },
            callback: (response: any) => {
                const list:any = response.list
                let bureauId = []
                list?.map((item, index) => {
                    bureauId.push(item.org_id)
                })

                setTeacherMultipleBureauList(bureauId)
                // setSearchSchoolList(response)
            },
        });
    }




    // 点击取消
    const handleCancel = () => {
        handleTransferDepartmentVisible(false)
    }

    // =====================================================================================
    // 获取学校列表
    const handleSearchOrg = (value: any) => {

        if (value.length > 1) {
            value = value.replace(/ /g, "%")
            const { dispatch } = dispatchProps;
            dispatch({
                type: 'teacher/ListOrgByOrgKeyWord',
                payload: {
                    keyWord: value
                },
                callback: (response: any) => {
                    setSearchSchoolList(response)
                },
            });
        }
    };

    // 选择学校获取部门
    const handleSchool = (value: any) => {
        console.log(value, 'state searchSchoolId')
        setSearchSchoolId(value)
        setOrgTreeList([])
        const { dispatch } = dispatchProps;
        dispatch({
            type: 'teacher/GetOrgTreeInfo',
            payload: {
                orgId: value
            },
            callback: (response: any) => {
                const orgList = response.list

            //    处理已经在的部门增加标记
                teacherMultipleBureauList.map((item,index)=>{
                    getArray(orgList,item)
                })
                setOrgTreeList(orgList)
                // setStageId(stage_id)
                // //获取入学年份
                // GetRxnfInfo(value, stage_id, value)
            },
        });
    }


    // 递归增加标记
    const getArray = (data,id) =>{
        for (var i in data) {
            if (data[i].org_id == id) {
                data[i].isIn=true;
                break;
            } else {
                getArray(data[i].children, id);
            }
        }
        
    }




    const handleTransferInfo = (department_id: string) => {
        // alert()
        console.log(department_id, 'sssssssssssss')

        transferDepartment(department_id)
    }
    console.log(orgTreeList, 'stage id')

    const options = searchSchoolList?.map(d => <Select.Option key={d.org_id}>{d.org_name}</Select.Option>);
    // const stageOptions = stageList.map(d => <Select.Option key={d.stage_id}>{d.stage_name}</Select.Option>);
    // const rxnfOptions = rxnfList.map(d => <Select.Option key={d}>{d}</Select.Option>);
    return (
        <Modal
            destroyOnClose
            title={"选择调转单位/部门"}
            visible={modalVisible}
            // onOk={okHandle}
            onCancel={handleCancel}
            width="900px"
            footer={null}
            maskClosable={false}
        >
            <div>
                <Form layout="inline">
                    <Row gutter={[16, { md: 8, lg: 24, xl: 48 }]} >
                        <Col md={8} sm={12}>
                            <FormItem label="单位">
                                <Select
                                    style={{ width: 200 }}
                                    showSearch
                                    value={searchSchoolId}
                                    defaultActiveFirstOption={false}
                                    showArrow={false}
                                    filterOption={false}
                                    onSearch={handleSearchOrg}
                                    onChange={handleSchool}
                                    notFoundContent={null}
                                >
                                    {options}
                                </Select>

                            </FormItem>
                        </Col>

                    </Row>
                </Form>


                {orgTreeList && orgTreeList.length ?
                    <Table
                        scroll={{ y: 350 }}
                        style={{ height: 428 }}
                        rowKey={(record: any) => record.org_id}
                        columns={columns}
                        dataSource={orgTreeList}
                        defaultExpandAllRows={true}
                        // defaultExpandedRowKeys={orgTreeList[0].org_id}
                        pagination={false}
                    /> : <div style={{ height: 428, paddingTop: 110 }}><Empty image={Empty.PRESENTED_IMAGE_SIMPLE} description="请输入学校" /></div>}
            </div>
        </Modal>
    );
};


export default Form.create<CreateFormProps>()(SelectLeader);
