import { Form, Input, Modal, Select, DatePicker, Cascader, Tooltip, Row, Col ,InputNumber} from 'antd';

import { FormComponentProps } from 'antd/es/form';
import moment from 'moment';
import React,{useState,useEffect} from 'react';
import QueueAnim from 'rc-queue-anim';
import { checkIdNo } from '@/utils/utils';
const FormItem = Form.Item;
const { Option } = Select;
const { MonthPicker } = DatePicker

interface UpdateFormProps extends FormComponentProps {
  modalVisible: boolean;
  handleUpdate: (fieldsValue: { desc: string }) => void;
  handleUpdateModalVisible: () => void;
  handleXbDateShow: (value: boolean) => void;
  getSubjectHandle: (value: string) => void;
  xbm: Array<string>;
  sfzjlxm: Array<string>;
  mzm: Array<string>;
  zzmmm: Array<string>;
  zcm: Array<string>;
  bzlbm: Array<string>;
  xlm: Array<string>;
  xwm: Array<string>;
  stageId: Array<string>;
  subjectId: Array<string>;
  teacherInfo: { [key: string]: string };
  isShowDateXb: boolean;
  bureauId:string;
  dispatchProps: any;

}
const UpdateTeacherForm: React.FC<UpdateFormProps> = props => {
  const { modalVisible, form, handleUpdate, handleUpdateModalVisible, getSubjectHandle, xbm, sfzjlxm, mzm, zzmmm, zcm,
    bzlbm, xlm, xwm, stageId, subjectId, teacherInfo, handleXbDateShow, isShowDateXb,bureauId,dispatchProps
  } = props;

  const [bureauList, setBureauId] = useState([])    //职务分管列表
  const [isIdNumber, setIsIdNumber] = useState(0) 

  const okHandle = () => {
    form.validateFields((err, fieldsValue) => {
      if (err) return;
      // form.resetFields();
      // fieldsValue.positionIds = fieldsValue.positionIds?.toString()
      console.log(fieldsValue,'fieldsValue')
      handleUpdate(fieldsValue);
    });
  };

  const disabledDate = (current: any) => {
    return current && current > moment().endOf('day');
  }
  useEffect(() => {

    if (bureauId) {
      const { dispatch } = dispatchProps
      dispatch({
        type: 'teacher/ListPositionByBureauId',
        payload: {
          bureauId: bureauId,
        },
        callback: (response: any) => {
          // console.log(response,'props111')
          setBureauId(response.list)
        },
      });
    }
  }, [bureauId]);
  const bhValidate = (rule, value, callback) => {
    const { form } = props;
    // const b = value;
    const e = form.getFieldValue("teacher_zjh");


    if (e) {
      if (checkIdNo(e)) {

        parseInt(e.substr(16, 1)) % 2 == 1 ? form.setFieldsValue({ teacher_xb: "1" }) : form.setFieldsValue({ teacher_xb: "2" })
        const data = e.substring(6, 10) + "/" + e.substring(10, 12) + "/" + e.substring(12, 14); 
        // console.log(data)
        form.setFieldsValue({teacher_csrq:moment(data)})
        return true
      } else {
        return false
      }
    } else {
      return true
    }


  }
  return (
    <Modal
      destroyOnClose
      title={`编辑教职工信息 - ${teacherInfo.org_name}`}
      visible={modalVisible}
      maskClosable={false}
      onOk={okHandle}
      onCancel={() => handleUpdateModalVisible()}
      width="800px"
    >
      {/* 教职工姓名 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="教职工姓名">
        {form.getFieldDecorator('teacher_name', {
          initialValue: teacherInfo.xm,
          rules: [
            {
              required: true,
              message: '请输入2-20个汉字或字母或数字',
            },
            {
              min: 2,
              max: 20,
              message: '长度不在范围内',
            },
            {
              pattern: new RegExp('^[\u4E00-\u9FA5A-Za-z0-9]+$', 'g'),
              message: '教职工姓名必须为汉字、字母或者数字',
            },
          ],
        })(<Input placeholder="请输入教职工姓名" maxLength={20} />)}
      </FormItem>
      {/* 身份证件类型 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 10 }} label="身份证件类型">
        {form.getFieldDecorator('teacher_sfzjlx', {
          initialValue: teacherInfo.sfzjlxm,
          // rules: [{ required: true, message: '请选择身份证件类型' }],
        })(<Select
          style={{ width: '100%' }}
          showSearch={true}
          onChange={(value) => {
           
            setIsIdNumber(value)
            // form.setFields({teacher_zjh:""})
        }}
        >
          {sfzjlxm.map(item => (
            <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
          ))}
        </Select>)}
      </FormItem>



      {/* 证件号 */}
      {isIdNumber == 0 ? "" : isIdNumber == 1 ? <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="身份证件号">
        {form.getFieldDecorator('teacher_zjh', {
           initialValue: teacherInfo.sfzjh,
          rules: [
            {
              validator: bhValidate,
              message: '身份证格式错误'
            }
          ],
        })(<Input placeholder="请输入证件号" maxLength={30} />)}
      </FormItem> : <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="证件号">
          {form.getFieldDecorator('teacher_zjh', {
             initialValue: teacherInfo.sfzjh,
            rules: [
              {
                min: 2,
                max: 30,
                message: '长度不在范围内',
              },
              {
                pattern: new RegExp('^\\w+$', 'g'),
                message: '证件号必须为字母或者数字',
              },
            ],
          })(<Input placeholder="请输入证件号" maxLength={30} />)}
        </FormItem>
      }




      {/* 性别 */}
      {/* 出生日期 */}
      <QueueAnim delay={300} className="queue-simple">
        
          <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 5 }} label="性别" key="a">
            {form.getFieldDecorator('teacher_xb', {
              initialValue: teacherInfo.xbm ? teacherInfo.xbm : "",
              rules: [{ required: true, message: '请选择性别' }],
            })(<Select
              style={{ width: '100%' }}
              showSearch={true}
            >
              {xbm.map(item => (
                <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
              ))}
            </Select>)}
          </FormItem>,
          <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="出生日期" key="b">
            {form.getFieldDecorator('teacher_csrq', {
              initialValue: teacherInfo.csrq ? moment(teacherInfo.csrq) : "",
              rules: [{ required: true, message: '请选择出生日期' }],
            })(<DatePicker placeholder="请选择出生日期" disabledDate={disabledDate} />)}
          </FormItem>
      

      </QueueAnim>
      {/* 民族 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 8 }} label="民族">
        {form.getFieldDecorator('teacher_mz', {
          initialValue: teacherInfo.mzm,
          rules: [{ required: true, message: '请选择民族' }],
        })(<Select
          style={{ width: '100%' }}
          showSearch={true}
        >
          {mzm.map(item => (
            <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
          ))}
        </Select>)}
      </FormItem>
      {/* 政治面貌 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 8 }} label="政治面貌">
        {form.getFieldDecorator('teacher_zzmm', {
          initialValue: teacherInfo.zzmmm,
          rules: [{ required: true, message: '请选择政治面貌' }],
        })(<Select
          style={{ width: '100%' }}
          showSearch={true}
        >
          {zzmmm.map(item => (
            <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
          ))}
        </Select>)}
      </FormItem>
      {/* 职称 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 8 }} label="职称">
        {form.getFieldDecorator('teacher_zc', {
          initialValue: teacherInfo.zcm,
          rules: [{ required: true, message: '请选择职称' }],
        })(<Select
          style={{ width: '100%' }}
          showSearch={true}
        >
          {zcm.map(item => (
            <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
          ))}
        </Select>)}
      </FormItem>
      {/* 编制 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 8 }} label="编制">
        {form.getFieldDecorator('teacher_bz', {
          initialValue: teacherInfo.bzlbm,
          rules: [{ required: true, message: '请选择编制' }],
        })(<Select
          style={{ width: '100%' }}
          showSearch={true}
        >
          {bzlbm.map(item => (
            <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
          ))}
        </Select>)}
      </FormItem>
      {/* 学历 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 8 }} label="学历">
        {form.getFieldDecorator('teacher_xl', {
          initialValue: teacherInfo.xlm,
          rules: [{ required: true, message: '请选择学历' }],
        })(<Select
          style={{ width: '100%' }}
          showSearch={true}
        >
          {xlm.map(item => (
            <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
          ))}
        </Select>)}
      </FormItem>
      {/* 学位 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 8 }} label="学位">
        {form.getFieldDecorator('teacher_xw', {
          initialValue: teacherInfo.xwm,
          rules: [{ required: true, message: '请选择学位' }],
        })(<Select
          style={{ width: '100%' }}
          showSearch={true}
        >
          {xwm.map(item => (
            <Select.Option value={item.dict_code} key={item.dict_code} >{item.dict_value}</Select.Option>
          ))}
        </Select>)}
      </FormItem>


      {/* 任教学段 */}
      <FormItem label="任教学段" style={{ display: "inline-block", width: '41%', marginLeft: '15%' }} labelCol={{ span: 6 }} wrapperCol={{ span: 15 }}>
        {form.getFieldDecorator('teacher_xd', {
          initialValue: teacherInfo.stage_id,
          rules: [{ required: true, message: '请选择任教学段' }],
        })(<Select
          style={{ width: '100%' }}
          showSearch={true}
          
          onChange={(value)=>{form.setFieldsValue({'teacher_xk':""}); getSubjectHandle(value);}}
          >
             {stageId.map(item => (
                  <Select.Option value={item.stage_id} key={item.stage_id} >{item.stage_name}</Select.Option>
                ))}
      </Select>)}
      </FormItem>
      {/* 任教学科 */}
      <FormItem label="任教学科" style={{display:"inline-block",width:'41%'}} labelCol={{ span: 6 }} wrapperCol={{ span: 15 }}>
      {form.getFieldDecorator('teacher_xk', {   
          initialValue:teacherInfo.subject_id,  
          rules: [{ required: true, message: '请选择任教学科'}],
        })(<Select
          style={{ width: '100%' }}
          showSearch={true}
        >
          {subjectId.map(item => (
            <Select.Option value={item.subject_id} key={item.subject_id} >{item.subject_name}</Select.Option>
          ))}
        </Select>)}
      </FormItem>


      {/* 职务分管 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="职务分管">
        {form.getFieldDecorator('positionIds',{
          initialValue:teacherInfo.position_id_array
        })(
          // <input />
          <Select
            mode="multiple"
            style={{ width: '100%' }}
            showSearch={true}
          >
            {bureauList.map(item => (
              <Select.Option value={item.id} key={item.id} >{item.node_name}</Select.Option>
            ))}
          </Select>
        )}
      </FormItem>

      {/* 从教年月 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 15 }} label="从教年月">
        {form.getFieldDecorator('tacher_date', { initialValue: teacherInfo.cjny ? moment(teacherInfo.cjny.substr(0, 7)) : null })(
          <MonthPicker placeholder="请选择从教年月"
            format='YYYY-MM'
          />
        )}
      </FormItem>
      {/* 联系电话 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 10 }} label="联系电话">
        {form.getFieldDecorator('teacher_phone', {
          initialValue: teacherInfo.lxdh,
          rules: [
            {
              min: 2,
              max: 30,
              message: '长度范围在2-30个字符之间。',
            },
            {
              pattern: new RegExp('^[ 0-9+-]*$', 'g'),
              message: '请输入电话可用字符。',
            },
          ],
        })(<Input placeholder="请输入联系电话" maxLength={30} />)}
      </FormItem>
      {/* 排序号 */}
      <FormItem labelCol={{ span: 6 }} wrapperCol={{ span: 5 }} label="排序号">
        {form.getFieldDecorator('teacher_sort', {
          initialValue: teacherInfo.sort_id ? teacherInfo.sort_id.toString() : "",
          rules: [
            {
              pattern: new RegExp('^[0-9]*$', 'g'),
              message: '请输入1~4位数字',
            },
          ]
        })(<InputNumber style={{ width: "100%" }} placeholder="请输入排序号" maxLength={4} min={1} max={9999} />)}
      </FormItem>
    </Modal>
  );


};

export default Form.create<UpdateFormProps>()(UpdateTeacherForm);
