import {
  Cascader,
  Button,
  Card,
  Col,
  DatePicker,
  Divider,
  Dropdown,
  Form,
  Icon,
  Modal,
  Input,
  Dropdown,
  Menu,
  Row,
  Popconfirm,
  Select,
  message,
  Switch,
  TreeSelect
} from 'antd';
import React, { Component, Fragment } from 'react';

import { Dispatch, Action } from 'redux';
import { FormComponentProps } from 'antd/es/form';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { SorterResult } from 'antd/es/table';
import { connect } from 'dva';
import { StateType } from './model';
import CreateForm from './components/CreateForm';
import UpdateTeacherForm from './components/UpdateTeacherForms'
import ImportInfoModal from './components/ImportInfoModal'
import DeptTreePanel from './components/DeptTreePanel'
import TransferDepartment from './components/TransferDepartment'
import TeacherMultipleBureau from './components/TeacherMultipleBureau'

import StandardTable, { StandardTableColumnProps } from './components/StandardTable';


import { TableListItem, TableListPagination, TableListParams } from './data.d';

import styles from './style.less';

const FormItem = Form.Item;
const { Option } = Select;
const getValue = (obj: { [x: string]: string[] }) =>
  Object.keys(obj)
    .map(key => obj[key])
    .join(',');

interface TableListProps extends FormComponentProps {
  dispatch: Dispatch<
    Action<
      | 'teacher/PageTeacherInfo'
      | 'teacher/GetTeacherInfo'
      | 'teacher/AddTeacherInfo'
      | 'teacher/UpdateTeacherInfo'
      | 'teacher/DeleteTeacherInfo'
      | 'teacher/ReviseTeacherOrg'
      | 'teacher/EnableAccountInfo'
      | 'teacher/DisableAccountInfo'
      | 'teacher/ResetManagerPassWord'
      | 'teacher/GetOrgTreeInfo'
      | 'teacher/GetRoleInfo'
      | 'dict/fetch'
      | 'dict/GetStageInfo'
      | 'dict/GetSubjectInfo'
      | 'dict/GetMultipleDictInfo'
      | 'teacher/TeacherTransferInfo'
    >
  >;
  loading: boolean;
  teacher: StateType;
}

interface TableListState {
  modalVisible: boolean;
  updateModalVisible: boolean;
  deptModalVisible: boolean; //部门面板是否显示
  importModalVisible: boolean; //导入面板是否显示
  importTipsShow: boolean,//导入面板错误提示是否显示
  expandForm: boolean;
  selectedRows: TableListItem[];
  formValues: { [key: string]: string };
  stepFormValues: Partial<TableListItem>;
  areaCode: string;
  page: number;
  pageSize: number;
  teacherInfo: { [key: string]: string }; //回显教师数据
  schoolId: string;
  identityId: string;
  xm: string;
  selectTreeNode: any;
  selectTreeName: any;
  deptTreeAry: Array<any>,
  subjectId: Array<string>, //学科字典数据
  dictInfo: { [key: string]: string },//字典数据
  stageId: Array<string>,//学段字典数据
  xbm: Array<string>;
  sfzjlxm: Array<string>;
  mzm: Array<string>;
  zzmmm: Array<string>;
  zcm: Array<string>;
  bzlbm: Array<string>;
  xlm: Array<string>;
  xwm: Array<string>;
  teacherId: string; //已选教师ID
  isShowDateXb: boolean; //是否显示性别和出生日期
  tipsUrl: string; //导入错误修改地址
  tipsLoading: boolean; //上传文件加载样式
  errorCode: string;
  visible: boolean;
  transferDepartmentVisible: boolean;
  transferPersonId: string;   //设置超级管理员id控制权限
  teacherMBId: string;   //设置超级管理员id控制权限
  transferTeacerMBVisible: boolean;   //所在多单位列表弹窗
  rand: number;   
}

/* eslint react/no-multi-comp:0 */
@connect(
  ({
    teacher,
    loading,
  }: {
    teacher: StateType;
    loading: {
      models: {
        [key: string]: boolean;
      };
    };
  }) => ({
    teacher,
    loading: loading.models.teacher,
  }),
)
class TableList extends Component<TableListProps, TableListState> {
  state: TableListState = {
    modalVisible: false,
    updateModalVisible: false,
    deptModalVisible: false,
    importModalVisible: false, //导入面板是否显示
    importTipsShow: false,//导入面板错误提示是否显示
    expandForm: false,
    selectedRows: [],
    formValues: {},
    stepFormValues: {},
    areaCode: "220100",
    page: 1,
    pageSize: 10,
    teacherInfo: {},//修改教职工信息
    schoolId: this.props.match.params.id ? this.props.match.params.id : '',
    identityId: '',
    xm: "",
    selectTreeNode: "",
    selectTreeName: "",//当前部门名称
    deptTreeAry: [],
    dictInfo: {},//字典数据
    stageId: [],//学段字典数据
    subjectId: [], //学科字典数据
    xbm: [],
    sfzjlxm: [],
    mzm: [],
    zzmmm: [],
    zcm: [],
    bzlbm: [],
    xlm: [],
    xwm: [],
    teacherId: "",
    isShowDateXb: false, //是否显示性别和出生日期
    tipsUrl: "", //导入错误修改地址
    tipsLoading: false, //上传文件加载样式
    errorCode: '',//错误码
    visible: false,
    transferDepartmentVisible: false,
    transferPersonId: "",
    teacherMBId: "",
    transferTeacerMBVisible: false,
    rand: 0,
  };

  columns: StandardTableColumnProps[] = [
    {
      title: '序号',
      render: (text, record, index) =>
        `${(this.state.page - 1) * (this.state.pageSize) + (index + 1)}`,
    },
    {
      title: '教职工姓名',
      dataIndex: 'xm',
    },
    {
      title: '性别',
      dataIndex: 'xb_name',
    },
    {
      title: '所属部门',
      dataIndex: 'org_name',
    },
    {
      title: '登录名',
      dataIndex: 'login_name',
    },
    {
      title: '初始密码',
      dataIndex: 'original_pwd',
    },
    {
      title: '账号状态',
      dataIndex: 'login_status',
      render: (text, record) => (
        <Switch checkedChildren={text} unCheckedChildren={text} checked={text == "已启用" ? true : false}
          onChange={(checked) => { this.onChangeSwitch(checked, record.person_id) }}
        // onChange={() => { this.setState({ visible: true }) }}
        />
      )
    },
    {
      title: '排序号',
      dataIndex: 'sort_id',
    },
    {
      title: '操作',
      width: 350,
      render: (text, record) => (
        <Fragment>
          <a type="link" onClick={() => { this.handleUpdateModalVisible(true, record.person_id) }}>编辑</a>
          <Divider type="vertical" />
          <Popconfirm
            title={'是否确认删除『' + record.xm + '』的信息？'}
            okText="确认"
            cancelText="取消"
            onConfirm={() => this.handleDelete(record.person_id)}
          >
            <a style={{ color: "red" }}>删除</a>
          </Popconfirm>
          <Divider type="vertical" />
          <Popconfirm
            title={'是否要重置『' + record.xm + '』的密码？'}
            okText="确认"
            cancelText="取消"
            onConfirm={() => this.resetTeacherPassword(record.person_id)}
          >
            <a>重置密码</a>
          </Popconfirm>
          <Divider type="vertical" />

          <Dropdown overlay={
            <Menu>
              <Menu.Item onClick={() => { this.handleTeacherMBVisible(record.person_id, true) }}>
                设置多单位部门
              </Menu.Item>
              {record.org_count > 1 ? <Menu.Item disabled onClick={() => { this.handleTransferDepartmentVisible(record.person_id, true) }}>
                调转单位
               </Menu.Item> : <Menu.Item onClick={() => { this.handleTransferDepartmentVisible(record.person_id, true) }}>
                  调转单位
               </Menu.Item>}
              {/* {record.org_count>1?<Menu.Item disabled><a target="_blank" rel="noopener noreferrer" onClick={() => { this.handleTransferDepartmentVisible(record.person_id,true) }}>
                  调转单位 
               </a></Menu.Item>:<Menu.Item><a target="_blank" rel="noopener noreferrer" onClick={() => { this.handleTransferDepartmentVisible(record.person_id,true) }}>
                  调转单位 
               </a></Menu.Item>} */}



            </Menu>
          }>
            <a className="ant-dropdown-link" onClick={e => e.preventDefault()}>
              更多 <Icon type="down" />
            </a>
          </Dropdown>
        </Fragment>
      ),
    },
  ];

  componentDidMount() {

    this.getRoleInfo()

  }

  //获取当前登录角色信息
  getRoleInfo() {

    if (this.props.match.params.id) {

      this.getTeacherList(this.state.schoolId, this.state.xm);
      this.getDeptTreeInfo();
      this.getDictInfo();

    } else {
      const { dispatch } = this.props;
      dispatch({
        type: 'teacher/GetRoleInfo',
        payload: {},
        callback: (response: any) => {

          if (response.list[0].role_id == '73E897FC-C9D1-4E48-AE22-AC7586425C1D' || response.list[0].role_id == '9CD6B804-0F89-4626-A812-29465CFC7410') {

            this.setState({ schoolId: response.list[0].rule_id, identityId: response.list[0].role_id }, () => {
              this.getTeacherList(this.state.schoolId, this.state.xm);
              this.getDeptTreeInfo();
              this.getDictInfo();
            })

          } else {
            message.error('当前角色权限错误，请联系管理员重新配置菜单');
          }

        },
      });
    }
  }

  //获取字典数据
  getDictInfo() {
    const { dispatch } = this.props;

    //获取字典
    dispatch({
      type: 'dict/GetMultipleDictInfo',
      payload: {
        dictKinds: "xbm,sfzjlxm,mzm,zzmmm,zcm,bzlbm,xlm,xwm"
      },
      callback: (response: any) => {
        this.setState({
          xbm: response.list.xbm,
          sfzjlxm: response.list.sfzjlxm,
          mzm: response.list.mzm,
          zzmmm: response.list.zzmmm,
          zcm: response.list.zcm,
          bzlbm: response.list.bzlbm,
          xlm: response.list.xlm,
          xwm: response.list.xwm,
        })
      },
    });

    //获取学段类型字典
    dispatch({
      type: 'dict/GetStageInfo',
      payload: {},
      callback: (response: any) => {
        this.setState({ stageId: response.list })
      },
    });

  }

  //获取部门树数据
  getDeptTreeInfo() {
    const { dispatch, form } = this.props;
    dispatch({
      type: 'teacher/GetOrgTreeInfo',
      payload: {
        orgId: this.state.schoolId
      },
      callback: (response: any) => {
        if (response.success) {
          form.setFieldsValue({
            status: this.state.schoolId
          })
          this.setState({ selectTreeNode: response.list[0].org_id, selectTreeName: response.list[0].org_name, deptTreeAry: this.getTreeList(response.list) })
        } else {
          message.error('获取失败,' + response.message);
        }
      },
    });
  }

  //整理树结构
  getTreeList(list: Array<any>) {
    let newList = list;
    const addList = (list: Array<any>) => {
      list.map((item, index) => {
        item.value = item.org_id;
        item.title = item.org_name;
        item.key = item.org_id;
        if (item.children) {
          addList(item.children)
        }
      })
    }

    addList(newList)

    return newList
  }

  // 获取教职工列表
  getTeacherList(schoolId: string, xm?: string, pagination?: { [key: string]: string }) {
    const { dispatch } = this.props;
    if (!pagination) {
      pagination = {
        page: this.state.page,
        limit: this.state.pageSize,
      }
    }
    dispatch({
      type: 'teacher/PageTeacherInfo',
      payload: {
        orgId: schoolId,
        xm: xm,
        ...pagination,
      },
    });
  }

  //启用/禁用账号信息
  onChangeSwitch(checked: boolean, personId: string) {
    const { dispatch } = this.props;
    if (checked) {  //启用

      dispatch({
        type: 'teacher/EnableAccountInfo',
        payload: {
          personIds: personId
        },
        callback: (response: any) => {
          if (response.success) {
            message.success('操作成功');
            this.getTeacherList(this.state.schoolId, this.state.xm);
          } else {
            message.error('操作失败,' + response.message);
          }
        },
      });

    } else {  //禁用

      dispatch({
        type: 'teacher/DisableAccountInfo',
        payload: {
          personIds: personId
        },
        callback: (response: any) => {
          if (response.success) {
            message.success('操作成功');
            this.getTeacherList(this.state.schoolId, this.state.xm);
          } else {
            message.error('操作失败,' + response.message);
          }
        },
      });
    }
  }

  //重置密码
  resetTeacherPassword = (personId: string) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'teacher/ResetManagerPassWord',
      payload: {
        ids: personId
      },
      callback: (response: any) => {
        if (response.success) {
          message.success('操作成功');
          this.getTeacherList(this.state.selectTreeNode, this.state.xm);
        } else {
          message.error('操作失败,' + response.message);
        }
      },
    });
  }


  //删除教职工信息
  handleDelete = (personId: string) => {
    const { dispatch } = this.props;
    dispatch({
      type: 'teacher/DeleteTeacherInfo',
      payload: {
        personIds: personId
      },
      callback: (response: any) => {
        if (response.success) {
          let pagination = {
            page: 1,
            limit: this.state.pageSize,
          }
          message.success('操作成功');
          this.getTeacherList(this.state.schoolId, this.state.xm, pagination);
          this.setState({
            page: 1,
            pageSize: pagination.limit,
            selectedRows: []
          })
        } else {
          message.error('操作失败,' + response.message);
        }
      },
    });
  }

  //分页操作
  handleStandardTableChange = (
    pagination: Partial<TableListPagination>,
    filtersArg: Record<keyof TableListItem, string[]>,
    sorter: SorterResult<TableListItem>,
  ) => {

    const page = pagination.current;
    const pageSize = pagination.pageSize;

    pagination = {
      page: page,
      limit: pageSize
    }

    this.getTeacherList(this.state.schoolId, this.state.xm, pagination)

    this.setState({
      page: page,
      pageSize: pageSize
    })
  };

  //批量删除教职工信息
  batchDeleteTeacherInfo = () => {

    if (this.state.selectedRows.length > 0) {
      let personIdAry = [];
      this.state.selectedRows.map((item) => {
        personIdAry.push(item.person_id)
      })
      let personIds = personIdAry.join(",")
      this.handleDelete(personIds)
    }

  }

  //根据学段获取对应学科
  getSubjectHandle = (value: string) => {
    const { dispatch } = this.props;
    //获取字典
    dispatch({
      type: 'dict/GetSubjectInfo',
      payload: {
        stageId: value
      },
      callback: (response: any) => {
        this.setState({ subjectId: response.list })
      },
    });
  }

  handleFormReset = () => {
    const { form, dispatch } = this.props;
    form.resetFields();
    this.setState({
      formValues: {},
    });
    // dispatch({
    //   type: 'school/fetch',
    //   payload: {},
    // });
  };

  toggleForm = () => {
    const { expandForm } = this.state;
    this.setState({
      expandForm: !expandForm,
    });
  };

  handleMenuClick = (e: { key: string }) => {
    const { dispatch } = this.props;
    const { selectedRows } = this.state;

    if (!selectedRows) return;
    // switch (e.key) {
    //   case 'remove':
    //     dispatch({
    //       type: 'school/remove',
    //       payload: {
    //         key: selectedRows.map(row => row.key),
    //       },
    //       callback: () => {
    //         this.setState({
    //           selectedRows: [],
    //         });
    //       },
    //     });
    //     break;
    //   default:
    //     break;
    // }
  };

  handleSelectRows = (selectedRows: TableListItem[]) => {
    this.setState({
      selectedRows: selectedRows,
    });
  };

  handleSearch = (e: React.FormEvent) => {
    e.preventDefault();

    const { form } = this.props;

    form.validateFields((err, fieldsValue) => {
      if (err) return;

      let pagination = {
        page: 1,
        limit: this.state.pageSize,
      }


      this.getTeacherList(this.state.selectTreeNode, fieldsValue.teacherName, pagination)

      this.setState({
        page: 1,
        pageSize: pagination.limit,
        selectedRows: [],
        xm: fieldsValue.teacherName
      })
    });
  };

  handleModalVisible = (flag?: boolean) => {
    this.setState({
      modalVisible: flag ? true : false,
      isShowDateXb: false
    });
  };

  //修改教职工面板弹出
  handleUpdateModalVisible = (flag?: boolean, personId?: string) => {
    const { dispatch } = this.props;
    if (personId) {
      dispatch({
        type: 'teacher/GetTeacherInfo',
        payload: {
          personId: personId,
          bureauId: this.props.match.params.id
        },
        callback: (response: any) => {
          if (response.success) {
            this.setState({
              updateModalVisible: flag ? true : false,
              teacherId: personId ? personId : "",
              teacherInfo: response.list[0],
              isShowDateXb: response.list[0].sfzjlxm == 1 ? false : true
            }, () => { this.getSubjectHandle(response.list[0].stage_id) });
          } else {
            message.error('操作失败,' + response.message);
          }
        },
      });
    } else {
      this.setState({
        updateModalVisible: flag ? true : false,
        isShowDateXb: false,
      });
    }


  };

  //增加教职工保存
  handleAdd = (fields: { [key: string]: string }) => {
    const { dispatch } = this.props;

    let params = {
      orgId: this.state.selectTreeNode,
      xm: fields.teacher_name,
      sfzjlxm: fields.teacher_sfzjlx,
      sfzjh: fields.teacher_zjh,
      mzm: fields.teacher_mz,
      zzmmm: fields.teacher_zzmm,
      zcm: fields.teacher_zc,
      bzlbm: fields.teacher_bz,
      xlm: fields.teacher_xl,
      xwm: fields.teacher_xw,
      stageId: fields.teacher_xd,
      subjectId: fields.teacher_xk,
      positionIds: fields.positionIds,    //职务分管
      cjny: fields.tacher_date === null || fields.tacher_date === undefined ? "" : fields.tacher_date.format('YYYY-MM'),
      lxdh: fields.teacher_phone ? fields.teacher_phone : "",
      dzxx: '',
      sortId: fields.teacher_sort ? fields.teacher_sort : "",
      csrq: fields.teacher_csrq ? fields.teacher_csrq.format('YYYY-MM-DD') : "",//出生日期
      xbm: fields.teacher_xb ? fields.teacher_xb : "",
    }


    dispatch({
      type: 'teacher/AddTeacherInfo',
      payload: params,
      callback: (response: any) => {
        if (response.success) {
          let pagination = {
            page: 1,
            limit: this.state.pageSize,
          }
          message.success('操作成功');
          this.getTeacherList(this.state.selectTreeNode, this.state.xm, pagination);
          this.setState({
            page: 1,
            pageSize: pagination.limit,
            selectedRows: [],
            modalVisible: false,
          })
        } else {
          message.error('操作失败,' + response.message);
        }
      },
    });


  };

  //修改教职工信息保存
  handleUpdate = (fields: { [key: string]: string }) => {
    const { dispatch } = this.props;

    let params = {
      personId: this.state.teacherId,
      xm: fields.teacher_name,
      sfzjlxm: fields.teacher_sfzjlx,
      sfzjh: fields.teacher_zjh,
      mzm: fields.teacher_mz,
      zzmmm: fields.teacher_zzmm,
      zcm: fields.teacher_zc,
      bzlbm: fields.teacher_bz,
      xlm: fields.teacher_xl,
      xwm: fields.teacher_xw,
      stageId: fields.teacher_xd,
      subjectId: fields.teacher_xk,
      positionIds: fields.positionIds?.toString(),
      cjny: fields.tacher_date === null || fields.tacher_date === undefined || fields.tacher_date === "" ? "" : fields.tacher_date.format('YYYY-MM'),
      lxdh: fields.teacher_phone ? fields.teacher_phone : "",
      dzxx: '',
      sortId: fields.teacher_sort ? fields.teacher_sort : "",
      csrq: fields.teacher_csrq ? fields.teacher_csrq.format('YYYY-MM-DD') : "",//出生日期
      xbm: fields.teacher_xb ? fields.teacher_xb : "",
    }

    dispatch({
      type: 'teacher/UpdateTeacherInfo',
      payload: params,
      callback: (response: any) => {
        if (response.success) {
          let pagination = {
            page: 1,
            limit: this.state.pageSize,
          }
          message.success('操作成功');
          this.getTeacherList(this.state.selectTreeNode, this.state.xm, pagination);
          this.setState({
            page: 1,
            pageSize: pagination.limit,
            selectedRows: [],
            updateModalVisible: false,
          })
        } else {
          message.error('操作失败,' + response.message);
        }
      },
    });

  };

  //选择部门(搜索)
  onChangeDeptSelect = (value: string, label: any) => {
    const { form } = this.props;
    form.resetFields();
    this.setState({
      formValues: {},
      selectTreeNode: value,
      selectTreeName: label[0]
    });
    this.getTeacherList(value)
  }

  //搜索区域组件
  renderSimpleForm() {
    const { form } = this.props;
    const { getFieldDecorator } = form;

    if (this.state.schoolId === '') {
      return null
    } else {
      return (
        <Form onSubmit={this.handleSearch} layout="inline">
          <Row gutter={{ md: 8, lg: 24, xl: 48 }}>
            <Col xxl={6} xl={8} lg={10} md={12} sm={12}>
              <FormItem label="所属部门">
                {getFieldDecorator('status')(
                  <TreeSelect
                    style={{ maxWidth: '12rem' }}
                    value={this.state.selectTreeNode}
                    treeDefaultExpandAll={true}
                    dropdownStyle={{ maxHeight: 400, overflow: 'auto' }}
                    placeholder="点击选择部门"
                    onChange={this.onChangeDeptSelect}
                    treeData={this.state.deptTreeAry}
                  // defaultValue={this.state.selectTreeNode === '' ? this.state.schoolId : this.state.selectTreeNode}
                  />
                )}
              </FormItem>
            </Col>
            <Col md={6} sm={12}>
              <FormItem label="教职工姓名">
                {getFieldDecorator('teacherName')(
                  <Input placeholder="请输入教职工姓名" allowClear={true} maxLength={20} />,
                )}
              </FormItem>
            </Col>
            <Col md={4} sm={12}>
              <span className={styles.submitButtons}>
                <Button type="primary" htmlType="submit">
                  查询
              </Button>
                {/* <Button style={{ marginLeft: 8 }} onClick={this.handleFormReset}>
                重置
              </Button> */}
              </span>
            </Col>
          </Row>
        </Form>
      );
    }

  }

  //改变教师部门回调
  handleDeptAdd = (selectTreeInfo: string[]) => {
    if (selectTreeInfo.length > 0) {
      const { dispatch } = this.props;
      let personIdAry = [];
      this.state.selectedRows.map((item) => {
        personIdAry.push(item.person_id)
      })
      let personIds = personIdAry.join(",")
      dispatch({
        type: 'teacher/ReviseTeacherOrg',
        payload: {
          personIds: personIds,
          orgId: selectTreeInfo[0]
        },
        callback: (response: any) => {
          if (response.success) {
            this.setState({
              deptModalVisible: false,
              selectedRows: []
            }, () => {
              message.success('操作成功');
              this.getTeacherList(this.state.selectTreeNode, this.state.xm);
            });
          } else {
            message.error('操作失败,' + response.message);
          }
        },
      });
    } else {
      message.warning('请选择部门');
    }
  }

  //展开/收起部门面板
  handleDeptModalVisible = (flag?: boolean) => {
    console.log(this.state.deptTreeAry, "1111111111111111")
    if (this.state.deptTreeAry[0].children) {
      this.setState({
        deptModalVisible: flag ? true : false,
      });
    } else {
      message.error('暂无其他部门信息，无法调整');
    }

  }

  //导入教职工信息面板显示隐藏
  importTeacherInfo = (flag?: boolean) => {
    this.setState({
      importModalVisible: flag ? true : false,
      importTipsShow: false,
      tipsLoading: false,
    });
  }

  //导出教职工信息
  exportTeacherInfo = () => {
    let downUrl = window.location.origin + '/base/teacher/ExportTeacherExcel?orgId=' + this.state.schoolId;
    window.open(downUrl, '_self')
  }

  //导出教职工账号信息
  exportTeacherUserInfo = () => {
    let downUrl = window.location.origin + '/base/teacher/ExportTeacherAccountExcel?orgId=' + this.state.schoolId;
    window.open(downUrl, '_self')
  }

  //显示隐藏新增修改弹出面板中性别和出生日期
  handleXbDateShow = (value: boolean) => {
    this.setState({ isShowDateXb: value })
  }

  //显示导入面板错误提示
  handleImportTipsShow = (message: string, code: string) => {
    this.setState({ importTipsShow: true, tipsUrl: message, tipsLoading: false, errorCode: code })
  }

  //导入成功回调
  handleSuccessImport = (messages: any) => {
    this.setState({
      importModalVisible: false,
      importTipsShow: false,
      tipsLoading: false
    }, () => {
      message.success(`导入成功! ${messages}`, 5);
      let pagination = {
        page: 1,
        limit: this.state.pageSize,
      }
      this.state.page = 1;
      this.state.pageSize = pagination.limit;
      this.getTeacherList(this.state.schoolId, this.state.xm, pagination);
    });
  }

  //导入中显示等待样式
  handleTipsLoading = () => {
    this.setState({ tipsLoading: true, importTipsShow: false })
  }

  handleTransferDepartmentVisible = (transferPersonId: string, flag?: boolean) => {

    this.setState({
      transferDepartmentVisible: flag ? true : false,
      transferPersonId: transferPersonId,
      rand:Math.random()
    })

  }

  transferDepartment = (orgId: string) => {

    console.log(this.state.transferPersonId, 'studentTransferId ')
    console.log(orgId, 'studentTransferInfo orgid')
    const { dispatch } = this.props;
    dispatch({
      type: 'teacher/TeacherTransferInfo',
      payload: {
        orgId: orgId,
        personId: this.state.transferPersonId
      },
      callback: (response: any) => {
        console.log(response, 'response transfer')
        if (response.success) {
          let pagination = {
            page: this.state.page,
            limit: this.state.pageSize,
          }
          this.getTeacherList(this.state.selectTreeNode, "", pagination)
          message.success('操作成功');
          this.handleTransferDepartmentVisible("", false)
          //       this.getStudentList(this.state.selectClassId, this.state.xm, pagination)
        } else {
          message.error('操作失败,' + response.message);
        }
      },
    });

  }

  // 多单位窗口可见
  handleTeacherMBVisible = (personId: string, flag?: boolean) => {

    this.setState({
      transferTeacerMBVisible: flag ? true : false,
      teacherMBId: personId
    })

  }



  render() {
    const {
      teacher: { data },
      loading,
    } = this.props;

    const { selectedRows, modalVisible, deptModalVisible, updateModalVisible, importModalVisible } = this.state;

    data.pagination = {
      current: this.state.page,
      total: data.count,
      pageSize: this.state.pageSize,
      showTotal: ((total: any) => {
        return `共 ${total} 条`;
      }),
    }


    console.log(this.state, "state")
    console.log(this.props, "this.props")
    const parentMethods = {
      handleAdd: this.handleAdd,
      handleModalVisible: this.handleModalVisible,
      getSubjectHandle: this.getSubjectHandle,
      handleXbDateShow: this.handleXbDateShow,
      xbm: this.state.xbm, //性别字典数据
      sfzjlxm: this.state.sfzjlxm, //身份证件类型字典数据
      mzm: this.state.mzm, //民族字典数据
      zzmmm: this.state.zzmmm, //政治面貌字典数据
      zcm: this.state.zcm, //职称字典数据
      bzlbm: this.state.bzlbm, //编制字典数据
      xlm: this.state.xlm, //学历字典数据
      xwm: this.state.xwm, //学位字典数据
      stageId: this.state.stageId, //学段字典数据  
      subjectId: this.state.subjectId, //学科字典数据  
      isShowDateXb: this.state.isShowDateXb, //是否显示性别和出生日期
      selectOrgName: this.state.selectTreeName, //当前已选部门名称
      bureauId: this.props.match.params.id  //单位id
    };

    const updateMethods = {
      handleUpdate: this.handleUpdate,
      handleUpdateModalVisible: this.handleUpdateModalVisible,
      getSubjectHandle: this.getSubjectHandle,
      handleXbDateShow: this.handleXbDateShow,
      xbm: this.state.xbm, //性别字典数据
      sfzjlxm: this.state.sfzjlxm, //身份证件类型字典数据
      mzm: this.state.mzm, //民族字典数据
      zzmmm: this.state.zzmmm, //政治面貌字典数据
      zcm: this.state.zcm, //职称字典数据
      bzlbm: this.state.bzlbm, //编制字典数据
      xlm: this.state.xlm, //学历字典数据
      xwm: this.state.xwm, //学位字典数据
      stageId: this.state.stageId, //学段字典数据  
      subjectId: this.state.subjectId, //学科字典数据 
      teacherInfo: this.state.teacherInfo, //回显教师数据
      isShowDateXb: this.state.isShowDateXb, //是否显示性别和出生日期
      bureauId: this.props.match.params.id  //单位id
    }

    const deptTreeMethods = {
      handleDeptAdd: this.handleDeptAdd,
      handleDeptModalVisible: this.handleDeptModalVisible,
      deptTreeAry: this.state.deptTreeAry,
    }

    const importInfoMethods = {
      handleImportTeacherInfo: this.importTeacherInfo,
      handleImportTipsShow: this.handleImportTipsShow,
      handleSuccessImport: this.handleSuccessImport,
      handleTipsLoading: this.handleTipsLoading,
      orgId: this.state.schoolId,
      importTipsShow: this.state.importTipsShow,
      tipsUrl: this.state.tipsUrl,
      tipsLoading: this.state.tipsLoading,
      errorCode: this.state.errorCode,
    }

    const TransferDepartmentProps = {
      handleTransferDepartmentVisible: this.handleTransferDepartmentVisible,
      transferDepartment: this.transferDepartment,
      transferPersonId: this.state.transferPersonId,
      rand:this.state.rand
    }
    const teacherMultipleBureauProps = {
      teacherMBId: this.state.teacherMBId,
      handleTeacherMBVisible: this.handleTeacherMBVisible
    }




    return (
      <PageHeaderWrapper>
        <Card bordered={false}>
          <div className={styles.tableList}>
            <div className={styles.tableListForm}>{this.renderSimpleForm()}</div>
            <div className={styles.tableListOperator}>
              <Button icon="plus" type="primary" onClick={() => this.handleModalVisible(true)}>
                增加教职工
              </Button>
              {selectedRows.length > 0 && (
                <span>
                  <Popconfirm
                    title={'是否确认删除所选中的教职工信息？'}
                    okText="确认"
                    cancelText="取消"
                    onConfirm={() => this.batchDeleteTeacherInfo()}
                  >
                    <Button type="danger">批量删除</Button>
                  </Popconfirm>

                  <Button onClick={() => { this.handleDeptModalVisible(true) }}>调整部门</Button>
                </span>
              )}

              <Button type="primary" onClick={() => this.importTeacherInfo(true)}
                style={{ marginLeft: "2%" }}
              >
                导入教职工信息
              </Button>
              <Button type="primary" onClick={() => this.exportTeacherInfo()}

              >
                导出教职工信息
              </Button>
              <Button type="primary" onClick={() => this.exportTeacherUserInfo()}

              >
                导出教职工账号信息
              </Button>


              {this.state.identityId === "9CD6B804-0F89-4626-A812-29465CFC7410" || this.state.identityId === "73E897FC-C9D1-4E48-AE22-AC7586425C1D" ? "" : <Button style={{ float: "right" }} type="primary" onClick={() => { window.history.back() }}>
                返回
              </Button>}



            </div>
            {/* <div className={styles.tableListOperator}>
              {selectedRows.length > 0 && (
                <span>
                  <Button>批量操作</Button>
                  <Dropdown overlay={menu}>
                    <Button>
                      更多操作 <Icon type="down" />
                    </Button>
                  </Dropdown>
                </span>
              )}
            </div> */}
            <StandardTable
              rowKey={record => record.person_id}
              selectedRows={selectedRows}
              loading={loading}
              data={data}
              columns={this.columns}
              onSelectRow={this.handleSelectRows}
              onChange={this.handleStandardTableChange}
            />
          </div>
          {/* <Modal
            title="Basic Modal"
            visible={this.state.visible}
            onOk={this.onChangeSwitch}
          // onCancel={this.handleCancel}
          >
            <p>是否要禁用当前账号？</p>
            <p>是否要启用当前账号？</p>
          </Modal> */}
        </Card>
        <CreateForm {...parentMethods} modalVisible={modalVisible} dispatchProps={this.props} />
        <UpdateTeacherForm  {...updateMethods} modalVisible={updateModalVisible} dispatchProps={this.props} />
        <DeptTreePanel {...deptTreeMethods} modalVisible={deptModalVisible} />
        <ImportInfoModal  {...importInfoMethods} modalVisible={importModalVisible} />
        <TransferDepartment  {...TransferDepartmentProps} modalVisible={this.state.transferDepartmentVisible} dispatchProps={this.props} />
        <TeacherMultipleBureau  {...teacherMultipleBureauProps} modalVisible={this.state.transferTeacerMBVisible} dispatchProps={this.props} />
      </PageHeaderWrapper>
    );
  }
}

export default Form.create<TableListProps>()(TableList);
