import { AnyAction, Reducer } from 'redux';
import { EffectsCommandMap } from 'dva';
import { PageTeacherInfo, GetTeacherInfo, AddTeacherInfo, UpdateTeacherInfo, DeleteTeacherInfo, ReviseTeacherOrg, EnableAccountInfo, 
  DisableAccountInfo, ResetManagerPassWord, GetOrgTreeInfo, GetRoleInfo,ListPositionByBureauId,
  ListOrgByOrgKeyWord,TeacherTransferInfo,PageTeacherMultipleBureauInfo,SettingTeacherMultipleBureauInfo,
  SettingMainOrgInfo,DeleteTeacherMultipleBureauInfo } from './service';

// eslint-disable-next-line import/no-unresolved
import { TableListData } from './data.d';

export interface StateType {
  data: TableListData;
}

export type Effect = (
  action: AnyAction,
  effects: EffectsCommandMap & { select: <T>(func: (state: StateType) => T) => T },
) => void;

export interface ModelType {
  namespace: string;
  state: StateType;
  effects: {
    PageTeacherInfo: Effect;
    GetTeacherInfo: Effect;
    AddTeacherInfo: Effect;
    UpdateTeacherInfo: Effect;
    DeleteTeacherInfo: Effect;
    ReviseTeacherOrg: Effect;
    EnableAccountInfo: Effect;
    DisableAccountInfo: Effect;
    ResetManagerPassWord: Effect;
    GetOrgTreeInfo: Effect;
    GetRoleInfo: Effect;
    ListPositionByBureauId: Effect;
    ListOrgByOrgKeyWord: Effect;
    TeacherTransferInfo: Effect;
    PageTeacherMultipleBureauInfo: Effect;
    SettingTeacherMultipleBureauInfo: Effect;
    SettingMainOrgInfo: Effect;
    DeleteTeacherMultipleBureauInfo: Effect;
  };
  reducers: {
    save: Reducer<StateType>;
  };
}

const Model: ModelType = {
  namespace: 'teacher',

  state: {
    data: {
      list: [],
      pagination: {},
    },
  },

  effects: {
    //获取教职工列表
    *PageTeacherInfo({ payload }, { call, put }) {
      let response = yield call(PageTeacherInfo, payload);

      // 处理最后一页删除数据后当前页面没有数据从新计算页数从新拿数据。
      let listLength = response.list.length
      while(listLength<1){
        payload.page=payload.page==1?1:payload.page-1;
        response = yield call(PageTeacherInfo, payload);
        listLength = response.list.length
        if(response.count==0)break;
      }

      yield put({
        type: 'save',
        payload: response,
      });
    },

    //获取教职工信息
    *GetTeacherInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetTeacherInfo, payload);
      if (callback) callback(response);
    },

     //根据单位ID获取部门树
     *GetOrgTreeInfo({ payload, callback }, { call, put }) {
      const response = yield call(GetOrgTreeInfo, payload);
      if (callback) callback(response);
    },

     //新增教职工信息
    *AddTeacherInfo({ payload, callback }, { call, put }) {
      const response = yield call(AddTeacherInfo, payload);
      if (callback) callback(response);
    },
    
     //修改教职工信息
    *UpdateTeacherInfo({ payload, callback }, { call, put }) {
      const response = yield call(UpdateTeacherInfo, payload);
      if (callback) callback(response);
    },

    //删除教职工信息
    *DeleteTeacherInfo({ payload, callback }, { call, put }) {
      const response = yield call(DeleteTeacherInfo, payload);
      if (callback) callback(response);
    },

    //调整教职工部门
    *ReviseTeacherOrg({ payload, callback }, { call, put }) {
      const response = yield call(ReviseTeacherOrg, payload);
      if (callback) callback(response);
    },

     //启用账号信息
     *EnableAccountInfo({ payload, callback }, { call, put }) {
      const response = yield call(EnableAccountInfo, payload);
      if (callback) callback(response);
    },

    //禁用账号信息
    *DisableAccountInfo({ payload, callback }, { call, put }) {
      const response = yield call(DisableAccountInfo, payload);
      if (callback) callback(response);
    },

    //重置账号密码
    *ResetManagerPassWord({ payload, callback }, { call, put }) {
      const response = yield call(ResetManagerPassWord, payload);
      if (callback) callback(response);
    },    

    //获取角色信息
    *GetRoleInfo({ payload, callback }, { call, put }) {
    const response = yield call(GetRoleInfo, payload);

    if (callback) callback(response);
   },
    //获取角色信息
    *ListPositionByBureauId({ payload, callback }, { call, put }) {
    const response = yield call(ListPositionByBureauId, payload);

    if (callback) callback(response);
   },
         // 根据名称获取学校 调学校
    *ListOrgByOrgKeyWord({ payload, callback }, { call, put }) {
      const response = yield call(ListOrgByOrgKeyWord, payload);
      if (callback) callback(response.list);
    },
    *TeacherTransferInfo({ payload, callback }, { call, put }) {
      const response = yield call(TeacherTransferInfo, payload);
      if (callback) callback(response);
    },
    *PageTeacherMultipleBureauInfo({ payload, callback }, { call, put }) {
      const response = yield call(PageTeacherMultipleBureauInfo, payload);
      if (callback) callback(response);
    },
    *SettingTeacherMultipleBureauInfo({ payload, callback }, { call, put }) {
      const response = yield call(SettingTeacherMultipleBureauInfo, payload);
      if (callback) callback(response);
    },
    *SettingMainOrgInfo({ payload, callback }, { call, put }) {
      const response = yield call(SettingMainOrgInfo, payload);
      if (callback) callback(response);
    },
    *DeleteTeacherMultipleBureauInfo({ payload, callback }, { call, put }) {
      const response = yield call(DeleteTeacherMultipleBureauInfo, payload);
      if (callback) callback(response);
    },
  },
         // 根据名称获取学校 调学校

  reducers: {
    save(state, action) {
      return {
        ...state,
        data: action.payload,
      };
    },
  },
};

export default Model;
