import request from '@/utils/request';


interface TableListParams {
  area_code: TableListParams;
  sorter: string;
  status: string;
  name: string;
  pageSize: number;
  currentPage: number;
}

/** *******************************************
 * 当行政区划API不提供唯一URI，采用多URI时
 * ********************************************
 */

/**
 * 拆分接口取数据
 * [省][市][区]
 * [00][00][00]
 */
export async function queryGeographic(params: TableListParams) {
  const id = params && params.area_code ? params.area_code : '100000'; // id='100000' 显示省级行政区
  const data = { areaCode: id, limit: 1000, page: params.currentPage || 1 };
  /**
   * 数据格式化处理
   */
  return request('/base/area/PageGovArea', {
    method: 'GET',
    params: data,
  });
}

export async function removeGeographic(params: TableListParams) {
  return request('/base/area/PageGovArea', {
    method: 'POST',
    data: {
      ...params,
      method: 'delete',
    },
  });
}

export async function addGeographic(params: TableListParams) {
  return request('/base/area/PageGovArea', {
    method: 'POST',
    data: {
      ...params,
      method: 'post',
    },
  });
}

export async function updateGeographic(params: TableListParams) {
  return request('/base/area/PageGovArea', {
    method: 'POST',
    data: {
      ...params,
      method: 'update',
    },
  });
}



/** *******************************************
 * 当行政区划API不提供唯一URI，采用多URI时
 * ********************************************
 */

/**
 * 拆分接口取数据
 * [省][市][区]
 * [00][00][00]
 */
export async function queryGeographic1(params: any) {
  let uri: string;
  // console.log('params:',params);
  
  const id = params ? params.id : null; // id=null 显示省级行政区

  let data:string=""
if(id=="100000"){
  data = "province"
}else{
  data = id.charAt(3) === '0' ? 'city' : 'area'
}

// console.log('params data',data)
  // params.level

  switch (data) { 
    case 'area':
      uri = `/api/geographic/area/${id}`;
      break;
    case 'city':
      uri = `/api/geographic/city/${id}`;
      break;
    case 'province':
      uri = '/api/geographic/province';
      break;
    default:
      uri = '/api/geographic/province';
      break;
  }
  // uri = '/api/geographic/province';
  return request(uri);
}
